<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['encryption'] = 'დაშიფვრა';
$labels['keyname'] = 'სახელი';
$labels['fingerprint'] = 'ანაბეჭდი';
$labels['subkeys'] = 'ქვეგასაღებები';
$labels['typesign'] = 'ხელმოწერა';
$labels['typeencrypt'] = 'დაშიფვრა';
$labels['typecert'] = 'დამოწმება';
$labels['typeauth'] = 'ავთენტიკაცია';
$labels['subkeyid'] = 'ID';
$labels['subkeyalgo'] = 'ალგორითმი';
$labels['subkeycreated'] = 'შექმნის დრო';
$labels['subkeyexpires'] = 'ვადა';
$labels['subkeyusage'] = 'გამოყენება';
$labels['expiresnever'] = 'არასდროს';
$labels['unknown'] = 'უცნობი';
$labels['uservalid'] = 'სწორია';
$labels['userid'] = 'ID';
$labels['valid'] = 'სწორია';
$labels['keyremove'] = 'წაშლა';
$labels['keydisable'] = 'გამორთვა';
$labels['keyrevoke'] = 'გაუქმება';
$labels['keychpass'] = 'პაროლის სეცვლა';
$labels['newkeyident'] = 'იდენტიფიკატორი';
$labels['newkeypass'] = 'პაროლი';
