<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Markdown düzenleyici';
$labels['editor_button_title'] = 'İletiyi markdown olarak oluşturun ve HTML olarak gönderilmesini sağlayın';
$labels['toolbar_button_quit'] = 'Düz yazı düzenleyiciye dön';
$labels['toolbar_button_help'] = 'Yeni bir pencerede bir markdown sözdizimi rehberini aç';
$labels['toolbar_button_preview'] = 'Gönderilecek HTML içeriğini ön izle';
$labels['toolbar_button_bold'] = 'Koyu';
$labels['toolbar_button_italic'] = 'Yatık';
$labels['toolbar_button_strike'] = 'Üzeri çizili';
$labels['toolbar_button_h1'] = '1. başlık düzeyi';
$labels['toolbar_button_h2'] = '2. başlık düzeyi';
$labels['toolbar_button_h3'] = '3. başlık düzeyi';
$labels['toolbar_button_h4'] = '4. başlık düzeyi';
$labels['toolbar_button_h5'] = '5. başlık düzeyi';
$labels['toolbar_button_h6'] = '6. başlık düzeyi';
$labels['toolbar_button_blockquote'] = 'Alıntı';
$labels['toolbar_button_unordered_list'] = 'Numarasız liste';
$labels['toolbar_button_ordered_list'] = 'Numaralı liste';
$labels['toolbar_button_link'] = 'Bağlantı';
$labels['toolbar_button_image'] = 'Görsel';
$labels['toolbar_button_undo'] = 'Geri al';
$labels['toolbar_button_redo'] = 'Yinele';
