<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Archief';
$labels['buttontitle'] = 'Archiveer dit bericht';
$labels['archived'] = 'Succesvol gearchiveerd';
$labels['archivedreload'] = 'Succesvol gearchiveerd. Herlaad de pagina om de nieuwe archiefmappen te zien.';
$labels['archiveerror'] = 'Sommige berichten konden niet gearchiveerd worden';
$labels['archivefolder'] = 'Archief';
$labels['settingstitle'] = 'Archief';
$labels['archivetype'] = 'Deel het archief door';
$labels['archivetypeyear'] = 'aar (bijv. Archief/2012)';
$labels['archivetypemonth'] = 'Maand (bijv. Archief/2012/06)';
$labels['archivetypetbmonth'] = 'Maand - compatibel met Thunderbird (bijv. Archief/2012/2012-06)';
$labels['archivetypefolder'] = 'Originele map';
$labels['archivetypefolderyear'] = 'Jaar en de originele map (bijv. Archief/2012/...)';
$labels['archivetypefoldermonth'] = 'Jaar, maand en de oorspronkelijke map (bijv. Archief/2012/06/...)';
$labels['archivetypesender'] = 'E-mail afzender';
$labels['unkownsender'] = 'onbekend';
$labels['readonarchive'] = 'Markeer het bericht als gelezen in het archief';
