<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Vcard Attachments plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['addvcardmsg'] = 'Добавяне на vCard към адресната книга';
$labels['vcardsavefailed'] = 'Невъзможен запис на vCard';
$labels['attachvcard'] = 'Прикачване на визитка (vCard)';
$labels['vcardattached'] = 'Прикачен vCard файл.';
$labels['vcard'] = 'vCard';
$labels['forwardvcard'] = 'Препращане на vCard';
$labels['contactsattached'] = 'Към това писмо са прикачени $num контакта.';
$labels['importedsuccessfully'] = 'Успешно импортиране на контактите в адресната книга.';
