<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Markdown editorea';
$labels['editor_button_title'] = 'Idatzi mezua Markdown-en eta bidali HTML gisa';
$labels['toolbar_button_quit'] = 'Itzuli testu arrunteko editorera';
$labels['toolbar_button_help'] = 'Ireki markdown sintaxi-gida bat leiho berri batean';
$labels['toolbar_button_preview'] = 'Aurreikusi HTML bidaliko litzatekeen moduan';
$labels['toolbar_button_bold'] = 'Lodia';
$labels['toolbar_button_italic'] = 'Etzana';
$labels['toolbar_button_strike'] = 'Marratua';
$labels['toolbar_button_h1'] = '1. izenburua';
$labels['toolbar_button_h2'] = '2. izenburua';
$labels['toolbar_button_h3'] = '3. izenburua';
$labels['toolbar_button_h4'] = '4. izenburua';
$labels['toolbar_button_h5'] = '5. izenburua';
$labels['toolbar_button_h6'] = '6. izenburua';
$labels['toolbar_button_blockquote'] = 'Aipu-blokea';
$labels['toolbar_button_unordered_list'] = 'Ordenatu gabeko zerrenda';
$labels['toolbar_button_ordered_list'] = 'Zerrenda ordenatuta';
$labels['toolbar_button_link'] = 'Esteka';
$labels['toolbar_button_image'] = 'Irudia';
$labels['toolbar_button_undo'] = 'Desegin';
$labels['toolbar_button_redo'] = 'Berregin';
