<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Rannañ';
$labels['myrights'] = 'Aotreoù mont e-barzh';
$labels['username'] = 'Implijer:';
$labels['advanced'] = 'Mod kempleshoc\'h';
$labels['add'] = 'Ouzhpennañ';
$labels['newuser'] = 'Ouzhpennañ un elfenn';
$labels['editperms'] = 'Embann an aotreoù';
$labels['actions'] = 'Aotreoù mont e-barzh';
$labels['anyone'] = 'An holl implijerien (neb hini)';
$labels['anonymous'] = 'Kouvidi (dizanv)';
$labels['identifier'] = 'Naoudi';
$labels['acll'] = 'Taol sell';
$labels['aclr'] = 'Kemennadennoù lennet';
$labels['acls'] = 'Derc\'hel ar stad "Gwelet"';
$labels['aclw'] = 'Bannieloù skrivañ';
$labels['acli'] = 'Enlakaat (Eilañ an digoradur)';
$labels['aclp'] = 'Postañ';
$labels['aclc'] = 'Krouiñ isteuliadoù';
$labels['aclk'] = 'Krouiñ isteuliadoù';
$labels['acld'] = 'Dilemel kemennadennoù';
$labels['aclt'] = 'Dilemel kemennadennoù';
$labels['acle'] = 'Skarzhañ';
$labels['aclx'] = 'Dilemel an teuliad';
$labels['acla'] = 'Ardeiñ';
$labels['acln'] = 'Notennaouiñ kemennadennoù';
$labels['aclfull'] = 'Reoliadur a-bezh';
$labels['aclother'] = 'All';
$labels['aclread'] = 'Lenn';
$labels['aclwrite'] = 'Skrivañ';
$labels['acldelete'] = 'Dilemel';
$labels['shortacll'] = 'Teurel ur sell';
$labels['shortaclr'] = 'Lenn';
$labels['shortacls'] = 'Derc\'hel';
$labels['shortaclw'] = 'Skrivañ';
$labels['shortacli'] = 'Enlakaat';
$labels['shortaclp'] = 'Postañ';
$labels['shortaclc'] = 'Krouiñ';
$labels['shortaclk'] = 'Krouiñ';
$labels['shortacld'] = 'Dilemel';
$labels['shortaclt'] = 'Dilemel';
$labels['shortacle'] = 'Skarzhañ';
$labels['shortaclx'] = 'Dilemel an teuliad';
$labels['shortacla'] = 'Ardeiñ';
$labels['shortacln'] = 'Notennaouiñ';
$labels['shortaclother'] = 'Traoù all';
$labels['shortaclread'] = 'Lenn';
$labels['shortaclwrite'] = 'Skrivañ';
$labels['shortacldelete'] = 'Dilemel';
$labels['longacll'] = 'Gwelus eo an teuliad-se er rolloù ha gallout a reer bezañ koumanantet dezhañ';
$labels['longaclr'] = 'Gallout a reer digeriñ an teuliad-mañ evit e lenn';
$labels['longacls'] = 'Gallout a reer kemmañ ar bannieloù "Kemennadenn gwelet"';
$labels['longaclw'] = 'Gallout a reer kemmañ an bannieloù kemennadennoù hag ar gerioù-alc\'hwez, war-bouez "Gwelet" ha "Dilamet"';
$labels['longacli'] = 'Gallout a ra ar c\'hemennadennoù bezañ skrivet be eilet en teuliad';
$labels['longaclp'] = 'Gallout a reer postañ kemennadennoù d\'an teuliad-mañ';
$labels['longaclc'] = 'Gallout a reer krouiñ (pe adenvel) teuliadoù en teuliad war-eeun';
$labels['longaclk'] = 'Gallout a reer krouiñ (pe adenvel) teuliadoù en teuliad war-eeun';
$labels['longacld'] = 'Gallout a reer kemmañ ar banniel ""Kemennadenn dilamet"';
$labels['longaclt'] = 'Gallout a reer kemmañ ar banniel ""Kemennadenn dilamet"';
$labels['longacle'] = 'Gallout a reer skarzhañ ar c\'hemennadennoù';
$labels['longaclx'] = 'Gallout a ra bezañ dilamet pe adanvet an teuliad';
$labels['longacla'] = 'Gallout a reer kemmañ aotreoù haeziñ an teuliad';
$labels['longacln'] = 'Metaroadennoù rannet (notennoù) ar c\'hemennadennoù a c\'hell bezañ kemmet';
$labels['longaclfull'] = 'Reoliadur a-bezh, ardeiñ an teuliad en o zouez';
$labels['longaclread'] = 'Gallout a reer digeriñ an teuliad evit e lenn';
$labels['longaclwrite'] = 'Gallout a reer merkañ, skrivañ pe eilañ kemennadennoù d\'an teuliad';
$labels['longacldelete'] = 'Gallout a reer dilemel ar c\'hemennadennoù';
$labels['longaclother'] = 'Aotreoù haeziñ all';
$labels['ariasummaryacltable'] = 'Roll an aotreoù haeziñ';
$labels['arialabelaclactions'] = 'Roll ar gweredoù';
$labels['arialabelaclform'] = 'Aotreoù haeziñ a-berzh';
$messages['deleting'] = 'O tilemel an aotreoù haeziñ...';
$messages['saving'] = 'Oc\'h enrollañ an aotreoù haeziñ...';
$messages['updatesuccess'] = 'Kemmet an aotreoù haeziñ gant berzh';
$messages['deletesuccess'] = 'Dilamet an aotreoù haeziñ gant berzh';
$messages['createsuccess'] = 'Ouzhpennet an aotreoù haeziñ gant berzh';
$messages['updateerror'] = 'N\'haller ket hizivaat an aotreoù haeziñ';
$messages['deleteerror'] = 'N\'haller ket dilemel an aotreoù haeziñ';
$messages['createerror'] = 'N\'haller ket ouzhpennañ aotreoù haeziñ';
$messages['deleteconfirm'] = 'Sur oc\'h e fell deoc\'h dilemel aotreoù haeziñ an arveriaded diuzet?';
$messages['norights'] = 'Aotre ebet erspizet!';
$messages['nouser'] = 'Anv arveriad ebet erspizet!';
