<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sound'] = 'नवीन संदेश आल्यास नाद करा';
$labels['test'] = 'चाचणी';
$labels['title'] = 'नवीन ईमेल';
$labels['body'] = 'तुमच्यासाठी नवीन संदेश आला आहे';
$labels['testbody'] = 'हा एक चाचणी निर्देश आहे';
