<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Ocorreu um erro!';
$messages['loginfailed']  = 'Falha na autenticação.';
$messages['cookiesdisabled'] = 'O seu navegador não está a aceitar cookies.';
$messages['sessionerror'] = 'A sua sessão é inválida ou expirou.';
$messages['cookiesmismatch'] = 'Foram detetadas incongruências nos cookies. Por favor limpe os cookies no seu navegador.';
$messages['storageerror'] = 'A ligação ao servidor IMAP falhou.';
$messages['servererror'] = 'Erro do servidor!';
$messages['servererrormsg'] = 'Erro do servidor: $msg';
$messages['accountlocked'] = 'Foram feitas demasiadas tentativas de autenticação falhadas. Tente novamente mais tarde.';
$messages['connerror'] = 'Erro de ligação (não foi possível alcançar o servidor)!';
$messages['dberror'] = 'Erro na base de dados!';
$messages['dbconnerror'] = 'Não foi possível conectar à base de dados!';
$messages['windowopenerror'] = 'A janela pop-up foi bloqueada!';
$messages['requesttimedout'] = 'Foi excedido o tempo limite de resposta';
$messages['errorreadonly'] = 'Não foi possível efetuar a operação. A pasta é só de leitura.';
$messages['errornoperm'] = 'Não tem permissões para efetuar esta operação.';
$messages['erroroverquota'] = 'Não foi possível executar a operação. Não há espaço livre em disco.';
$messages['erroroverquotadelete'] = 'Não há espaço livre em disco. Use SHIFT + DEL para eliminar algumas mensagens.';
$messages['invalidrequest'] = 'Pedido inválido! Não foi guardada nenhuma informação.';
$messages['invalidhost'] = 'Nome do servidor inválido.';
$messages['nomessagesfound'] = 'Não existem mensagens nesta pasta.';
$messages['loggedout'] = 'A sua sessão foi encerrada com sucesso. Até breve!';
$messages['mailboxempty'] = 'A caixa de entrada está vazia';
$messages['nomessages'] = 'Não existem mensagens';
$messages['refreshing'] = 'A atualizar...';
$messages['loading'] = 'A carregar...';
$messages['uploading'] = 'A enviar ficheiro...';
$messages['attaching'] = 'A anexar ficheiro...';
$messages['uploadingmany'] = 'A enviar ficheiros...';
$messages['loadingdata'] = 'A carregar dados...';
$messages['checkingmail'] = 'A verificar se existem novas mensagens...';
$messages['sendingmessage'] = 'A enviar mensagem...';
$messages['messagesent'] = 'Mensagem enviada com sucesso.';
$messages['savingmessage'] = 'A guardar mensagem...';
$messages['messagesaved'] = 'Mensagem guardada nos Rascunhos.';
$messages['successfullysaved'] = 'Guardado com sucesso.';
$messages['savingresponse'] = 'A guardar texto de resposta...';
$messages['deleteresponseconfirm'] = 'Deseja realmente apagar este texto de resposta?';
$messages['nocontactselected'] = 'Ainda não selecionou um contacto.';
$messages['addedsuccessfully'] = 'Contacto adicionado com sucesso no livro de endereços.';
$messages['contactexists'] = 'Já existe um contacto com este endereço de email.';
$messages['contactnameexists'] = 'Já existe um contacto com este nome.';
$messages['blockedimages'] = 'Para proteger a sua privacidade, as imagens desta mensagem foram bloqueadas.';
$messages['blockedresources'] = 'Para proteger a sua privacidade os recursos remotos foram bloqueados.';
$messages['suspiciousemail'] = 'Esta mensagem contém endereços de email suspeitos que podem ser fraudulentos.';
$messages['bccemail'] = 'A(s) mensagem(ns) reencaminhada(s) contêm destinatários confidenciais (Bcc).';
$messages['bouncehint'] = 'A mensagem será enviada sem nenhuma alteração, ou seja, usando o corpo, cabeçalhos e destinatários original.';
$messages['encryptedmessage'] = 'Esta mensagem está encriptada e não pode ser apresentada. Desculpe!';
$messages['externalmessagedecryption'] = 'Isto é uma mensagem encriptada e pode ser desencriptada com uma extensão do seu navegador.';
$messages['nopubkeyfor'] = 'Não foi encontrada nenhuma chave pública válida para $email';
$messages['nopubkeyforsender'] = 'Não foi encontrada nenhuma chave pública válida para a sua identidade de remetente. Deseja encriptar a mensagem apenas para os destinatários?';
$messages['encryptnoattachments'] = 'Os anexos já enviados não podem ser encriptados. Por favor, adicione-os novamente no editor de criptografia.';
$messages['searchpubkeyservers'] = 'Deseja procurar servidores de chaves públicas para as chaves em falta?';
$messages['encryptpubkeysfound'] = 'Foram encontradas as seguintes chaves públicas:';
$messages['keyservererror'] = 'Falha ao obter a chave do servidor de chaves.';
$messages['keyimportsuccess'] = 'Chave pública $key importada com sucesso para o seu chaveiro.';
$messages['nocontactsfound'] = 'Nenhum contacto encontrado.';
$messages['contactnotfound'] = 'O contacto especificado não foi encontrado.';
$messages['contactsearchonly'] = 'Tem de usar o formulário de pesquisa para ver contactos do livro de endereços selecionado.';
$messages['sendingfailed'] = 'Falha no envio da mensagem.';
$messages['senttooquickly'] = 'Por favor, aguarde $sec segundos antes de enviar esta mensagem.';
$messages['errorsavingsent'] = 'Ocorreu um erro ao guardar a mensagem enviada.';
$messages['errorsaving'] = 'Ocorreu um erro ao guardar.';
$messages['errormoving'] = 'Não foi possível mover as mensagens.';
$messages['errorcopying'] = 'Não foi possível copiar as mensagens.';
$messages['errordeleting'] = 'Não foi possível eliminar as mensagens.';
$messages['errormarking'] = 'Não foi possível marcar as mensagens.';
$messages['alerttitle'] = 'Atenção';
$messages['confirmationtitle'] = 'Tem a certeza...';
$messages['deletecontactconfirm']  = 'Tem a certeza que pretende eliminar os contactos selecionados?';
$messages['deletegroupconfirm']  = 'Tem a certeza que pretende eliminar o grupo selecionado?';
$messages['deletemessagesconfirm'] = 'Tem a certeza que pretende eliminar as mensagens selecionadas?';
$messages['deletefolderconfirm']  = 'Quer mesmo eliminar esta pasta?';
$messages['movefolderconfirm']  = 'Quer mesmo mover esta pasta?';
$messages['purgefolderconfirm']  = 'Quer mesmo eliminar todas mensagens desta pasta?';
$messages['contactdeleting'] = 'A eliminar contactos...';
$messages['groupdeleting'] = 'A eliminar grupo...';
$messages['folderdeleting'] = 'A eliminar pasta...';
$messages['foldermoving'] = 'A mover pasta...';
$messages['foldersubscribing'] = 'A subscrever pasta...';
$messages['folderunsubscribing'] = 'A cancelar subscrição da pasta...';
$messages['formincomplete'] = 'Os campos não foram completamente preenchidos.';
$messages['noemailwarning'] = 'Por favor, introduza um endereço de email válido.';
$messages['nonamewarning']  = 'Por favor, escreva um nome.';
$messages['nopagesizewarning'] = 'Por favor, introduza o tamanho da página.';
$messages['nosenderwarning'] = 'Por favor, introduza o endereço de email do remetente.';
$messages['recipientsadded'] = 'Destinatário(s) adicionado(s) com sucesso.';
$messages['norecipientwarning'] = 'Por favor, insira pelo menos um destinatário.';
$messages['disclosedrecipwarning'] = 'Todos os destinatários irão ver os endereços de e-mail uns dos outros. Para evitar isso e proteger a sua privacidade, pode utilizar o campo Bcc.';
$messages['disclosedreciptitle'] = 'Demasiados destinatários públicos';
$messages['nosubjectwarning']  = 'O campo "Assunto" não foi preenchido. Deseja incluí-lo agora?';
$messages['nosubjecttitle']  = 'Sem assunto';
$messages['nobodywarning'] = 'Enviar a mensagem sem texto?';
$messages['notsentwarning'] = 'A mensagem não foi enviada e tem alterações por guardar. Deseja descartar essas alterações?';
$messages['restoresavedcomposedata'] = 'Foi encontrada uma mensagem anteriormente composta mas não enviada.\n\nAssunto: $subject\nGuardada: $date\n\nDeseja restaurar esta mensagem?';
$messages['nosearchname'] = 'Por favor insira o nome do contacto ou endereço de email.';
$messages['notuploadedwarning'] = 'Nem todos os anexos foram ainda enviados. Por favor aguarde ou cancele o envio.';
$messages['searchsuccessful'] = '$nr mensagens encontradas.';
$messages['contactsearchsuccessful'] = '$nr contactos encontrados.';
$messages['searchnomatch'] = 'A pesquisa não obteve resultados.';
$messages['searching'] = 'A pesquisar...';
$messages['checking'] = 'A verificar...';
$messages['stillsearching'] = 'Ainda a procurar...';
$messages['nospellerrors'] = 'Não foi encontrado nenhum erro ortográfico.';
$messages['folderdeleted'] = 'Pasta eliminada com sucesso.';
$messages['foldersubscribed'] = 'Subscrição da pasta concluída com sucesso';
$messages['folderunsubscribed'] = 'Subscrição da pasta cancelada com sucesso.';
$messages['folderpurged'] = 'Pasta esvaziada com sucesso.';
$messages['folderexpunged'] = 'Pasta compactada com sucesso.';
$messages['deletedsuccessfully'] = 'Eliminado com sucesso.';
$messages['converting'] = 'A remover a formatação...';
$messages['messageopenerror'] = 'Não foi possível carregar a mensagem.';
$messages['filelinkerror'] = 'Falha ao anexar o ficheiro.';
$messages['fileuploaderror'] = 'Falha ao carregar o ficheiro.';
$messages['csvfilemismatch'] = 'A importação de vários ficheiros CSV com campos diferentes não é suportada.';
$messages['filesizeerror'] = 'O ficheiro excede o tamanho máximo permitido de $size.';
$messages['filecounterror'] = 'Pode carregar, no máximo, $count ficheiro(s) de cada vez.';
$messages['msgsizeerror'] = 'Falha ao anexar um ficheiro. O tamanho máximo da mensagem ($size) foi excedido.';
$messages['msgsizeerrorfwd'] = 'O tamanho máximo para uma mensagem ($size) foi excedido. $num mensagem(ns) não foi(ram) anexada(s).';
$messages['copysuccess'] = '$nr contacto(s) copiado(s) com sucesso.';
$messages['movesuccess'] = '$nr contacto(s) movido(s) com sucesso.';
$messages['copyerror'] = 'Não foi possível copiar o(s) contacto(s).';
$messages['moveerror'] = 'Não foi possível mover o(s) contacto(s).';
$messages['sourceisreadonly'] = 'Esta origem de endereços é só de leitura.';
$messages['errorsavingcontact'] = 'Não foi possível guardar o endereço deste contacto.';
$messages['movingmessage'] = 'A mover mensagem(ns)...';
$messages['copyingmessage'] = 'A copiar mensagem(ns)...';
$messages['copyingcontact'] = 'A copiar contacto(s)...';
$messages['movingcontact'] = 'A mover contacto(s)...';
$messages['deletingmessage'] = 'A eliminar mensagem(ns)...';
$messages['markingmessage'] = 'A marcar mensagem(ns)...';
$messages['addingmember'] = 'A adicionar contacto(s) ao grupo...';
$messages['removingmember'] = 'A remover contacto(s) do grupo...';
$messages['receiptsent'] = 'Recibo de leitura enviado com sucesso.';
$messages['errorsendingreceipt'] = 'Não foi possível enviar o recibo.';
$messages['deleteidentityconfirm'] = 'Pretende realmente eliminar esta identidade?';
$messages['nodeletelastidentity'] = 'Esta é a sua última identidade, não é possível eliminá-la.';
$messages['forbiddencharacter'] = 'O nome da pasta contém um caractere inválido.';
$messages['selectimportfile'] = 'Por favor, selecione um ficheiro para enviar.';
$messages['addresswriterror'] = 'Não é possível escrever no livro de endereços selecionado.';
$messages['contactaddedtogroup'] = 'Contacto adicionado com sucesso a este grupo.';
$messages['contactremovedfromgroup'] = 'Contacto removido com sucesso deste grupo.';
$messages['nogroupassignmentschanged'] = 'Não foi alterada nenhuma atribuição de grupo.';
$messages['importwait'] = 'A importar, por favor aguarde...';
$messages['importformaterror'] = 'A importação falhou! O ficheiro enviado não é um ficheiro de dados válido.';
$messages['importconfirm'] = '<b>Foram importados com sucesso $inserted contactos</b>';
$messages['importconfirmskipped'] = '<b>Ignorado(s) $skipped contacto(s) existente(s)</b>';
$messages['importconfirminvalid'] = 'Ignorado(s) $invalid contacto(s) inválido(s)';
$messages['importconfirmerrors'] = 'Falha ao importar $errors contacto(s) válido(s)';
$messages['importmessagesuccess'] = 'Foram importadas com sucesso $nr mensagens';
$messages['importmessageerror'] = 'A importação falhou! O ficheiro carregado não é um arquivo de caixa de correio ou ficheiro de mensagem válido.';
$messages['opnotpermitted'] = 'Operação não permitida!';
$messages['nofromaddress'] = 'Falta o endereço de email na identidade selecionada.';
$messages['editorwarning'] = 'Alterar o tipo de editor pode causar a perda da formatação do texto. Deseja continuar?';
$messages['httpreceivedencrypterror'] = 'Ocorreu um erro fatal de configuração. Contacte o seu Administrador imediatamente. <b>A sua mensagem não pôde ser enviada.</b>';
$messages['smtpconnerror'] = 'Erro SMTP ($code): A ligação ao servidor falhou.';
$messages['smtpautherror'] = 'Erro SMTP ($code): A autenticação falhou.';
$messages['smtpfromerror'] = 'Erro SMTP ($code): Falha ao definir o remetente "$from" ($msg).';
$messages['smtptoerror'] = 'Erro SMTP ($code): Falha ao adicionar o destinatário: "$to" ($msg).';
$messages['smtprecipientserror'] = 'Erro SMTP: Impossível analisar a lista de destinatários.';
$messages['smtputf8error'] = 'Erro de SMTP: O servidor não suporta Unicode nos endereços de email.';
$messages['smtpsizeerror'] = 'Erro SMTP: O tamanho da mensagem excede o limite do servidor ($limit)';
$messages['smtperror'] = 'Erro SMTP: $msg';
$messages['emailformaterror'] = 'Endereço de email incorreto: $email';
$messages['toomanyrecipients'] = 'Demasiados destinatários. Reduza o número de destinatários para o máximo de $max.';
$messages['maxgroupmembersreached'] = 'O número de membros do grupo ultrapassa o máximo permitido de $max.';
$messages['internalerror'] = 'Ocorreu um erro interno. Por favor, tente novamente.';
$messages['contactdelerror'] = 'Não foi possível eliminar o(s) contacto(s).';
$messages['contactdeleted'] = 'Contacto(s) eliminado(s) com sucesso.';
$messages['contactrestoreerror'] = 'Não foi possível restaurar o(s) contacto(s) eliminados.';
$messages['contactrestored'] = 'Contacto(s) restaurado(s) com sucesso.';
$messages['groupdeleted'] = 'Grupo eliminado com sucesso.';
$messages['grouprenamed'] = 'Grupo renomeado com sucesso.';
$messages['groupcreated'] = 'Grupo criado com sucesso.';
$messages['savedsearchdeleted'] = 'A pesquisa guardada foi eliminada com sucesso.';
$messages['savedsearchdeleteerror'] = 'Não foi possível eliminar a pesquisa guardada.';
$messages['savedsearchcreated'] = 'Pesquisa guardada criada com sucesso.';
$messages['savedsearchcreateerror'] = 'Não foi possível criar a pesquisa guardada.';
$messages['messagedeleted'] = 'Mensagem(ns) eliminada(s) com sucesso.';
$messages['messagemoved'] = 'Mensagem(ns) movida(s) com sucesso.';
$messages['messagemovedtotrash'] = 'Mensagem(ns) movida(s) com sucesso para a Reciclagem.';
$messages['messagecopied'] = 'Mensagem(ns) copiada(s) com sucesso.';
$messages['messagemarked'] = 'Mensagem(ns) marcada(s) com sucesso.';
$messages['autocompletechars'] = 'Indique pelo menos $min caracteres para o auto preenchimento.';
$messages['autocompletemore'] = 'Demasiados registos encontrados. Por favor, insira mais caracteres.';
$messages['namecannotbeempty'] = 'O nome não pode estar em branco.';
$messages['nametoolong'] = 'O nome é demasiado longo.';
$messages['namedotforbidden'] = 'O nome da pasta não pode começar com um ponto.';
$messages['folderupdated'] = 'Atualização da pasta concluída com sucesso.';
$messages['foldercreated'] = 'Pasta criada com sucesso.';
$messages['invalidimageformat'] = 'O formato da imagem não é suportado.';
$messages['mispellingsfound'] = 'Foram detetados erros de ortografia nesta mensagem.';
$messages['parentnotwritable'] = 'Não é possível criar/mover esta pasta para a pasta selecionada. O acesso foi negado.';
$messages['messagetoobig'] = 'A mensagem é demasiado grande para ser processada.';
$messages['attachmentvalidationerror'] = 'Este anexo é suspeito porque o seu tipo não corresponde ao tipo declarado na mensagem. Se não confiar no remetente, não deve abri-lo no navegador, pois pode conter conteúdo malicioso.
Esperado: $expected; encontrado: $detected';
$messages['noscriptwarning'] = 'Aviso: Este serviço de webmail utiliza Javascript! Para o poder utilizar, ative o Javascript nas definições do seu navegador.';
$messages['messageissent'] = 'A mensagem já foi enviada, mas ainda não foi guardada. Deseja guardá-la agora?';
$messages['errnotfound'] = 'Ficheiro não encontrado';
$messages['errnotfoundexplain'] = 'O recurso solicitado não foi encontrado!';
$messages['errfailedrequest'] = 'A solicitação falhou';
$messages['errauthorizationfailed'] = 'Falha na autorização';
$messages['errunauthorizedexplain'] = 'Não foi possível verificar se está autorizado a aceder a este serviço!';
$messages['errrequestcheckfailed'] = 'Falha na verificação da solicitação ';
$messages['errcsrfprotectionexplain'] = "Para sua proteção, o acesso a este recurso está protegido contra CSRF.\nlf Se está a ver isto, provavelmente não fez logout antes de sair da aplicação web.\n\nAgora, é necessária interação humana para continuar.";
$messages['errcontactserveradmin'] = 'Por favor, contacte o administrador do servidor.';
$messages['clicktoresumesession'] = 'Clique aqui para retomar a sua sessão anterior';
$messages['errcomposesession'] = 'Erro na sessão de composição';
$messages['errcomposesessionexplain'] = 'A sessão de composição solicitada não foi encontrada.';
$messages['clicktocompose'] = 'Clique aqui para escrever uma nova mensagem';
$messages['nosupporterror'] = 'Esta funcionalidade não é suportada pelo seu navegador.';
$messages['siginserted'] = 'Assinatura inserida com sucesso.';
$messages['responseinserted'] = 'Resposta inserida com sucesso.';
$messages['noresponsesavailable'] = 'Sem respostas disponíveis';
$messages['listempty'] = 'A lista está vazia.';
$messages['listusebutton'] = 'Use o botão Criar para adicionar um novo registo.';
$messages['keypaircreatesuccess'] = 'Um novo par de chaves foi criado com sucesso para $identity.';
$messages['emptyattachment'] = 'Este anexo parece estar vazio.<br>Por favor, verifique com a pessoa que o enviou.';
$messages['oauthloginfailed'] = 'O login do OAuth falhou. Por favor, tente novamente.';
$messages['oauthinvalidrequest'] = 'O pedido de autorização era inválido ou incompleto.';
$messages['oauthaccessdenied'] = 'O servidor de autorização ou o utilizador negou o pedido.';
