<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'பிழை ஏற்பட்டது!';
$messages['loginfailed']  = 'நுழைவு தோல்வியடைந்தது';
$messages['cookiesdisabled'] = 'உங்கள் உலாவி நினைவிகளை அனுமதிப்பதில்லை';
$messages['sessionerror'] = 'உங்கள் அமர்வு செல்லாது அல்லது முடிவுற்றது';
$messages['storageerror'] = 'IMAP சேவையகத்திற்கான இணைப்பு தோல்வியடைந்தது';
$messages['servererror'] = 'சேவையக பிழை!';
$messages['servererrormsg'] = 'சேவையக பிழை: $msg';
$messages['invalidrequest'] = 'செல்லாத வேண்டுகோள்! எந்த தரவும் சேமிக்கப்படவில்லை.';
$messages['nomessagesfound'] = 'இந்த தபால் பெட்டியில் எந்த தரவும் சேமிக்கப்படவில்லை';
$messages['mailboxempty'] = 'தபால் பெட்டி காலியாக உள்ளது';
$messages['loading'] = 'ஏற்றுகிறது...';
$messages['uploading'] = 'கோப்பை ஏற்றுகிறது...';
$messages['loadingdata'] = 'தரவை ஏற்றுகிறது...';
$messages['checkingmail'] = 'புது செய்திகளை சரிபார்க்கிறது...';
$messages['sendingmessage'] = 'செய்தியை அனுப்புகிறது...';
$messages['messagesent'] = 'செய்தி வெற்றிகரமாக அனுப்பப்பட்டது';
$messages['savingmessage'] = 'செய்தியை சேமிக்கிறது...';
$messages['messagesaved'] = 'செய்தி வரைவில் சேமிக்கப்பட்டது';
$messages['successfullysaved'] = 'வெற்றிகரமாக சேமிக்கப்பட்டது';
$messages['addedsuccessfully'] = 'தொடர்பு சேமிக்கப்பட்டது';
$messages['blockedimages'] = 'உங்கள் தனிப்பட்ட தகவலை பாதுகாக்க, தொலை தூரப் படங்கள் இந்த செய்தியில் தடுக்கப்பட்டது';
$messages['encryptedmessage'] = 'மன்னிக்கவும்! இந்த செய்தி குறிமுறையாக்கப்பட்டது அதனால் காட்ட முடியாது.';
$messages['nocontactsfound'] = 'எந்த தொடர்புகளும் காணப்படவில்லை';
$messages['contactnotfound'] = 'நீங்கள் வேண்டிய தொடர்பு காணப்படவில்லை';
$messages['sendingfailed'] = 'செய்தி அனுப்புவது தோல்வியுற்றது';
$messages['senttooquickly'] = 'இந்த செய்தி அனுப்புவதற்கு முன்பு தயவு செய்து $sec வினாடி(கள்) காத்திருக்கவும்.';
$messages['errormoving'] = 'செய்தியை நகர்த்த முடியவில்லை';
$messages['errordeleting'] = 'செய்தியை நீக்க முடியவில்லை';
$messages['errormarking'] = 'செய்தியை நட்சத்திரமிட முடியவில்லை';
$messages['deletecontactconfirm']  = 'நீங்கள் தேர்ந்தெடுத்த தொடர்புகளை நீக்க விரும்புகிறீர்களா ?';
$messages['deletemessagesconfirm'] = 'நீங்கள் தேர்ந்தெடுத்த செய்திகளை நீக்க விரும்புகிறீர்களா ?';
$messages['deletefolderconfirm']  = 'நீங்கள் இந்த அடைவை நீக்க விரும்புகிறீர்களா ?';
$messages['purgefolderconfirm']  = 'நீங்கள் இந்த அடைவிலிருக்கும் எல்லா செய்திகளையும் நீக்க விரும்புகிறீர்களா ?';
$messages['folderdeleting'] = 'அடைவை நீக்குகிறது...';
$messages['foldermoving'] = 'அடைவை நகர்த்துகிறது...';
$messages['formincomplete'] = 'விண்ணப்பத்தை முழுமையாக நிறைவு செய்யவில்லை';
$messages['noemailwarning'] = 'தயவு செய்து உண்மையான மின்னஞ்சலை எழுதுங்கள்';
$messages['nonamewarning']  = 'தயவு செய்து பெயரை எழுதுங்கள்';
$messages['nopagesizewarning'] = 'தயவு செய்து தாழின் அளவை எழுதுங்கள்';
$messages['norecipientwarning'] = 'தயவு செய்து ஒரு பெறுனரையாவது எழுதுங்கள்';
$messages['nosubjectwarning']  = 'தலைப்பு காலியாக உள்ளது. இப்போது எழுத விரும்புகிறீர்களா?';
$messages['nobodywarning'] = 'உரையில்லாமல் இந்த செய்தியை அனுப்ப வேண்டுமா?';
$messages['nosearchname'] = 'தயவு செய்து தொடர்பின் பெயரோ மின்னஞ்சல் முகவரியோ எழுதுங்கள்';
$messages['notuploadedwarning'] = 'எல்லா இணைப்புகளும் ஏற்றப்படவில்லை. தயவு செய்து காத்திருங்கள் அல்லது ஏற்றத்தை ரத்து செய்யுங்கள்.';
$messages['searchsuccessful'] = '$nr செய்திகள் கண்டுபிடிக்கப்பட்டது';
$messages['searchnomatch'] = 'தேடுதல் எந்த பொருத்தத்தையும் அனுப்பவில்லை';
$messages['searching'] = 'தேடுகிறது...';
$messages['checking'] = 'சரி பார்க்கிறது...';
$messages['nospellerrors'] = 'எழுத்து பிழைகள் இல்லை';
$messages['folderdeleted'] = 'அடைவு வெற்றிகரமாக நீக்கப்பட்டது';
$messages['deletedsuccessfully'] = 'வெற்றிகரமாக நீக்கப்பட்டது';
$messages['converting'] = 'வடிவத்தை நீக்குகிறது...';
$messages['messageopenerror'] = 'சேவையகத்திலிருந்து செய்தியை ஏற்ற முடியவில்லை';
$messages['fileuploaderror'] = 'கோப்பு ஏற்றம் தோல்வியடாந்தது';
$messages['filesizeerror'] = 'ஏற்றிய கோப்பு அதிகபட்ச அளவான $size-ஐ மீறியது';
$messages['sourceisreadonly'] = 'இந்த முகவரியின் மூலத்தை படிக்க மட்டும்தான் முடியும்';
$messages['errorsavingcontact'] = 'தொடர்பு முகவரியை சேமிக்க முடியவில்லை';
$messages['movingmessage'] = 'செய்தியை நகர்த்துகிறது...';
$messages['receiptsent'] = 'படித்த சீட்டு வெற்றிகரமாக அனுப்பப்பட்டது';
$messages['errorsendingreceipt'] = 'சீட்டை அனுப்ப முடியவில்லை';
$messages['nodeletelastidentity'] = 'நீங்கள் இந்த அடையாளத்தை நீக்க முடியாது இது தான் கடைசி';
$messages['forbiddencharacter'] = 'அடைவு பெயரில் தடை செய்யப்பட்ட எழுத்துக்கள் உள்ளது';
$messages['selectimportfile'] = 'தயவு செய்து ஏற்றுவதற்கு ஒரு கோப்பை தேர்ந்தெடுங்கள்';
$messages['addresswriterror'] = 'நீங்கள் தேர்ந்தெடுத்த தொடர்புகளில் எழுத முடியாது';
$messages['importwait'] = 'ஏற்றுகிறது, தயவு செய்து காத்திருங்கள்...';
$messages['importconfirm'] = '<b>வெற்றிகரமாக $inserted தொடர்புகள் ஏற்றப்பட்டது, ஏற்கனவே உள்ள $skipped தொடர்புகள் தவிர்க்கப்பட்டது</b>: <p><em>$names</em></p>';
$messages['opnotpermitted'] = 'பணி அனுமதிக்கப்படவில்லை!';
$messages['httpreceivedencrypterror'] = 'அமைப்பில் பெரிய பிழை ஏற்பட்டது. உங்கள் நிர்வாகியை உடனே தொடர்பு கொள்ளவும். <b>உங்கள் செய்தியை அனுப்ப முடியாது.</b>';
$messages['smtpconnerror'] = 'SMTP பிழை ($code): சேவையகத்தின் இணைப்பு தோல்வியடைந்தது';
$messages['smtpautherror'] = 'SMTP பிழை ($code): நம்பகத்தன்மை தோல்வியடைந்தது';
$messages['smtpfromerror'] = 'SMTP பிழை ($code): அனுப்புனரை "$from" ஆக வைப்பதில் தோல்வி';
$messages['smtptoerror'] = 'SMTP பிழை ($code): "$to" பெறுனரை சேர்பதில் தோல்வி';
$messages['smtprecipientserror'] = 'SMTP பிழை : பெறுனர் பட்டியலை பிரிக்க முடியவில்லை';
$messages['smtperror'] = 'SMTP பிழை: $msg';
