<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Филтри';
$labels['managefilters'] = 'Управление на филтри за входяща поща';
$labels['filtername'] = 'Име на филтър';
$labels['newfilter'] = 'Нов филтър';
$labels['filteradd'] = 'Добавяне на филтър';
$labels['filterdel'] = 'Изтриване на филтър';
$labels['rules'] = 'Условия';
$labels['actions'] = 'Действия';
$labels['scope'] = 'Обхват';
$labels['moveup'] = 'Преместване нагоре';
$labels['movedown'] = 'Преместване надолу';
$labels['filterallof'] = 'при изпълнение на всички условия';
$labels['filteranyof'] = 'при изпълнение на някое от условията';
$labels['filterany'] = 'за всички писма';
$labels['filtercontains'] = 'съдържа';
$labels['filternotcontains'] = 'не съдържа';
$labels['filteris'] = 'е равно на';
$labels['filterisnot'] = 'не е равно на';
$labels['filterexists'] = 'съществува';
$labels['filternotexists'] = 'не съществува';
$labels['filtermatches'] = 'съвпада с израз';
$labels['filternotmatches'] = 'не съвпада с израз';
$labels['filterregex'] = 'отговаря на регулярен израз';
$labels['filternotregex'] = 'не отговаря на регулярен израз';
$labels['filterunder'] = 'под';
$labels['filterover'] = 'над';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME част:';
$labels['mime-message'] = 'писмо';
$labels['mime-anychild'] = 'която и да е';
$labels['mime-type'] = 'тип';
$labels['mime-subtype'] = 'подтип';
$labels['mime-contenttype'] = 'тип на съдържанието';
$labels['mime-param'] = 'параметър';
$labels['addrule'] = 'Ново условие';
$labels['delrule'] = 'Изтриване на условие';
$labels['messagemoveto'] = 'Премести писмото във';
$labels['messageredirect'] = 'Пренасочи писмото до';
$labels['messagecopyto'] = 'Копирай писмото във';
$labels['messagesendcopy'] = 'Изпрати копие на писмото до';
$labels['messagereply'] = 'Отговори с писмо';
$labels['messagedelete'] = 'Изтрий писмото';
$labels['messagediscard'] = 'Отхвърли с писмо';
$labels['messagekeep'] = 'Остави писмото във Входящи';
$labels['messagesrules'] = 'При получаване на поща:';
$labels['messagesactions'] = '...изпълни следните действия:';
$labels['add'] = 'Добави';
$labels['del'] = 'Изтрий';
$labels['sender'] = 'Подател';
$labels['recipient'] = 'Получател';
$labels['vacationaddr'] = 'Мои адреси на ел. поща:';
$labels['vacationdays'] = 'Колко често да праща писма (в дни):';
$labels['vacationinterval'] = 'Колко често да праща писма:';
$labels['vacationreason'] = 'Текст на писмото (причина за отпуск):';
$labels['vacationfrom'] = 'Адрес за отговор на подателя:';
$labels['vacationsubject'] = 'Заглавие на писмото:';
$labels['days'] = 'дни';
$labels['seconds'] = 'секунди';
$labels['rulestop'] = 'Спри проверка на други условия';
$labels['enable'] = 'Включи/Изключи';
$labels['filterset'] = 'Набор филтри';
$labels['filtersets'] = 'Набори филтри';
$labels['filtersetadd'] = 'Добавяне на набор филтри';
$labels['filtersetdel'] = 'Изтриване на набор филтри';
$labels['filtersetact'] = 'Активиране на текущ набор филтри';
$labels['filtersetdeact'] = 'Деактивиране на текущ набор филтри';
$labels['filterseteditraw'] = 'Редакция на набор филтри';
$labels['filtersetswitch'] = 'Включи/Изключи набор филтри';
$labels['filterdef'] = 'Дефиниране на филтър';
$labels['filtersetname'] = 'Име на набор филтри';
$labels['newfilterset'] = 'Нов набор филтри';
$labels['active'] = 'активен';
$labels['none'] = 'няма';
$labels['fromset'] = 'от набор';
$labels['fromfile'] = 'от файл';
$labels['filterdisabled'] = 'Изключен филтър';
$labels['filterenabled'] = 'Включен филтър';
$labels['countisgreaterthan'] = 'брой е по-голям от';
$labels['countisgreaterthanequal'] = 'брой е по-голям или равен на';
$labels['countislessthan'] = 'брой е по-малък от';
$labels['countislessthanequal'] = 'брой е по-малък или равен на';
$labels['countequals'] = 'брой е равен на';
$labels['countnotequals'] = 'брой не е равен на';
$labels['valueisgreaterthan'] = 'стойност е по-голяма от';
$labels['valueisgreaterthanequal'] = 'стойност е по-голяма или равна на';
$labels['valueislessthan'] = 'стойност е по-малка от';
$labels['valueislessthanequal'] = 'стойност е по-малка или равна на';
$labels['valueequals'] = 'стойност е равна на';
$labels['valuenotequals'] = 'стойност не е равна на';
$labels['setflags'] = 'Установи флагове на писмото';
$labels['addflags'] = 'Добави флагове към писмо';
$labels['removeflags'] = 'Премахни флагове от писмо';
$labels['flagread'] = 'Прочетено';
$labels['flagdeleted'] = 'Изтрито';
$labels['flaganswered'] = 'Отговорено';
$labels['flagflagged'] = 'Отбелязано';
$labels['flagdraft'] = 'Чернова';
$labels['addheader'] = 'Добави заглавен блок към писмо';
$labels['deleteheader'] = 'Премахни заглавен блок от писмо';
$labels['headername'] = 'Име на заглавен блок';
$labels['headervalue'] = 'Стойност на заглавен блок';
$labels['headerpos'] = 'Позиция на заглавен блок';
$labels['headeratstart'] = 'в началото';
$labels['headeratend'] = 'в края';
$labels['headeroccurrence'] = 'Поява/позиция на заглавен блок';
$labels['headerfromstart'] = 'от началото';
$labels['headerfromend'] = 'от края';
$labels['headerpatterns'] = 'Модели на стойността на заглавен блок';
$labels['headermatchtype'] = 'тип съвпадение:';
$labels['setvariable'] = 'Установи променлива';
$labels['setvarname'] = 'Име на променлива:';
$labels['setvarvalue'] = 'Стойност на променлива:';
$labels['setvarmodifiers'] = 'Модификатори:';
$labels['varlower'] = 'малки букви';
$labels['varupper'] = 'главни букви';
$labels['varlowerfirst'] = 'първи знак с малка буква';
$labels['varupperfirst'] = 'първи знак с главна буква';
$labels['varquotewildcard'] = 'цитиране на специални знаци';
$labels['varlength'] = 'дължина';
$labels['varencodeurl'] = 'percent-encoded (за URL адреси)';
$labels['notify'] = 'Изпрати известие';
$labels['notifytarget'] = 'Известие към:';
$labels['notifymessage'] = 'Съдържание на известие (опционално):';
$labels['notifyoptions'] = 'Опции на известие (опционално):';
$labels['notifyfrom'] = 'Подател на известието (опционално):';
$labels['notifyimportance'] = 'Приоритет:';
$labels['notifyimportancelow'] = 'нисък';
$labels['notifyimportancenormal'] = 'нормален';
$labels['notifyimportancehigh'] = 'висок';
$labels['notifymethodmailto'] = 'Ел. поща';
$labels['notifymethodtel'] = 'Телефон';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Използвай за нов филтър';
$labels['usedata'] = 'Използвай следните данни във филтъра:';
$labels['nextstep'] = 'Следваща стъпка';
$labels['...'] = '...';
$labels['string'] = 'Низ';
$labels['currdate'] = 'Текуща дата';
$labels['datetest'] = 'Дата';
$labels['dateheader'] = 'заглавен блок:';
$labels['year'] = 'година';
$labels['month'] = 'месец';
$labels['day'] = 'ден';
$labels['date'] = 'дата (гггг-мм-дд)';
$labels['julian'] = 'дата (юлианска)';
$labels['hour'] = 'час';
$labels['minute'] = 'минута';
$labels['second'] = 'секунда';
$labels['time'] = 'време (чч:мм:сс)';
$labels['iso8601'] = 'дата (ISO8601)';
$labels['std11'] = 'дата (RFC2822)';
$labels['zone'] = 'часова зона';
$labels['weekday'] = 'ден от седмицата (0-6)';
$labels['advancedopts'] = 'Разширени настройки';
$labels['body'] = 'Основен текст';
$labels['address'] = 'адрес';
$labels['envelope'] = 'плик';
$labels['modifier'] = 'модификатор:';
$labels['text'] = 'текст';
$labels['undecoded'] = 'недекодиран (суров)';
$labels['contenttype'] = 'тип на съдържанието';
$labels['modtype'] = 'тип:';
$labels['allparts'] = 'всичко';
$labels['domain'] = 'домейн';
$labels['localpart'] = 'локална част';
$labels['user'] = 'потребител';
$labels['detail'] = 'детайли';
$labels['comparator'] = 'сравнител:';
$labels['default'] = 'по подразбиране';
$labels['octet'] = 'стриктно (октет)';
$labels['asciicasemap'] = 'без значение малки/големи букви';
$labels['asciinumeric'] = 'цифрово';
$labels['index'] = 'индекс:';
$labels['indexlast'] = 'наобратно';
$labels['spamtest'] = 'Ниво на Спам';
$labels['spamtestisgreaterthan'] = 'е по-голямо от';
$labels['spamtestisgreaterthanequal'] = 'е по-голямо или равно на';
$labels['spamtestislessthan'] = 'е по-малко от';
$labels['spamtestislessthanequal'] = 'е по-малко или равно на';
$labels['spamtestequals'] = 'е равно на';
$labels['spamtestnotequals'] = 'не е равно на';
$labels['spamtestisunknown'] = 'е неизвестно';
$labels['vacation'] = 'Отпуск';
$labels['vacation.reply'] = 'Писмо отговор';
$labels['vacation.advanced'] = 'Разширени настройки';
$labels['vacation.from'] = 'Адрес за отговор на подателя:';
$labels['vacation.subject'] = 'Относно';
$labels['vacation.body'] = 'Съдържание';
$labels['vacation.start'] = 'Начало';
$labels['vacation.end'] = 'Край';
$labels['vacation.status'] = 'Статус';
$labels['vacation.on'] = 'Вкл.';
$labels['vacation.off'] = 'Изкл.';
$labels['vacation.addresses'] = 'Мои адреси на ел. поща';
$labels['vacation.interval'] = 'Интервал на отговор';
$labels['vacation.after'] = 'Постави правилото за отпуск след';
$labels['vacation.saving'] = 'Запис на данни...';
$labels['vacation.action'] = 'Действие при получаване на писмо';
$labels['vacation.keep'] = 'Запази';
$labels['vacation.discard'] = 'Изхвърли';
$labels['vacation.redirect'] = 'Препрати на';
$labels['vacation.copy'] = 'Прати копие на';
$labels['forward'] = 'Препращане';
$labels['forward.redirect'] = 'Препрати на';
$labels['forward.copy'] = 'Прати копие на';
$labels['forward.on'] = 'Вкл.';
$labels['forward.off'] = 'Изкл.';
$labels['forward.status'] = 'Статус:';
$labels['forward.action'] = 'При получаване на поща изпълни следното действие:';
$labels['forward.saving'] = 'Запис на данни...';
$labels['filladdresses'] = 'Попълни с всички мои адреси';
$labels['arialabelfiltersetactions'] = 'Действия за набор от филтри';
$labels['arialabelfilteractions'] = 'Действия на филтър';
$labels['arialabelfilterform'] = 'Свойства на филтър';
$labels['ariasummaryfilterslist'] = 'Списък филтри';
$labels['ariasummaryfiltersetslist'] = 'Списък набори от филтри';
$labels['filterstitle'] = 'Редакция на филтри за входяща поща';
$labels['vacationtitle'] = 'Редакция на правило за отпуск (извън офиса)';
$labels['forwardtitle'] = 'Редактиране на правилото за препращане на поща';
$labels['message'] = 'Писмо';
$labels['duplicate'] = 'е дубликат';
$labels['notduplicate'] = 'не е дубликат';
$labels['duplicate.handle'] = 'манипулатор:';
$labels['duplicate.header'] = 'заглавен блок:';
$labels['duplicate.uniqueid'] = 'идентификатор:';
$labels['duplicate.seconds'] = 'време за отказ (секунди)';
$labels['duplicate.last'] = 'спрямо последното изпълнение';
$messages['filterunknownerror'] = 'Неизвестна сървърна грешка.';
$messages['filterconnerror'] = 'Неуспешно свързване с managesieve сървъра.';
$messages['filterdeleteerror'] = 'Невъзможно изтриване на филтъра. Възникна сървърна грешка.';
$messages['filterdeleted'] = 'Филтърът е изтрит успешно.';
$messages['filtersaved'] = 'Филтърът е записан успешно.';
$messages['filtersaveerror'] = 'Невъзможно записване на филтъра. Възникна сървърна грешка.';
$messages['filterformerror'] = 'Филтър формата съдържа грешки.';
$messages['filterdeleteconfirm'] = 'Наистина ли желаете да изтриете избрания филтър?';
$messages['ruledeleteconfirm'] = 'Сигурни ли сте, че желаете да изтриете избраното условие?';
$messages['actiondeleteconfirm'] = 'Сигурни ли сте, че желаете да изтриете избраното действие?';
$messages['forbiddenchars'] = 'Забранени символи в полето.';
$messages['cannotbeempty'] = 'Полето не може да бъде празно.';
$messages['ruleexist'] = 'Вече има филтър с указаното име.';
$messages['setactivateerror'] = 'Невъзможно активиране на избрания набор от филтри. Възникна сървърна грешка.';
$messages['setdeactivateerror'] = 'Невъзможно деактивиране на избрания набор от филтри. Възникна сървърна грешка.';
$messages['setdeleteerror'] = 'Невъзможно изтриване на избрания набор от филтри. Възникна сървърна грешка.';
$messages['setactivated'] = 'Наборът от филтри е активиран успешно.';
$messages['setdeactivated'] = 'Наборът от филтри е деактивиран успешно.';
$messages['setdeleted'] = 'Наборът от филтри е изтрит успешно.';
$messages['setupdated'] = 'Наборът от филтри е променен успешно.';
$messages['setdeleteconfirm'] = 'Сигурни ли сте, че желаете да изтриете избрания набор от филтри?';
$messages['setcreateerror'] = 'Невъзможно създаване на набор от филтри. Възникна сървърна грешка.';
$messages['setcreated'] = 'Наборът от филтри е създаден успешно.';
$messages['activateerror'] = 'Невъзможно включване на филтъра. Възникна сървърна грешка.';
$messages['deactivateerror'] = 'Невъзможно изключване на филтъра. Възникна сървърна грешка.';
$messages['deactivated'] = 'Филтърът е изключен успешно.';
$messages['activated'] = 'Филтърът е включен успешно.';
$messages['moved'] = 'Филтърът е преместен успешно.';
$messages['moveerror'] = 'Невъзможно преместване на филтъра. Възникна сървърна грешка.';
$messages['nametoolong'] = 'Името е прекалено дълго.';
$messages['namereserved'] = 'Резервирано име.';
$messages['setexist'] = 'Вече има такъв набор филтри.';
$messages['nodata'] = 'Поне една позиция трябва да е избрана!';
$messages['invaliddateformat'] = 'невалидна дата или формат на част от дата';
$messages['saveerror'] = 'Невъзможен запис на данни. Грешка при достъп до сървър.';
$messages['vacationsaved'] = 'Данните за отпуск са записани успешно.';
$messages['forwardsaved'] = 'Данните за препращане са записани успешно.';
$messages['emptyvacationbody'] = 'Липсва текст на писмо при отпуск!';
$messages['duplicate.conflict.err'] = 'Не е позволено едновременното използване на заглавен блок и уникален идентификатор.';
$messages['disabledaction'] = 'Непозволенo действие.';
$messages['lastindexempty'] = 'Необходим е индекс, когато се брои от края';
$messages['noflagset'] = 'Поне един флаг трябва да е избран.';
