<?php return array(
    'root' => array(
        'name' => 'roundcube/roundcubemail',
        'pretty_version' => '1.7.0',
        'version' => '1.7.0.0',
        'reference' => null,
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'bacon/bacon-qr-code' => array(
            'pretty_version' => 'v3.1.1',
            'version' => '3.1.1.0',
            'reference' => '4da2233e72eeecd9be3b62e0dc2cc9ed8e2e31c2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../bacon/bacon-qr-code',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dasprid/enum' => array(
            'pretty_version' => '1.0.7',
            'version' => '1.0.7.0',
            'reference' => 'b5874fa9ed0043116c72162ec7f4fb50e02e7cce',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dasprid/enum',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dflydev/dot-access-data' => array(
            'pretty_version' => 'v3.0.3',
            'version' => '3.0.3.0',
            'reference' => 'a23a2bf4f31d3518f3ecb38660c95715dfead60f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dflydev/dot-access-data',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/guzzle' => array(
            'pretty_version' => '7.10.0',
            'version' => '7.10.0.0',
            'reference' => 'b51ac707cfa420b7bfd4e4d5e510ba8008e822b4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/guzzle',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/promises' => array(
            'pretty_version' => '2.3.0',
            'version' => '2.3.0.0',
            'reference' => '481557b130ef3790cf82b713667b43030dc9c957',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/promises',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '2.9.0',
            'version' => '2.9.0.0',
            'reference' => '7d0ed42f28e42d61352a7a79de682e5e67fec884',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'kolab/net_ldap3' => array(
            'pretty_version' => 'v1.1.5',
            'version' => '1.1.5.0',
            'reference' => '5a319cf437d75aad564ce7fd076cc5423722868b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../kolab/net_ldap3',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/commonmark' => array(
            'pretty_version' => '2.8.2',
            'version' => '2.8.2.0',
            'reference' => '59fb075d2101740c337c7216e3f32b36c204218b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/commonmark',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/config' => array(
            'pretty_version' => 'v1.2.0',
            'version' => '1.2.0.0',
            'reference' => '754b3604fb2984c71f4af4a9cbe7b57f346ec1f3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/config',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'masterminds/html5' => array(
            'pretty_version' => '2.9.0',
            'version' => '2.9.0.0',
            'reference' => 'f5ac2c0b0a2eefca70b2ce32a5809992227e75a6',
            'type' => 'library',
            'install_path' => __DIR__ . '/../masterminds/html5',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mlocati/ip-lib' => array(
            'pretty_version' => '1.22.0',
            'version' => '1.22.0.0',
            'reference' => '4e40ffd3bf9989db19403d89c4d8be44b87b8a91',
            'type' => 'library',
            'install_path' => __DIR__ . '/../mlocati/ip-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nette/schema' => array(
            'pretty_version' => 'v1.3.5',
            'version' => '1.3.5.0',
            'reference' => 'f0ab1a3cda782dbc5da270d28545236aa80c4002',
            'type' => 'library',
            'install_path' => __DIR__ . '/../nette/schema',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nette/utils' => array(
            'pretty_version' => 'v4.0.10',
            'version' => '4.0.10.0',
            'reference' => '2778deb6aab136c8db4ed1f4d6e9f465ca2dbee3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../nette/utils',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/auth_sasl' => array(
            'pretty_version' => 'v1.2.0',
            'version' => '1.2.0.0',
            'reference' => 'ebf4c2c5ea190b283229f8443b866ccf34422471',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/auth_sasl',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/console_getopt' => array(
            'pretty_version' => 'v1.4.3',
            'version' => '1.4.3.0',
            'reference' => 'a41f8d3e668987609178c7c4a9fe48fecac53fa0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/console_getopt',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/crypt_gpg' => array(
            'pretty_version' => 'v1.7.0',
            'version' => '1.7.0.0',
            'reference' => 'f300cc7873e5265e5b413028f21a3e62028782e5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/crypt_gpg',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/mail_mime' => array(
            'pretty_version' => '1.10.12',
            'version' => '1.10.12.0',
            'reference' => 'd032c7c9335e96d5954ac6e93d33955f3b7246e2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/mail_mime',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/net_ldap2' => array(
            'pretty_version' => 'v2.3.0',
            'version' => '2.3.0.0',
            'reference' => '6eae6d20533469ffe1c01684923cd09f0fae3b77',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/net_ldap2',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/net_sieve' => array(
            'pretty_version' => '1.4.8',
            'version' => '1.4.8.0',
            'reference' => '345eb171c0b377e4f9f6fe9c6e532a76dfe2d754',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/net_sieve',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/net_smtp' => array(
            'pretty_version' => '1.12.2',
            'version' => '1.12.2.0',
            'reference' => '76173b3ee542a683127ab5429612b6ea519db64d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/net_smtp',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/net_socket' => array(
            'pretty_version' => 'v1.2.2',
            'version' => '1.2.2.0',
            'reference' => 'bbe6a12bb4f7059dba161f6ddd43f369c0ec8d09',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/net_socket',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/pear-core-minimal' => array(
            'pretty_version' => 'v1.10.18',
            'version' => '1.10.18.0',
            'reference' => 'c7b55789d01de0ce090d289b73f1bbd6a2f113b1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/pear-core-minimal',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/pear_exception' => array(
            'pretty_version' => 'v1.0.2',
            'version' => '1.0.2.0',
            'reference' => 'b14fbe2ddb0b9f94f5b24cf08783d599f776fff0',
            'type' => 'class',
            'install_path' => __DIR__ . '/../pear/pear_exception',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/event-dispatcher' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'dbefd12671e8a14ec7f180cab83036ed26714bb0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/event-dispatcher',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'reference' => 'bb5906edc1c324c9a05aa0873d40117941e5fa90',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '2b4765fddfe3b508ac62f829e852b1501d3f6e8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '2.0',
            'version' => '2.0.0.0',
            'reference' => '402d35bcb92c70c026d1a6a9883f06b2ead23d71',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'roundcube/plugin-installer' => array(
            'pretty_version' => '0.3.11',
            'version' => '0.3.11.0',
            'reference' => '93c5cfc660d47929aaca64585791e7e3887948ed',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../roundcube/plugin-installer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'roundcube/roundcubemail' => array(
            'pretty_version' => '1.7.0',
            'version' => '1.7.0.0',
            'reference' => null,
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'roundcube/rtf-html-php' => array(
            'pretty_version' => 'v2.2',
            'version' => '2.2.0.0',
            'reference' => 'a3432ca249b73bf24fec50114191a63ad8b1478c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../roundcube/rtf-html-php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rsky/pear-core-min' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.10.18',
            ),
        ),
        'symfony/deprecation-contracts' => array(
            'pretty_version' => 'v3.7.0',
            'version' => '3.7.0.0',
            'reference' => '50f59d1f3ca46d41ac911f97a78626b6756af35b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/deprecation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php80' => array(
            'pretty_version' => 'v1.37.0',
            'version' => '1.37.0.0',
            'reference' => 'dfb55726c3a76ea3b6459fcfda1ec2d80a682411',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php80',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php85' => array(
            'pretty_version' => 'v1.37.0',
            'version' => '1.37.0.0',
            'reference' => 'fcfa4973a9917cef23f2e38774da74a2b7d115ee',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php85',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
