<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'UTC';
$labels['tz:africa'] = 'Efrîka';
$labels['tz:africa:abidjan'] = 'Abidjan';
$labels['tz:africa:accra'] = 'Akkra';
$labels['tz:africa:addis_ababa'] = 'Addîs Ababa';
$labels['tz:africa:algiers'] = 'Cezayîr';
$labels['tz:africa:cairo'] = 'Qahîre';
$labels['tz:africa:casablanca'] = 'Kazablanka';
$labels['tz:africa:ceuta'] = 'Seûta';
$labels['tz:africa:conakry'] = 'Konakry';
$labels['tz:africa:djibouti'] = 'Jiboutî';
$labels['tz:africa:khartoum'] = 'Xartûm';
$labels['tz:africa:lome'] = 'Lome';
$labels['tz:africa:luanda'] = 'Luanda';
$labels['tz:africa:lubumbashi'] = 'Lubumbaşi';
$labels['tz:africa:lusaka'] = 'Lusaka';
$labels['tz:europe:berlin'] = 'Berlîn';
