<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Совместный доступ';
$labels['myrights'] = 'Права доступа';
$labels['username'] = 'Пользователь:';
$labels['advanced'] = 'Экспертный режим';
$labels['add'] = 'Добавить';
$labels['newuser'] = 'Добавить поле';
$labels['editperms'] = 'Редактировать права';
$labels['actions'] = 'Действия с правами доступа...';
$labels['anyone'] = 'Все пользователи (любые)';
$labels['anonymous'] = 'Гости (анонимные)';
$labels['identifier'] = 'Идентификатор';
$labels['acll'] = 'Просмотр';
$labels['aclr'] = 'Чтение сообщений';
$labels['acls'] = 'Сохранение состояния Прочитано';
$labels['aclw'] = 'Запись флагов';
$labels['acli'] = 'Вставка (копирование в...)';
$labels['aclp'] = 'Отправить';
$labels['aclc'] = 'Создание вложенных папок';
$labels['aclk'] = 'Создание вложенных папок';
$labels['acld'] = 'Удаление сообщений';
$labels['aclt'] = 'Удаление сообщений';
$labels['acle'] = 'Уничтожение сообщений';
$labels['aclx'] = 'Удаление папки';
$labels['acla'] = 'Администрировать';
$labels['acln'] = 'Комментировать сообщения';
$labels['aclfull'] = 'Полный доступ';
$labels['aclother'] = 'Другое';
$labels['aclread'] = 'Чтение';
$labels['aclwrite'] = 'Запись';
$labels['acldelete'] = 'Удаление';
$labels['shortacll'] = 'Поиск';
$labels['shortaclr'] = 'Чтение';
$labels['shortacls'] = 'Прочитано';
$labels['shortaclw'] = 'Запись';
$labels['shortacli'] = 'Вставить';
$labels['shortaclp'] = 'Отправить';
$labels['shortaclc'] = 'Создать';
$labels['shortaclk'] = 'Создать';
$labels['shortacld'] = 'Удаление';
$labels['shortaclt'] = 'Удаление';
$labels['shortacle'] = 'Уничтожение';
$labels['shortaclx'] = 'Удаление папки';
$labels['shortacla'] = 'Администрировать';
$labels['shortacln'] = 'Комментировать';
$labels['shortaclother'] = 'Другое';
$labels['shortaclread'] = 'Чтение';
$labels['shortaclwrite'] = 'Запись';
$labels['shortacldelete'] = 'Удаление';
$labels['longacll'] = 'Папка видима в списках и доступна для подписки';
$labels['longaclr'] = 'Эта папка может быть открыта для чтения';
$labels['longacls'] = 'Флаг Прочитано может быть изменен';
$labels['longaclw'] = 'Флаги и ключевые слова, кроме Прочитано и Удалено, могут быть изменены';
$labels['longacli'] = 'Сообщения могут быть записаны или скопированы в папку';
$labels['longaclp'] = 'Сообщения могут быть отправлены в эту папку';
$labels['longaclc'] = 'Подпапки могут быть созданы или переименованы прямо в этой папке';
$labels['longaclk'] = 'Подпапки могут быть созданы или переименованы прямо в этой папке';
$labels['longacld'] = 'Флаг Удалено может быть изменен';
$labels['longaclt'] = 'Флаг Удалено может быть изменен';
$labels['longacle'] = 'Сообщения могут быть уничтожены';
$labels['longaclx'] = 'Эта папка может быть переименована или удалена';
$labels['longacla'] = 'Права доступа к папке могут быть изменены';
$labels['longacln'] = 'Совместные медаданные сообщений (комментарии) могут быть изменены';
$labels['longaclfull'] = 'Полный доступ, включая управление папкой';
$labels['longaclread'] = 'Эта папка может быть открыта для чтения';
$labels['longaclwrite'] = 'Сообщения можно помечать, записывать или копировать в папку';
$labels['longacldelete'] = 'Сообщения можно удалять';
$labels['longaclother'] = 'Прочие права доступа';
$labels['ariasummaryacltable'] = 'Список прав доступа';
$labels['arialabelaclactions'] = 'Список действий';
$labels['arialabelaclform'] = 'Форма прав доступа';
$messages['deleting'] = 'Удаление прав доступа...';
$messages['saving'] = 'Сохранение прав доступа...';
$messages['updatesuccess'] = 'Права доступа успешно изменены';
$messages['deletesuccess'] = 'Права доступа успешно удалены';
$messages['createsuccess'] = 'Успешно добавлены права доступа';
$messages['updateerror'] = 'Невозможно обновить права доступа';
$messages['deleteerror'] = 'Невозможно удалить права доступа';
$messages['createerror'] = 'Невозможно добавить права доступа';
$messages['deleteconfirm'] = 'Вы уверены в том, что хотите удалить права доступа выбранных пользователей?';
$messages['norights'] = 'Права доступа не установлены!';
$messages['nouser'] = 'Не определено имя пользователя!';
