<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Настана грешка!';
$messages['loginfailed']  = 'Најавата не успеа';
$messages['cookiesdisabled'] = 'Вашиот прелистувач не прифаќа колачиња';
$messages['sessionerror'] = 'Сесијата е неважечка или е истечена';
$messages['storageerror'] = 'Поврзувањето со IMAP не успеа';
$messages['servererror'] = 'Грешка во серверот!';
$messages['servererrormsg'] = 'Грешка со серверот: $msg';
$messages['accountlocked'] = 'Премногу обиди за најава. Пробајте повторно подоцна.';
$messages['connerror'] = 'Грешка со конекција (Неуспешно конектирање со серверот)!';
$messages['dberror'] = 'Грешка со датабазата!';
$messages['windowopenerror'] = 'Popup прозорецот беше блокиран!';
$messages['requesttimedout'] = 'Сесијата за барањето истече';
$messages['errorreadonly'] = 'Операцијата неможе да се изврши. Папката може само да се прегледува.';
$messages['errornoperm'] = 'Операцијата неможе да се изврши. Немате доволно пермисии.';
$messages['erroroverquota'] = 'Операцијата неможе да се изврши. Нема слободно место.';
$messages['erroroverquotadelete'] = 'Немате повеќе слободно место. Користете SHIFT+DEL да избришете порака.';
$messages['invalidrequest'] = 'Неважечко барање! Податоците не се зачувани.';
$messages['invalidhost'] = 'Името на серверот не е валидно.';
$messages['nomessagesfound'] = 'Немате писма во ова сандаче';
$messages['mailboxempty'] = 'Поштенското сандаче е празно.';
$messages['nomessages'] = 'Нема пораки';
$messages['refreshing'] = 'Освежување...';
$messages['loading'] = 'Вчитувам...';
$messages['uploading'] = 'Ја подигам податотеката...';
$messages['attaching'] = 'Датотеката се прикачува...';
$messages['uploadingmany'] = 'Датотеките се прикачуваат...';
$messages['loadingdata'] = 'Ги вчитувам податоците...';
$messages['checkingmail'] = 'Проверувам нова пошта...';
$messages['sendingmessage'] = 'Ја испраќам пораката...';
$messages['messagesent'] = 'Пораката е успешно испратена';
$messages['savingmessage'] = 'Ја зачувувам пораката...';
$messages['messagesaved'] = 'Пораката е зачувана во Непратени';
$messages['successfullysaved'] = 'Успешно зачувано';
$messages['savingresponse'] = 'Одговорот се снима...';
$messages['deleteresponseconfirm'] = 'Избриши го одговорот?';
$messages['addedsuccessfully'] = 'Името е успешно додадено во Именикот';
$messages['contactexists'] = 'Контакт со иста адреса на Е-пошта веќе постои.';
$messages['contactnameexists'] = 'Контакт со истото име веќе постои.';
$messages['blockedimages'] = 'За да се заштити вашата приватност, сликите во оваа порака не се прикажани.';
$messages['encryptedmessage'] = 'Оваа порака е кодирана и не може да се прикаже. Жалиме!';
$messages['externalmessagedecryption'] = 'Ова е енкриптирана порака и може да се декриптира со вашата ехтензија.';
$messages['nopubkeyfor'] = 'Не е пронајден јавен клуч за $email';
$messages['nopubkeyforsender'] = 'Не е пронајден валиден јавен сертификат за идентитетот на испараќачот. Дали сакате да ја енкриптирате пораката само за примачите ?';
$messages['encryptnoattachments'] = 'Веќе прикачени додатоци не може да се енкриптираат. Ве молиме додадете ги повторно во уредникот за енкрипција.';
$messages['searchpubkeyservers'] = 'Дали сакате да ги пребарувате јавните клуч сервери за клучевите што недостасуваат?';
$messages['encryptpubkeysfound'] = 'Следниот јавен клуч е пронајден:';
$messages['nocontactsfound'] = 'Нема пронајдено имиња.';
$messages['contactnotfound'] = 'Бараното име не е пронајдено';
$messages['sendingfailed'] = 'Не упеав да го испратам писмото';
$messages['senttooquickly'] = 'Почекајте $sec секунда/и пред да го испратите писмото';
$messages['errorsavingsent'] = 'Се случи грешка при снимањето на испратената порака.';
$messages['errorsaving'] = 'Се случи грешка при снимањето.';
$messages['errormoving'] = 'Не можев да го преместам писмото';
$messages['errorcopying'] = 'Пораката (пораките) не е успешно ископрана.';
$messages['errordeleting'] = 'Не можев да го избришам писмото';
$messages['errormarking'] = 'Не можев да го обележам писмото';
$messages['deletecontactconfirm']  = 'Дали сте сигурни дека сакате да го избришете одбраното(те) име(ња)?';
$messages['deletegroupconfirm']  = 'Избриши ја изберената група?';
$messages['deletemessagesconfirm'] = 'Дали сте сигурни дека сакате да го(и) избришете обележаниот(те) писмо(а)?';
$messages['deletefolderconfirm']  = 'Дали сте сигурни дека сакате да ја избришете оваа папка?';
$messages['purgefolderconfirm']  = 'Дали сте сигурни дека сакате да ги избршете сите писма во оваа папка?';
$messages['contactdeleting'] = 'Контактот (контактите) се брише....';
$messages['groupdeleting'] = 'Бришење група...';
$messages['folderdeleting'] = 'Ја бришам папката...';
$messages['foldermoving'] = 'Ја преместувам папката...';
$messages['foldersubscribing'] = 'Претплатување папка...';
$messages['folderunsubscribing'] = 'Отпишување папка...';
$messages['formincomplete'] = 'Имате изоставено непополнети информации';
$messages['noemailwarning'] = 'Внесете валидна е-поштенска адреса';
$messages['nonamewarning']  = 'Внесете име';
$messages['nopagesizewarning'] = 'Внесете големина на страницата';
$messages['nosenderwarning'] = 'Ве молиме внесете е-пошта на праќач';
$messages['norecipientwarning'] = 'Внесете барем еден примач';
$messages['disclosedreciptitle'] = 'Бремногу јавни приматели';
$messages['nosubjectwarning']  = 'Немате внесено „Наслов“. Дали сакате да внесете?';
$messages['nosubjecttitle']  = 'Нема предмет';
$messages['nobodywarning'] = 'Писмото нема текст во него. Дали сакате да го испратите?';
$messages['notsentwarning'] = 'Пораката не е пратена и има незачувани промени. Дали сакате да ги отфрлите промените?';
$messages['restoresavedcomposedata'] = 'Претходно компонирана но не испратена порака е пронајдена.\n\n$предмет\nЗачувано: $дата\n\n Дали сакате да ја вратите оваа порака?';
$messages['nosearchname'] = 'Внесете име или е-поштенска адреса';
$messages['notuploadedwarning'] = 'Сè уште нема подигнати прилози. Почекајте или откажете го подигањето';
$messages['searchsuccessful'] = 'Пронајадени се $nr пораки';
$messages['contactsearchsuccessful'] = '$nr контакти пронајдено.';
$messages['searchnomatch'] = 'Пребарувањето не даде резлутати';
$messages['searching'] = 'Пребарувам....';
$messages['checking'] = 'Проверувам...';
$messages['stillsearching'] = 'Пребарувањето трае уште...';
$messages['nospellerrors'] = 'Нема грешки во спелувањето';
$messages['folderdeleted'] = 'Папката е успешно избришана';
$messages['foldersubscribed'] = 'Успешно претплатена папка.';
$messages['folderunsubscribed'] = 'Успешно отпишана папк.';
$messages['deletedsuccessfully'] = 'Успешно избришано';
$messages['converting'] = 'Форматирањето на писмото е отстрането...';
$messages['messageopenerror'] = 'Не можев да го вчитам писното од серверот';
$messages['filelinkerror'] = 'Прикачувањето на дадотеката е неуспешно.';
$messages['fileuploaderror'] = 'Прикачувањето е неуспешно';
$messages['filesizeerror'] = 'Подигнатата податотека го надминува ограничувањето од $size';
$messages['filecounterror'] = 'Мозе да прикачиш максимум $count датотеки одеднаш.';
$messages['msgsizeerror'] = 'Не успеа да прикачувањето на датотекта.Максималната големина на пораката ($size) е надмината.';
$messages['copysuccess'] = 'Успешно копирани $nr контакти.';
$messages['movesuccess'] = 'успешно преместени $nr контакти.';
$messages['copyerror'] = 'Не можеше да се копираат контакти.';
$messages['moveerror'] = 'Не можеше да се преместат контакти.';
$messages['sourceisreadonly'] = 'Изворот на оваа адреса неможе да се промени';
$messages['errorsavingcontact'] = 'Името неможе да се сними';
$messages['movingmessage'] = 'Пораката се преместува...';
$messages['copyingmessage'] = 'Копирање порака(и)...';
$messages['copyingcontact'] = 'Копирање контакт(и)...';
$messages['movingcontact'] = 'Преместување контакт(и)...';
$messages['deletingmessage'] = 'Бришање порака(и)...';
$messages['markingmessage'] = 'Обележување порака(и)...';
$messages['addingmember'] = 'Додавање контакт(и) во групата...';
$messages['removingmember'] = 'Отстранување контакт(и) оф групата...';
$messages['receiptsent'] = 'Известувањето е успешно пратено';
$messages['errorsendingreceipt'] = 'Известувањето не е пратено';
$messages['deleteidentityconfirm'] = 'Дали навистина сакаш да го избришеш овој идентитет?';
$messages['nodeletelastidentity'] = 'Овој идентитет неможе да се избрише, тој е последниот.';
$messages['forbiddencharacter'] = 'Името на папката содржи несоодветен формат';
$messages['selectimportfile'] = 'Изберете ја податотеката која сакате да ја прикачите';
$messages['addresswriterror'] = 'Одбраниот именик не може да се менува';
$messages['contactaddedtogroup'] = 'Успешно дададени контакти во групата.';
$messages['contactremovedfromgroup'] = 'Успешно отстранети контакти од групата.';
$messages['nogroupassignmentschanged'] = 'Не се промениле групните задачи.';
$messages['importwait'] = 'Убезувам,, почекајте...';
$messages['importformaterror'] = 'Внесувањето не успеа! Пркачената датотека не е валидна датотека за внес.';
$messages['importconfirm'] = '<b>Успешно се увезени $inserted имиња, $skipped веќе постојат и се прескокнати</b>:<p><em>$names</em></p>';
$messages['importmessagesuccess'] = 'Успешно внесени $nr пораки';
$messages['importmessageerror'] = 'Внесувањето не успеа! Прикачената датотека не е валидна порака или датотека од сандаче';
$messages['opnotpermitted'] = 'Операцијата не е дозволена';
$messages['nofromaddress'] = 'Недостасува емиал адреса во селектираниот идентитет.';
$messages['editorwarning'] = 'Менување на типот на едитор може да предизвика губење на текс форматирањето.  Дали сакате да продолжите? ';
$messages['httpreceivedencrypterror'] = 'Се појави фатална конфигурациска грешка. Веднаш контактирајте го администраторот. <b>Вашето писмо не мож.</b>';
$messages['smtpconnerror'] = 'SMTP грешка ($code): Не успеав да се поврзам со серверот';
$messages['smtpautherror'] = 'SMTP грешка: Не успееа потврдувањето';
$messages['smtpfromerror'] = 'SMTP грешка ($code): Не успеав да го поставам испраќачот „$from“ ($msg)';
$messages['smtptoerror'] = 'SMTP грешка ($code): Не успеав да го поставам примачот „$yo“ ($msg)';
$messages['smtprecipientserror'] = 'SMTP грешка: Не успеав да ја испарсирам листата на примачи';
$messages['smtperror'] = 'SMTP Error: $msg';
$messages['emailformaterror'] = 'Невалидна емаил адреса: $email ';
$messages['toomanyrecipients'] = 'Премногу примачи. Намалете го бројот на примачи на $max.';
$messages['maxgroupmembersreached'] = 'Бројот на членови на групата го надминува максимумот од $max.';
$messages['internalerror'] = 'настана внатрешна грешка. Ве молиме обидете се повторно.';
$messages['contactdelerror'] = 'Не можеше да се избришат контакт(и).';
$messages['contactdeleted'] = 'Контакт(и) беа успешно избришани.';
$messages['contactrestoreerror'] = 'Избришаниот контакт(и) не може да се врати.';
$messages['contactrestored'] = 'Контактот(ите) се успешно вратени.';
$messages['groupdeleted'] = 'Групата е успешно избришана.';
$messages['grouprenamed'] = 'Групата е успешно преименувана.';
$messages['groupcreated'] = 'Групата е успешно создадена.';
$messages['savedsearchdeleted'] = 'Зачуваните пребарувања се успешно избришани.';
$messages['savedsearchdeleteerror'] = 'Не можеше на се избришат зачуваните пребарувања ';
$messages['savedsearchcreated'] = 'Зачувани пребарувања беа успешно креирани.';
$messages['savedsearchcreateerror'] = 'Не можеше да е креираат зачувани пребарувања.';
$messages['messagedeleted'] = 'Порака(ите) беа успешно избришани.';
$messages['messagemoved'] = 'Порака(ите) беа успешно преместени.';
$messages['messagemovedtotrash'] = 'Порака(ите) беа успешно преместени во ѓубрето.';
$messages['messagecopied'] = 'Порака(ите) беа успешно копирани.';
$messages['messagemarked'] = 'Порака(ите) беа успешно обележани.';
$messages['autocompletechars'] = 'Внесете барем $min карактери за автоматско завршување.';
$messages['autocompletemore'] = 'Пронајдени се повеќе исти внесови. Ве молиме внесете повеќе знаци.';
$messages['namecannotbeempty'] = 'Името не може да биде празно.';
$messages['nametoolong'] = 'Името е предолго.';
$messages['namedotforbidden'] = 'Името на папката не може да почнува со точка.';
$messages['folderupdated'] = 'Папката е успешно ажурирана.';
$messages['foldercreated'] = 'Папката е успешно креирана.';
$messages['invalidimageformat'] = 'Невалиден формат на слика.';
$messages['mispellingsfound'] = 'Детектирана е правописна грешка во пораката.';
$messages['parentnotwritable'] = 'Невозможно да се креира/премести папката во селектираната папка родител. Нема права на пристап.';
$messages['messagetoobig'] = 'Делот со пораката е преголем за да се процесира.';
$messages['noscriptwarning'] = 'Прдупредување: Овој webmail сервис бара Javascript! За да го користите ве молиме вклучете го Javascript во поставувањата на вашиот пребарувач.';
$messages['messageissent'] = 'Оваа порака беше пратена, но сеуште не е зачувана. Дали сакате да ја зачувате сега ? ';
$messages['errnotfound'] = 'Датотеката не е најдена';
$messages['errnotfoundexplain'] = 'Бараниот ресурс не беше пронајден!';
$messages['errfailedrequest'] = 'Неуспешно барање';
$messages['errauthorizationfailed'] = 'Овластувањето не успеа';
$messages['errunauthorizedexplain'] = 'Не може да се потврди дали вие се обвластени да пристапите до овој сервис! ';
$messages['errrequestcheckfailed'] = 'Барањето за проверка не успеа';
$messages['errcsrfprotectionexplain'] = "За ваша заштита, пристапот до овој ресурс е обезбеден против CSRF.\n ако го видите ова, вие најверојатно не сте се одјавиле пред напуштање на веб апликацијата. \n\n Сега е потребна човечка интеракција за да продолжите.";
$messages['errcontactserveradmin'] = 'Ве молиме контактирајте го вашиот сервер администратор.';
$messages['clicktoresumesession'] = 'Кликнете овде за да продолжите со претходната сесија';
$messages['errcomposesession'] = 'Грешка при компонирање сесија';
$messages['errcomposesessionexplain'] = 'Бараната композиција на сесија не е најдена.';
$messages['clicktocompose'] = 'Кликнете овде за да компонирате нова порака';
