<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'שיתוף';
$labels['myrights'] = 'זכויות גישה';
$labels['username'] = 'משתמש:';
$labels['advanced'] = 'מצב מתקדם';
$labels['add'] = 'הוספה';
$labels['newuser'] = 'הוסף ערך';
$labels['editperms'] = 'עריכת הרשאות';
$labels['actions'] = 'פעולות על זכויות גישה...';
$labels['anyone'] = 'כל המשתמשים (כל אחד)';
$labels['anonymous'] = 'אורחים (אנונימי)';
$labels['identifier'] = 'מזהה';
$labels['acll'] = 'חיפוש';
$labels['aclr'] = 'קריאת הודעות';
$labels['acls'] = 'שמירה על סטטוס נראה';
$labels['aclw'] = 'דגלי כתיבה';
$labels['acli'] = 'הוספה בין ערכים (העתקה לתוך)';
$labels['aclp'] = 'פרסום';
$labels['aclc'] = 'יצירת תת־תיקיות';
$labels['aclk'] = 'יצירת תת־תיקיות';
$labels['acld'] = 'מחיקת הודעות';
$labels['aclt'] = 'מחיקת הודעות';
$labels['acle'] = 'ניקוי רשומות שבוטלו';
$labels['aclx'] = 'מחיקת תיקיה';
$labels['acla'] = 'מנהל';
$labels['acln'] = 'הוספה של הערת תיוג להודעות';
$labels['aclfull'] = 'שליטה מלאה';
$labels['aclother'] = 'אחר';
$labels['aclread'] = 'קריאה';
$labels['aclwrite'] = 'כתיבה';
$labels['acldelete'] = 'מחיקה';
$labels['shortacll'] = 'חיפוש';
$labels['shortaclr'] = 'קריאה';
$labels['shortacls'] = 'להשאיר';
$labels['shortaclw'] = 'כתיבה';
$labels['shortacli'] = 'הוספה בין ערכים';
$labels['shortaclp'] = 'פרסום';
$labels['shortaclc'] = 'יצירה';
$labels['shortaclk'] = 'יצירה';
$labels['shortacld'] = 'מחיקה';
$labels['shortaclt'] = 'מחיקה';
$labels['shortacle'] = 'ניקוי רשומות שבוטלו';
$labels['shortaclx'] = 'מחיקת תיקיה';
$labels['shortacla'] = 'מנהל';
$labels['shortacln'] = 'הוספה של הערת תיוג';
$labels['shortaclother'] = 'אחר';
$labels['shortaclread'] = 'קריאה';
$labels['shortaclwrite'] = 'כתיבה';
$labels['shortacldelete'] = 'מחיקה';
$labels['longacll'] = 'התיקיה תראה ברשימות וניתן יהיה להרשם אליה';
$labels['longaclr'] = 'ניתן לפתוח את התיקיה ולקרוא בה';
$labels['longacls'] = 'ניתן לשנות דגל נראה בהודעות';
$labels['longaclw'] = 'ניתן לשנות דגלים ומילות מפתח בהודעות, למעט נראה ונמחק';
$labels['longacli'] = 'ניתן לכתוב הודעות לתיקיה או למוחקן';
$labels['longaclp'] = 'ניתן לפרסם הודעות לתוך תיקיה זו';
$labels['longaclc'] = 'ניתן ליצור (או לשנות שם) תיקיות, ישירות תחת תיקיה זו';
$labels['longaclk'] = 'ניתן ליצור (או לשנות שם) תיקיות, ישירות תחת תיקיה זו';
$labels['longacld'] = 'ניתן לשנות דגל נמחק של הודעות';
$labels['longaclt'] = 'ניתן לשנות דגל נמחק של הודעות';
$labels['longacle'] = 'ניתן לנקות הודעות שסומנו כמבוטלות';
$labels['longaclx'] = 'ניתן למחוק תיקיה זו או לשנות שמה';
$labels['longacla'] = 'ניתן לשנות זכויות גישה של תיקיה זו';
$labels['longacln'] = 'ניתן לשנות הערות תיוג המשותפות להודעות';
$labels['longaclfull'] = 'שליטה מלאה כולל ניהול התיקיה';
$labels['longaclread'] = 'ניתן לפתוח את התיקיה ולקרוא בה';
$labels['longaclwrite'] = 'ניתן לסמן, לכתוב או להעתיק הודעות לתיקיה זו';
$labels['longacldelete'] = 'ניתן למחוק הודעות';
$labels['longaclother'] = 'זכויות גישה אחרות';
$labels['ariasummaryacltable'] = 'רשימת זכויות גישה';
$labels['arialabelaclactions'] = 'רשימת פעולות';
$labels['arialabelaclform'] = 'טופס זכויות גישה';
$messages['deleting'] = 'זכויות גישה נמחקות...';
$messages['saving'] = 'זכויות גישה נשמרות...';
$messages['updatesuccess'] = 'זכויות גישה שונו בהצלחה';
$messages['deletesuccess'] = 'זכויות גישה נמחקו בהצלחה';
$messages['createsuccess'] = 'זכויות גישה נוספו בהצלחה';
$messages['updateerror'] = 'לא ניתן לעדכן הרשאות גישה';
$messages['deleteerror'] = 'לא ניתן למחוק זכויות גישה';
$messages['createerror'] = 'לא ניתן להוסיף זכויות גישה';
$messages['deleteconfirm'] = 'האם ודאי שברצונך להסיר זכויות גישה של המשתמש(ים) שנבחרו?';
$messages['norights'] = 'לא צוינו זכויות גישה כלשהן !';
$messages['nouser'] = 'לא צוין שם משתמש כלשהו!';
