<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'فیلترها';
$labels['filtername'] = 'نام فیلتر';
$labels['newfilter'] = 'فیلتر جدید';
$labels['filteranyof'] = 'تطبیق با هر کدام از رول های زیر';
$labels['filterany'] = 'تمام پیام ها';
$labels['filtercontains'] = 'شامل';
$labels['filteris'] = 'مساوی با';
$labels['filterunder'] = 'زیر';
$labels['filterover'] = 'بالای';
$labels['addrule'] = 'افزودن نقش';
$labels['delrule'] = 'حذف نقش';
$labels['messagereply'] = 'پاسخ توسط پیام';
$labels['messagedelete'] = 'حذف پیام';
$labels['add'] = 'افزودن';
$labels['del'] = 'حذف';
$labels['sender'] = 'فرستنده';
$labels['recipient'] = 'گیرنده';
$labels['days'] = 'روز';
$labels['filtersets'] = 'مجموعه فیلتر';
$labels['filterdef'] = 'تعریف فیلتر';
$labels['active'] = 'فعال';
$labels['none'] = 'هیچ کدام';
$labels['flagread'] = 'خواندن';
$labels['flagdeleted'] = 'حذف شد';
$labels['flagflagged'] = 'نشانه گذاری شده';
$labels['flagdraft'] = 'پیش نویس';
$labels['varlength'] = 'طول';
$labels['notifyimportancenormal'] = 'عادی';
$labels['notifymethodmailto'] = 'ایمیل';
$labels['nextstep'] = 'مرحله بعدی';
$labels['...'] = '...';
$labels['currdate'] = 'تاریخ کنونی';
$labels['datetest'] = 'تاریخ';
$labels['dateheader'] = 'سرایند:';
$labels['year'] = 'سال';
$labels['month'] = 'ماه';
$labels['day'] = 'روز';
$labels['second'] = 'ثانیه';
$labels['advancedopts'] = 'انتخاب های پیشرفته';
$labels['body'] = 'متن پیام';
$labels['address'] = 'آدرس';
$labels['envelope'] = 'پاکت نامه';
$labels['modifier'] = 'ویرایش کننده:';
$labels['text'] = 'متن';
$labels['contenttype'] = 'نوع محتوا';
$labels['allparts'] = 'همه';
$labels['domain'] = 'دامنه';
$labels['localpart'] = 'جز محلی';
$labels['user'] = 'کاربر';
$labels['detail'] = 'جزئیات';
$labels['comparator'] = 'مقایسه کننده:';
$labels['default'] = 'پیش فرض';
$labels['index'] = 'اندیس';
$labels['spamtestequals'] = 'مساوی با';
$labels['vacation.reply'] = 'پیام پاسخ';
$labels['vacation.advanced'] = 'تنظیمات پیشرفته';
$labels['vacation.subject'] = 'موضوع';
$labels['vacation.body'] = 'متن پیام';
$labels['vacation.status'] = 'وضعیت';
$labels['vacation.on'] = 'فعال';
$labels['vacation.off'] = 'غیرفعال';
$labels['forward.on'] = 'فعال';
$labels['forward.off'] = 'غیرفعال';
$labels['arialabelfilterform'] = 'خصوصیات فیلترها';
$labels['ariasummaryfilterslist'] = 'لیست فیلترها';
$labels['duplicate.header'] = 'سرایند:';
$messages['filterdeleted'] = 'فیلتر با موفقیت حذف شد.';
$messages['filtersaved'] = 'فیلتر با موفقیت ذخیره شد.';
$messages['deactivated'] = 'فیلتر(ها) با موفقیت غیر فعال شدند';
$messages['nametoolong'] = 'نام بسیار بلند است.';
$messages['namereserved'] = 'نام  رزرو شده.';
