<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/csv2vcard.inc                                     |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['Aniversário'] = 'anniversary';
$map['Nome do Assistente'] = 'assistant';
$map['Fone do Assistente'] = 'phone:assistant';
$map['Aniversário'] = 'birthday';
$map['Cidade comercial'] = 'locality:work';
$map['Região/País comercial'] = 'country:work';
$map['Fax comercial'] = 'phone:workfax';
$map['Fone comercial'] = 'phone:work';
$map['Fone comercial 2'] = 'phone:work2';
$map['Código postal comercial'] = 'zipcode:work';
$map['Estado comercial'] = 'region:work';
$map['Rua comercial'] = 'street:work';
$map['Fone do carro'] = 'phone:car';
$map['Categorias'] = 'groups';
$map['Empresa'] = 'organization';
$map['Departamento'] = 'department';
$map['Endereço de E-mail'] = 'email:other';
$map['Endereço de E-mail 2'] = 'email:other';
$map['Endereço de E-mail 3'] = 'email:other';
$map['Primeiro nome'] = 'firstname';
$map['Gênero'] = 'gender';
$map['Cidade de casa'] = 'locality:home';
$map['Região/País de casa'] = 'country:home';
$map['Fax de casa'] = 'phone:homefax';
$map['Fone de casa'] = 'phone:home';
$map['Fone de casa 2'] = 'phone:home2';
$map['Código Postal de casa'] = 'zipcode:home';
$map['Estado de casa'] = 'region:home';
$map['Rua de casa'] = 'street:home';
$map['Cargo'] = 'jobtitle';
$map['Último nome'] = 'surname';
$map['Nome do gerente'] = 'manager';
$map['Nome do meio'] = 'middlename';
$map['Celular'] = 'phone:mobile';
$map['Notas'] = 'notes';
$map['Outra cidade'] = 'locality:other';
$map['Outro País/Região'] = 'country:other';
$map['Outro Fax'] = 'phone:other';
$map['Outro Fone'] = 'phone:other';
$map['Outro Código Postal'] = 'zipcode:other';
$map['Outro Estado'] = 'region:other';
$map['Outra Rua'] = 'street:other';
$map['Pager'] = 'phone:pager';
$map['Fone Primario'] = 'phone:main';
$map['Spouse'] = 'spouse';
$map['Sufixo'] = 'suffix';
$map['Título'] = 'prefix';
$map['Página Web'] = 'website:homepage';
$map['Dia de nascimento'] = 'birthday-d';
$map['Mês de nascimento'] = 'birthday-m';
$map['Ano de nascimento'] = 'birthday-y';
$map['Mostrar nome'] = 'name';
$map['Número de Fax'] = 'phone:homefax';
$map['Endereço de casa'] = 'street:home';
$map['País de casa'] = 'country:home';
$map['CEP de casa'] = 'zipcode:home';
$map['Celular'] = 'phone:mobile';
$map['Apelido'] = 'nickname';
$map['Organização'] = 'organization';
$map['Número do Pager'] = 'phone:pager';
$map['E-mail primário'] = 'email:home';
$map['E-mail secundário'] = 'email:other';
$map['Web Page 1'] = 'website:homepage';
$map['Web Page 2'] = 'website:other';
$map['Fone de trabalho'] = 'phone:work';
$map['Endereço de trabalho'] = 'street:work';
$map['País de trabalho'] = 'country:work';
$map['CEP de trabalho'] = 'zipcode:work';
$map['Data de nascimento'] = 'birthday';
$map['E-mail'] = 'email:home';
$map['Celular pessoal'] = 'phone:mobile';
$map['CEP pessoal'] = 'zipcode:home';
$map['Informações'] = 'notes';
$map['Foto do Usuário'] = 'photo';
$map['URL'] = 'website:homepage';
$map['Cidade de trabalho'] = 'locality:work';
$map['Empresa'] = 'organization';
$map['Departamento'] = 'department';
$map['Fax'] = 'phone:workfax';
$map['Celular de trabalho'] = 'phone:other';
$map['Estado'] = 'region:work';
$map['Cargo'] = 'jobtitle';
$map['CEP'] = 'zipcode:work';
