<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Dielen';
$labels['myrights'] = 'Tagong Rjochten';
$labels['username'] = 'Brûker:';
$labels['advanced'] = 'Avansearre modus';
$labels['add'] = 'Tafoegje';
$labels['newuser'] = 'Ynfier taheakje';
$labels['editperms'] = 'Bewurkje tagongsrjochten';
$labels['actions'] = 'Tagong aksjes...';
$labels['anyone'] = 'Alle brûkers (eltsenien)';
$labels['anonymous'] = 'Gasten (anonym)';
$labels['identifier'] = 'Identifikator';
$labels['acll'] = 'Opsykje';
$labels['aclr'] = 'Lêzen berjochten';
$labels['acls'] = 'Bewarje Sjoen steat';
$labels['aclw'] = 'Skriuw flaggen';
$labels['acli'] = 'Ynfoegje (Kopiearje yn)';
$labels['aclp'] = 'Pleatse';
$labels['aclc'] = 'Underlizzende mappen oanmeitsje';
$labels['aclk'] = 'Underlizzende mappen oanmeitsje';
$labels['acld'] = 'Berjochten wiskje';
$labels['aclt'] = 'Berjochten wiskje';
$labels['acle'] = 'Level';
$labels['aclx'] = 'Map ferwiderje';
$labels['acla'] = 'Beheare';
$labels['acln'] = 'Annotate berjochten';
$labels['aclfull'] = 'Folsleine kontrôle';
$labels['aclother'] = 'Oars';
$labels['aclread'] = 'Lêze';
$labels['aclwrite'] = 'Skriuwe';
$labels['acldelete'] = 'Ferwiderje';
$labels['shortacll'] = 'Opsykje';
$labels['shortaclr'] = 'Lêze';
$labels['shortacls'] = 'Hâlde';
$labels['shortaclw'] = 'Skriuwe';
$labels['shortacli'] = 'Ynfoegje';
$labels['shortaclp'] = 'Pleatse';
$labels['shortaclc'] = 'Oanmeitsje';
$labels['shortaclk'] = 'Oanmeitsje';
$labels['shortacld'] = 'Ferwiderje';
$labels['shortaclt'] = 'Ferwiderje';
$labels['shortacle'] = 'Level';
$labels['shortaclx'] = 'Map ferwiderje';
$labels['shortacla'] = 'Beheare';
$labels['shortaclother'] = 'Oars';
$labels['shortaclread'] = 'Lêze';
$labels['shortaclwrite'] = 'Skriuwe';
$labels['shortacldelete'] = 'Ferwiderje';
