<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Benvenite a $product';
$labels['username'] = 'Nomine de usator';
$labels['password'] = 'Contrasigno';
$labels['server'] = 'Servitor';
$labels['login'] = 'Aperir session';
$labels['oauthlogin'] = 'Aperir session con $provider';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Clauder session';
$labels['mail'] = 'E-mail';
$labels['settings'] = 'Parametros';
$labels['addressbook'] = 'Adressario';
$labels['darkmode'] = 'Modo obscur';
$labels['lightmode'] = 'Modo clar';
$labels['inbox'] = 'Cassa de entrata';
$labels['drafts'] = 'Versiones provisori';
$labels['sent'] = 'Inviate';
$labels['trash'] = 'Corbe a papiro';
$labels['junk'] = 'Posta indesirate';
$labels['show_real_foldernames'] = 'Monstrar nomines real pro le dossiers special';
$labels['subject'] = 'Subjecto';
$labels['from'] = 'De';
$labels['sender'] = 'Expeditor';
$labels['to'] = 'A';
$labels['cc'] = 'Copia';
$labels['bcc'] = 'Copia occultate';
$labels['replyto'] = 'Responder a';
$labels['followupto'] = 'Continuar discussion in';
$labels['date'] = 'Data';
$labels['size'] = 'Dimension';
$labels['priority'] = 'Prioritate';
$labels['organization'] = 'Organisation';
$labels['readstatus'] = 'Stato de lectura';
$labels['listoptions'] = 'Optiones de lista…';
$labels['listoptionstitle'] = 'Optiones de lista';
$labels['mailboxlist'] = 'Dossiers';
$labels['messagesfromto'] = 'Messages $from a $to de $count';
$labels['threadsfromto'] = 'Topicos $from a $to de $count';
$labels['messagenrof'] = 'Message $nr de $count';
$labels['fromtoshort'] = '$from – $to de $count';
$labels['copy'] = 'Copiar';
$labels['move'] = 'Displaciar';
$labels['moveto'] = 'Displaciar a…';
$labels['copyto'] = 'Copiar a…';
$labels['download'] = 'Discargar';
$labels['open'] = 'Aperir';
$labels['showattachment'] = 'Monstrar';
$labels['showanyway'] = 'Monstrar lo in omne caso';
$labels['filename'] = 'Nomine de file';
$labels['filesize'] = 'Dimension del file';
$labels['addtoaddressbook'] = 'Adder al adressario';
$labels['sun'] = 'dom';
$labels['mon'] = 'lun';
$labels['tue'] = 'mar';
$labels['wed'] = 'mer';
$labels['thu'] = 'jov';
$labels['fri'] = 'ven';
$labels['sat'] = 'sab';
$labels['sunday'] = 'dominica';
$labels['monday'] = 'lunedi';
$labels['tuesday'] = 'martedi';
$labels['wednesday'] = 'mercuridi';
$labels['thursday'] = 'jovedi';
$labels['friday'] = 'venerdi';
$labels['saturday'] = 'sabbato';
$labels['jan'] = 'jan';
$labels['feb'] = 'feb';
$labels['mar'] = 'mar';
$labels['apr'] = 'apr';
$labels['may'] = 'mai';
$labels['jun'] = 'jun';
$labels['jul'] = 'jul';
$labels['aug'] = 'aug';
$labels['sep'] = 'sep';
$labels['oct'] = 'oct';
$labels['nov'] = 'nov';
$labels['dec'] = 'dec';
$labels['longjan'] = 'januario';
$labels['longfeb'] = 'februario';
$labels['longmar'] = 'martio';
$labels['longapr'] = 'april';
$labels['longmay'] = 'mai';
$labels['longjun'] = 'junio';
$labels['longjul'] = 'julio';
$labels['longaug'] = 'augusto';
$labels['longsep'] = 'septembre';
$labels['longoct'] = 'octobre';
$labels['longnov'] = 'novembre';
$labels['longdec'] = 'decembre';
$labels['today'] = 'hodie';
$labels['refresh'] = 'Refrescar';
$labels['checkmail'] = 'Verificar si il ha nove messages';
$labels['compose'] = 'Componer';
$labels['writenewmessage'] = 'Crear un nove message';
$labels['reply'] = 'Responder';
$labels['replytomessage'] = 'Responder al expeditor';
$labels['replytoallmessage'] = 'Responder al lista o al expeditor e tote le destinatarios';
$labels['replyall'] = 'Responder a totes';
$labels['replylist'] = 'Responder al lista';
$labels['forward'] = 'Retransmitter';
$labels['forwardinline'] = 'Retransmitter in le texto del message';
$labels['forwardattachment'] = 'Retransmitter como annexo';
$labels['forwardmessage'] = 'Retransmitter le message';
$labels['bouncemsg'] = 'Retransmitter (message retrosaltate)';
$labels['bounce'] = 'Retransmitter';
$labels['deletemessage'] = 'Deler messsage';
$labels['undeletemessage'] = 'Restaurar message';
$labels['movemessagetotrash'] = 'Jectar message in corbe';
$labels['printmessage'] = 'Imprimer iste message';
$labels['previousmessage'] = 'Monstrar previe message';
$labels['firstmessage'] = 'Monstrar prime message';
$labels['nextmessage'] = 'Monstrar proxime message';
$labels['lastmessage'] = 'Monstrar ultime message';
$labels['backtolist'] = 'Retornar al lista de messages';
$labels['viewsource'] = 'Monstrar fonte';
$labels['mark'] = 'Marcar';
$labels['markmessages'] = 'Marcar messages';
$labels['markread'] = 'Como legite';
$labels['markunread'] = 'Como non legite';
$labels['markflagged'] = 'Como signalate';
$labels['markunflagged'] = 'Como non signalate';
$labels['markundeleted'] = 'Como non delite';
$labels['markasread'] = 'Marcar como legite';
$labels['markasunread'] = 'Marcar como non legite';
$labels['markasflagged'] = 'Marcar como signalate';
$labels['markasunflagged'] = 'Marcar como non signalate';
$labels['moreactions'] = 'Altere actiones…';
$labels['markallread'] = 'Marcar tote messages como legite';
$labels['folders-cur'] = 'Solmente le dossier seligite';
$labels['folders-sub'] = 'Le dossier seligite e su subdossieres';
$labels['folders-all'] = 'Tote le dossieres';
$labels['more'] = 'Plus';
$labels['back'] = 'Retornar';
$labels['options'] = 'Optiones';
$labels['composeoptions'] = 'Optiones de composition';
$labels['optionsandattachments'] = 'Optiones e annexos';
$labels['actions'] = 'Actiones';
$labels['first'] = 'Prime';
$labels['last'] = 'Ultime';
$labels['previous'] = 'Previe';
$labels['next'] = 'Proxime';
$labels['select'] = 'Seliger';
$labels['selection'] = 'Selection';
$labels['all'] = 'Totes';
$labels['none'] = 'Nulle';
$labels['currpage'] = 'Pagina actual';
$labels['isread'] = 'Legite';
$labels['unread'] = 'Non legite';
$labels['flagged'] = 'Signalate';
$labels['unflagged'] = 'Non signalate';
$labels['unanswered'] = 'Non respondite';
$labels['withattachment'] = 'Con annexo';
$labels['deleted'] = 'Delite';
$labels['undeleted'] = 'Non delite';
$labels['replied'] = 'Respondite';
$labels['forwarded'] = 'Reinviate';
$labels['invert'] = 'Inverter';
$labels['filter'] = 'Filtro';
$labels['list'] = 'Lista';
$labels['threads'] = 'Topicos';
$labels['expand-all'] = 'Displicar totes';
$labels['expand-unread'] = 'Displicar non legite';
$labels['collapse-all'] = 'Plicar totes';
$labels['threaded'] = 'Vista arborescente';
$labels['showunread'] = 'Monstrar messages non legite';
$labels['autoexpand_threads'] = 'Displicar topicos de messages';
$labels['do_expand'] = 'tote le topicos';
$labels['expand_only_unread'] = 'solmente con messages non legite';
$labels['fromto'] = 'De/A';
$labels['flag'] = 'Signalar';
$labels['attachment'] = 'Annexo';
$labels['nonesort'] = 'Nulle';
$labels['sentdate'] = 'Data de invio';
$labels['arrival'] = 'Data de arrivata';
$labels['asc'] = 'ascendente';
$labels['desc'] = 'descendente';
$labels['listcolumns'] = 'Columnas de lista';
$labels['listsorting'] = 'Columna clave';
$labels['listorder'] = 'Ordinamento';
$labels['listmode'] = 'Visualisation de lista';
$labels['lmode'] = 'Modo de lista';
$labels['layout'] = 'Disposition';
$labels['layoutwidescreen'] = 'Schermo large';
$labels['layoutdesktop'] = 'Scriptorio';
$labels['layoutlist'] = 'Lista';
$labels['layoutwidescreendesc'] = 'Schermo large (3 columnas)';
$labels['layoutdesktopdesc'] = 'Scriptorio (lista large e previsualisation de posta sub illo)';
$labels['layoutlistdesc'] = 'Lista (sin previsualisation de posta)';
$labels['folderactions'] = 'Actiones de dossier…';
$labels['compact'] = 'Compacte';
$labels['empty'] = 'Vacue';
$labels['importmessages'] = 'Importar messages';
$labels['mailimportdesc'] = 'Files de posta pote esser incargate in formato <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> o <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> .';
$labels['mailimportzip'] = 'Plure files pote esser comprimite in archivos zip.';
$labels['quota'] = 'Spatio occupate';
$labels['unknown'] = 'incognite';
$labels['unlimited'] = 'sin limite';
$labels['quotatype'] = 'Typo de quota';
$labels['quotatotal'] = 'Limite';
$labels['quotaused'] = 'Usate';
$labels['quotastorage'] = 'Spatio de immagazinage';
$labels['quotamessage'] = 'Numero de messages';
$labels['shortheaderdate'] = 'Le $date';
$labels['shortheaderto'] = 'A $to le $date';
$labels['shortheaderfrom'] = 'De $from le $date';
$labels['quicksearch'] = 'Recerca rapide';
$labels['searchplaceholder'] = 'Cercar…';
$labels['resetsearch'] = 'Reinitialisar recerca';
$labels['searchmod'] = 'Modificatores de recerca';
$labels['msgtext'] = 'Message complete';
$labels['body'] = 'Texto';
$labels['type'] = 'Typo';
$labels['namex'] = 'Nomine';
$labels['searchscope'] = 'Ambito';
$labels['currentfolder'] = 'Dossier actual';
$labels['subfolders'] = 'Iste e subdossiers';
$labels['allfolders'] = 'Tote le dossiers';
$labels['searchinterval-1W'] = 'plus ancian que un septimana';
$labels['searchinterval-1M'] = 'plus ancian que un mense';
$labels['searchinterval-1Y'] = 'plus ancian que un anno';
$labels['searchinterval1W'] = 'plus juvene que un septimana';
$labels['searchinterval1M'] = 'plus ancian que un mense';
$labels['searchinterval1Y'] = 'plus juvene que un anno';
$labels['openinextwin'] = 'Aperir in nove fenestra';
$labels['emlsave'] = 'Discargar (.eml)';
$labels['changeformattext'] = 'Monstrar in formato de texto simple';
$labels['changeformathtml'] = 'Monstrar in formato HTML';
$labels['editasnew'] = 'Modificar como nove';
$labels['send'] = 'Inviar';
$labels['sendmessage'] = 'Inviar message';
$labels['savemessage'] = 'Salveguardar como version provisori';
$labels['addattachment'] = 'Annexar un file';
$labels['charset'] = 'Codification de characteres';
$labels['editortype'] = 'Typo de editor';
$labels['returnreceipt'] = 'Confirmation de reception';
$labels['dsn'] = 'Notification de stato de livration';
$labels['keepformatting'] = 'Mantener formatation';
$labels['mailreplyintro'] = 'Le $date, $sender ha scribite:';
$labels['originalmessage'] = 'Message original';
$labels['selectimage'] = 'Seliger imagine';
$labels['addimage'] = 'Adder imagine';
$labels['selectmedia'] = 'Seliger film';
$labels['addmedia'] = 'Adder film';
$labels['encrypt'] = 'Cryptar';
$labels['encryptmessage'] = 'Cryptar message';
$labels['encryptmessagemailvelope'] = 'Cryptar message con Mailvelope';
$labels['importpubkeys'] = 'Importar claves public';
$labels['encryptedsendialog'] = 'A inviar message cryptate';
$labels['encryptandsign'] = 'Cryptar e signar';
$labels['keyid'] = 'ID del clave';
$labels['keylength'] = 'Bits';
$labels['keyexpired'] = 'Expirate';
$labels['keyrevoked'] = 'Revocate';
$labels['bccinstead'] = 'Usar "Copia occultate"';
$labels['insert'] = 'Inserer';
$labels['insertcontact'] = 'Inserer contacto(s)';
$labels['recipient'] = 'Destinatario';
$labels['recipientedit'] = 'Modificar destinatario';
$labels['editidents'] = 'Modificar identitates';
$labels['spellcheck'] = 'Orthographia';
$labels['checkspelling'] = 'Verificar orthographia';
$labels['resumeediting'] = 'Continuar le modification';
$labels['revertto'] = 'Reverter a';
$labels['restore'] = 'Restaurar';
$labels['restoremessage'] = 'Restaurar le message?';
$labels['ignore'] = 'Ignorar';
$labels['responses'] = 'Responsas';
$labels['insertresponse'] = 'Inserer un responsa';
$labels['manageresponses'] = 'Gerer responsas';
$labels['newresponse'] = 'Crear nove responsa';
$labels['addresponse'] = 'Adder responsa';
$labels['editresponse'] = 'Modificar responsa';
$labels['editresponses'] = 'Modificar responsas';
$labels['responsename'] = 'Nomine';
$labels['responsetext'] = 'Texto del responsa';
$labels['attach'] = 'Annexar';
$labels['attachments'] = 'Annexos';
$labels['upload'] = 'Incargar';
$labels['uploadprogress'] = '$percent ($current de $total)';
$labels['close'] = 'Clauder';
$labels['messageoptions'] = 'Optiones de message…';
$labels['togglecomposeoptions'] = 'Alternar optiones de composition';
$labels['attachmentrename'] = 'Renominar annexo';
$labels['low'] = 'Basse';
$labels['lowest'] = 'Minimal';
$labels['normal'] = 'Normal';
$labels['high'] = 'Alte';
$labels['highest'] = 'Maximal';
$labels['nosubject'] = '(sin subjecto)';
$labels['showimages'] = 'Monstrar imagines';
$labels['allow'] = 'Permitter';
$labels['alwaysshow'] = 'Sempre monstrar imagines de $sender';
$labels['alwaysallow'] = 'Sempre permitter de $sender';
$labels['isdraft'] = 'Iste es un message provisori.';
$labels['andnmore'] = '$nr alteres…';
$labels['details'] = 'Detalios';
$labels['summary'] = 'Summario';
$labels['headers'] = 'Capites';
$labels['allheaders'] = 'Tote le capites…';
$labels['togglemoreheaders'] = 'Monstrar plus capites de message';
$labels['togglefullheaders'] = 'Monstrar/celar capites crude';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Texto simple';
$labels['savesentmessagein'] = 'Salveguardar message inviate in';
$labels['dontsave'] = 'non salveguardar';
$labels['maxuploadsize'] = 'Le dimension maximal de iste file es $size';
$labels['addcc'] = 'Adder "Copia"';
$labels['addbcc'] = 'Adder "Copia occultate"';
$labels['addreplyto'] = 'Adder "Responder a:"';
$labels['addfollowupto'] = 'Adder "Continuar discussion in:"';
$labels['sendreceipt'] = 'Inviar recepta de lectura?';
$labels['mdnrequest'] = 'Le expeditor de iste message ha demandate de reciper un notification quando tu lege iste message. Vole tu notificar le expeditor?';
$labels['receiptread'] = 'Confirmation de reception (legite)';
$labels['yourmessage'] = 'Isto es un confirmation del reception de tu message';
$labels['receiptnote'] = 'Nota ben: Iste recepta solmente confirma que le message ha essite visualisate sur le computator del destinatario. Il non ha garantia que le destinatario ha legite o comprendite le contento del message.';
$labels['sendalwaysto'] = 'Sempre inviar a $email';
$labels['zoomin'] = 'Zoom avante';
$labels['zoomout'] = 'Zoom retro';
$labels['rotate'] = 'otar';
$labels['increaseimage'] = 'Augmentar le dimension del imagine';
$labels['decreaseimage'] = 'Diminuer le dimension del imagine';
$labels['rotateimage'] = 'Rotar imagine';
$labels['showtools'] = 'Monstrar instrumentos de imagines';
$labels['hidetools'] = 'Celar instrumentos de imagines';
$labels['name'] = 'Nomine de presentation';
$labels['firstname'] = 'Prenomine';
$labels['surname'] = 'Nomine de familia';
$labels['middlename'] = 'Secunde nomine';
$labels['nameprefix'] = 'Prefixo';
$labels['namesuffix'] = 'Suffixo';
$labels['nickname'] = 'Pseudonymo';
$labels['jobtitle'] = 'Titulo professional';
$labels['department'] = 'Departimento';
$labels['gender'] = 'Sexo';
$labels['maidenname'] = 'Nomine de puera';
$labels['email'] = 'E-mail';
$labels['phone'] = 'Telephono';
$labels['address'] = 'Adresse';
$labels['street'] = 'Strata';
$labels['locality'] = 'Citate';
$labels['zipcode'] = 'Codice postal';
$labels['region'] = 'Provincia o stato';
$labels['country'] = 'Pais';
$labels['birthday'] = 'Data de nascentia';
$labels['anniversary'] = 'Anniversario';
$labels['website'] = 'Sito web';
$labels['instantmessenger'] = 'MI';
$labels['notes'] = 'Notas';
$labels['male'] = 'masculin';
$labels['female'] = 'feminin';
$labels['manager'] = 'Gerente';
$labels['assistant'] = 'Assistente';
$labels['spouse'] = 'Sposo/a';
$labels['allfields'] = 'Omne campos';
$labels['search'] = 'Cercar';
$labels['searchresult'] = 'Resultato del recerca';
$labels['advsearch'] = 'Recerca avantiate';
$labels['advanced'] = 'Avantiate';
$labels['other'] = 'Altere';
$labels['printcontact'] = 'Imprimer contacto';
$labels['qrcode'] = 'Codice QR';
$labels['typehome'] = 'Domicilio';
$labels['typework'] = 'Labor';
$labels['typeother'] = 'Altere';
$labels['typemobile'] = 'Mobile';
$labels['typemain'] = 'Principal';
$labels['typehomefax'] = 'Fax a domicilio';
$labels['typeworkfax'] = 'Fax a labor';
$labels['typecar'] = 'Auto';
$labels['typepager'] = 'Pager';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Assistente';
$labels['typehomepage'] = 'Pagina principal';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profilo';
$labels['addfield'] = 'Adder campo…';
$labels['addcontact'] = 'Adder contacto';
$labels['editcontact'] = 'Modificar contacto';
$labels['contacts'] = 'Contactos';
$labels['contactproperties'] = 'Proprietates de contacto';
$labels['contactnameandorg'] = 'Nomine e organisation';
$labels['personalinfo'] = 'Information personal';
$labels['personal'] = 'Personal';
$labels['contactphoto'] = 'Photo del contacto';
$labels['edit'] = 'Modificar';
$labels['cancel'] = 'Cancellar';
$labels['save'] = 'Salveguardar';
$labels['delete'] = 'Deler';
$labels['discard'] = 'Abandonar';
$labels['continue'] = 'Continuar';
$labels['ok'] = 'OK';
$labels['rename'] = 'Renominar';
$labels['addphoto'] = 'Adder';
$labels['replacephoto'] = 'Reimplaciar';
$labels['uploadphoto'] = 'Incargar photo';
$labels['choosefile'] = 'Eliger file…';
$labels['choosefiles'] = 'Eliger files…';
$labels['browse'] = 'Navigar';
$labels['newcontact'] = 'Crear nove contacto';
$labels['deletecontact'] = 'Deler contactos seligite';
$labels['composeto'] = 'Componer message a';
$labels['contactsfromto'] = 'Contacts $from a $to de $count';
$labels['print'] = 'Imprimer';
$labels['export'] = 'Exportar';
$labels['exportall'] = 'Exportar totes';
$labels['exportsel'] = 'Exportar seligite';
$labels['exportvcards'] = 'Exportar contactos in formato vCard';
$labels['newgroup'] = 'Crear nove gruppo';
$labels['addgroup'] = 'Adder gruppo';
$labels['grouprename'] = 'Renominar gruppo';
$labels['groupdelete'] = 'Deler gruppo';
$labels['groupassign'] = 'Assignar a gruppo…';
$labels['groupremove'] = 'Remover del gruppo';
$labels['groupremoveselected'] = 'Remover contactos seligite del gruppo';
$labels['uponelevel'] = 'Un nivello in alto';
$labels['previouspage'] = 'Monstrar previe pagina';
$labels['firstpage'] = 'Monstrar prime pagina';
$labels['nextpage'] = 'Monstrar proxime pagina';
$labels['lastpage'] = 'Monstrar ultime pagina';
$labels['group'] = 'Gruppo';
$labels['groups'] = 'Gruppos';
$labels['listgroup'] = 'Listar membros del gruppo';
$labels['personaladrbook'] = 'Adresses personal';
$labels['searchsave'] = 'Salveguardar recerca';
$labels['searchdelete'] = 'Deler recerca';
$labels['import'] = 'Importar';
$labels['importcontacts'] = 'Importar contactos';
$labels['importfromfile'] = 'Importar ab file';
$labels['importtarget'] = 'Adder contactos a';
$labels['importreplace'] = 'Reimplaciar tote le adressario';
$labels['importgroups'] = 'Importar assignationes de gruppo';
$labels['importgroupsall'] = 'Totes (crear gruppos si necessari)';
$labels['importgroupsexisting'] = 'Solmente pro gruppos existente';
$labels['importdesc'] = 'Tu pote incargar le contactos de un adressario existente.<br/>Il es actualmente possibile importar adresses in formato <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> o CSV (datos separate per commas).';
$labels['importmapdesc'] = 'Per favor confirma que le arrangiamento de campos monstrate hic infra es correcte ante de continuar con le importation de datos CSV (valores separate per commas).';
$labels['fieldnotmapped'] = 'Campo non assignate (non importar)';
$labels['skipheader'] = 'Non importar le prime linea (capites)';
$labels['done'] = 'Facite';
$labels['settingsfor'] = 'Configurationes pro';
$labels['about'] = 'A proposito';
$labels['preferences'] = 'Preferentias';
$labels['userpreferences'] = 'Preferentias de usator';
$labels['editpreferences'] = 'Modificar preferentias de usator';
$labels['identities'] = 'Identitates';
$labels['manageidentities'] = 'Gerer identitates';
$labels['newidentity'] = 'Crear nove identitate';
$labels['addidentity'] = 'Adder identitate';
$labels['editidentity'] = 'Modifiar identitate';
$labels['identityencryption'] = 'Cryptographia';
$labels['preferhtml'] = 'Monstrar HTML';
$labels['defaultcharset'] = 'Codification de characteres predefinite';
$labels['htmlmessage'] = 'Message HTML';
$labels['messagepart'] = 'Parte';
$labels['digitalsig'] = 'Signatura digital';
$labels['dateformat'] = 'Formato de data';
$labels['timeformat'] = 'Formato de hora';
$labels['prettydate'] = 'Imbellir datas';
$labels['setdefault'] = 'Fixar como predefinite';
$labels['autodetect'] = 'Auto';
$labels['language'] = 'Lingua';
$labels['timezone'] = 'Fuso horari';
$labels['pagesize'] = 'Lineas per pagina';
$labels['signature'] = 'Signatura';
$labels['dstactive'] = 'Hora estive';
$labels['showinextwin'] = 'Aperir message in nove fenestra';
$labels['composeextwin'] = 'Componer in un nove fenestra';
$labels['htmleditor'] = 'Componer messages in HTML';
$labels['htmlonreply'] = 'quando responder a un message HTML';
$labels['htmlonreplyandforward'] = 'quando reinviar o responder a un message HTML';
$labels['htmlsignature'] = 'Signatura HTML';
$labels['showemail'] = 'Monstrar adresse de e-mail con nomine de presentation';
$labels['previewpane'] = 'Monstrar quadro de previsualisation';
$labels['skin'] = 'Apparentia de interfacie';
$labels['logoutclear'] = 'Vacuar le corbe a papiro al clausura de session';
$labels['logoutcompact'] = 'Compactar le cassa de entrata al clausura de session';
$labels['uisettings'] = 'Interfacie de usator';
$labels['serversettings'] = 'Configurationes de servitor';
$labels['mailboxview'] = 'Vista de cassa postal';
$labels['mdnrequests'] = 'Quando on requesta un confirmation de reception';
$labels['askuser'] = 'demanda me lo';
$labels['autosend'] = 'invia un recepta';
$labels['autosendknown'] = 'invia un recepta a mi contactos, alteremente demanda me lo';
$labels['autosendknownignore'] = 'invia un recepta a mi contactos, alteremente ignora lo';
$labels['autosendtrusted'] = 'inviar recepta a expeditores de confidentia, si non, demandar me lo';
$labels['autosendtrustedignore'] = 'inviar recepta a expeditores de confidentia, si non, ignorar';
$labels['ignorerequest'] = 'ignora le requesta';
$labels['readwhendeleted'] = 'Marcar le message como legite al deletion';
$labels['flagfordeletion'] = 'Marcar le message pro deletion in vice de deler lo';
$labels['skipdeleted'] = 'Non monstrar messages delite';
$labels['deletealways'] = 'Si le displaciamento de messages al corbe a papiro non succede, deler los';
$labels['deletejunk'] = 'Directemente deler le messages indesirate';
$labels['showremoteimages'] = 'Visualisar imagines incorporate a distantia';
$labels['allowremoteresources'] = 'Permitter ressources (imagines, stilos) distante';
$labels['fromknownsenders'] = 'de expeditores cognite';
$labels['fromtrustedsenders'] = 'de expeditores de confidentia';
$labels['frommycontacts'] = 'de mi contactos';
$labels['always'] = 'sempre';
$labels['alwaysbutplain'] = 'sempre, excepte quando responder a texto simple';
$labels['showinlineimages'] = 'Monstrar le imagines annexate sub le message';
$labels['autosavedraft'] = 'Automaticamente salveguardar version provisori';
$labels['everynminutes'] = 'cata $n minuta(s)';
$labels['refreshinterval'] = 'Refrescar (verificar si il ha nove messages, etc.)';
$labels['never'] = 'nunquam';
$labels['immediately'] = 'immediatemente';
$labels['messagesdisplaying'] = 'Presentation de messages';
$labels['messagescomposition'] = 'Composition de messages';
$labels['mimeparamfolding'] = 'Nomines de annexo';
$labels['2231folding'] = 'RFC 2231 complete (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 complete (altere)';
$labels['force7bit'] = 'Usar le codification MIME pro characteres a 8 bits';
$labels['savelocalstorage'] = "Salveguardar in le immagazinage local del navigator (temporarimente)";
$labels['advancedoptions'] = 'Optiones avantiate';
$labels['toggleadvancedoptions'] = 'Monstrar/celar optiones avantiate';
$labels['focusonnewmessage'] = 'Focalisar le fenestra del navigator sur le nove message';
$labels['checkallfolders'] = 'Verificar in tote le dossieres si il ha nove messages';
$labels['displaynext'] = 'Monstrar le proxime entrata del lista post deler/displaciar';
$labels['defaultfont'] = 'Typo de litteras predefinite pro messages HTML';
$labels['mainoptions'] = 'Optiones principal';
$labels['browseroptions'] = 'Optiones de navigator';
$labels['section'] = 'Section';
$labels['maintenance'] = 'Mantenimento';
$labels['newmessage'] = 'Nove message';
$labels['signatureoptions'] = 'Optiones de signatura';
$labels['whenreplying'] = 'Quando responder';
$labels['replyempty'] = 'non citar le message original';
$labels['replytopposting'] = 'comenciar le nove message super le citation';
$labels['replytoppostingnoindent'] = 'comenciar un nove message ante le citation (sin indentation)';
$labels['replybottomposting'] = 'comenciar le nove message sub le citation';
$labels['replyremovesignature'] = 'Quando responder, remover le signatura del citation';
$labels['autoaddsignature'] = 'Automaticamente inserta signatura';
$labels['newmessageonly'] = 'nove message solmente';
$labels['replyandforwardonly'] = 'responsas e reinvios solmente';
$labels['insertsignature'] = 'Insertar signatura';
$labels['sigbelow'] = 'Mitter signatura post le message citate';
$labels['sigseparator'] = 'Fortiar le separator standard in signatura';
$labels['automarkread'] = 'Marcar messages como legite';
$labels['afternseconds'] = 'post $n secundas';
$labels['reqmdn'] = 'Sempre requestar un confirmation de reception';
$labels['reqdsn'] = 'Sempre requestar un notification de stato de livration';
$labels['replysamefolder'] = 'Placiar responsas in le dossier del message respondite';
$labels['defaultabook'] = 'Adressario predefinite';
$labels['autocompletesingle'] = 'Saltar adresses de e-mail altenrative in autocompletion';
$labels['listnamedisplay'] = 'Listar contactos como';
$labels['contactformmode'] = 'Modo de formulario de contacto';
$labels['privatemode'] = 'Private (a casa)';
$labels['businessmode'] = 'Interprisa (labor)';
$labels['collectedaddresses'] = 'Adresses colligite';
$labels['collectedrecipients'] = 'Destinatarios colligite';
$labels['collectedrecipientsopt'] = 'Immagazinar destinatarios de e-posta sortiente in';
$labels['collectedsendersopt'] = 'Immagazinar expeditores de confidentia in';
$labels['trustedsenders'] = 'Expeditores de confidentia';
$labels['spellcheckbeforesend'] = 'Verificar orthographia ante inviar un message';
$labels['spellcheckoptions'] = 'Optiones de verification orthographic';
$labels['spellcheckignoresyms'] = 'Ignorar parolas con symbolos';
$labels['spellcheckignorenums'] = 'Ignorar parolas con numeros';
$labels['spellcheckignorecaps'] = 'Ignorar parolas toto in majusculas';
$labels['addtodict'] = 'Adder al dictionario';
$labels['mailtoprotohandler'] = 'Registrar un gestor de protocollo pro ligamines mailto:';
$labels['standardwindows'] = 'Gerer pop-ups como fenestras normal';
$labels['forwardmode'] = 'Reinvio de messages';
$labels['inline'] = 'in texto';
$labels['asattachment'] = 'como annexo';
$labels['replyallmode'] = 'Action predefinite del button [Responder a totes]';
$labels['replyalldefault'] = 'responder a totes';
$labels['replyalllist'] = 'responder solmente al lista de diffusion (si trovate)';
$labels['allmessages'] = 'tote le messages';
$labels['olderxdays'] = 'plus ancian que $x dies';
$labels['folder'] = 'Dossier';
$labels['folders'] = 'Dossieres';
$labels['foldername'] = 'Nomine de dossier';
$labels['subscribed'] = 'Subscribite';
$labels['messagecount'] = 'Messages';
$labels['create'] = 'Crear';
$labels['createfolder'] = 'Crear un nove dossier';
$labels['managefolders'] = 'Gerer le dossieres';
$labels['specialfolders'] = 'Dossieres special';
$labels['properties'] = 'Proprietates';
$labels['folderproperties'] = 'Proprietates de dossier';
$labels['parentfolder'] = 'Dossier genitor';
$labels['location'] = 'Location';
$labels['info'] = 'Information';
$labels['getfoldersize'] = 'Clicca pro obtener le dimension del dossier';
$labels['changesubscription'] = 'Clicca pro cambiar le subscription';
$labels['foldertype'] = 'Typo de dossier';
$labels['personalfolder'] = 'Dossier private';
$labels['otherfolder'] = 'Dossier de altere usator';
$labels['sharedfolder'] = 'Dossier public';
$labels['findfolders'] = 'Cercar dossieres';
$labels['findcontacts'] = 'Cercar contactos';
$labels['findmail'] = 'Cercar messages de posta';
$labels['namespace.personal'] = 'Personal';
$labels['namespace.other'] = 'Altere usatores';
$labels['namespace.shared'] = 'Commun';
$labels['dualuselabel'] = 'Pote continer solmente';
$labels['dualusemail'] = 'messages';
$labels['dualusefolder'] = 'dossieres';
$labels['generate'] = 'Generar';
$labels['encryptioncreatekey'] = 'Crear un nove par de claves';
$labels['openmailvelopesettings'] = 'Aperir le parametros de Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Tu ha $nr claves private correspondente immagazinate in tu portaclaves de Mailvelope:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Iste identitate de expeditor non ha ancora un clave PGP private immagazinate in tu extension Mailvelope. Vole tu crear un, a fin de permitter le messageria cryptate?';
$labels['encryption'] = 'Cryptographia';
$labels['mailvelopeoptions'] = 'Optiones de Mailvelope';
$labels['mailvelopemainkeyring'] = 'Usar le portaclaves principal de Mailvelope';
$labels['mailvelopenotfound'] = 'Le extension Mailvelope non ha essite activate/installate in tu navigator.';
$labels['sortby'] = 'Ordinar per';
$labels['sortasc'] = 'Mitter in ordine ascendente';
$labels['sortdesc'] = 'Mitter in ordine descendente';
$labels['undo'] = 'Disfacer';
$labels['installedplugins'] = 'Plug-ins installate';
$labels['plugin'] = 'Plug-in';
$labels['version'] = 'Version';
$labels['source'] = 'Fonte';
$labels['destination'] = 'Destination';
$labels['license'] = 'Licentia';
$labels['support'] = 'Obtener supporto';
$labels['savedsearches'] = 'Recercas salveguardate';
$labels['dateformatY'] = 'AAAA';
$labels['dateformaty'] = 'AA';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Anglese';
$labels['westerneuropean'] = 'Europa del west';
$labels['easterneuropean'] = 'Europa del est';
$labels['southeasterneuropean'] = 'Europa del sud-est';
$labels['baltic'] = 'Baltic';
$labels['cyrillic'] = 'Cyrillic';
$labels['arabic'] = 'Arabe';
$labels['greek'] = 'Grec';
$labels['hebrew'] = 'Hebraic';
$labels['turkish'] = 'Turc';
$labels['nordic'] = 'Nordic';
$labels['thai'] = 'Thai';
$labels['celtic'] = 'Celtic';
$labels['vietnamese'] = 'Vietnamese';
$labels['japanese'] = 'Japonese';
$labels['korean'] = 'Coreano';
$labels['chinese'] = 'Chinese';
$labels['arialabeltopnav'] = 'Controlo de fenestras';
$labels['arialabeltasknav'] = 'Cargas de application';
$labels['arialabeltoolbar'] = 'Instrumentario de application';
$labels['arialabellistnav'] = 'Navigation de lista';
$labels['arialabelactivetask'] = 'Carga active';
$labels['arialabelmessagessearchfilter'] = 'Filtro de lista de e-mail';
$labels['arialabelmailsearchform'] = 'Formulario de recerca de message de e-mail';
$labels['arialabelcontactsearchform'] = 'Formulario de recerca de contactos';
$labels['arialabelmailquicksearchbox'] = 'Entrata de recerca de e-mail';
$labels['arialabelquicksearchbox'] = 'Entrata de recerca';
$labels['arialabelfoldersearchfilter'] = 'Filtro de lista de dossieres';
$labels['arialabelfoldersearchform'] = 'Formulario de recerca de dossieres';
$labels['arialabelfolderlist'] = 'Selection de dossier de e-mail';
$labels['arialabelmessagelist'] = 'Lista de messages de e-mail';
$labels['arialabelmailpreviewframe'] = 'Previsualisation de message';
$labels['arialabelmailboxmenu'] = 'Menu de actiones de dossier';
$labels['arialabellistselectmenu'] = 'Menu de selection de lista';
$labels['arialabelthreadselectmenu'] = 'Menu de listas de topicos';
$labels['arialabelmessagelistoptions'] = 'Optiones de visualisation e ordinamento de lista de messages';
$labels['arialabelmailimportdialog'] = 'Dialogo de importation de messages';
$labels['arialabelmessagenav'] = 'Navigation inter messages';
$labels['arialabelmessagebody'] = 'Texto de message';
$labels['arialabelmessageactions'] = 'Actiones de message';
$labels['arialabelcontactquicksearch'] = 'Formulario de recerca de contactos';
$labels['arialabelcontactsearchbox'] = 'Entrata de recerca de contactos';
$labels['arialabelmessageheaders'] = 'Capites de message';
$labels['arialabelforwardingoptions'] = 'Optiones de reinvio';
$labels['arialabelreplyalloptions'] = 'Optiones pro responder a totes';
$labels['arialabelmoremessageactions'] = 'Altere actiones de message';
$labels['arialabelmorecontactactions'] = 'Plus actiones de contacto';
$labels['arialabelmarkmessagesas'] = 'Marcar le messages seligite como…';
$labels['arialabelcomposeoptions'] = 'Optiones de composition';
$labels['arialabelresponsesmenu'] = 'Menu de responsas prefabricate';
$labels['arialabelattachmentuploadform'] = 'Formulario de incargamento de annexos';
$labels['arialabelattachmentmenu'] = 'Optiones de annexos';
$labels['arialabelmailtomenu'] = 'Optiones de adresse de e-mail';
$labels['arialabelattachmentpreview'] = 'Previsualisation del annexo';
$labels['ariasummarycomposecontacts'] = 'Lista de contactos e gruppos a seliger como destinatarios';
$labels['arialabelcontactexportoptions'] = 'Optiones de exportation de contactos';
$labels['arialabelabookgroupoptions'] = 'Optiones de adressario/gruppo';
$labels['arialabelpreferencesform'] = 'Formulario de preferentias';
$labels['arialabelidentityeditfrom'] = 'Formulario de modification de identitate';
$labels['arialabelresponseeditfrom'] = 'Formulario de modification de responsa';
$labels['arialabelsearchterms'] = 'Terminos de recerca';
$labels['arialabeldropactionmenu'] = 'Menu de actiones traher-e-deponer';
$labels['arialabelheadersmenu'] = 'Menu de addition de destinatario (capite)';
$labels['arialabelimagetools'] = 'Instrumentos de imagine';
$labels['helplistnavigation'] = 'Lista de claves de navigation';
$labels['helplistkeyboardnavigation'] = "Flechas in alto/basso: Focalisar un altere linea.
Barra de spatio: Seliger le linea focalisate.
Shift + alto/basso: Seliger un linea additional supra/infra.
Ctrl + barra de spatio: Adder/subtraher le linea focalisate al selection.";
$labels['helplistkeyboardnavmessages'] = "Flechas a dextra/sinistra: Displicar/plicar un topico de messages (solmente in vista arborescente).
Enter: Aperir le message seligite/focalisate.
Delete: Jectar le messages seligite in le corbe a papiro.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Aperir le contacto seligite/focalisate.";
