<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Une erreur est survenue';
$messages['loginfailed']  = 'La connexion a échoué.';
$messages['cookiesdisabled'] = 'Votre navigateur n’accepte pas les témoins.';
$messages['sessionerror'] = 'Votre session est invalide ou a expiré.';
$messages['cookiesmismatch'] = 'Une non-concordance de témoin a été détectée. Effacez les témoins de votre navigateur.';
$messages['storageerror'] = 'Erreur de connexion au serveur de stockage.';
$messages['servererror'] = 'Erreur de serveur';
$messages['servererrormsg'] = 'Erreur de serveur : $msg';
$messages['accountlocked'] = 'Trop de tentatives de connexion infructueuses. Réessayez ultérieurement.';
$messages['connerror'] = 'Erreur de connexion (n’a pu atteindre le serveur)';
$messages['dberror'] = 'Erreur de base de données';
$messages['dbconnerror'] = 'La connexion à la base de données n’aboutit pas';
$messages['windowopenerror'] = 'La fenêtre surgissante a été bloquée';
$messages['requesttimedout'] = 'Délai de la requête expiré';
$messages['errorreadonly'] = 'Impossible d’effectuer l’opération. Le dossier est en lecture seule.';
$messages['errornoperm'] = 'Impossible d’effectuer l’opération. Permission refusée.';
$messages['erroroverquota'] = 'Impossible d’effectuer l’opération. L’espace disque est saturé.';
$messages['erroroverquotadelete'] = 'L’espace disque est saturé. Utilisez Maj+Suppr pour supprimer un courriel.';
$messages['invalidrequest'] = 'La requête est invalide. Aucune donnée n’a été enregistrée.';
$messages['invalidhost'] = 'Nom du serveur invalide.';
$messages['nomessagesfound'] = 'Aucun courriel n’a été trouvé dans cette boîte de courriel';
$messages['loggedout'] = 'Vous avez mis fin à cette session avec succès. Au revoir.';
$messages['mailboxempty'] = 'La boîte de courriel est vide';
$messages['nomessages'] = 'Aucun courriel';
$messages['refreshing'] = 'Actualisation…';
$messages['loading'] = 'Chargement…';
$messages['uploading'] = 'Téléversement du fichier…';
$messages['attaching'] = 'Ajout du fichier…';
$messages['uploadingmany'] = 'Téléversement des fichiers…';
$messages['loadingdata'] = 'Chargement des données…';
$messages['checkingmail'] = 'Relève des nouveaux courriels…';
$messages['sendingmessage'] = 'Envoi du courriel…';
$messages['messagesent'] = 'Le courriel a été envoyé avec succès.';
$messages['savingmessage'] = 'Enregistrement du courriel…';
$messages['messagesaved'] = 'Courriel sauvegardé dans Brouillons.';
$messages['successfullysaved'] = 'Enregistré avec succès.';
$messages['savingresponse'] = 'Enregistrement du texte de réponse…';
$messages['deleteresponseconfirm'] = 'Voulez-vous vraiment supprimer ce texte de réponse ?';
$messages['nocontactselected'] = 'Vous n’avez pas encore choisi un contact.';
$messages['addedsuccessfully'] = 'Le contact a été ajouté avec succès au carnet d’adresses.';
$messages['contactexists'] = 'Un contact avec la même adresse courriel existe déjà.';
$messages['contactnameexists'] = 'Un contact avec le même nom existe déjà.';
$messages['blockedimages'] = 'Pour protéger votre confidentialité, les images distantes sont bloquées dans ce courriel.';
$messages['blockedresources'] = 'Pour protéger votre confidentialité, les ressources distantes ont été bloquées.';
$messages['suspiciousemail'] = 'Ce courriel comprend des adresses courriel suspectes qui pourraient être frauduleuses.';
$messages['bccemail'] = 'Les courriels transférés comprennent des destinataires confidentiels (Cci).';
$messages['bouncehint'] = 'Le courriel sera envoyé sans aucune modification, c’est-à-dire avec le corps, les en-têtes et les destinataires originaux.';
$messages['encryptedmessage'] = 'Ce courriel est chiffré et ne peut pas être affiché. Désolé.';
$messages['externalmessagedecryption'] = 'Ce courriel est chiffré et peut être déchiffré grâce au module complémentaire de votre navigateur.';
$messages['nopubkeyfor'] = 'Aucune clé publique valide n’a été trouvée pour $email';
$messages['nopubkeyforsender'] = 'Aucune clé publique valide n’a été trouvée pour votre identité d’expéditeur. Voulez-vous chiffrer le courriel pour les destinataires seulement ?';
$messages['encryptnoattachments'] = 'Les fichiers joints déjà téléversés ne peuvent pas être chiffrés.  Ajoutez-les de nouveau dans l’éditeur de chiffrement.';
$messages['searchpubkeyservers'] = 'Voulez-vous chercher les clés manquantes sur les serveurs de clés publiques ?';
$messages['encryptpubkeysfound'] = 'Les clés publiques suivantes ont été trouvées :';
$messages['keyservererror'] = 'Échec d’obtention de la clé sur le serveur de clés.';
$messages['keyimportsuccess'] = 'La clé publique $key a été importée dans le porte-clés avec succès.';
$messages['nocontactsfound'] = 'Aucun contact n’a été trouvé.';
$messages['contactnotfound'] = 'Le contact demandé n’a pas été trouvé.';
$messages['contactsearchonly'] = 'Vous devez utiliser un formulaire de recherche pour voir les contacts du carnet d’adresses sélectionné.';
$messages['sendingfailed'] = 'Échec d’envoi du courriel.';
$messages['senttooquickly'] = 'Patientez $sec s avant d’envoyer ce courriel.';
$messages['errorsavingsent'] = 'Une erreur est survenue durant l’enregistrement du courriel envoyé.';
$messages['errorsaving'] = 'Une erreur est survenue durant l’enregistrement.';
$messages['errormoving'] = 'Impossible de déplacer les courriels.';
$messages['errorcopying'] = 'Impossible de copier les courriels.';
$messages['errordeleting'] = 'Impossible de supprimer les courriels.';
$messages['errormarking'] = 'Impossible de marquer les courriels.';
$messages['alerttitle'] = 'Attention';
$messages['confirmationtitle'] = 'Êtes-vous certain…';
$messages['deletecontactconfirm']  = 'Voulez-vous vraiment supprimer les contacts sélectionnés ?';
$messages['deletegroupconfirm']  = 'Voulez-vous vraiment supprimer le groupe sélectionné ?';
$messages['deletemessagesconfirm'] = 'Voulez-vous vraiment supprimer les courriels sélectionnés ?';
$messages['deletefolderconfirm']  = 'Voulez-vous vraiment supprimer ce dossier ?';
$messages['movefolderconfirm']  = 'Voulez-vous vraiment déplacer ce dossier ?';
$messages['purgefolderconfirm']  = 'Voulez-vous vraiment supprimer tous les courriels dans ce dossier ?';
$messages['contactdeleting'] = 'Suppression des contacts…';
$messages['groupdeleting'] = 'Suppression du groupe…';
$messages['folderdeleting'] = 'Suppression du dossier…';
$messages['foldermoving'] = 'Déplacement du dossier…';
$messages['foldersubscribing'] = 'Abonnement au dossier…';
$messages['folderunsubscribing'] = 'Désabonnement au dossier…';
$messages['formincomplete'] = 'Le formulaire n’a pas été entièrement rempli.';
$messages['noemailwarning'] = 'Saisissez une adresse courriel valide.';
$messages['nonamewarning']  = 'Saisissez un nom.';
$messages['nopagesizewarning'] = 'Saisissez une taille de page.';
$messages['nosenderwarning'] = 'Saisissez l’adresse courriel de l’expéditeur.';
$messages['recipientsadded'] = 'Les destinataires ont été ajoutés avec succès.';
$messages['norecipientwarning'] = 'Saisissez au moins un destinataire.';
$messages['disclosedrecipwarning'] = 'Tous les destinataires verront réciproquement leur adresse courriel. Afin d’empêcher cela et de protéger la confidentialité, vous pouvez utiliser le champ Cci.';
$messages['disclosedreciptitle'] = 'Trop de destinataires publics';
$messages['nosubjectwarning']  = 'Le champ « Objet » est vide. Voulez-vous le remplir maintenant ?';
$messages['nosubjecttitle']  = 'Aucun objet';
$messages['nobodywarning'] = 'Envoyer ce courriel sans texte ?';
$messages['notsentwarning'] = 'Le courriel n’a pas été envoyé et contient des changements non enregistrés. Voulez-vous rejeter vos changements ?';
$messages['restoresavedcomposedata'] = 'Un courriel rédigé précédemment mais non envoyé a été trouvé.\n\nObjet : $subject\nEnregistré le : $date\n\nSouhaitez-vous restaurer ce courriel ?';
$messages['nosearchname'] = 'Saisissez un nom de contact ou une adresse de courriel.';
$messages['notuploadedwarning'] = 'Toutes les fichiers joints n’ont pas encore été téléversés. Patientez ou annuler le téléversement.';
$messages['searchsuccessful'] = '$nr courriels trouvés.';
$messages['contactsearchsuccessful'] = '$nr contacts trouvés.';
$messages['searchnomatch'] = 'La recherche n’a retourné aucun résultat.';
$messages['searching'] = 'Recherche…';
$messages['checking'] = 'Relève…';
$messages['stillsearching'] = 'Recherche toujours en cours…';
$messages['nospellerrors'] = 'Aucune faute d’orthographe n’a été trouvée.';
$messages['folderdeleted'] = 'Le dossier a été effacé avec succès.';
$messages['foldersubscribed'] = 'L’abonnement au dossier a réussi.';
$messages['folderunsubscribed'] = 'Le désabonnement au dossier a réussi.';
$messages['folderpurged'] = 'Le dossier a été vidé avec succès.';
$messages['folderexpunged'] = 'Le dossier a été compacté avec succès.';
$messages['deletedsuccessfully'] = 'Supprimé avec succès.';
$messages['converting'] = 'Suppression de la mise en forme…';
$messages['messageopenerror'] = 'Impossible de charger le courriel depuis le serveur.';
$messages['filelinkerror'] = 'Échec d’ajout du fichier.';
$messages['fileuploaderror'] = 'Échec de téléversement du fichier.';
$messages['csvfilemismatch'] = 'L’importation de plusieurs fichiers CSV avec différents champs n’est pas prise en charge.';
$messages['filesizeerror'] = 'Le fichier téléversé dépasse la taille maximale de $size.';
$messages['filecounterror'] = 'Vous pouvez téléverser un maximum de $count fichiers à la fois.';
$messages['msgsizeerror'] = 'Échec d’ajout de fichier. La taille maximale d’un fichier ($size) a été dépassée.';
$messages['msgsizeerrorfwd'] = 'La taille maximale d’un courriel ($size) a été dépassée. $num courriel(s) n’ont pas été joints.';
$messages['copysuccess'] = '$nr contacts copiés avec succès.';
$messages['movesuccess'] = '$nr contacts déplacés avec succès.';
$messages['copyerror'] = 'Impossible de copier des contacts.';
$messages['moveerror'] = 'Aucun contact n’a pu être déplacé.';
$messages['sourceisreadonly'] = 'Cette source d’adresse est en lecture seule.';
$messages['errorsavingcontact'] = 'Impossible d’enregistrer l’adresse du contact.';
$messages['movingmessage'] = 'Déplacement des courriels…';
$messages['copyingmessage'] = 'Copie des courriels…';
$messages['copyingcontact'] = 'Copie des contacts…';
$messages['movingcontact'] = 'Déplacement des contacts…';
$messages['deletingmessage'] = 'Suppression des courriels…';
$messages['markingmessage'] = 'Marquage des courriels…';
$messages['addingmember'] = 'Ajout des contacts au groupe…';
$messages['removingmember'] = 'Suppression des contacts du groupe…';
$messages['receiptsent'] = 'Un avis de lecture a été envoyé avec succès.';
$messages['errorsendingreceipt'] = 'Impossible d’envoyer l’avis.';
$messages['deleteidentityconfirm'] = 'Voulez-vous vraiment supprimer cette identité ?';
$messages['nodeletelastidentity'] = 'Vous ne pouvez pas effacer cette identité, c’est votre dernière.';
$messages['forbiddencharacter'] = 'Le nom du dossier contient un caractère interdit.';
$messages['selectimportfile'] = 'Choisissez un fichier à téléverser.';
$messages['addresswriterror'] = 'Impossible d’écrire dans le carnet d’adresse choisi.';
$messages['contactaddedtogroup'] = 'Les contacts ont été ajoutés à ce groupe avec succès.';
$messages['contactremovedfromgroup'] = 'Les contacts ont été supprimés de ce groupe avec succès.';
$messages['nogroupassignmentschanged'] = 'Aucune affection de groupe n’a été changée.';
$messages['importwait'] = 'Importation, patientez…';
$messages['importformaterror'] = 'Échec d’importation. Le fichier téléversé n’est pas un fichier d’importation de données valide.';
$messages['importconfirm'] = '<b>Les $inserted contacts ont été importés avec succès</b>';
$messages['importconfirmskipped'] = '<b>$skipped contacts existants ont été ignorés</b>';
$messages['importconfirminvalid'] = '<b>$invalid contacts invalides ont été ignorés</b>';
$messages['importconfirmerrors'] = '<b>Échec d’importation de $errors contacts valide</b>';
$messages['importmessagesuccess'] = '$nr courriels importés avec succès';
$messages['importmessageerror'] = 'Échec d’importation. Le fichier téléversé n’est ni un courriel valide ni un fichier de boîte de courriel';
$messages['opnotpermitted'] = 'L’opération n’est pas permise';
$messages['nofromaddress'] = 'Adresse courriel manquante dans l’identité choisie.';
$messages['editorwarning'] = 'Changer de type d’éditeur pourrait causer la perte du formatage du texte. Voulez-vous continuer ?';
$messages['httpreceivedencrypterror'] = 'Une erreur fatale de configuration est survenue. Contactez votre administrateur immédiatement. <b>Votre courriel ne peut pas être envoyé.</b>';
$messages['smtpconnerror'] = 'Erreur SMTP ($code) : échec de connexion au serveur.';
$messages['smtpautherror'] = 'Erreur SMTP ($code) : échec d’authentification.';
$messages['smtpfromerror'] = 'Erreur SMTP ($code) : impossible de définir l’expéditeur « $from » ($msg)';
$messages['smtptoerror'] = 'Erreur SMTP ($code) : échec d’ajout du destinataire « $to » ($msg)';
$messages['smtprecipientserror'] = 'Erreur SMTP : impossible d’analyser la liste des destinataires.';
$messages['smtputf8error'] = 'Erreur SMTP : le serveur ne prend pas en charge Unicode dans l’adresse courriel.';
$messages['smtpsizeerror'] = 'Erreur SMTP : la taille du courriel dépasse la limite du serveur ($limit)';
$messages['smtperror'] = 'Erreur SMTP : $msg';
$messages['emailformaterror'] = 'Adresse courriel invalide : $email';
$messages['toomanyrecipients'] = 'Trop de destinataires. Réduire leur nombre à $max.';
$messages['maxgroupmembersreached'] = 'Le nombre de membres du groupe dépasse le maximum de $max.';
$messages['internalerror'] = 'Une erreur interne est survenue. Réessayez.';
$messages['contactdelerror'] = 'Impossible de supprimer les contacts.';
$messages['contactdeleted'] = 'Contacts supprimés avec succès.';
$messages['contactrestoreerror'] = 'Impossible de restaurer les contacts supprimés.';
$messages['contactrestored'] = 'Contacts restaurés avec succès.';
$messages['groupdeleted'] = 'Groupe supprimé avec succès.';
$messages['grouprenamed'] = 'Groupe renommé avec succès.';
$messages['groupcreated'] = 'Groupe créé avec succès.';
$messages['savedsearchdeleted'] = 'Recherche enregistrée supprimée avec succès.';
$messages['savedsearchdeleteerror'] = 'Impossible de supprimer la recherche enregistrée.';
$messages['savedsearchcreated'] = 'Recherche enregistrée créée avec succès.';
$messages['savedsearchcreateerror'] = 'Impossible de créer la recherche enregistrée.';
$messages['messagedeleted'] = 'Courriels supprimés avec succès.';
$messages['messagemoved'] = 'Courriels déplacés avec succès.';
$messages['messagemovedtotrash'] = 'Les courriels ont été déplacés vers la corbeille avec succès.';
$messages['messagecopied'] = 'Courriels copiés avec succès.';
$messages['messagemarked'] = 'Courriels marqués avec succès.';
$messages['autocompletechars'] = 'Saisir au moins $min caractères pour le remplissage automatique.';
$messages['autocompletemore'] = 'Plusieurs entrées concordantes trouvées. Tapez plus de caractères.';
$messages['namecannotbeempty'] = 'Le nom ne peut pas être vide.';
$messages['nametoolong'] = 'Le nom est trop long.';
$messages['namedotforbidden'] = 'Un nom de dossier ne peut pas commencer par un point.';
$messages['folderupdated'] = 'Dossier mis à jour avec succès.';
$messages['foldercreated'] = 'Dossier créé avec succès.';
$messages['invalidimageformat'] = 'N’est pas un format d’image valide.';
$messages['mispellingsfound'] = 'Fautes d’orthographe détectées dans le courriel.';
$messages['parentnotwritable'] = 'Impossible de créer ni déplacer le dossier dans le dossier parent sélectionné. Aucun droit d’accès.';
$messages['messagetoobig'] = 'La partie courriel est trop grosse pour être traitée.';
$messages['attachmentvalidationerror'] = 'Ce fichier joint est suspect, car son type ne correspond pas au type déclaré dans le courriel. Si vous ne faites pas confiance à l’expéditeur, vous ne devriez pas l’ouvrir dans le navigateur, car son contenu pourrait être malveillant.<br/><br/><em>Attendu : $expected ; trouvé : $detected</em>';
$messages['noscriptwarning'] = 'Avertissement : Ce service de courriel Web exige JavaScript. Afin de l’utiliser, activez JavaScript dans les paramètres de votre navigateur.';
$messages['messageissent'] = 'Le courriel a déjà été envoyé, mais n’a pas encore été enregistré. Voulez-vous l’enregistrer maintenant ?';
$messages['errnotfound'] = 'Ficher introuvable';
$messages['errnotfoundexplain'] = 'La ressource demandée n’a pas été trouvée';
$messages['errfailedrequest'] = 'Échec de la demande';
$messages['errauthorizationfailed'] = 'Échec d’autorisation';
$messages['errunauthorizedexplain'] = 'Impossible de vérifier que vous êtes autorisé à accéder à ce service';
$messages['errrequestcheckfailed'] = 'Échec de vérification de la demande';
$messages['errcsrfprotectionexplain'] = "Pour votre protection, l’accès à cette ressource est protégé contre les attaques CSRF.\nSi vous voyez ceci, vous ne vous êtes probablement pas déconnecté avant de quitter l’application Web.\n\nUne interaction humaine est maintenant exigé afin de continuer.";
$messages['errcontactserveradmin'] = 'Contactez l’administrateur de votre serveur.';
$messages['clicktoresumesession'] = 'Cliquez ici afin de reprendre votre session précédente.';
$messages['errcomposesession'] = 'Erreur de session de rédaction';
$messages['errcomposesessionexplain'] = 'La session de rédaction demandée est introuvable.';
$messages['clicktocompose'] = 'Cliquer ici pour rédiger un nouveau courriel';
$messages['nosupporterror'] = 'Cette fonction n’est pas prise en charge par votre navigateur Web.';
$messages['siginserted'] = 'La signature a été insérée avec succès.';
$messages['responseinserted'] = 'La réponse a été insérée avec succès.';
$messages['noresponsesavailable'] = 'Aucune réponse n’est proposée';
$messages['listempty'] = 'La liste est vide.';
$messages['listusebutton'] = 'Utiliser le bouton Créer pour ajouter un nouvel enregistrement.';
$messages['keypaircreatesuccess'] = 'Une nouvelle biclé a été créée avec succès pour $identity.';
$messages['emptyattachment'] = 'Votre fichier joint semble vide.<br>Vérifiez auprès de la personne qui l’a envoyé.';
$messages['oauthloginfailed'] = 'Échec de connexion OAuth. Réessayez.';
$messages['oauthinvalidrequest'] = 'La demande d’autorisation était invalide ou incomplète.';
$messages['oauthaccessdenied'] = 'Le serveur d’autorisation ou l’utilisateur a refusé la demande.';
