<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = '篩選';
$labels['managefilters'] = '設定篩選';
$labels['filtername'] = '篩選名稱';
$labels['newfilter'] = '建立新篩選';
$labels['filteradd'] = '加入篩選';
$labels['filterdel'] = '刪除篩選';
$labels['rules'] = '規則';
$labels['actions'] = '動作';
$labels['scope'] = '範圍';
$labels['moveup'] = '上移';
$labels['movedown'] = '下移';
$labels['filterallof'] = '符合所有規則';
$labels['filteranyof'] = '符合任一條規則';
$labels['filterany'] = '所有郵件';
$labels['filtercontains'] = '包含';
$labels['filternotcontains'] = '不包含';
$labels['filteris'] = '等於';
$labels['filterisnot'] = '不等於';
$labels['filterexists'] = '存在';
$labels['filternotexists'] = '不存在';
$labels['filtermatches'] = '符合表達式';
$labels['filternotmatches'] = '不符合表達式';
$labels['filterregex'] = '符合正規表達式';
$labels['filternotregex'] = '不符合正規表達式';
$labels['filterunder'] = '小於';
$labels['filterover'] = '大於';
$labels['mime'] = 'MIME：';
$labels['mimepart'] = 'MIME 部分：';
$labels['mime-message'] = '郵件';
$labels['mime-anychild'] = '任何';
$labels['mime-type'] = '類型';
$labels['mime-subtype'] = '子類型';
$labels['mime-contenttype'] = '內容類型';
$labels['mime-param'] = '參數';
$labels['addrule'] = '加入規則';
$labels['delrule'] = '刪除規則';
$labels['messagemoveto'] = '將郵件移至';
$labels['messageredirect'] = '將郵件轉寄至';
$labels['messagecopyto'] = '將郵件複製至';
$labels['messagesendcopy'] = '寄送郵件複本至';
$labels['messagereply'] = '用以下內容回覆';
$labels['messagedelete'] = '刪除郵件';
$labels['messagediscard'] = '刪除郵件並用以下內容回覆';
$labels['messagekeep'] = '在收件匣保留郵件';
$labels['messagesrules'] = '對新收到的郵件：';
$labels['messagesactions'] = '執行以下動作：';
$labels['add'] = '加入';
$labels['del'] = '刪除';
$labels['sender'] = '寄件者';
$labels['recipient'] = '收件者';
$labels['vacationaddr'] = '我的電郵位址：';
$labels['vacationdays'] = '多久回覆一次（單位：天）：';
$labels['vacationinterval'] = '多久回覆一次：';
$labels['vacationreason'] = '郵件內容 (休假原因)：';
$labels['vacationfrom'] = '回覆寄件者位址：';
$labels['vacationsubject'] = '郵件主旨：';
$labels['days'] = '天';
$labels['seconds'] = '秒';
$labels['rulestop'] = '停止評估規則';
$labels['enable'] = '啟用/停用';
$labels['filterset'] = '篩選集';
$labels['filtersets'] = '篩選集合';
$labels['filtersetadd'] = '加入篩選集';
$labels['filtersetdel'] = '刪除篩選集';
$labels['filtersetact'] = '啟用現有篩選集';
$labels['filtersetdeact'] = '停用現有篩選集';
$labels['filterseteditraw'] = '編輯篩選集合';
$labels['filtersetswitch'] = '啟用/停用篩選集';
$labels['filterdef'] = '篩選定義';
$labels['filtersetname'] = '篩選集名稱';
$labels['newfilterset'] = '新篩選集';
$labels['active'] = '啟用';
$labels['none'] = '無';
$labels['fromset'] = '從集合';
$labels['fromfile'] = '從檔案';
$labels['filterdisabled'] = '篩選已停用';
$labels['filterenabled'] = '已啟用篩選';
$labels['countisgreaterthan'] = '數量大於';
$labels['countisgreaterthanequal'] = '數量大於或等於';
$labels['countislessthan'] = '數量小於';
$labels['countislessthanequal'] = '數量小於或等於';
$labels['countequals'] = '數量等於';
$labels['countnotequals'] = '數量不等於';
$labels['valueisgreaterthan'] = '值大於';
$labels['valueisgreaterthanequal'] = '值大於或等於';
$labels['valueislessthan'] = '值小於';
$labels['valueislessthanequal'] = '值小於或等於';
$labels['valueequals'] = '值等於';
$labels['valuenotequals'] = '值不等於';
$labels['setflags'] = '設定旗標';
$labels['addflags'] = '新增旗標到郵件';
$labels['removeflags'] = '移除郵件旗標';
$labels['flagread'] = '已讀';
$labels['flagdeleted'] = '已刪除';
$labels['flaganswered'] = '已經回覆';
$labels['flagflagged'] = '已加旗標';
$labels['flagdraft'] = '草稿';
$labels['addheader'] = '為郵件加入標頭';
$labels['deleteheader'] = '為郵件移除標頭';
$labels['headername'] = '標頭名稱';
$labels['headervalue'] = '標頭值';
$labels['headerpos'] = '標頭位置';
$labels['headeratstart'] = '開首';
$labels['headeratend'] = '結尾';
$labels['headeroccurrence'] = '標頭出現與否/位置';
$labels['headerfromstart'] = '由開首開始';
$labels['headerfromend'] = '由結尾開始';
$labels['headerpatterns'] = '標頭植樣式';
$labels['headermatchtype'] = '符合類型：';
$labels['setvariable'] = '設定變數';
$labels['setvarname'] = '變數名稱:';
$labels['setvarvalue'] = '變數值:';
$labels['setvarmodifiers'] = '修改:';
$labels['varlower'] = '小楷';
$labels['varupper'] = '大楷';
$labels['varlowerfirst'] = '第一個字母小楷';
$labels['varupperfirst'] = '第一個字母大楷';
$labels['varquotewildcard'] = '跳脫字元';
$labels['varlength'] = '長度';
$labels['notify'] = '寄送通知';
$labels['notifytarget'] = '通知收件人';
$labels['notifymessage'] = '通知內容訊息(選填):';
$labels['notifyoptions'] = '通知項目(選填):';
$labels['notifyfrom'] = '通知寄件人(選填):';
$labels['notifyimportance'] = '重要性:';
$labels['notifyimportancelow'] = '低';
$labels['notifyimportancenormal'] = '一般';
$labels['notifyimportancehigh'] = '高';
$labels['notifymethodmailto'] = '電郵';
$labels['notifymethodtel'] = '電話';
$labels['notifymethodsms'] = 'SMS短訊';
$labels['filtercreate'] = '建立篩選';
$labels['usedata'] = '於篩選使用以下資料：';
$labels['nextstep'] = '下一步';
$labels['...'] = '…';
$labels['string'] = '字串';
$labels['currdate'] = '現在日期';
$labels['datetest'] = '日期';
$labels['dateheader'] = '標頭：';
$labels['year'] = '年';
$labels['month'] = '月';
$labels['day'] = '日';
$labels['date'] = '日期 (yyyy-mm-dd)';
$labels['julian'] = '日期 (公曆)';
$labels['hour'] = '小時';
$labels['minute'] = '分鐘';
$labels['second'] = '秒';
$labels['time'] = '時間 (hh:mm:ss)';
$labels['iso8601'] = '日期 (ISO8601)';
$labels['std11'] = '日期 (RFC2822)';
$labels['zone'] = '時區';
$labels['weekday'] = '週幾 (0-6)';
$labels['advancedopts'] = '進階選項';
$labels['body'] = '內文';
$labels['address'] = '郵件位址';
$labels['envelope'] = '信封';
$labels['modifier'] = '修改：';
$labels['text'] = '文字';
$labels['undecoded'] = '未解碼 (原始)';
$labels['contenttype'] = '內容類型';
$labels['modtype'] = '類型：';
$labels['allparts'] = '全部';
$labels['domain'] = '網域';
$labels['localpart'] = '本機部分';
$labels['user'] = '使用者';
$labels['detail'] = '細節';
$labels['comparator'] = '比較：';
$labels['default'] = '預設';
$labels['octet'] = '嚴謹模式 (八位元組)';
$labels['asciicasemap'] = '不區分大小寫 (採用 ASCII-casemap)';
$labels['asciinumeric'] = '數字類型 (ASCII-numeric)';
$labels['index'] = '索引：';
$labels['indexlast'] = '向後';
$labels['spamtest'] = '垃圾郵件等級';
$labels['spamtestisgreaterthan'] = '大於';
$labels['spamtestisgreaterthanequal'] = '大於或等於';
$labels['spamtestislessthan'] = '小於';
$labels['spamtestislessthanequal'] = '小於或等於';
$labels['spamtestequals'] = '等於';
$labels['spamtestnotequals'] = '不等於';
$labels['spamtestisunknown'] = '未知';
$labels['vacation'] = '不在辦公室';
$labels['vacation.reply'] = '回覆郵件';
$labels['vacation.advanced'] = '進階設定';
$labels['vacation.from'] = '回覆寄件者位址';
$labels['vacation.subject'] = '主旨';
$labels['vacation.body'] = '內文';
$labels['vacation.start'] = '開始時間';
$labels['vacation.end'] = '結束時間';
$labels['vacation.status'] = '狀態';
$labels['vacation.on'] = '開';
$labels['vacation.off'] = '關';
$labels['vacation.addresses'] = '我的電子郵件位址';
$labels['vacation.interval'] = '回覆間隔';
$labels['vacation.after'] = '在此項目之後放置「不在辦公室」規則：';
$labels['vacation.saving'] = '正在儲存資料...';
$labels['vacation.action'] = '對收到的郵件的動作';
$labels['vacation.keep'] = '保留';
$labels['vacation.discard'] = '丟棄';
$labels['vacation.redirect'] = '重定向至';
$labels['vacation.copy'] = '傳送複本至';
$labels['forward'] = '轉寄';
$labels['forward.redirect'] = '重定向至';
$labels['forward.copy'] = '傳送複本至';
$labels['forward.on'] = '開';
$labels['forward.off'] = '關';
$labels['forward.status'] = '狀態：';
$labels['forward.action'] = '對於收到的郵件，執行以下動作：';
$labels['forward.saving'] = '正在儲存資料...';
$labels['filladdresses'] = '填入我所有的位址';
$labels['arialabelfiltersetactions'] = '篩選集合動作';
$labels['arialabelfilteractions'] = '篩選動作';
$labels['arialabelfilterform'] = '篩選內容';
$labels['ariasummaryfilterslist'] = '篩選清單';
$labels['ariasummaryfiltersetslist'] = '篩選集合清單';
$labels['filterstitle'] = '編輯「收到郵件的篩選」';
$labels['vacationtitle'] = '編輯「不在辦公室」規則';
$labels['forwardtitle'] = '編輯郵件轉寄規則';
$labels['message'] = '郵件';
$labels['duplicate'] = '重覆';
$labels['notduplicate'] = '不是重覆';
$labels['duplicate.handle'] = '處理常式：';
$labels['duplicate.header'] = '標頭：';
$labels['duplicate.uniqueid'] = '識別碼：';
$labels['duplicate.seconds'] = '逾時 (秒)：';
$labels['duplicate.last'] = '相對於上次執行';
$messages['filterunknownerror'] = '未知的伺服器錯誤';
$messages['filterconnerror'] = '無法與伺服器連線';
$messages['filterdeleteerror'] = '無法刪除篩選。伺服器出錯';
$messages['filterdeleted'] = '成功刪除篩選器';
$messages['filtersaved'] = '成功儲存篩選器。';
$messages['filtersaveerror'] = '無法儲存篩選。伺服器出錯';
$messages['filterformerror'] = '篩選表單出錯';
$messages['filterdeleteconfirm'] = '確定要刪除所選的郵件規則嗎?';
$messages['ruledeleteconfirm'] = '確定要刪除所選的郵件規則嗎？';
$messages['actiondeleteconfirm'] = '確定要刪除所選的動作嗎？';
$messages['forbiddenchars'] = '內容包含禁用字元';
$messages['cannotbeempty'] = '內容不能為空白';
$messages['ruleexist'] = '規則名稱重複';
$messages['setactivateerror'] = '無法啟用所選的篩選集。伺服器出錯。';
$messages['setdeactivateerror'] = '無法停用所選的篩選集。伺服器出錯。';
$messages['setdeleteerror'] = '無法刪除所選的篩選集。伺服器出錯。';
$messages['setactivated'] = '已啟用篩選集。';
$messages['setdeactivated'] = '已停用篩選集。';
$messages['setdeleted'] = '已刪除篩選集。';
$messages['setupdated'] = '已更新篩選集。';
$messages['setdeleteconfirm'] = '確定要刪除所選的篩選集？';
$messages['setcreateerror'] = '無法建立篩選集。伺服器出錯。';
$messages['setcreated'] = '成功建立篩選集。';
$messages['activateerror'] = '無法啟用所選的篩選。伺服器出錯';
$messages['deactivateerror'] = '無法停用所選的篩選。伺服器出錯';
$messages['deactivated'] = '篩選器已停用';
$messages['activated'] = '篩選器已啟用';
$messages['moved'] = '篩選器已移動';
$messages['moveerror'] = '無法移動所選的篩選。伺服器出錯';
$messages['nametoolong'] = '名稱太長。';
$messages['namereserved'] = '保留名稱。';
$messages['setexist'] = '集合已存在';
$messages['nodata'] = '至少要選擇一個位置';
$messages['invaliddateformat'] = '日期或時間部分格式無效';
$messages['saveerror'] = '無法儲存資料。伺服器出錯';
$messages['vacationsaved'] = '成功儲存「不在辦公室」資料。';
$messages['forwardsaved'] = '成功儲存轉寄資料。';
$messages['emptyvacationbody'] = '休假郵件要有內容！';
$messages['duplicate.conflict.err'] = '不允許標頭和識別碼都是獨一無二的';
$messages['disabledaction'] = '不允許的動作。';
$messages['lastindexempty'] = '若要由結尾開始計算，要先有索引';
$messages['noflagset'] = '必須至少選取一個旗標。';
