<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Partage';
$labels['myrights'] = 'Droits d’accès';
$labels['username'] = 'Utilisateur :';
$labels['advanced'] = 'Mode avancé';
$labels['add'] = 'Ajouter';
$labels['newuser'] = 'Ajouter une entrée';
$labels['editperms'] = 'Modifier les permissions';
$labels['actions'] = 'Actions des droits d’accès…';
$labels['anyone'] = 'Tous les utilisateurs (n’importe qui)';
$labels['anonymous'] = 'Invités (anonyme)';
$labels['identifier'] = 'Identifiant';
$labels['acll'] = 'Consultation';
$labels['aclr'] = 'Lire les courriels';
$labels['acls'] = 'Garder l’état « vu »';
$labels['aclw'] = 'Drapeaux d’écriture';
$labels['acli'] = 'Insérer (copier dans)';
$labels['aclp'] = 'Publier';
$labels['aclc'] = 'Créer des sous-dossiers';
$labels['aclk'] = 'Créer des sous-dossiers';
$labels['acld'] = 'Supprimer des courriels';
$labels['aclt'] = 'Supprimer des courriels';
$labels['acle'] = 'Purger';
$labels['aclx'] = 'Supprimer un dossier';
$labels['acla'] = 'Administrer';
$labels['acln'] = 'Annoter les courriels';
$labels['aclfull'] = 'Contrôle total';
$labels['aclother'] = 'Autre';
$labels['aclread'] = 'Lecture';
$labels['aclwrite'] = 'Écriture';
$labels['acldelete'] = 'Supprimer';
$labels['shortacll'] = 'Consultation';
$labels['shortaclr'] = 'Lecture';
$labels['shortacls'] = 'Conserver';
$labels['shortaclw'] = 'Écriture';
$labels['shortacli'] = 'Insérer';
$labels['shortaclp'] = 'Publier';
$labels['shortaclc'] = 'Créer';
$labels['shortaclk'] = 'Créer';
$labels['shortacld'] = 'Supprimer';
$labels['shortaclt'] = 'Supprimer';
$labels['shortacle'] = 'Purger';
$labels['shortaclx'] = 'Suppression de dossier';
$labels['shortacla'] = 'Administrer';
$labels['shortacln'] = 'Annoter';
$labels['shortaclother'] = 'Autre';
$labels['shortaclread'] = 'Lecture';
$labels['shortaclwrite'] = 'Écriture';
$labels['shortacldelete'] = 'Supprimer';
$labels['longacll'] = 'Ce dossier est visible dans les listes et on peut s’y abonner';
$labels['longaclr'] = 'Le dossier peut-être ouvert en lecture';
$labels['longacls'] = 'Le drapeau Vu des courriels peut-être changée';
$labels['longaclw'] = 'Les drapeaux et mots-clés des courriels peuvent être changés, sauf pour Vu et Supprimé';
$labels['longacli'] = 'Les courriels peuvent-être écrits ou copiés dans le dossier';
$labels['longaclp'] = 'Les courriels peuvent-être publiés dans ce dossier';
$labels['longaclc'] = 'Les dossiers peuvent-être créés (ou renommés) directement depuis ce dossier';
$labels['longaclk'] = 'Les dossiers peuvent-être créés (ou renommés) directement depuis ce dossier';
$labels['longacld'] = 'Le drapeau de suppression des courriels peut-être modifiée';
$labels['longaclt'] = 'Le drapeau de suppression des courriels peut-être modifiée';
$labels['longacle'] = 'Les courriels peuvent-être purgés';
$labels['longaclx'] = 'Le dossier peut-être supprimé ou renommé';
$labels['longacla'] = 'Les droits d’accès du dossier peuvent être modifiés';
$labels['longacln'] = 'Les métadonnées partagées des courriels (annotations) peuvent être changées';
$labels['longaclfull'] = 'Contrôle total, incluant l’administration des dossiers';
$labels['longaclread'] = 'Le dossier peut-être ouvert en lecture';
$labels['longaclwrite'] = 'Les courriels peuvent-être marqués, écrits ou copiés dans ce dossier';
$labels['longacldelete'] = 'Les courriels peuvent être supprimés';
$labels['longaclother'] = 'Autres droits d’accès';
$labels['ariasummaryacltable'] = 'Liste de droits d’accès';
$labels['arialabelaclactions'] = 'Actions de listage';
$labels['arialabelaclform'] = 'Formulaire de droits d’accès';
$messages['deleting'] = 'Suppression des droits d’accès…';
$messages['saving'] = 'Enregistrement des droits d’accès…';
$messages['updatesuccess'] = 'Les droits d’accès ont été changés avec succès';
$messages['deletesuccess'] = 'Les droits d’accès ont été supprimés avec succès';
$messages['createsuccess'] = 'Les droits d’accès ont été ajoutés avec succès';
$messages['updateerror'] = 'Impossible de mettre à jour les droits d’accès';
$messages['deleteerror'] = 'Impossible de supprimer les droits d’accès';
$messages['createerror'] = 'Impossible d’ajouter des droits d’accès';
$messages['deleteconfirm'] = 'Êtes-vous certain de vouloir retirer les droits d’accès des utilisateurs sélectionnés ?';
$messages['norights'] = 'Aucun droit n’a été indiqué';
$messages['nouser'] = 'Aucun nom d’utilisateur n’a été indiqué';
