<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Velkomen til $product';
$labels['username'] = 'Brukarnamn';
$labels['password'] = 'Passord';
$labels['server'] = 'Tenar';
$labels['login'] = 'Logg inn';
$labels['logout'] = 'Logg ut';
$labels['mail'] = 'E-post';
$labels['settings'] = 'Personlege innstillingar';
$labels['addressbook'] = 'Adressebok';
$labels['inbox'] = 'Innboks';
$labels['drafts'] = 'Kladd';
$labels['sent'] = 'Sendt';
$labels['trash'] = 'Sletta';
$labels['junk'] = 'Søppel';
$labels['subject'] = 'Emne';
$labels['from'] = 'Frå';
$labels['sender'] = 'Avsendar';
$labels['to'] = 'Til';
$labels['cc'] = 'Kopi til';
$labels['bcc'] = 'Blindkopi til';
$labels['replyto'] = 'Svar til';
$labels['followupto'] = 'Oppfølging til';
$labels['date'] = 'Dato';
$labels['size'] = 'Storleik';
$labels['priority'] = 'Prioritet';
$labels['organization'] = 'Organisasjon';
$labels['readstatus'] = 'Lesestatus';
$labels['listoptions'] = 'Listeinnstillingar …';
$labels['mailboxlist'] = 'Mapper';
$labels['messagesfromto'] = 'Melding $from til $to av $count';
$labels['threadsfromto'] = 'Tråd $from til $to ($count stk)';
$labels['messagenrof'] = 'Melding $nr av $count';
$labels['fromtoshort'] = '$from-$to av $count';
$labels['copy'] = 'Kopier';
$labels['move'] = 'Flytt';
$labels['moveto'] = 'flytt til …';
$labels['download'] = 'Last ned';
$labels['showattachment'] = 'Vis';
$labels['showanyway'] = 'Vis likevel';
$labels['filename'] = 'Filnamn';
$labels['filesize'] = 'Filstorleik';
$labels['addtoaddressbook'] = 'Legg til i adressebok';
$labels['sun'] = 'Sun';
$labels['mon'] = 'Mån';
$labels['tue'] = 'Tys';
$labels['wed'] = 'Ons';
$labels['thu'] = 'Tor';
$labels['fri'] = 'Fre';
$labels['sat'] = 'Lau';
$labels['sunday'] = 'Sundag';
$labels['monday'] = 'Måndag';
$labels['tuesday'] = 'Tysdag';
$labels['wednesday'] = 'Onsdag';
$labels['thursday'] = 'Torsdag';
$labels['friday'] = 'Fredag';
$labels['saturday'] = 'Laurdag';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Mai';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Aug';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Des';
$labels['longjan'] = 'Januar';
$labels['longfeb'] = 'Februar';
$labels['longmar'] = 'Mars';
$labels['longapr'] = 'April';
$labels['longmay'] = 'Mai';
$labels['longjun'] = 'Juni';
$labels['longjul'] = 'Juli';
$labels['longaug'] = 'August';
$labels['longsep'] = 'September';
$labels['longoct'] = 'Oktober';
$labels['longnov'] = 'November';
$labels['longdec'] = 'Desember';
$labels['today'] = 'I dag';
$labels['refresh'] = 'Frisk opp att';
$labels['checkmail'] = 'Sjå etter nye meldingar';
$labels['compose'] = 'Skriv ei melding';
$labels['writenewmessage'] = 'Skriv ei ny melding';
$labels['reply'] = 'Svar';
$labels['replytomessage'] = 'Svar til avsendar';
$labels['replytoallmessage'] = 'Svar til avsendar og alle mottakarar';
$labels['replyall'] = 'Svar til alle';
$labels['replylist'] = 'Svar til liste';
$labels['forward'] = 'Vidaresend';
$labels['forwardinline'] = 'Send vidare innbygd';
$labels['forwardattachment'] = 'Vidresend som vedlegg';
$labels['forwardmessage'] = 'Vidaresend meldinga';
$labels['deletemessage'] = 'Slett meldinga';
$labels['movemessagetotrash'] = 'Flytt meldinga til «sletta»';
$labels['printmessage'] = 'Skriv ut meldinga';
$labels['previousmessage'] = 'Vis førre melding';
$labels['firstmessage'] = 'Vis den første meldinga';
$labels['nextmessage'] = 'Vis den neste meldinga';
$labels['lastmessage'] = 'Vis den siste meldinga';
$labels['backtolist'] = 'Tilbake til meldingslista';
$labels['viewsource'] = 'Vis kjelde';
$labels['mark'] = 'Merke';
$labels['markmessages'] = 'Marker meldingar';
$labels['markread'] = 'Som lese';
$labels['markunread'] = 'Som ulese';
$labels['markflagged'] = 'Som flagga';
$labels['markunflagged'] = 'Som uflagga';
$labels['moreactions'] = 'Fleire handlingar';
$labels['more'] = 'Meir';
$labels['back'] = 'Tilbake';
$labels['options'] = 'Innstillingar';
$labels['select'] = 'Vel';
$labels['all'] = 'Alle';
$labels['none'] = 'Ingen';
$labels['currpage'] = 'Gjeldande side';
$labels['isread'] = 'Lese';
$labels['unread'] = 'Uleste';
$labels['flagged'] = 'Flagga';
$labels['unanswered'] = 'Ikkje svara';
$labels['deleted'] = 'Sletta';
$labels['undeleted'] = 'Ikkje sletta';
$labels['invert'] = 'Inverter';
$labels['filter'] = 'Filtrer';
$labels['list'] = 'List opp';
$labels['threads'] = 'Trådar';
$labels['expand-all'] = 'Utvid alle';
$labels['expand-unread'] = 'Utvid ulesne';
$labels['collapse-all'] = 'Slå saman alle';
$labels['threaded'] = 'Tråda';
$labels['autoexpand_threads'] = 'Utvid eposttråder';
$labels['do_expand'] = 'alle tråder';
$labels['expand_only_unread'] = 'berre med ulesne epostar';
$labels['fromto'] = 'Sendar/Mottakar';
$labels['flag'] = 'Flagg';
$labels['attachment'] = 'Vedlegg';
$labels['nonesort'] = 'Ingen';
$labels['sentdate'] = 'Sendtdato';
$labels['arrival'] = 'Mottaksdato';
$labels['asc'] = 'Alfabetisk';
$labels['desc'] = 'Motsatt alfabetisk';
$labels['listcolumns'] = 'Vis kolonner';
$labels['listsorting'] = 'Sorteringskolonne';
$labels['listorder'] = 'Sorteringsveg';
$labels['listmode'] = 'Listevisningmodus';
$labels['layoutlist'] = 'List opp';
$labels['folderactions'] = 'Mappehandlingar';
$labels['compact'] = 'Kompakt';
$labels['empty'] = 'Tom';
$labels['quota'] = 'Plassbruk';
$labels['unknown'] = 'ukjend';
$labels['unlimited'] = 'ubegrensa';
$labels['quicksearch'] = 'Snøggsøk';
$labels['resetsearch'] = 'Tilbakestill søk';
$labels['searchmod'] = 'Søkeutsagn';
$labels['msgtext'] = 'Heile eposten';
$labels['body'] = 'Meldingstekst';
$labels['openinextwin'] = 'Opna i nytt vindauga';
$labels['emlsave'] = 'Last ned (.eml)';
$labels['editasnew'] = 'Rediger som ny';
$labels['send'] = 'Send';
$labels['sendmessage'] = 'Send meldinga no';
$labels['savemessage'] = 'Lagra kladd';
$labels['addattachment'] = 'Legg ved ei fil';
$labels['charset'] = 'Teiknkoding';
$labels['editortype'] = 'Redigeringstype';
$labels['returnreceipt'] = 'Epost-er-lest-kvittering';
$labels['dsn'] = 'Leveringsstatus';
$labels['mailreplyintro'] = 'Den $date skreiv $sender:';
$labels['originalmessage'] = 'Opphavleg melding';
$labels['insert'] = 'Sett inn';
$labels['recipient'] = 'Mottakar';
$labels['editidents'] = 'Redigere identitetar';
$labels['spellcheck'] = 'Stavekontroll';
$labels['checkspelling'] = 'Stavekontroll';
$labels['resumeediting'] = 'Hald fram redigering';
$labels['revertto'] = 'Tilbakestill til';
$labels['attach'] = 'Legg ved';
$labels['attachments'] = 'Vedlegg';
$labels['upload'] = 'Last opp';
$labels['close'] = 'Steng';
$labels['messageoptions'] = 'Meldingsalternativ';
$labels['low'] = 'Låg';
$labels['lowest'] = 'Lågast';
$labels['normal'] = 'Normal';
$labels['high'] = 'Høg';
$labels['highest'] = 'Høgast';
$labels['nosubject'] = '(ingen emne)';
$labels['showimages'] = 'Vis bilete';
$labels['alwaysshow'] = 'Alltid vis bilete frå $sender';
$labels['isdraft'] = 'Dette er ein kladd.';
$labels['andnmore'] = '$nr fleire …';
$labels['togglemoreheaders'] = 'Vis fleire meldingshovud';
$labels['togglefullheaders'] = 'Veksle vising av meldinga sine headere i råformat';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Vanleg tekst';
$labels['savesentmessagein'] = 'Lagra sendt epost i';
$labels['dontsave'] = 'Ikkje lagra';
$labels['maxuploadsize'] = 'Maksimalt tillatte storleik på filar er $size';
$labels['addcc'] = 'Legg til kopi';
$labels['addbcc'] = 'Legg til blindkopi';
$labels['addreplyto'] = 'Legg til svaradressa';
$labels['addfollowupto'] = 'Legg til oppfylgjing';
$labels['mdnrequest'] = 'Sendaren av denne meldinga ynskjer å få kvittering når du har lest meldinga. Ynskjer du å senda denne kvitteringa?';
$labels['receiptread'] = 'Svarkvittering (eposten-er-lest-kvittering)';
$labels['yourmessage'] = 'Dette er ein retur-kvittering for meldinga di.';
$labels['receiptnote'] = 'Hugs: Denne kvitteringa seier berre at meldinga di vart vist på mottakar sin datamaskin. Det er ingen garanti for at mottakaren faktisk har lese eller forstått innhaldet i meldinga.';
$labels['name'] = 'Visingsnamn';
$labels['firstname'] = 'Førenamn';
$labels['surname'] = 'Etternamn';
$labels['middlename'] = 'Mellomnamn';
$labels['nameprefix'] = 'Prefiks';
$labels['namesuffix'] = 'Suffiks';
$labels['nickname'] = 'Kallenamn';
$labels['jobtitle'] = 'Jobbtittel';
$labels['department'] = 'Avdeling';
$labels['gender'] = 'Kjønn';
$labels['maidenname'] = 'Pikenamn';
$labels['email'] = 'E-post';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Adresse';
$labels['street'] = 'Gate';
$labels['locality'] = 'By';
$labels['zipcode'] = 'Postnummer';
$labels['region'] = 'Stat/provins';
$labels['country'] = 'Land';
$labels['birthday'] = 'Fødselsdag';
$labels['anniversary'] = 'Bryllaupsdag';
$labels['website'] = 'Internettside';
$labels['instantmessenger'] = 'Lynmelding';
$labels['notes'] = 'Notatar';
$labels['male'] = 'Mann';
$labels['female'] = 'Kvinne';
$labels['manager'] = 'Leiar';
$labels['assistant'] = 'Assistent';
$labels['spouse'] = 'Ektefelle';
$labels['allfields'] = 'Alle felt';
$labels['search'] = 'Søk';
$labels['advsearch'] = 'Avansert søk';
$labels['advanced'] = 'Avansert';
$labels['other'] = 'Andre';
$labels['typehome'] = 'Heim';
$labels['typework'] = 'Jobb';
$labels['typeother'] = 'Andre';
$labels['typemobile'] = 'Mobil';
$labels['typemain'] = 'Hovud';
$labels['typehomefax'] = 'Heimefax';
$labels['typeworkfax'] = 'Jobbfax';
$labels['typecar'] = 'Bil';
$labels['typepager'] = 'Personsøkjar';
$labels['typevideo'] = 'VIdeo';
$labels['typeassistant'] = 'Assistent';
$labels['typehomepage'] = 'Heimeside';
$labels['typeblog'] = 'Blogg';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Legg til felt...';
$labels['editcontact'] = 'Redigere kontakt';
$labels['contacts'] = 'Kontakter';
$labels['contactproperties'] = 'Eigenskapar';
$labels['personalinfo'] = 'Personleg informasjon';
$labels['edit'] = 'Redigere';
$labels['cancel'] = 'Avbryt';
$labels['save'] = 'Lagre';
$labels['delete'] = 'Slette';
$labels['rename'] = 'Gi nytt namn';
$labels['addphoto'] = 'Legg til';
$labels['replacephoto'] = 'Erstatt';
$labels['uploadphoto'] = 'Last opp bilete';
$labels['deletecontact'] = 'Slett valde kontaktar';
$labels['composeto'] = 'Ny melding til';
$labels['contactsfromto'] = 'Kontaktar $from til $to av $count';
$labels['print'] = 'Skriv ut';
$labels['export'] = 'Eksport';
$labels['exportall'] = 'Eksporter alle';
$labels['exportsel'] = 'Eksporter valde';
$labels['exportvcards'] = 'Eksporter kontaktar i vCard-format';
$labels['grouprename'] = 'Endre namn på gruppe';
$labels['groupdelete'] = 'Slett gruppe';
$labels['groupremoveselected'] = 'Fjern valde kontaktar frå gruppe';
$labels['previouspage'] = 'Førre side';
$labels['firstpage'] = 'Første side';
$labels['nextpage'] = 'Neste side';
$labels['lastpage'] = 'Siste side';
$labels['group'] = 'Gruppe';
$labels['groups'] = 'Gruppar';
$labels['personaladrbook'] = 'Personlege adresser';
$labels['searchsave'] = 'Lagre søk';
$labels['searchdelete'] = 'Slett søk';
$labels['import'] = 'Importer';
$labels['importcontacts'] = 'Importer kontaktar';
$labels['importreplace'] = 'Byt ut heile adresseboka';
$labels['done'] = 'Ferdig';
$labels['settingsfor'] = 'Innstillingar for';
$labels['about'] = 'Om';
$labels['preferences'] = 'Innstillingar';
$labels['userpreferences'] = 'Brukarinnstillingar';
$labels['editpreferences'] = 'Redigere brukarinnstillingar';
$labels['identities'] = 'Identitetar';
$labels['preferhtml'] = 'Føretrekk HTML';
$labels['defaultcharset'] = 'Standard karaktersett (charset)';
$labels['htmlmessage'] = 'HTML-melding';
$labels['messagepart'] = 'Del';
$labels['digitalsig'] = 'Digital signatur';
$labels['dateformat'] = 'Datoformat';
$labels['timeformat'] = 'Tidsformat';
$labels['prettydate'] = 'Pene datoar';
$labels['setdefault'] = 'Set som standard';
$labels['autodetect'] = 'Automatisk';
$labels['language'] = 'Språk';
$labels['timezone'] = 'Tidssone';
$labels['pagesize'] = 'Rader pr side';
$labels['signature'] = 'Signartur';
$labels['dstactive'] = 'Sumartid';
$labels['showinextwin'] = 'Opna melding i nytt vindauge';
$labels['composeextwin'] = 'Skriv i nytt vindauge';
$labels['htmleditor'] = 'Lag HTML-meldingar';
$labels['htmlonreply'] = 'ved svar på HTML-melding';
$labels['htmlonreplyandforward'] = 'ved vidaresending av eller svar på HTML-melding';
$labels['htmlsignature'] = 'HTML-signatur';
$labels['previewpane'] = 'Vis førehandsvisningsboks';
$labels['skin'] = 'Bunad';
$labels['logoutclear'] = 'Fjern alt i «sletta element» ved utlogging';
$labels['logoutcompact'] = 'Samanpress innboks ved utlogging';
$labels['uisettings'] = 'Brukargrensesnitt';
$labels['serversettings'] = 'Tenarinstillingar';
$labels['mailboxview'] = 'Epostboksvisning';
$labels['mdnrequests'] = 'Sender-notifisering';
$labels['askuser'] = 'spør brukaren';
$labels['autosend'] = 'send automatisk';
$labels['autosendknown'] = 'send kvittering til kontaktane mine, ellers spør meg';
$labels['autosendknownignore'] = 'send kvittering til kontaktane mine, ellers oversjå';
$labels['readwhendeleted'] = 'Marker melding som lese ved sletting';
$labels['flagfordeletion'] = 'Flagg meldinga for sletting i staden for å sletta';
$labels['skipdeleted'] = 'Ikkje vis sletta epostar';
$labels['deletealways'] = 'Slett epostar som ikkje kan flyttast til søppelkorga';
$labels['deletejunk'] = 'Slett meldingar i spam direkte';
$labels['showremoteimages'] = 'Vis eksterne bilete';
$labels['fromknownsenders'] = 'frå kjende sendarar';
$labels['always'] = 'alltid';
$labels['showinlineimages'] = 'Vis vedlagte bilete under meldinga';
$labels['autosavedraft'] = 'Lagra kladd automatisk';
$labels['everynminutes'] = 'kvart $n minutt';
$labels['refreshinterval'] = 'Oppdater (sjekk for nye meldingar osv.)';
$labels['never'] = 'aldri';
$labels['immediately'] = 'med ein gong';
$labels['messagesdisplaying'] = 'Meldingar som viser';
$labels['messagescomposition'] = 'Meldingar sin komposisjon';
$labels['mimeparamfolding'] = 'Vedleggsnamn';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (other)';
$labels['force7bit'] = 'Bruk MIME-enkoding for 8-bit characterer (æøå og slik)';
$labels['advancedoptions'] = 'Avanserte val';
$labels['focusonnewmessage'] = 'Fokuser nettlesarvindauge på ny epost';
$labels['checkallfolders'] = 'Sjekk alle mappar for nye epostar';
$labels['defaultfont'] = 'Standard skrifttype i HTML-melding';
$labels['mainoptions'] = 'Hovudinnstillingar';
$labels['browseroptions'] = 'Alternativ for nettlesar';
$labels['section'] = 'Seksjon';
$labels['maintenance'] = 'Vedlikehald';
$labels['newmessage'] = 'Ny epost';
$labels['signatureoptions'] = 'Signatur-innstillingar';
$labels['whenreplying'] = 'Når du svarar';
$labels['replyempty'] = 'Ikkje siter den opphavlege meldinga';
$labels['replytopposting'] = 'start ny epost oppante originalen';
$labels['replybottomposting'] = 'start ny epost nedanfor originalen';
$labels['replyremovesignature'] = 'Fjern den original signatur frå eposten når du svarar';
$labels['autoaddsignature'] = 'Legg signatur til automatisk';
$labels['newmessageonly'] = 'berre på nye epostar';
$labels['replyandforwardonly'] = 'berre på svar og vidaresending';
$labels['insertsignature'] = 'Sett inn signatur';
$labels['afternseconds'] = 'etter $n sekund';
$labels['reqmdn'] = 'Alltid be om svarkvittering';
$labels['reqdsn'] = 'Alltid be om leveringsstatus';
$labels['replysamefolder'] = 'Legg svar i mappa til meldinga det vert svara på';
$labels['defaultabook'] = 'Standard adressebok';
$labels['autocompletesingle'] = 'Hopp over alternative e-postadresser i autofullføring';
$labels['listnamedisplay'] = 'Vis kontaktar som';
$labels['spellcheckbeforesend'] = 'Kontroller staving før ei melding sendast';
$labels['spellcheckoptions'] = 'Alternativ for stavekontroll';
$labels['spellcheckignoresyms'] = 'Ignorer ord med symbol';
$labels['spellcheckignorenums'] = 'Ignorer ord med tal';
$labels['spellcheckignorecaps'] = 'Ignorer ord med berre store bokstavar';
$labels['addtodict'] = 'Legg til i ordliste';
$labels['mailtoprotohandler'] = 'Registrer protokollhandsaming for mailto-lenkjer';
$labels['forwardmode'] = 'Meldingar vidaresendast';
$labels['inline'] = 'i teksten';
$labels['asattachment'] = 'som vedlegg';
$labels['allmessages'] = 'alle meldingar';
$labels['folder'] = 'Mappe';
$labels['folders'] = 'Mapper';
$labels['foldername'] = 'Mappenamn';
$labels['subscribed'] = 'Abonnert';
$labels['messagecount'] = 'Meldingar';
$labels['create'] = 'Opprette';
$labels['createfolder'] = 'Opprett ny mappe';
$labels['managefolders'] = 'Mappehandsaming';
$labels['specialfolders'] = 'Spesialmapper';
$labels['properties'] = 'Eigenskapar';
$labels['folderproperties'] = 'Eigenskapar for mappe';
$labels['parentfolder'] = 'Mappa over';
$labels['location'] = 'Stad';
$labels['info'] = 'Informasjon';
$labels['getfoldersize'] = 'Klikk for å få mappestørrelse';
$labels['changesubscription'] = 'Klikk for å endre abonnement';
$labels['foldertype'] = 'Mappetype';
$labels['personalfolder'] = 'Privat mappe';
$labels['otherfolder'] = 'Annan brukar si mappe';
$labels['sharedfolder'] = 'Offentleg mappe';
$labels['sortby'] = 'Sorter etter';
$labels['sortasc'] = 'Sorter stigande';
$labels['sortdesc'] = 'Sorter søkkjande';
$labels['undo'] = 'Gjer om';
$labels['installedplugins'] = 'Installerte tillegg';
$labels['plugin'] = 'Tilleggsmodul';
$labels['version'] = 'Versjon';
$labels['source'] = 'Kjelde';
$labels['license'] = 'Lisens';
$labels['support'] = 'Få hjelp';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'UNicode';
$labels['english'] = 'Engelsk';
$labels['westerneuropean'] = 'Vest-europesik';
$labels['easterneuropean'] = 'Aust-europesik';
$labels['southeasterneuropean'] = 'Sør-aust-europeisk';
$labels['baltic'] = 'Baltisk';
$labels['cyrillic'] = 'Kyrilisk';
$labels['arabic'] = 'Arabisk';
$labels['greek'] = 'Gresk';
$labels['hebrew'] = 'Hebraisk';
$labels['turkish'] = 'Tyrkisk';
$labels['nordic'] = 'Nordisk';
$labels['thai'] = 'Thai';
$labels['celtic'] = 'Keltisk';
$labels['vietnamese'] = 'Vietnamesisk';
$labels['japanese'] = 'Japansk';
$labels['korean'] = 'Koreansk';
$labels['chinese'] = 'Kinesisk';
