<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Vcard Attachments plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['addvcardmsg'] = 'הוספת כרטיס ביקור בפורמט vCard לספר הכתובות';
$labels['vcardsavefailed'] = 'לא ניתן לשמור את כרטיס הביקור  vCard';
$labels['attachvcard'] = 'צרפ/י קובץ חתימה (vCard)';
$labels['vcardattached'] = 'צורף קובץ vCard';
$labels['vcard'] = 'קובץ חתימה (vCard)';
$labels['forwardvcard'] = 'העברה של כרטיס ביקור';
$labels['contactsattached'] = 'להודעה זו קשורים num$ אנשי קשר';
$labels['importedsuccessfully'] = 'אנשי קשר יובאו בהצלחה לפנקס הכתובות';
