<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Deling';
$labels['myrights'] = 'Adgangrettigheder';
$labels['username'] = 'Bruger:';
$labels['advanced'] = 'Avanceret tilstand';
$labels['add'] = 'Tilføje';
$labels['newuser'] = 'Tilføj indgang';
$labels['editperms'] = 'Rediger tilladelser';
$labels['actions'] = 'Tilgangsrettigheder...';
$labels['anyone'] = 'Alle brugere';
$labels['anonymous'] = 'Gæst (anonym)';
$labels['identifier'] = 'Identifikator';
$labels['acll'] = 'Slå op';
$labels['aclr'] = 'Læs beskeder';
$labels['acls'] = 'Behold læst-status';
$labels['aclw'] = 'Skriv flag';
$labels['acli'] = 'Indsæt (kopier ind i)';
$labels['aclp'] = 'Send';
$labels['aclc'] = 'Opret undermapper';
$labels['aclk'] = 'Opret undermapper';
$labels['acld'] = 'Slet beskeder';
$labels['aclt'] = 'Slet beskeder';
$labels['acle'] = 'Udslet';
$labels['aclx'] = 'Slet mappe';
$labels['acla'] = 'Administrer';
$labels['acln'] = 'Annoter beskeder';
$labels['aclfull'] = 'Fuld kontrol';
$labels['aclother'] = 'Andet';
$labels['aclread'] = 'Læse';
$labels['aclwrite'] = 'Skrive';
$labels['acldelete'] = 'Slet';
$labels['shortacll'] = 'Slå op';
$labels['shortaclr'] = 'Læse';
$labels['shortacls'] = 'Behold';
$labels['shortaclw'] = 'Skrive';
$labels['shortacli'] = 'Indsæt';
$labels['shortaclp'] = 'Send';
$labels['shortaclc'] = 'Opret';
$labels['shortaclk'] = 'Opret';
$labels['shortacld'] = 'Slet';
$labels['shortaclt'] = 'Slet';
$labels['shortacle'] = 'Udslet';
$labels['shortaclx'] = 'Slet mappe';
$labels['shortacla'] = 'Administrer';
$labels['shortacln'] = 'Annoter';
$labels['shortaclother'] = 'Andet';
$labels['shortaclread'] = 'Læse';
$labels['shortaclwrite'] = 'Skrive';
$labels['shortacldelete'] = 'Slet';
$labels['longacll'] = 'Mappen er synlig på listen og kan abonneres på';
$labels['longaclr'] = 'Mappen kan åbnes for læsning';
$labels['longacls'] = 'Beskeders Læst-flag kan ændres';
$labels['longaclw'] = 'Beskeders flag og nøgleord kan ændres med undtagelse af Læst og Slettet';
$labels['longacli'] = 'Beskeder kan blive skrevet eller kopieret til mappen';
$labels['longaclp'] = 'Beskeder kan sendes til denne mappe';
$labels['longaclc'] = 'Mapper kan blive oprettet (eller omdøbt) direkte under denne mappe';
$labels['longaclk'] = 'Mapper kan blive oprettet (eller omdøbt) direkte under denne mappe';
$labels['longacld'] = 'Beskeders Slet-flag kan ændres';
$labels['longaclt'] = 'Beskeders Slet-flag kan ændres';
$labels['longacle'] = 'Beskeder kan slettes';
$labels['longaclx'] = 'Mappen kan blive slettet eller omdøbt';
$labels['longacla'] = 'Mappen adgangsrettigheder kan ændres';
$labels['longacln'] = 'Meddelte delte metadata (annoteringer) kan ændres';
$labels['longaclfull'] = 'Fuld kontrol inklusiv mappeadministration';
$labels['longaclread'] = 'Mappen kan åbnes for læsning';
$labels['longaclwrite'] = 'Beskeder kan blive markeret, skrevet eller kopieret til mappen';
$labels['longacldelete'] = 'Beskeder kan slettes';
$labels['longaclother'] = 'Andre adgangsrettigheder';
$labels['ariasummaryacltable'] = 'Liste over adgangsrettigheder';
$labels['arialabelaclactions'] = 'Liste handlinger';
$labels['arialabelaclform'] = 'Adgangsret form';
$messages['deleting'] = 'Slette rettigheder...';
$messages['saving'] = 'Gemme rettigheder...';
$messages['updatesuccess'] = 'Tilgangsrettighederne blev ændret';
$messages['deletesuccess'] = 'Sletterettigheder blev ændret';
$messages['createsuccess'] = 'Tilgangsrettigheder blev tilføjet';
$messages['updateerror'] = 'Kunne ikke opdatere adgangsrettigheder';
$messages['deleteerror'] = 'Kunne ikke slette tilgangsrettigheder';
$messages['createerror'] = 'Kunne ikke tilføje tilgangsrettigheder';
$messages['deleteconfirm'] = 'Er du sikker på, at du vil slette tilgangsrettigheder fra de(n) valgte bruger(e)?';
$messages['norights'] = 'Der er ikke specificeret nogle rettigheder!';
$messages['nouser'] = 'Der er ikke angiver et brugernavn!';
