<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Филтри ';
$labels['managefilters'] = 'Управувај филтри за дојдовна пошта';
$labels['filtername'] = 'Име на филтер ';
$labels['newfilter'] = 'Нов филтер ';
$labels['filteradd'] = 'Додај филтер ';
$labels['filterdel'] = 'Избришај филтер ';
$labels['scope'] = 'Опсег';
$labels['moveup'] = 'Помести нагоре ';
$labels['movedown'] = 'Помести надолу ';
$labels['filterallof'] = 'Појавување на сите од следниве правила';
$labels['filteranyof'] = 'Појавување на било кои од следниве правила';
$labels['filterany'] = 'Сите пораки ';
$labels['filtercontains'] = 'Содржи';
$labels['filternotcontains'] = 'Не содржи';
$labels['filteris'] = 'Е еднакво на ';
$labels['filterisnot'] = 'Не е еднакво на ';
$labels['filterexists'] = 'Постои ';
$labels['filternotexists'] = 'Не постои ';
$labels['filtermatches'] = 'Се совпаѓаат изразувањата ';
$labels['filternotmatches'] = 'Не се совпаѓаат изразувањата';
$labels['filterregex'] = 'Се совпаѓаат регуларни изразувања';
$labels['filternotregex'] = 'Не се совпаѓаат регуларни изразувања';
$labels['filterunder'] = 'Под ';
$labels['filterover'] = 'Над';
$labels['addrule'] = 'Додај правило';
$labels['delrule'] = 'Избришај правило';
$labels['messagemoveto'] = 'Премести порака во ';
$labels['messageredirect'] = 'Пренасочи порака до ';
$labels['messagecopyto'] = 'Копирај порака до ';
$labels['messagesendcopy'] = 'Прати порака до ';
$labels['messagereply'] = 'Врати со порака ';
$labels['messagedelete'] = 'Избриши порака ';
$labels['messagediscard'] = 'Отфрли со порака ';
$labels['messagekeep'] = 'Задржи ја пораката во дојдовно сандаче ';
$labels['messagesrules'] = 'За дојдовна пошта:';
$labels['messagesactions'] = '...Изврши ги следните акции:';
$labels['add'] = 'Додај';
$labels['del'] = 'Избриши';
$labels['sender'] = 'Праќач';
$labels['recipient'] = 'Примач';
$labels['vacationaddr'] = 'Мојата електорнска пошта:';
$labels['vacationdays'] = 'Колку често праќа пораки (дневно):';
$labels['vacationinterval'] = 'Колку често праќа пораки:';
$labels['vacationreason'] = 'Тело на порака (причина за одмор)';
$labels['vacationfrom'] = 'Врати адреса на испраќач:';
$labels['vacationsubject'] = 'Предмет на порака ';
$labels['days'] = 'Денови';
$labels['seconds'] = 'Секунди';
$labels['rulestop'] = 'Престани да евалуираш правила ';
$labels['enable'] = 'Овозможи/Оневозможи';
$labels['filtersets'] = 'Сетови филтри';
$labels['filterseteditraw'] = 'Уреди го филтер сетот ';
$labels['filterdef'] = 'Дефиниција на филтер ';
$labels['active'] = 'Активен';
$labels['none'] = 'Нема ';
$labels['fromset'] = 'од сет ';
$labels['fromfile'] = 'од папка';
$labels['filterdisabled'] = 'Филтер исклучен';
$labels['countisgreaterthan'] = 'Бројот е поголем од ';
$labels['countisgreaterthanequal'] = 'бројот е поголем од или еднаков на ';
$labels['countislessthan'] = 'бројот е помал од ';
$labels['countislessthanequal'] = 'бројот е помл од или еднаков на ';
$labels['countequals'] = 'бројот е еднаков на ';
$labels['countnotequals'] = 'бројот не е еднаков на ';
$labels['valueisgreaterthan'] = 'вредноста е поголема од ';
$labels['valueisgreaterthanequal'] = 'вредноста е поголема од или еднаква на ';
$labels['valueislessthan'] = 'вредноста е помала од ';
$labels['valueislessthanequal'] = 'вредноста е помало од или еднаква на ';
$labels['valueequals'] = 'вредноста е еднаква на ';
$labels['valuenotequals'] = 'вредноста не е еднаква на ';
$labels['setflags'] = 'Постави знамиња на пораката ';
$labels['addflags'] = 'Додај знамиња на пораката ';
$labels['removeflags'] = 'Тргни знамиња од пораката ';
$labels['flagread'] = 'Читај';
$labels['flagdeleted'] = 'Избришани';
$labels['flaganswered'] = 'Одговорени';
$labels['flagflagged'] = 'Означени';
$labels['flagdraft'] = 'Предлог';
$labels['setvariable'] = 'Постави променлива';
$labels['setvarname'] = 'Име на променлива:';
$labels['setvarvalue'] = 'Вредност на променлива:';
$labels['setvarmodifiers'] = 'Модификатори:';
$labels['varlower'] = 'мали букви';
$labels['varupper'] = 'големи букви';
$labels['varlowerfirst'] = 'мала прва буква';
$labels['varupperfirst'] = 'голем прва буква';
$labels['varquotewildcard'] = 'цитирај специјален карактер ';
$labels['varlength'] = 'должина';
$labels['notify'] = 'Испрати известување';
$labels['notifytarget'] = 'Цел на известување:';
$labels['notifymessage'] = 'Порака за известување (незадолжително):';
$labels['notifyoptions'] = 'Опции за известување (незадолжително):';
$labels['notifyfrom'] = 'Известување за испраќачот (незадолжително):';
$labels['notifyimportance'] = 'Важност:';
$labels['notifyimportancelow'] = 'ниско';
$labels['notifyimportancenormal'] = 'нормално';
$labels['notifyimportancehigh'] = 'високо';
$labels['notifymethodmailto'] = 'Електронска пошта';
$labels['notifymethodtel'] = 'Телефон';
$labels['notifymethodsms'] = 'СМС';
$labels['filtercreate'] = 'Креирај филтер';
$labels['usedata'] = 'Искористи ги следните податоци за филтер:';
$labels['nextstep'] = 'Следен чекор';
$labels['...'] = '...';
$labels['string'] = 'Низа';
$labels['currdate'] = 'Денешна дата ';
$labels['datetest'] = 'Дата ';
$labels['dateheader'] = 'Заглавие';
$labels['year'] = 'година';
$labels['month'] = 'месец';
$labels['day'] = 'ден';
$labels['date'] = 'дата (гггг-мм-дд)';
$labels['julian'] = 'дата (јулијански календар)';
$labels['hour'] = 'час';
$labels['minute'] = 'минута';
$labels['second'] = 'секунда';
$labels['time'] = 'време (чч:мм:сс)';
$labels['iso8601'] = 'дата (ISO8601)';
$labels['std11'] = 'дата (RFC2822)';
$labels['zone'] = 'временска зона';
$labels['weekday'] = 'ден од неделата (0-6)';
$labels['advancedopts'] = 'Напредни опции';
$labels['body'] = 'Тело';
$labels['address'] = 'адреса';
$labels['envelope'] = 'плик';
$labels['modifier'] = 'модификатор:';
$labels['text'] = 'текст';
$labels['undecoded'] = 'Недекодирано (сурово)';
$labels['contenttype'] = 'тип на содржина';
$labels['modtype'] = 'Тип:';
$labels['allparts'] = 'сите ';
$labels['domain'] = 'домен';
$labels['localpart'] = 'локален дел';
$labels['user'] = 'корисник';
$labels['detail'] = 'детал';
$labels['comparator'] = 'Компаратор:';
$labels['default'] = 'стандардно';
$labels['octet'] = 'строг (октет)';
$labels['asciicasemap'] = 'Нечуствителен за големи и мали букви (ascii-csemap)';
$labels['asciinumeric'] = 'Нумерички (ascii-numeric)';
$labels['index'] = 'Индекс:';
$labels['indexlast'] = 'наназад';
$labels['spamtestequals'] = 'Е еднакво на ';
$labels['spamtestnotequals'] = 'Не е еднакво на ';
$labels['vacation.reply'] = 'Порака за одговор ';
$labels['vacation.advanced'] = 'Напредни подесувања';
$labels['vacation.from'] = 'Одговори на адресата на испраќачот';
$labels['vacation.subject'] = 'Предмет';
$labels['vacation.body'] = 'Тело';
$labels['vacation.status'] = 'Статус ';
$labels['vacation.on'] = 'Вклучи';
$labels['vacation.off'] = 'Исклучи';
$labels['vacation.addresses'] = 'Моите електронски пошти';
$labels['vacation.interval'] = 'Интервал на враќање ';
$labels['vacation.saving'] = 'Зачувување на податок...';
$labels['vacation.action'] = 'Акција за дојдовна порака';
$labels['vacation.keep'] = 'Задржи';
$labels['vacation.discard'] = 'Отфрли';
$labels['vacation.redirect'] = 'Пренасочи до';
$labels['vacation.copy'] = 'Испрати копија до ';
$labels['forward.redirect'] = 'Пренасочи до';
$labels['forward.copy'] = 'Испрати копија до ';
$labels['forward.on'] = 'Вклучи';
$labels['forward.off'] = 'Исклучи';
$labels['forward.saving'] = 'Зачувување на податок...';
$labels['filladdresses'] = 'Пополни со сите мои адреси ';
$labels['arialabelfiltersetactions'] = 'Акции на филтер сет ';
$labels['arialabelfilteractions'] = 'Акции на филтер ';
$labels['arialabelfilterform'] = 'Својства на филтер ';
$labels['ariasummaryfilterslist'] = 'Иста од филтри';
$labels['ariasummaryfiltersetslist'] = 'Листа од филтер сетови';
$labels['filterstitle'] = 'Уреди ги дојдовните филтри за пошта ';
$labels['vacationtitle'] = 'Уреди го надвор од канцеларија правилото';
$labels['message'] = 'Порака ';
$labels['duplicate'] = 'е дупликат ';
$labels['notduplicate'] = 'не е дупликат';
$labels['duplicate.handle'] = 'Справи се со:';
$labels['duplicate.header'] = 'заглавие:';
$labels['duplicate.uniqueid'] = 'идентификатор:';
$labels['duplicate.seconds'] = 'Истек на време (секунди):';
$labels['duplicate.last'] = 'Во однос на последното извршување';
$messages['filterunknownerror'] = 'Непозната грешка на серверот.';
$messages['filterconnerror'] = 'Не може да се поврзе со серверот .';
$messages['filterdeleteerror'] = 'Не може да се избришат филтри. Настана грешка со серверот  ';
$messages['filterdeleted'] = 'Филтерот е успешно избришан';
$messages['filtersaved'] = 'Филтерот е успешно зачуван';
$messages['filtersaveerror'] = 'Не може да се зачува филтерот. Настана грешка со серверот ';
$messages['filterformerror'] = 'Формата за филтер содржи грешка';
$messages['filterdeleteconfirm'] = 'Дали навистина сакате да го избришате избраниот филтер?';
$messages['ruledeleteconfirm'] = 'Дали сте сигурни дека сакате да го избришате избраното правило?';
$messages['actiondeleteconfirm'] = 'Дали сте сигурни дека сакате да го избришате избранота акција?';
$messages['forbiddenchars'] = 'Забранет карактер во полето.';
$messages['cannotbeempty'] = 'Полето не може да биде празно.';
$messages['ruleexist'] = 'Веќе постои филтер со избраното поле.';
$messages['activateerror'] = 'Не може да се овозможи селектираниот филтер(и). настана грешка со серверот.';
$messages['deactivateerror'] = 'Не може да се оневозможи избраниот филтер(и). Настана грешка со серверот.';
$messages['deactivated'] = 'Филтер(и) е успешно оневозможен.';
$messages['activated'] = 'Филтер(и) е успешно овозможен.';
$messages['moved'] = 'Филтерот е успешно преместен.';
$messages['moveerror'] = 'Не може да се премести избраниот филтер. Настана грешка со серверот.';
$messages['nametoolong'] = 'Името е премногу долго.';
$messages['namereserved'] = 'Резервирано име.';
$messages['setexist'] = 'Сетот веќе постои.';
$messages['nodata'] = 'Мора барем една позиција да биде селектирана!';
$messages['invaliddateformat'] = 'Невалиден датум или дел од форматот за датум';
$messages['saveerror'] = 'Податокот не може да се зачува. Настана грешка со серверот.';
$messages['emptyvacationbody'] = 'Потребно е тело на пораката за одмор!';
$messages['duplicate.conflict.err'] = 'Заглавје и единствен идентификатор не се дозволени.';
