<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'إظهار رسالة تنبيه فى المتصفح عند وصول رسالة جديدة';
$labels['desktop'] = 'إظهار رسالة تنبيه على سطح المكتب عند وصول رسالة جديدة';
$labels['sound'] = 'التنبيه الصوتى عند وصول رسالة جديدة';
$labels['test'] = 'إختبار';
$labels['title'] = 'رسالة جديدة';
$labels['body'] = 'لديك رسالة جديدة';
$labels['testbody'] = 'هذه رسالة تجربية';
$labels['desktopdisabled'] = 'رسائل التنبيه على سطح المكتب غير مفعلة فى متصفح الانترنت الخاص بك';
$labels['desktopunsupported'] = 'المتصفح الخاص بك لا يدعم رسائل سطح المكتب';
$labels['desktoptimeout'] = 'اغلاق تنبيهات سطح المكتب';
