<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Mostrar notificação quando uma nova mensagem chegar';
$labels['desktop'] = 'Mostrar alerta no ambiente de trabalho de nova mensagem';
$labels['sound'] = 'Alerta sonoro para nova mensagem';
$labels['test'] = 'Testar';
$labels['title'] = 'Novo email!';
$labels['body'] = 'Você recebeu uma nova mensagem.';
$labels['testbody'] = 'Isto é uma notificação de teste.';
$labels['desktopdisabled'] = 'As notificações no ambiente de trabalho estão desactivadas no seu navegador.';
$labels['desktopunsupported'] = 'O seu navegador não suporta notificações no ambiente de trabalho';
$labels['desktoptimeout'] = 'Fechar notificação no ambiente de trabalho';
