<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Beṭṭu';
$labels['myrights'] = 'Izerfan n unekcum';
$labels['username'] = 'Aseqdac:';
$labels['advanced'] = 'Askar leqqayen';
$labels['newuser'] = 'Rnu anekcam';
$labels['editperms'] = 'Ẓreg tisirag';
$labels['actions'] = 'Tigawin n izerfan n unekcum...';
$labels['anyone'] = 'Akk iseqdacen (yal yiwen)';
$labels['anonymous'] = 'Inebgawen (udrigen)';
$labels['identifier'] = 'Sulu';
$labels['acll'] = 'Nadi';
$labels['aclr'] = 'Ɣer iznan';
$labels['aclp'] = 'Aru izen';
$labels['aclc'] = 'Rnu ikaramen isnawanen';
$labels['aclk'] = 'Rnu ikaramen isnawanen';
$labels['acld'] = 'Kkes iznan';
$labels['aclt'] = 'Ɣer iznan';
$labels['acle'] = 'Sfeḍ';
$labels['aclx'] = 'Kkes akaram';
$labels['acla'] = 'Sefrek';
$labels['acln'] = 'Rnu tizmilin i yiznan';
$labels['aclother'] = 'Ayen-nniḍen';
$labels['aclread'] = 'Ɣeṛ';
$labels['aclwrite'] = 'Aru';
$labels['acldelete'] = 'Kkes';
$labels['shortacll'] = 'Nadi';
$labels['shortaclr'] = 'Ɣeṛ';
$labels['shortaclw'] = 'Aru';
$labels['shortaclp'] = 'Aru izen';
$labels['shortaclc'] = 'Rnu';
$labels['shortaclk'] = 'Rnu';
$labels['shortacld'] = 'Kkes';
$labels['shortaclt'] = 'Kkes';
$labels['shortacle'] = 'Sfeḍ';
$labels['shortacla'] = 'Sefrek';
$labels['shortacln'] = 'Rnu tazmilt';
$labels['shortaclother'] = 'Ayen-nniḍen';
$labels['shortaclread'] = 'Ɣeṛ';
$labels['shortaclwrite'] = 'Aru';
$labels['shortacldelete'] = 'Kkes';
$messages['deleting'] = 'Kkes akk izerfan n unekcum...';
