<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Skupna raba';
$labels['myrights'] = 'Pravice dostopa';
$labels['username'] = 'Uporabnik:';
$labels['advanced'] = 'Napredni način';
$labels['add'] = 'Dodaj';
$labels['newuser'] = 'Dodaj vnos';
$labels['editperms'] = 'Uredi pravice';
$labels['actions'] = 'Nastavitve pravic dostopa';
$labels['anyone'] = 'Vsi uporabniki';
$labels['anonymous'] = 'Gosti';
$labels['identifier'] = 'Označevalnik';
$labels['acll'] = 'Iskanje';
$labels['aclr'] = 'Prebrana sporočila';
$labels['acls'] = 'Ohrani status \'Prebrano\'';
$labels['aclw'] = 'Označi pisanje sporočila';
$labels['acli'] = 'Vstavi (Kopiraj v)';
$labels['aclp'] = 'Objava';
$labels['aclc'] = 'Ustvari podmape';
$labels['aclk'] = 'Ustvari podmape';
$labels['acld'] = 'Izbriši sporočila';
$labels['aclt'] = 'Izbriši sporočila';
$labels['acle'] = 'Izbriši';
$labels['aclx'] = 'Izbriši mapo';
$labels['acla'] = 'Uredi';
$labels['acln'] = 'Komentarji';
$labels['aclfull'] = 'Popolno upravljanje';
$labels['aclother'] = 'Ostalo';
$labels['aclread'] = 'Preberi';
$labels['aclwrite'] = 'Sestavi';
$labels['acldelete'] = 'Izbriši';
$labels['shortacll'] = 'Iskanje';
$labels['shortaclr'] = 'Preberi';
$labels['shortacls'] = 'Ohrani';
$labels['shortaclw'] = 'Sestavi';
$labels['shortacli'] = 'Vstavi';
$labels['shortaclp'] = 'Objava';
$labels['shortaclc'] = 'Ustvari';
$labels['shortaclk'] = 'Ustvari';
$labels['shortacld'] = 'Izbriši';
$labels['shortaclt'] = 'Izbriši';
$labels['shortacle'] = 'Izbriši';
$labels['shortaclx'] = 'Izbriši mapo';
$labels['shortacla'] = 'Uredi';
$labels['shortacln'] = 'Dodaj komentar';
$labels['shortaclother'] = 'Ostalo';
$labels['shortaclread'] = 'Preberi';
$labels['shortaclwrite'] = 'Sestavi';
$labels['shortacldelete'] = 'Izbriši';
$labels['longacll'] = 'Mapa je vidna na seznamih in jo lahko naročite';
$labels['longaclr'] = 'Mapa je na voljo za branje';
$labels['longacls'] = 'Oznaka \'Prebrano sporočilo\' je lahko spremenjena';
$labels['longaclw'] = 'Oznake sporočil in ključne besede je mogoče spremeniti, z izjemo oznak "Prebrano" in "Izbrisano';
$labels['longacli'] = 'Sporočilo je lahko poslano ali kopirano v mapo';
$labels['longaclp'] = 'Sporočilo je lahko poslano v to mapo';
$labels['longaclc'] = 'V tej mapi so lahko ustvarjene (ali preimenovane) podmape';
$labels['longaclk'] = 'V tej mapi so lahko ustvarjene (ali preimenovane) podmape';
$labels['longacld'] = 'Oznako sporočila  \'Izbrisano\' je mogoče spremeniti';
$labels['longaclt'] = 'Oznako sporočila  \'Izbrisano\' je mogoče spremeniti';
$labels['longacle'] = 'Sporočila so lahko izbrisana';
$labels['longaclx'] = 'Mapa je lahko izbrisana ali preimenovana';
$labels['longacla'] = 'Pravice na mapi so lahko spremenjene';
$labels['longacln'] = 'Metapodatke (komentarjev), ki so v skupni rabi, je mogoče spremeniti';
$labels['longaclfull'] = 'Popolno upravljanje, vključno z urejanjem map';
$labels['longaclread'] = 'Mapa je na voljo za branje';
$labels['longaclwrite'] = 'Sporočila je mogoče označiti, sestaviti ali kopirati v mapo';
$labels['longacldelete'] = 'Sporočila so lahko izbrisana';
$labels['longaclother'] = 'Ostale pravice dostopa';
$labels['ariasummaryacltable'] = 'Seznam pravic dostopa';
$labels['arialabelaclactions'] = 'Prikaži možnosti';
$labels['arialabelaclform'] = 'Obrazec za nastavitve pravic dostopa';
$messages['deleting'] = 'Brisanje pravic';
$messages['saving'] = 'Shranjevanje pravic';
$messages['updatesuccess'] = 'Pravice so bile uspešno spremenjene';
$messages['deletesuccess'] = 'Pravice so bile uspešno izbrisane';
$messages['createsuccess'] = 'Pravice so bile uspešno dodane';
$messages['updateerror'] = 'Pravic ni mogoče posodobiti';
$messages['deleteerror'] = 'Pravic ni mogoče izbrisati';
$messages['createerror'] = 'Pravic ni bilo mogoče dodati';
$messages['deleteconfirm'] = 'Ste prepričani, da želite odstraniti pravice dostopa za izbrane uporabnike?';
$messages['norights'] = 'Pravic niste določili';
$messages['nouser'] = 'Niste določili uporabnišlega imena';
