<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Ndarje Me të Tjerë';
$labels['myrights'] = 'Të drejta Hyrjeje';
$labels['username'] = 'Përdorues:';
$labels['advanced'] = 'Mënyra e përparuar';
$labels['add'] = 'Shtoje';
$labels['newuser'] = 'Shtoni zë';
$labels['editperms'] = 'Përpunoni leje';
$labels['actions'] = 'Veprime të drejtash hyrjeje…';
$labels['anyone'] = 'Krejt përdoruesit (cilido)';
$labels['anonymous'] = 'Mysafirë (në mënyrë anonime)';
$labels['identifier'] = 'Identifikues';
$labels['acll'] = 'Kërkim';
$labels['aclr'] = 'Lexoni mesazhe';
$labels['acls'] = 'Mbaje gjendjen i Parë';
$labels['aclw'] = 'Shkruaju shenjat';
$labels['acli'] = 'Fut (Kopje te)';
$labels['aclp'] = 'Postim';
$labels['aclc'] = 'Krijo nëndosje';
$labels['aclk'] = 'Krijo nëndosje';
$labels['acld'] = 'Fshiji mesazhet';
$labels['aclt'] = 'Fshiji mesazhet';
$labels['acle'] = 'Spastroje';
$labels['aclx'] = 'Fshije dosjen';
$labels['acla'] = 'Administroni';
$labels['acln'] = 'Shto shënime te mesazhet';
$labels['aclfull'] = 'Kontroll i plotë';
$labels['aclother'] = 'Tjetër';
$labels['aclread'] = 'Leximi';
$labels['aclwrite'] = 'Shkrimi';
$labels['acldelete'] = 'Fshije';
$labels['shortacll'] = 'Kërkim';
$labels['shortaclr'] = 'Leximi';
$labels['shortacls'] = 'Mbaje';
$labels['shortaclw'] = 'Shkrimi';
$labels['shortacli'] = 'Fut';
$labels['shortaclp'] = 'Posto';
$labels['shortaclc'] = 'Krijoje';
$labels['shortaclk'] = 'Krijoje';
$labels['shortacld'] = 'Fshije';
$labels['shortaclt'] = 'Fshije';
$labels['shortacle'] = 'Spastro';
$labels['shortaclx'] = 'Fshirje dosjeje';
$labels['shortacla'] = 'Administro';
$labels['shortacln'] = 'Shto shënim';
$labels['shortaclother'] = 'Tjetër';
$labels['shortaclread'] = 'Leximi';
$labels['shortaclwrite'] = 'Shkrimi';
$labels['shortacldelete'] = 'Fshirjeje';
$labels['longacll'] = 'Dosja është e dukshme në lista dhe në të mund të pajtoheni';
$labels['longaclr'] = 'Dosja mund të hapet për lexim';
$labels['longacls'] = 'Mund të ndryshohet shenja Mesazhe të Parë';
$labels['longaclw'] = 'Mund të ndryshohen shenjat dhe fjalëkyçet për mesazhet, hiq të Parë dhe të Fshirë';
$labels['longacli'] = 'Mesazhet mund të shkruhen ose kopjohen në dosje';
$labels['longaclp'] = 'Mesazhet mund të postohen te kjo dosje';
$labels['longaclc'] = 'Dosjet mund të krijohen (ose riemërtohen) drejt e nën këtë dosje';
$labels['longaclk'] = 'Dosjet mund të krijohen (ose riemërtohen) drejt e nën këtë dosje';
$labels['longacld'] = 'Mund të ndryshohet shenja Mesazhe të Fshirë';
$labels['longaclt'] = 'Mund të ndryshohet shenja Mesazhe të Parë';
$labels['longacle'] = 'Mesazhet mund të spastrohen';
$labels['longaclx'] = 'Dosja mund të fshihet ose riemërtohet';
$labels['longacla'] = 'Mund të ndryshohen të drejta hyrjeje te dosja';
$labels['longacln'] = 'Mund të ndryshohen tejtëdhëna të përbashkëta (shënime) mesazhesh';
$labels['longaclfull'] = 'Kontroll i plotë, përfshi administrim dosjesh';
$labels['longaclread'] = 'Dosja mund të hapet për lexim';
$labels['longaclwrite'] = 'Mesazheve mund t’u vihet shenjë, shkruhen ose kopjohen te dosja';
$labels['longacldelete'] = 'Mesazhet mund të fshihen';
$labels['longaclother'] = 'Të tjera të drejta hyrjesh';
$labels['ariasummaryacltable'] = 'Listë të drejtash hyrjeje';
$labels['arialabelaclactions'] = 'Paraqit veprime';
$labels['arialabelaclform'] = 'Formular të drejtash hyrjeje';
$messages['deleting'] = 'Po fshihen të drejta hyrjeje…';
$messages['saving'] = 'Po ruhen të drejtash hyrjeje…';
$messages['updatesuccess'] = 'U ndryshuan me sukses të drejta hyrjeje';
$messages['deletesuccess'] = 'U fshinë me sukses të drejta hyrjeje';
$messages['createsuccess'] = 'U shtuan me sukses të drejta hyrjeje';
$messages['updateerror'] = 'S’arrihet të përditësohen të drejta hyrjeje';
$messages['deleteerror'] = 'S’arrihet të fshihen të drejta hyrjeje';
$messages['createerror'] = 'S’arrihet të shtohen të drejta hyrjeje';
$messages['deleteconfirm'] = 'Jeni i sigurt, doni t’i hiqni të drejta hyrjeje përdoruesit(ve) të përzgjedhur?';
$messages['norights'] = 'S’janë specifikuar të drejta!';
$messages['nouser'] = 'S’është specifikuar emër përdoruesi!';
