<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'UTC';
$labels['tz:africa'] = 'აფრიკა';
$labels['tz:africa:abidjan'] = 'აბიჯანი';
$labels['tz:africa:accra'] = 'აკრა';
$labels['tz:africa:algiers'] = 'ალჟირი';
$labels['tz:africa:asmara'] = 'ასმარა';
$labels['tz:africa:bamako'] = 'ბამაკო';
$labels['tz:africa:bangui'] = 'ბანგული';
$labels['tz:africa:banjul'] = 'ბანჯული';
$labels['tz:africa:bissau'] = 'ბისაუ';
$labels['tz:africa:blantyre'] = 'ბლანტირი';
$labels['tz:africa:brazzaville'] = 'ბრაზავილი';
$labels['tz:africa:bujumbura'] = 'ბუჟუმბურა';
$labels['tz:africa:cairo'] = 'ქაირო';
$labels['tz:africa:casablanca'] = 'კასაბლანკა';
$labels['tz:africa:ceuta'] = 'სეუტა';
$labels['tz:africa:conakry'] = 'კონაკრი';
$labels['tz:africa:dakar'] = 'დაქარი';
$labels['tz:africa:djibouti'] = 'ჯიბუტი';
$labels['tz:africa:douala'] = 'დუალა';
$labels['tz:africa:freetown'] = 'ფრიტაუნი';
$labels['tz:africa:gaborone'] = 'გაბორონე';
$labels['tz:africa:harare'] = 'ჰარარე';
$labels['tz:africa:johannesburg'] = 'იოჰანესბურგი';
$labels['tz:africa:juba'] = 'ჯუბა';
$labels['tz:africa:kampala'] = 'კამპალა';
$labels['tz:africa:khartoum'] = 'ხარტუმი';
$labels['tz:africa:kigali'] = 'კიგალი';
$labels['tz:africa:kinshasa'] = 'კინშასა';
$labels['tz:africa:lagos'] = 'ლაგოსი';
$labels['tz:africa:libreville'] = 'ლიბრევილი';
$labels['tz:africa:lome'] = 'ლომე';
$labels['tz:africa:luanda'] = 'ლუანდა';
$labels['tz:africa:lubumbashi'] = 'ლუბუმბაში';
$labels['tz:africa:lusaka'] = 'ლუსაკა';
$labels['tz:africa:malabo'] = 'მალაბო';
$labels['tz:africa:maputo'] = 'მაპუტო';
$labels['tz:africa:maseru'] = 'მასერუ';
$labels['tz:africa:mbabane'] = 'მბაბანე';
$labels['tz:africa:mogadishu'] = 'მოგადიშო';
$labels['tz:africa:monrovia'] = 'მონროვია';
$labels['tz:africa:nairobi'] = 'ნაირობი';
$labels['tz:africa:ndjamena'] = 'ნჯამენა';
$labels['tz:africa:niamey'] = 'ნიამეი';
$labels['tz:africa:nouakchott'] = 'ნუაქშოტი';
$labels['tz:africa:ouagadougou'] = 'უაგადუგუ';
$labels['tz:africa:porto-novo'] = 'პორტო-ნოვო';
$labels['tz:africa:tripoli'] = 'ტრიპოლი';
$labels['tz:africa:tunis'] = 'ტუნისი';
$labels['tz:africa:windhoek'] = 'ვინდჰუკი';
$labels['tz:america'] = 'ამერიკა';
$labels['tz:america:adak'] = 'ადაკი';
$labels['tz:america:anchorage'] = 'ანკორიჯი';
$labels['tz:america:anguilla'] = 'ანგუილა';
$labels['tz:america:antigua'] = 'ანტიგუა';
$labels['tz:america:araguaina'] = 'არაგუიაინა';
$labels['tz:america:argentina'] = 'არგენტინა';
$labels['tz:america:argentina:catamarca'] = 'კატამარკა';
$labels['tz:america:argentina:cordoba'] = 'კორდობა';
$labels['tz:america:argentina:jujuy'] = 'ხუხუი';
$labels['tz:america:argentina:mendoza'] = 'მენდოზა';
$labels['tz:america:argentina:salta'] = 'სალტა';
$labels['tz:america:argentina:tucuman'] = 'ტუკუმანი';
$labels['tz:america:argentina:ushuaia'] = 'უშუაია';
$labels['tz:america:aruba'] = 'არუბა';
$labels['tz:america:asuncion'] = 'ასუნსიონი';
$labels['tz:america:atikokan'] = 'ატიკოკანი';
$labels['tz:america:bahia'] = 'ბაია';
$labels['tz:america:barbados'] = 'ბარბადოსი';
$labels['tz:america:belem'] = 'ბელემი';
$labels['tz:america:belize'] = 'ბელიზი';
$labels['tz:america:blanc-sablon'] = 'ბლანკ-საბლონი';
$labels['tz:america:bogota'] = 'ბოგოტა';
$labels['tz:america:boise'] = 'ბოისე';
$labels['tz:america:cancun'] = 'კანკუნი';
$labels['tz:america:caracas'] = 'კარაკასი';
$labels['tz:america:cayenne'] = 'კაიენი';
$labels['tz:america:cayman'] = 'კეიმანი';
$labels['tz:america:chicago'] = 'ჩიკაგო';
$labels['tz:america:chihuahua'] = 'ჩიხუახუა';
$labels['tz:america:creston'] = 'კრესტონი';
$labels['tz:america:cuiaba'] = 'კუიაბა';
$labels['tz:america:curacao'] = 'კიურასაო';
$labels['tz:america:danmarkshavn'] = 'დანმარკშავნი';
$labels['tz:america:dawson'] = 'დოუსონი';
$labels['tz:america:denver'] = 'დენვერი';
$labels['tz:america:detroit'] = 'დეტროიტი';
$labels['tz:america:dominica'] = 'დომინიკა';
$labels['tz:america:edmonton'] = 'ედმონტონი';
$labels['tz:america:eirunepe'] = 'ეირუნეპე';
$labels['tz:america:fortaleza'] = 'ფორტალეზა';
$labels['tz:america:godthab'] = 'ნუუკი';
$labels['tz:america:grenada'] = 'გრენადა';
$labels['tz:america:guadeloupe'] = 'გვადელუპა';
$labels['tz:america:guatemala'] = 'გვატემალა';
$labels['tz:america:guayaquil'] = 'გუაიაკილი';
$labels['tz:america:guyana'] = 'გაიანა';
$labels['tz:america:halifax'] = 'ჰალიფაქსი';
$labels['tz:america:havana'] = 'ჰავანა';
$labels['tz:america:hermosillo'] = 'ერმოსილიო';
$labels['tz:america:indiana'] = 'ინდიანა';
$labels['tz:america:indiana:indianapolis'] = 'ინდიანაპოლისი';
$labels['tz:america:indiana:knox'] = 'ნოქსი';
$labels['tz:america:indiana:marengo'] = 'მარენგო';
$labels['tz:america:indiana:petersburg'] = 'პიტერსბურგი';
$labels['tz:america:indiana:vevay'] = 'ვივეი';
$labels['tz:america:indiana:vincennes'] = 'ვინსენსი';
$labels['tz:america:indiana:winamac'] = 'უინამაკი';
$labels['tz:america:inuvik'] = 'ინუვიკი';
$labels['tz:america:iqaluit'] = 'იკალუიტი';
$labels['tz:america:jamaica'] = 'იამაიკა';
$labels['tz:america:juneau'] = 'ჯუნო';
$labels['tz:america:kentucky'] = 'კენტუკი';
$labels['tz:america:kentucky:louisville'] = 'ლუისვილი';
$labels['tz:america:kentucky:monticello'] = 'მონტიჩელო';
$labels['tz:america:kralendijk'] = 'კრალენდეიკი';
$labels['tz:america:lima'] = 'ლიმა';
$labels['tz:america:maceio'] = 'მაკეიო';
$labels['tz:america:managua'] = 'მანაგუა';
$labels['tz:america:manaus'] = 'მანაუსი';
$labels['tz:america:marigot'] = 'მარიგო';
$labels['tz:america:martinique'] = 'მარტინიკა';
$labels['tz:america:matamoros'] = 'მატამოროსი';
$labels['tz:america:mazatlan'] = 'მაზატლანი';
$labels['tz:america:menominee'] = 'მენომინი';
$labels['tz:america:merida'] = 'მერიდა';
$labels['tz:america:metlakatla'] = 'მეტლაკატლა';
$labels['tz:america:miquelon'] = 'მიკელონი';
$labels['tz:america:moncton'] = 'მონქტონი';
$labels['tz:america:monterrey'] = 'მონტერეი';
$labels['tz:america:montevideo'] = 'მონტევიდეო';
$labels['tz:america:montserrat'] = 'მონცერატი';
$labels['tz:america:nassau'] = 'ნასაუ';
$labels['tz:america:nipigon'] = 'ნიპიგონი';
$labels['tz:america:nome'] = 'ნომი';
$labels['tz:america:noronha'] = 'ნორონია';
$labels['tz:america:north_dakota:beulah'] = 'ბიულა';
$labels['tz:america:north_dakota:center'] = 'ცენტრი';
$labels['tz:america:ojinaga'] = 'ოხინაგა';
$labels['tz:america:panama'] = 'პანამა';
$labels['tz:america:pangnirtung'] = 'პანგი';
$labels['tz:america:paramaribo'] = 'პარამირიბო';
$labels['tz:america:phoenix'] = 'ფენიქსი';
$labels['tz:america:port-au-prince'] = 'პორტ-ო-პრინცი';
$labels['tz:america:recife'] = 'რესიფი';
$labels['tz:america:regina'] = 'რეგინა';
$labels['tz:america:resolute'] = 'რესოლუტი';
$labels['tz:america:santarem'] = 'სანტარემი';
$labels['tz:america:santiago'] = 'სანტიაგო';
$labels['tz:america:scoresbysund'] = 'იტოკორტოორმიიტი';
$labels['tz:america:sitka'] = 'სიტკა';
$labels['tz:america:tegucigalpa'] = 'ტეგუსიგალპა';
$labels['tz:america:thule'] = 'თულე';
$labels['tz:america:tijuana'] = 'ტიხუანა';
$labels['tz:america:toronto'] = 'ტორონტო';
$labels['tz:america:tortola'] = 'ტორტოლა';
$labels['tz:america:vancouver'] = 'ვანკუვერი';
$labels['tz:america:whitehorse'] = 'უაიტჰორსი';
$labels['tz:america:winnipeg'] = 'უინიპეგი';
$labels['tz:america:yakutat'] = 'იაკუტატი';
$labels['tz:america:yellowknife'] = 'იელოუნაიფი';
$labels['tz:antarctica'] = 'ანტარქტიკა';
$labels['tz:antarctica:casey'] = 'კეისი';
$labels['tz:antarctica:davis'] = 'დავისი';
$labels['tz:antarctica:macquarie'] = 'მაკუორი';
$labels['tz:antarctica:mawson'] = 'მოუსონი';
$labels['tz:antarctica:mcmurdo'] = 'მაკმურდო';
$labels['tz:antarctica:palmer'] = 'პალმერი';
$labels['tz:antarctica:rothera'] = 'როტერა';
$labels['tz:antarctica:syowa'] = 'სიოვა';
$labels['tz:antarctica:troll'] = 'ტროლი';
$labels['tz:antarctica:vostok'] = 'ვოსტოკი';
$labels['tz:arctic'] = 'არქტიკა';
$labels['tz:arctic:longyearbyen'] = 'ლონგირი';
$labels['tz:asia'] = 'აზია';
$labels['tz:asia:aden'] = 'ადენი';
$labels['tz:asia:almaty'] = 'ალმა-ატა';
$labels['tz:asia:amman'] = 'ამანი';
$labels['tz:asia:anadyr'] = 'ანადირი';
$labels['tz:asia:aqtau'] = 'აქტაუ';
$labels['tz:asia:aqtobe'] = 'აქტობე';
$labels['tz:asia:ashgabat'] = 'აშხაბადი';
$labels['tz:asia:atyrau'] = 'ატირაუ';
$labels['tz:asia:baghdad'] = 'ბაღდადი';
$labels['tz:asia:bahrain'] = 'ბაჰრეინი';
$labels['tz:asia:baku'] = 'ბაქო';
$labels['tz:asia:bangkok'] = 'ბანგკოკი';
$labels['tz:asia:barnaul'] = 'ბარნაული';
$labels['tz:asia:beirut'] = 'ბეირუთი';
$labels['tz:asia:bishkek'] = 'ბიშკეკი';
$labels['tz:asia:brunei'] = 'ბრუნეი';
$labels['tz:asia:chita'] = 'ჩიტა';
$labels['tz:asia:choibalsan'] = 'ჩოიბალსანი';
$labels['tz:asia:colombo'] = 'კოლომბო';
$labels['tz:asia:damascus'] = 'დამასკო';
$labels['tz:asia:dhaka'] = 'დაკა';
$labels['tz:asia:dili'] = 'დილი';
$labels['tz:asia:dubai'] = 'დუბაი';
$labels['tz:asia:dushanbe'] = 'დუშანბე';
$labels['tz:asia:famagusta'] = 'ფამაგუსტა';
$labels['tz:asia:gaza'] = 'ღაზა';
$labels['tz:asia:hebron'] = 'ხებრონი';
$labels['tz:asia:hovd'] = 'ხოვდი';
$labels['tz:asia:irkutsk'] = 'ირკუტსკი';
$labels['tz:asia:jakarta'] = 'ჯაკარტა';
$labels['tz:asia:jayapura'] = 'ჯაიაპურა';
$labels['tz:asia:jerusalem'] = 'იერუსალიმი';
$labels['tz:asia:kabul'] = 'ქაბული';
$labels['tz:asia:kamchatka'] = 'კამჩატკა';
$labels['tz:asia:karachi'] = 'კარაჩი';
$labels['tz:asia:kathmandu'] = 'კატმანდუ';
$labels['tz:asia:khandyga'] = 'ხანდიგა';
$labels['tz:asia:kolkata'] = 'კოლკატა';
$labels['tz:asia:krasnoyarsk'] = 'კრასნოიარსკი';
$labels['tz:asia:kuching'] = 'კუჩინგი';
$labels['tz:asia:kuwait'] = 'კუვეიტი';
$labels['tz:asia:macau'] = 'მაკაო';
$labels['tz:asia:magadan'] = 'მაგადანი';
$labels['tz:asia:makassar'] = 'მაკასარი';
$labels['tz:asia:manila'] = 'მანილა';
$labels['tz:asia:muscat'] = 'მუსკატი';
$labels['tz:asia:nicosia'] = 'ნიქოზია';
$labels['tz:asia:novokuznetsk'] = 'ნოვოკუზნეცკი';
$labels['tz:asia:novosibirsk'] = 'ნოვოსიბირსკი';
$labels['tz:asia:omsk'] = 'ომსკი';
$labels['tz:asia:oral'] = 'ორალი';
$labels['tz:asia:pontianak'] = 'პონტიანაკი';
$labels['tz:asia:pyongyang'] = 'ფხენიანი';
$labels['tz:asia:qatar'] = 'კატარი';
$labels['tz:asia:qyzylorda'] = 'ყიზილორდა';
$labels['tz:asia:riyadh'] = 'ერ-რიადი';
$labels['tz:asia:sakhalin'] = 'სახალინი';
$labels['tz:asia:samarkand'] = 'სამარყანდა';
$labels['tz:asia:seoul'] = 'სეული';
$labels['tz:asia:shanghai'] = 'შანგჰაი';
$labels['tz:asia:singapore'] = 'სინგაპური';
$labels['tz:asia:srednekolymsk'] = 'სრედნოკოლიმსკი';
$labels['tz:asia:taipei'] = 'ტაიპეი';
$labels['tz:asia:tashkent'] = 'ტაშკენტი';
$labels['tz:asia:tbilisi'] = 'თბილისი';
$labels['tz:asia:tehran'] = 'თეირანი';
$labels['tz:asia:thimphu'] = 'თიმფუ';
$labels['tz:asia:tokyo'] = 'ტოკიო';
$labels['tz:asia:tomsk'] = 'ტომსკი';
$labels['tz:asia:ulaanbaatar'] = 'ულანბატორი';
$labels['tz:asia:urumqi'] = 'ურუმჩი';
$labels['tz:asia:ust-nera'] = 'უსტ-ნერა';
$labels['tz:asia:vientiane'] = 'ვიენტიანი';
$labels['tz:asia:vladivostok'] = 'ვლადივოსტოკი';
$labels['tz:asia:yakutsk'] = 'იაკუტსკი';
$labels['tz:asia:yangon'] = 'იანგონი';
$labels['tz:asia:yekaterinburg'] = 'ეკატერინბურგი';
$labels['tz:asia:yerevan'] = 'ერევანი';
$labels['tz:atlantic'] = 'ატლანტიკის ოკეანე';
$labels['tz:atlantic:azores'] = 'აზორები';
$labels['tz:atlantic:bermuda'] = 'ბერმუდა';
$labels['tz:atlantic:canary'] = 'კანარი';
$labels['tz:atlantic:faroe'] = 'ფარო';
$labels['tz:atlantic:madeira'] = 'მადეირა';
$labels['tz:atlantic:reykjavik'] = 'რეიკიავიკი';
$labels['tz:atlantic:stanley'] = 'სტენლი';
$labels['tz:australia'] = 'ავსტრალია';
$labels['tz:australia:adelaide'] = 'ადელაიდე';
$labels['tz:australia:brisbane'] = 'ბრიზბანი';
$labels['tz:australia:currie'] = 'კიური';
$labels['tz:australia:darwin'] = 'დარვინი';
$labels['tz:australia:eucla'] = 'ეუკლა';
$labels['tz:australia:hobart'] = 'ჰობარტი';
$labels['tz:australia:lindeman'] = 'ლინდემანი';
$labels['tz:australia:melbourne'] = 'მელბურნი';
$labels['tz:australia:perth'] = 'პერთი';
$labels['tz:australia:sydney'] = 'სიდნეი';
$labels['tz:europe'] = 'ევროპა';
$labels['tz:europe:amsterdam'] = 'ამსტერდამი';
$labels['tz:europe:andorra'] = 'ანდორა';
$labels['tz:europe:astrakhan'] = 'ასტრახანი';
$labels['tz:europe:athens'] = 'ათენი';
$labels['tz:europe:belgrade'] = 'ბელგრადი';
$labels['tz:europe:berlin'] = 'ბერლინი';
$labels['tz:europe:bratislava'] = 'ბრატისლავა';
$labels['tz:europe:brussels'] = 'ბრიუსელი';
$labels['tz:europe:bucharest'] = 'ბუქარესტი';
$labels['tz:europe:budapest'] = 'ბუდაპეშტი';
$labels['tz:europe:busingen'] = 'ბიუზინგენი';
$labels['tz:europe:chisinau'] = 'ჩისინაუ';
$labels['tz:europe:copenhagen'] = 'კოპენჰაგენი';
$labels['tz:europe:dublin'] = 'დუბლინი';
$labels['tz:europe:gibraltar'] = 'გიბრალტარი';
$labels['tz:europe:guernsey'] = 'გერნსი';
$labels['tz:europe:helsinki'] = 'ჰელსინკი';
$labels['tz:europe:istanbul'] = 'სტამბოლი';
$labels['tz:europe:jersey'] = 'ჯერსი';
$labels['tz:europe:kaliningrad'] = 'კალინინგრადი';
$labels['tz:europe:kiev'] = 'კიევი';
$labels['tz:europe:kirov'] = 'კიროვი';
$labels['tz:europe:lisbon'] = 'ლისაბონი';
$labels['tz:europe:ljubljana'] = 'ლუბლიანა';
$labels['tz:europe:london'] = 'ლონდონი';
$labels['tz:europe:luxembourg'] = 'ლუქსემბურგი';
$labels['tz:europe:madrid'] = 'მადრიდი';
$labels['tz:europe:malta'] = 'მალტა';
$labels['tz:europe:mariehamn'] = 'მარიენჰამნი';
$labels['tz:europe:minsk'] = 'მინსკი';
$labels['tz:europe:monaco'] = 'მონაკო';
$labels['tz:europe:moscow'] = 'მოსკოვი';
$labels['tz:europe:oslo'] = 'ოსლო';
$labels['tz:europe:paris'] = 'პარიზი';
$labels['tz:europe:podgorica'] = 'პოდგორიცა';
$labels['tz:europe:prague'] = 'პრაღა';
$labels['tz:europe:riga'] = 'რიგა';
$labels['tz:europe:rome'] = 'რომი';
$labels['tz:europe:samara'] = 'სამარა';
$labels['tz:europe:sarajevo'] = 'სარაევო';
$labels['tz:europe:saratov'] = 'სარატოვი';
$labels['tz:europe:simferopol'] = 'სიმფეროპოლი';
$labels['tz:europe:skopje'] = 'სკოპიე';
$labels['tz:europe:sofia'] = 'სოფია';
$labels['tz:europe:stockholm'] = 'სტოკჰოლმი';
$labels['tz:europe:tallinn'] = 'ტალინი';
$labels['tz:europe:tirane'] = 'ტირანა';
$labels['tz:europe:ulyanovsk'] = 'ულიანოვსკი';
$labels['tz:europe:uzhgorod'] = 'უჟგოროდი';
$labels['tz:europe:vaduz'] = 'ვადუცი';
$labels['tz:europe:vatican'] = 'ვატიკანი';
$labels['tz:europe:vienna'] = 'ვენა';
$labels['tz:europe:vilnius'] = 'ვილნიუსი';
$labels['tz:europe:volgograd'] = 'ვოლგოგრადი';
$labels['tz:europe:warsaw'] = 'ვარშავა';
$labels['tz:europe:zagreb'] = 'ზაგრები';
$labels['tz:europe:zaporozhye'] = 'ზაპოროჟიე';
$labels['tz:europe:zurich'] = 'ციურიხი';
$labels['tz:indian'] = 'ინდური';
$labels['tz:indian:antananarivo'] = 'ანტანანარივუ';
$labels['tz:indian:chagos'] = 'ჩაგოსი';
$labels['tz:indian:christmas'] = 'შობა';
$labels['tz:indian:cocos'] = 'ქოქოსი';
$labels['tz:indian:comoro'] = 'კომორი';
$labels['tz:indian:kerguelen'] = 'კერგელენი';
$labels['tz:indian:mahe'] = 'მიაჰე';
$labels['tz:indian:maldives'] = 'მალდივები';
$labels['tz:indian:mauritius'] = 'მავრიკი';
$labels['tz:indian:mayotte'] = 'მაიოტი';
$labels['tz:indian:reunion'] = 'რეიუნიონი';
$labels['tz:pacific'] = 'წყნარი ოკეანე';
$labels['tz:pacific:apia'] = 'აპია';
$labels['tz:pacific:auckland'] = 'ოკლენდი';
$labels['tz:pacific:bougainville'] = 'ბუგენვილი';
$labels['tz:pacific:chatham'] = 'ჩათემი';
$labels['tz:pacific:chuuk'] = 'ჩუუკი';
$labels['tz:pacific:easter'] = 'აღდგომა';
$labels['tz:pacific:efate'] = 'ეფატე';
$labels['tz:pacific:enderbury'] = 'ენდერბერი';
$labels['tz:pacific:fakaofo'] = 'კაფაოფო';
$labels['tz:pacific:fiji'] = 'ფიჯი';
$labels['tz:pacific:funafuti'] = 'ფუნაფუტი';
$labels['tz:pacific:galapagos'] = 'გალაპაგოსი';
$labels['tz:pacific:gambier'] = 'გამბიე';
$labels['tz:pacific:guadalcanal'] = 'გუადალკანალი';
$labels['tz:pacific:guam'] = 'გუამი';
$labels['tz:pacific:honolulu'] = 'ჰონოლულუ';
$labels['tz:pacific:johnston'] = 'ჯონსტონი';
$labels['tz:pacific:kiritimati'] = 'შობის კუნძული';
$labels['tz:pacific:kosrae'] = 'კოსრაე';
$labels['tz:pacific:kwajalein'] = 'კვაჯალეინი';
$labels['tz:pacific:majuro'] = 'მაჯურო';
$labels['tz:pacific:marquesas'] = 'მარკიზის კუნძულები';
$labels['tz:pacific:midway'] = 'მიდუეი';
$labels['tz:pacific:nauru'] = 'ნაურუ';
$labels['tz:pacific:niue'] = 'ნიუე';
$labels['tz:pacific:norfolk'] = 'ნორფოლკი';
$labels['tz:pacific:noumea'] = 'ნუმეა';
$labels['tz:pacific:palau'] = 'პალაუ';
$labels['tz:pacific:pitcairn'] = 'პიტკერნი';
$labels['tz:pacific:pohnpei'] = 'პონპეი';
$labels['tz:pacific:rarotonga'] = 'რაროტონგა';
$labels['tz:pacific:saipan'] = 'საიპანი';
$labels['tz:pacific:tahiti'] = 'ტაჰიტი';
$labels['tz:pacific:tarawa'] = 'ტარავა';
$labels['tz:pacific:tongatapu'] = 'ტონგატაპუ';
$labels['tz:pacific:wake'] = 'უეიკი';
$labels['tz:pacific:wallis'] = 'უოლისი';
