<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Shfaqni njoftime shfletuesi kur ka mesazhe të rinj';
$labels['desktop'] = 'Shfaqni njoftime për desktop kur ka mesazhe të rinj';
$labels['sound'] = 'Kur ka mesazhe të rinj, luaj tingullin';
$labels['test'] = 'Test';
$labels['title'] = 'Email i ri!';
$labels['body'] = 'Morët një mesazh të ri.';
$labels['testbody'] = 'Ky është një njoftim test.';
$labels['desktopdisabled'] = 'Njoftimet për desktop janë të çaktivizuara te shfletuesi juaj.';
$labels['desktopunsupported'] = 'Shfletuesi juaj nuk mbulon njoftime për desktop.';
$labels['desktoptimeout'] = 'Mbylle njoftimin për desktop';
