<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'نمایش تذکرهای مرورگر برای پیام جدید';
$labels['desktop'] = 'نمایش تذکرهای رومیزی برای پیام جدید';
$labels['sound'] = 'پخش صدا برای پیام جدید';
$labels['test'] = 'آزمایش';
$labels['title'] = 'رایانامه‌ی جدید!';
$labels['body'] = 'شما یک پیام جدید دریافت کرده‌اید.';
$labels['testbody'] = 'این یک تذکر آزمایشی است.';
$labels['desktopdisabled'] = 'تذکرهای رومیزی در مرورگر شما غیرفعال شده‌اند.';
$labels['desktopunsupported'] = 'مرورگر شما تذکرهای رومیزی را پشتیبانی نمی‌کند.';
$labels['desktoptimeout'] = 'بستن تذکر دسکتاپ';
