<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Villa kom upp!';
$messages['loginfailed']  = 'Innskráning mistókst.';
$messages['cookiesdisabled'] = 'Vafrinn þinn samþykkir ekki vefkökur.';
$messages['sessionerror'] = 'Innskráningin þín er ógild eða útrunnin.';
$messages['cookiesmismatch'] = 'Fann misræmi í vefkökum. Endilega hreinsaðu skyndiminni vafrans af vefkökum.';
$messages['storageerror'] = 'Tenging við geymsluþjón mistókst.';
$messages['servererror'] = 'Villa í þjóni!';
$messages['servererrormsg'] = 'Villa í þjóni: $msg';
$messages['accountlocked'] = 'Of margar tilraunir til innskráningar. Reyndu aftur síðar.';
$messages['connerror'] = 'Villa í tengingu (mistókst að ná í þjóninn)!';
$messages['dberror'] = 'Villa í gagnagrunni!';
$messages['dbconnerror'] = 'Tókst ekki að tengjast gagnagrunninum!';
$messages['windowopenerror'] = 'Lokað var á sprettgluggann!';
$messages['requesttimedout'] = 'Fyrirspurn féll á tíma';
$messages['errorreadonly'] = 'Tókst ekki að framkvæma aðgerð. Mappa er skrifvarin.';
$messages['errornoperm'] = 'Tókst ekki að framkvæma aðgerð. Heimild var hafnað.';
$messages['erroroverquota'] = 'Tókst ekki að framkvæma aðgerð. Ekkert laust diskpláss.';
$messages['erroroverquotadelete'] = 'Ekki nægt laust diskpláss. Notaðu SHIFT+DEL til að eyða skilaboðum.';
$messages['invalidrequest'] = 'Ógild fyrirspurn! Engin gögn voru vistuð.';
$messages['invalidhost'] = 'Ógilt heiti á þjóni.';
$messages['nomessagesfound'] = 'Engin skilaboð fundust í þessu pósthólfi.';
$messages['loggedout'] = 'Þú hefur lokað setunni. Bless í bili!';
$messages['mailboxempty'] = 'Pósthólf er tómt';
$messages['nomessages'] = 'Engin skilaboð';
$messages['refreshing'] = 'Endurles...';
$messages['loading'] = 'Hleð...';
$messages['uploading'] = 'Sendi inn skrá...';
$messages['attaching'] = 'Hengi við skrá...';
$messages['uploadingmany'] = 'Sendi inn skrár...';
$messages['loadingdata'] = 'Hleð inn gögnum...';
$messages['checkingmail'] = 'Athuga með ný skilaboð...';
$messages['sendingmessage'] = 'Sendi skilaboð...';
$messages['messagesent'] = 'Skilaboðin voru send.';
$messages['savingmessage'] = 'Vista skilaboð...';
$messages['messagesaved'] = 'Skilaboð vistuð í Drög.';
$messages['successfullysaved'] = 'Vistun heppnaðist!';
$messages['savingresponse'] = 'Vista texta svars...';
$messages['deleteresponseconfirm'] = 'Ertu viss um að þú viljir eyða þessum svartexta?';
$messages['nocontactselected'] = 'Þú hefur ekki enn valið tengilið.';
$messages['addedsuccessfully'] = 'Netfangi var bætt í netfangaskrá.';
$messages['contactexists'] = 'Tengiliður með sama nafn er þegar skráður í netfangaskrána.';
$messages['contactnameexists'] = 'Tengiliður með sama nafn er þegar skráður í netfangaskrána.';
$messages['blockedimages'] = 'Til verndar hefur verið lokað á allar fjartengdar myndir í þessum skilaboðum.';
$messages['blockedresources'] = 'Til verndar hefur verið lokað á öll fjartengd tilföng.';
$messages['suspiciousemail'] = 'Þessi skilaboð innihalda grunsamleg tölvupóstföng sem gætu verið tilraun til svika.';
$messages['bccemail'] = 'Áframsendu skilaboðin innihalda leynilega viðtakendur (Bcc).';
$messages['bouncehint'] = 'Þessi skilaboð verða send án nokkurra breytinga, þ.e.a.s. með upprunalegu meginmáli, haus og viðtakendum.';
$messages['encryptedmessage'] = 'Þetta eru dulrituð skilaboð og því er ekki hægt að birta þau!';
$messages['externalmessagedecryption'] = 'Þetta eru dulrituð skilaboð og er hægt að afkóða þau með vafraviðbótinni.';
$messages['nopubkeyfor'] = 'Enginn gildur dreifilykill fannst fyrir $email';
$messages['nopubkeyforsender'] = 'Enginn gildur dreifilykill fannst fyrir sendandaauðkennið þitt. Viltu dulrita skilaboðin einungis fyrir viðtakendurna?';
$messages['encryptnoattachments'] = 'Viðhengi sem þegar er búið að senda inn er ekki hægt að dulrita. Bættu þeim við aftur í dulritunarritlinum.';
$messages['searchpubkeyservers'] = 'Viltu leita að þeim lyklum sem vantar á opinberum lyklaþjónum?';
$messages['encryptpubkeysfound'] = 'Eftirfarandi dreifilyklar fundust:';
$messages['keyservererror'] = 'Mistókst að nálgast lykil á lyklaþjóni.';
$messages['keyimportsuccess'] = 'Það tókst að flytja $key dreifilykilinn inn í lyklakippuna þína.';
$messages['nocontactsfound'] = 'Engir tengiliðir fundust.';
$messages['contactnotfound'] = 'Umbeðinn tengiliður fannst ekki.';
$messages['contactsearchonly'] = 'Þú verður að nota leitarform til að sjá tengiliði úr völdu nafnaskránni.';
$messages['sendingfailed'] = 'Sending skilaboðanna misheppnaðist.';
$messages['senttooquickly'] = 'Bíða í $sec sekúndu(r) áður en þessi skilaboð eru send.';
$messages['errorsavingsent'] = 'Villa kom upp við vistun sendra skilaboða.';
$messages['errorsaving'] = 'Villa kom upp við vistun.';
$messages['errormoving'] = 'Gat ekki fært skilaboðin.';
$messages['errorcopying'] = 'Gat ekki afritað skilaboð.';
$messages['errordeleting'] = 'Gat ekki eytt skilaboðum.';
$messages['errormarking'] = 'Gat ekki merkt skilaboð.';
$messages['alerttitle'] = 'Varúð';
$messages['confirmationtitle'] = 'Ertu viss...';
$messages['deletecontactconfirm']  = 'Ertu viss um að þú viljir eyða völdum tengiliðum?';
$messages['deletegroupconfirm']  = 'Ertu viss um að þú viljir eyða völdum hópi?';
$messages['deletemessagesconfirm'] = 'Ertu viss um að þú viljir eyða völdum skilaboðum?';
$messages['deletefolderconfirm']  = 'Ertu viss um að vilja eyða þessari möppu?';
$messages['movefolderconfirm']  = 'Ertu viss um að vilja færa þessa möppu?';
$messages['purgefolderconfirm']  = 'Ertu viss um að þú viljir eyða öllum skilaboðum í þessari möppu?';
$messages['contactdeleting'] = 'Eyði tengilið(um)...';
$messages['groupdeleting'] = 'Eyði hóp...';
$messages['folderdeleting'] = 'Eyði möppu...';
$messages['foldermoving'] = 'Færi möppu...';
$messages['foldersubscribing'] = 'Tek möppu í áskrift...';
$messages['folderunsubscribing'] = 'Segi upp áskrift að möppu...';
$messages['formincomplete'] = 'Formið var ekki fyllt út að fullu';
$messages['noemailwarning'] = 'Sláðu inn gildt netfang';
$messages['nonamewarning']  = 'Sláðu inn nafn';
$messages['nopagesizewarning'] = 'Sláðu inn síðustærð';
$messages['nosenderwarning'] = 'Settu inn tölvupóstfang sendanda.';
$messages['recipientsadded'] = 'Tókst að bæta við tengilið(um).';
$messages['norecipientwarning'] = 'Í það minnsta einn viðtakandi verður að vera';
$messages['disclosedrecipwarning'] = 'Allir viðtakendur munu sjá tölvupóstföng hvers annars. Til að komast hjá þessu og vernda persónuauðkenni viðtakenda geturði notað BCC (falið afrit) reitinn.';
$messages['disclosedreciptitle'] = 'Of margir opinberir viðtakendur';
$messages['nosubjectwarning']  = 'Efnislínan er tóm. Viltu slá eitthvað inn í hana?';
$messages['nosubjecttitle']  = 'Án titils';
$messages['nobodywarning'] = 'Viltu senda þessi skilaboð án texta?';
$messages['notsentwarning'] = 'Þessi skilaboð hafa ekki verið send og eru þau með óvistaðar breytingar. Viltu henda þessum breytingum?';
$messages['restoresavedcomposedata'] = 'Áður skrifuð en ósend skilaboð fundust.\n\nEfni: $subject\nVistað: $date\n\nViltu endurheimta þessi skilaboð?';
$messages['nosearchname'] = 'Sláðu inn nafn eða netfang';
$messages['notuploadedwarning'] = 'Ekki er búið að senda inn öll viðhengi. Bíddu aðeins eða hættu við innsendinguna.';
$messages['searchsuccessful'] = '$nr skilaboð fundust.';
$messages['contactsearchsuccessful'] = '$nr tengiliðir fundust.';
$messages['searchnomatch'] = 'Leit skilaði engu';
$messages['searching'] = 'Leita...';
$messages['checking'] = 'Gái...';
$messages['stillsearching'] = 'Enn að leita...';
$messages['nospellerrors'] = 'Engar innsláttarvillur fundust';
$messages['folderdeleted'] = 'Möppu var eytt';
$messages['foldersubscribed'] = 'Tókst að setja möppu í áskrift.';
$messages['folderunsubscribed'] = 'Tókst að taka möppu úr áskrift.';
$messages['folderpurged'] = 'Tókst að tæma möppu.';
$messages['folderexpunged'] = 'Tókst að þjappa möppu.';
$messages['deletedsuccessfully'] = 'Tókst að eyða.';
$messages['converting'] = 'Fjarlægi snið...';
$messages['messageopenerror'] = 'Gat ekki hlaðið skilaboðum inn af póstþjóni.';
$messages['filelinkerror'] = 'Mistókst að hengja við skrá.';
$messages['fileuploaderror'] = 'Innsending skráar mistókst.';
$messages['csvfilemismatch'] = 'Innflutningur á mörgum CSV-skrám með mismunandi gagnasviðum er ekki studdur.';
$messages['filesizeerror'] = 'Innsenda skráin er yfir $size leyfilegri stærð.';
$messages['filecounterror'] = 'Þú getur í mesta lagi sent inn $count skrár í einu.';
$messages['msgsizeerror'] = 'Mistókst að hengja við skrá. Fór yfir leyfilega hámarksstærð ($size) skilaboða.';
$messages['msgsizeerrorfwd'] = 'Hámarksstærð skilaboða ($size) náð. $num skilaboð hafa ekki verið hengd við.';
$messages['copysuccess'] = 'Tókst að afrita $nr tengiliði';
$messages['movesuccess'] = 'Tókst að færa $nr tengiliði';
$messages['copyerror'] = 'Gat ekki afritað neina tengiliði.';
$messages['moveerror'] = 'Gat ekki fært neina tengiliði.';
$messages['sourceisreadonly'] = 'Þessi nafnaskrárgjafi er skrifvarinn.';
$messages['errorsavingcontact'] = 'Gat ekki vistað vistfang tengiliðar.';
$messages['movingmessage'] = 'Færi skilaboð...';
$messages['copyingmessage'] = 'Afrita skilaboð...';
$messages['copyingcontact'] = 'Afrita tengiliði...';
$messages['movingcontact'] = 'Færi tengiliði...';
$messages['deletingmessage'] = 'Eyði skilaboðum...';
$messages['markingmessage'] = 'Merki skilaboð...';
$messages['addingmember'] = 'Bæti tengiliðum í hópinn...';
$messages['removingmember'] = 'Fjarlægi tengiliði úr hópi...';
$messages['receiptsent'] = 'Tókst að senda leskvittun.';
$messages['errorsendingreceipt'] = 'Gat ekki sent leskvittunina.';
$messages['deleteidentityconfirm'] = 'Ertu viss um að vilja eyða þessu auðkenni?';
$messages['nodeletelastidentity'] = 'Þú getur ekki eytt þessu auðkenni, þetta er það síðasta sem er eftir.';
$messages['forbiddencharacter'] = 'Heiti möppu inniheldur óleyfilegan staf.';
$messages['selectimportfile'] = 'Veldu skrá til að senda inn.';
$messages['addresswriterror'] = 'Valin nafnaskrá er ekki ritanleg.';
$messages['contactaddedtogroup'] = 'Tókst að bæta tengiliðunum í þennan hóp.';
$messages['contactremovedfromgroup'] = 'Tókst að fjarlægja tengiliði úr þessum hóp.';
$messages['nogroupassignmentschanged'] = 'Engin breyting á úthlutun hópa.';
$messages['importwait'] = 'Flyt inn, bíddu aðeins...';
$messages['importformaterror'] = 'Innflutningur mistókst! Innsenda skráin er ekki gild gagnainnflutningsskrá';
$messages['importconfirm'] = '<b>Tókst að flytja inn $inserted tengiliði</b>';
$messages['importconfirmskipped'] = '<b>Sleppti $skipped fyrirliggjandi tengiliðum</b>';
$messages['importconfirminvalid'] = '<b>Sleppti $skipped ógildum tengiliðum</b>';
$messages['importconfirmerrors'] = 'Mistókst að flytja inn $skipped gilda tengiliði</b>';
$messages['importmessagesuccess'] = 'Tókst að flytja inn $nr skilaboð';
$messages['importmessageerror'] = 'Innflutningur mistókst! Innsenda skráin er ekki gild skilaboða- eða pósthólfsskrá';
$messages['opnotpermitted'] = 'Aðgerð ekki leyfð!';
$messages['nofromaddress'] = 'Vantar tölvupóstfang í völdu auðkenni.';
$messages['editorwarning'] = 'Ef skipt er um ritil getur snið texta tapast. Viltu halda áfram?';
$messages['httpreceivedencrypterror'] = 'Alvarleg villa kom upp í uppsetningu. Hafðu strax samband við kerfisstjórann þinn. <b>Ekki var hægt að senda skilaboðin.</b>';
$messages['smtpconnerror'] = 'SMTP-villa ($code): Tenging við póstþjón mistókst.';
$messages['smtpautherror'] = 'SMTP-villa ($code): Auðkenning mistókst.';
$messages['smtpfromerror'] = 'SMTP-villa ($code): Mistókst að setja sendanda "$from" ($msg).';
$messages['smtptoerror'] = 'SMTP-villa ($code): Mistókst að bæta við viðtakandanum "$to" ($msg).';
$messages['smtprecipientserror'] = 'SMTP-villa: Mistókst að þátta lista yfir viðtakendur.';
$messages['smtputf8error'] = 'SMTP-villa: Vefþjónn styður ekki Unicode í tölvupóstföngum.';
$messages['smtpsizeerror'] = 'SMTP-villa: Stærð skilaboða yfir takmörkum vefþjóns ($limit)';
$messages['smtperror'] = 'SMTP villa: $msg';
$messages['emailformaterror'] = 'Ógilt tölvupóstfang: $email';
$messages['toomanyrecipients'] = 'Of margir viðtakendur. Fækkaðu þeim í $max.';
$messages['maxgroupmembersreached'] = 'Fjöldi meðlima í hópnum fer fram úr hámarksfjöldanum $max.';
$messages['internalerror'] = 'Innri villa kom upp. Prófaðu aftur.';
$messages['contactdelerror'] = 'Gat ekki eytt tengilið(um).';
$messages['contactdeleted'] = 'Tókst að eyða tengilið(um).';
$messages['contactrestoreerror'] = 'Gat ekki endurheimt eydda tengiliði.';
$messages['contactrestored'] = 'Tókst að endurheimta tengilið(i).';
$messages['groupdeleted'] = 'Tókst að eyða hópi.';
$messages['grouprenamed'] = 'Tókst að endurnefna hóp.';
$messages['groupcreated'] = 'Tókst að búa til hóp.';
$messages['savedsearchdeleted'] = 'Tókst að eyða vistaðri leit.';
$messages['savedsearchdeleteerror'] = 'Gat ekki eytt vistaðri leit.';
$messages['savedsearchcreated'] = 'Tókst að búa til vistaða leit.';
$messages['savedsearchcreateerror'] = 'Gat ekki búið til vistaða leit.';
$messages['messagedeleted'] = 'Tókst að eyða skilaboðum.';
$messages['messagemoved'] = 'Tókst að færa skilaboð.';
$messages['messagemovedtotrash'] = 'Tókst að færa skilaboð í rusl.';
$messages['messagecopied'] = 'Tókst að afrita skilaboð.';
$messages['messagemarked'] = 'Tókst að merkja skilaboð.';
$messages['autocompletechars'] = 'Settu inn a.m.k. $min stafi fyrir orðaklárun.';
$messages['autocompletemore'] = 'Fleiri samsvarandi færslur fundust. Sláðu inn fleiri stafi.';
$messages['namecannotbeempty'] = 'Nafn má ekki vera autt.';
$messages['nametoolong'] = 'Nafn er of langt.';
$messages['namedotforbidden'] = 'Heiti möppu má ekki byrja á punkti.';
$messages['folderupdated'] = 'Tókst að uppfæra möppu';
$messages['foldercreated'] = 'Tókst að búa til möppu.';
$messages['invalidimageformat'] = 'Ekki gilt myndasnið.';
$messages['mispellingsfound'] = 'Stafsetningarvillur fundust í skilaboðunum.';
$messages['parentnotwritable'] = 'Tókst ekki að útbúa möppu eða færa inn í valda yfirmöppu. Það vantar aðgangsheimildir.';
$messages['messagetoobig'] = 'Efnishluti skilaboðanna er of stór til að hægt sé að meðhöndla skilaboðin.';
$messages['attachmentvalidationerror'] = 'Þetta viðhengi er grunsamlegt þar sem tegund þess samsvarar ekki tegundinni sem gefin er upp í skilaboðunum. Ef þú treystir ekki sendandanum, ættirðu ekki að opna það í vafranum því það gæti innihaldið óværur.<br/><br/><em>Átti von á: $expected; fann: $detected</em>';
$messages['noscriptwarning'] = 'Aðvörun: Þessi vefpóstþjónusta þarfnast JavaScript! Til að nota hana þarftu að virkja JavaScript í stillingum vafrans.';
$messages['messageissent'] = 'Þessi skilaboð hafa þegar verið send, en hafa ekki verið vistuð. Viltu vista þau núna?';
$messages['errnotfound'] = 'Skrá fannst ekki';
$messages['errnotfoundexplain'] = 'Umbeðið tilfang fannst ekki!';
$messages['errfailedrequest'] = 'Beiðni misfórst';
$messages['errauthorizationfailed'] = 'Auðkenning mistókst';
$messages['errunauthorizedexplain'] = 'Gat ekki gengið úr skugga um að þú hafir heimild til að nota þessa þjónustu!';
$messages['errrequestcheckfailed'] = 'Athugun á beiðni mistókst';
$messages['errcsrfprotectionexplain'] = "Til að verja þig er aðgangur að þessu tilfang gerður öruggur á móti CSRF.\nEf þú sérð þetta er líklegast að þú hafir ekki skráð þig út áður en þú hættir í vefviðmótinu.\n\nNú þarftu að grípa til aðgerða til að geta haldið áfram.";
$messages['errcontactserveradmin'] = 'Hafðu samband við kerfisstjóra þjónsins þíns';
$messages['clicktoresumesession'] = 'Smelltu hér til að halda áfram með fyrri setu';
$messages['errcomposesession'] = 'Villa í samningarsetu';
$messages['errcomposesessionexplain'] = 'Umbeðin samningarseta fannst ekki.';
$messages['clicktocompose'] = 'Smelltu hér til að búa til ný skilaboð';
$messages['nosupporterror'] = 'Þessi eiginleiki er ekki studdur af vafranum þínum.';
$messages['siginserted'] = 'Tókst að setja inn undirskrift.';
$messages['responseinserted'] = 'Tókst að setja inn svar.';
$messages['noresponsesavailable'] = 'Engin svör tiltæk';
$messages['listempty'] = 'Listinn er tómur.';
$messages['listusebutton'] = 'Notaðu \'Búa til\' hnappinn til að bæta við færslu.';
$messages['keypaircreatesuccess'] = 'Tókst að útbúa nýtt lyklapar fyrir $identity.';
$messages['emptyattachment'] = 'Þetta viðhengi lítur út fyrir að vera tómt. <br>Hafðu samband við þann sem sendi þetta.';
$messages['oauthloginfailed'] = 'OAuth-innskráning mistókst. Reyndu aftur.';
$messages['oauthinvalidrequest'] = 'Auðkenningarbeiðni var ógild eða ófullgerð.';
$messages['oauthaccessdenied'] = 'Auðkenningarþjónn eða notandi höfnuðu beiðninni.';
