<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'មាន​បញ្ហា​បាន​កើត​ឡើង!';
$messages['loginfailed']  = 'បាន​បរាជ័យ​ក្នុង​ការ​ចូល។';
$messages['cookiesdisabled'] = 'កម្មវិធី​អ៊ីនធឺណិត​របស់​អ្នក​មិន​ទទួល​ខូគី​ទេ។';
$messages['sessionerror'] = 'សម័យ​របស់​អ្នក​មិន​ត្រឹម​ត្រូវ ឬ​ផុត​កំណត់។';
$messages['storageerror'] = 'មិន​អាច​តភ្ជាប់​ទៅ​ម៉ាស៊ីន​ឃ្លាំង​ផ្ទុក។';
$messages['servererror'] = 'ម៉ាស៊ីន​មេ​មាន​បញ្ហា!';
$messages['servererrormsg'] = 'បញ្ហា: $msg';
$messages['dberror'] = 'កំហុស​មូលដ្ឋាន​ទិន្នន័យ!';
$messages['requesttimedout'] = 'សំណើ​អស់​ពេល';
$messages['errorreadonly'] = 'មិនអាចប្រតិបត្តិបានពីព្រោះថតនេះត្រូវបានគេកំណត់សំរាប់តែមើល';
$messages['errornoperm'] = 'មិនអាចប្រតិបត្តិបានពីព្រោះមិនមានសិទ្ទគ្រប់គ្រាន់';
$messages['invalidrequest'] = 'មិនអាចរក្សាទុកទិន្នន័យបានពីព្រោះមានបញ្ហានៅពេលបញ្ជូនទិន្នន័យ';
$messages['invalidhost'] = 'ឈ្មោះ​ម៉ាស៊ីន​មេ​មិន​ត្រឹមត្រូវ។';
$messages['nomessagesfound'] = 'ពុំមានសំបុត្រក្នុងប្រអប់សំបុត្រនេះទេ';
$messages['refreshing'] = 'កំពុង​ផ្ទុកឡើងវិញ...';
$messages['loading'] = 'កំពុងដំណើរការ...';
$messages['uploading'] = 'កំពុងបញ្ជូនឯកសារ...';
$messages['uploadingmany'] = 'កំពុង​ផ្ទុកឯកសារ​ឡើង...';
$messages['loadingdata'] = 'កំពុងបើកឯកសារ...';
$messages['checkingmail'] = 'កំពុងស្វែងរកមើលសំបុត្រថ្មី៝...';
$messages['sendingmessage'] = 'កំពុងផ្ញើសំបុត្រ...';
$messages['messagesent'] = 'សំបុត្រត្រូវបានបញ្ជូនដោយជោគជ័យ!';
$messages['savingmessage'] = 'កំពុងរក្សាសំបុត្រទុក...';
$messages['messagesaved'] = 'សំបុត្រត្រូវបានរក្សាទុកក្នុងថតពង្រៀង';
$messages['successfullysaved'] = 'រក្សាទុកដោយជោគជ័យ';
$messages['addedsuccessfully'] = 'អាសយដ្ឋានត្រូវបានរក្សាទុកដោយជោគជ័យ';
$messages['contactnameexists'] = 'មាន​ទំនាក់ទំនង​ដែលមាន​ឈ្មោះ​ដូច​គ្នា​នេះ​រួច​ហើយ។';
$messages['blockedimages'] = 'រូបភាពដែលមានក្នុងសំបុត្រនេះត្រូវបានបិទដើម្បីរក្សាសុវត្ថភាព';
$messages['encryptedmessage'] = 'លោកអ្នកមិនអាចមើលសំបុត្រនេះបានទេពីព្រោះសំបុត្រនេះជាសំបុត្រសំងាត់';
$messages['nocontactsfound'] = 'ពុំមានអាសយដ្ឋានទាក់ទងទេ';
$messages['contactnotfound'] = 'អាសយដ្ឋានទាក់ទងដែលលោកអ្នកចង់រកពុំមានឡើយ';
$messages['sendingfailed'] = 'មិនអាចផ្ញើសំបុត្របាន';
$messages['senttooquickly'] = 'សូមរងចាំ $sec វិនាទីមុននឹងផ្ញើសំបុត្រនេះ';
$messages['errormoving'] = 'មិនអាចផ្ទេរសំបុត្របាន';
$messages['errorcopying'] = 'មិនអាចចំលងសំបុត្របាន';
$messages['errordeleting'] = 'មិនអាចលុបសំបុត្រចោលបាន';
$messages['errormarking'] = 'មិនអាចកំណត់ចំណាំលើសំបុត្របាន';
$messages['deletecontactconfirm']  = 'តើលោកអ្នកពិតជាចង់លុបព័ត៌មានទំនាក់ទំនងនេះមែនទេ?';
$messages['deletegroupconfirm']  = 'តើអ្នកពិត​ជា​ចង់លុប​ក្រុម​បានជ្រើស?';
$messages['deletemessagesconfirm'] = 'តើលោកអ្នកពិតជាចង់លុបសំបុត្រនេះមែនទេ?';
$messages['deletefolderconfirm']  = 'តើលោកអ្នកពិតជាចង់លុបថតនេះមែនទេ?';
$messages['purgefolderconfirm']  = 'តើលោកអ្នកពិតជាចង់លុបសំបុត្រទាំងអស់នៅក្នុងថតនេះមែនទេ?';
$messages['contactdeleting'] = 'កំពុង​លុប​ទំនាក់ទំនង...';
$messages['groupdeleting'] = 'កំពុង​លុប​ក្រុម...';
$messages['folderdeleting'] = 'កំពុងលុបថតសំរាប់ទុកឯកសារ...';
$messages['foldermoving'] = 'កំពុងផ្ទេរថតសំរាប់ទុកឯកសារ...';
$messages['foldersubscribing'] = 'កំពុងកំណត់ប្រើថតសំរាប់ទុកឯកសារ...';
$messages['folderunsubscribing'] = 'កំពុងកំណត់មិនប្រើថតសំរាប់ទុកឯកសារ...';
$messages['formincomplete'] = 'សូមបំពេញទិន្នន័យអោយបានគ្រប់';
$messages['noemailwarning'] = 'អ៊ីមែលត្រឹមត្រូវ';
$messages['nonamewarning']  = 'សូមសរសេរឈ្មោះរបស់អ្នក';
$messages['nopagesizewarning'] = 'សូមកំណត់ទំហំទំព័រ';
$messages['norecipientwarning'] = 'សូមសរសេរអ្នកទទួលយ៉ាងហោចណាស់ម្នាក់';
$messages['nosubjectwarning']  = 'សំបុត្រគ្មានចំណងជើងតើអ្នកចង់សរសេរចំណងជើងនៅពេលនេះទេ?';
$messages['nobodywarning'] = 'តើលោកអ្នកចង់ផ្ញើសំបុត្រដែលគ្មានតួអត្ថបទសំបុត្រទេ?';
$messages['nosearchname'] = 'សូមបំពេញឈ្មោះទំនាក់ទំនង ឬអាសយដ្ឋានអ៊ីមែល';
$messages['notuploadedwarning'] = 'ឯកសារ​ភ្ជាប់​ទាំង​អស់​មិន​ត្រូវ​បាន​ផ្ទុក​ឡើង​នៅឡើយ​ទេ។ សូម​រង់ចាំ​ ឬ​បោះបង់​ការ​​ផ្ទុក​ឡើង។';
$messages['searchsuccessful'] = 'រកឃើញសំបុត្រចំនួន $nr';
$messages['contactsearchsuccessful'] = 'រក​ឃើញ​ទំនាក់ទំនង $nr ។';
$messages['searchnomatch'] = 'រកមិនឃើញអ្វីទាំងអស់';
$messages['searching'] = 'កំពុងស្វែងរក...';
$messages['checking'] = 'កំពុងពិនិត្យរក...';
$messages['nospellerrors'] = 'គ្មានកំហុសអក្ខរាវិរុទ្ធទេ';
$messages['folderdeleted'] = 'លុបថតបានដោយជោគជ័យ';
$messages['foldersubscribed'] = 'អាចកំណត់ប្រើថតបានដោយជោគជ័យ';
$messages['folderunsubscribed'] = 'កំណត់លែងប្រើថតបានដោយជោគជ័យ';
$messages['deletedsuccessfully'] = 'លុបបានដោយជោគជ័យ';
$messages['converting'] = 'កំពុងលុបការរចនាចោល...';
$messages['messageopenerror'] = 'មិនអាចទាញយកសំបុត្រពីម៉ាស៊ីនមេបានទេ';
$messages['fileuploaderror'] = 'មិនអាចបញ្ជូលភ្ជាប់ឯកសារ';
$messages['filesizeerror'] = 'ទំហំឯកសារត្រូវបញ្ជូនលើសចំណុះទំហំធំបំផុតគឺ $size';
$messages['sourceisreadonly'] = 'លោកអ្នកមានសិទ្ធត្រឹមតែមើលប្រភពនៃអាសយដ្ឋាននេះ';
$messages['errorsavingcontact'] = 'មិនអាចរក្សាអាសយដ្ឋានបានទេ';
$messages['movingmessage'] = 'កំពុកផ្តេរសំបុត្រ...';
$messages['copyingmessage'] = 'កំពុងចំលងសំបុត្រ...';
$messages['copyingcontact'] = 'កំពុង​ចម្លង​ទំនាក់ទំនង...';
$messages['deletingmessage'] = 'កំពុងលុបសំបុត្រ...';
$messages['markingmessage'] = 'កំពុងកំណត់សំគាល់សំបុត្រ...';
$messages['addingmember'] = 'កំពុង​បន្ថែម​ទំនាក់ទំនង​ទៅ​ក្រុម...';
$messages['removingmember'] = 'កំពុង​លុបទំនាក់ទំនង​ពី​ក្រុម...';
$messages['receiptsent'] = 'បានបញ្ជូនអត្ថបទបញ្ជាក់ថាបានអានបានសំរេច';
$messages['errorsendingreceipt'] = 'មិនអាចបញ្ជូនអត្ថបទបញ្ជាក់ថាបានអាន ទេ';
$messages['deleteidentityconfirm'] = 'តើអ្នក​ពិត​ជា​ចង់​លុប​អត្តសញ្ញាណ​នេះ?';
$messages['nodeletelastidentity'] = 'លោកអ្នកមិនអាចលុបអត្តសញ្ញាណនេះទេព្រោះវានៅសល់ចុងក្រោយគេ';
$messages['forbiddencharacter'] = 'ឈ្មោះថតនេះមានអក្សរដែលត្រូវហាមឃាត់';
$messages['selectimportfile'] = 'សូមជ្រើសរើសឯកសារដើម្បីបញ្ជូនភ្ជាប់';
$messages['addresswriterror'] = 'សៀវភៅអាសយដ្ឋាននោះមិនអាចសរសេរចូលបានទេ';
$messages['contactaddedtogroup'] = 'បានដាក់ពត៌មានទំនាក់ទំនងចូលក្នុងក្រុមនេះដោយជោគជ័យ';
$messages['contactremovedfromgroup'] = 'បានលុបពត៌មានទំនាក់ទំនងចេញពីក្រុមនេះដោយជោគជ័យ';
$messages['nogroupassignmentschanged'] = 'គ្មាន​ការ​ផ្ដល់​ក្រុម​បាន​ប្ដូរ។';
$messages['importwait'] = 'សូមមេត្តារង់ចាំកំពុងទាញទិន្នន័យចូល ...';
$messages['importconfirm'] = '<b>ព័ត៌មានទំនាក់ទំនង $insertedបានបញ្ចូលដោយជោគជ័យ,ហើយបានរំលងចោលពត៌មានដែលមានស្រាប់$skipped </b>:<p><em>$names</em></p>';
$messages['opnotpermitted'] = 'ប្រតិ្តបត្តិការត្រូវបានគេហាមឃាត់!';
$messages['smtpconnerror'] = 'SMTP Error ($code):មិនអាចភ្ជាប់ទៅម៉ាស៊ីនមេ';
$messages['smtpautherror'] = 'SMTP Error ($code):ព័ត៌មានគនីយមិនត្រឹមត្រូវ';
$messages['smtpfromerror'] = 'SMTP Error ($code):មិនអាចកំនត់អ្នកផ្ញើ "$from" ($msg)';
$messages['smtptoerror'] = 'SMTP Error ($code):មិនអាចកំនត់អ្នកទទួល "$to" ($msg)';
$messages['smtprecipientserror'] = 'SMTP Error:មិនអាចបំលែងបញ្ជីអ្នកទទួល';
$messages['smtperror'] = 'SMTP Error: $msg';
$messages['toomanyrecipients'] = 'ចំនួនអ្នកទទួលច្រើនលើសកំនត់!សូមមេត្តាលុបចោលរហូតដល់ $max។';
$messages['maxgroupmembersreached'] = 'ចំនួនក្រុមលើសកំនត់ហើយចំនួនច្រើនបំផុតគឺ $max';
$messages['contactdelerror'] = 'មិនអាចលុបអាសយដ្ឋានទំនាក់ទំនង';
$messages['contactdeleted'] = 'អាសយដ្ឋានទំនាក់ទំនងត្រូវបានលុបដោយជោគជ័យ';
$messages['groupdeleted'] = 'លុបក្រុមបានដោយជោគជ័យ';
$messages['grouprenamed'] = 'ប្តូរឈ្មោះក្រុមបានដោយជោគជ័យ';
$messages['groupcreated'] = 'បង្កើតក្រុមបានដោយជោគជ័យ';
$messages['messagedeleted'] = 'លុបសំបុត្របានដោយជោគជ័យ';
$messages['messagemoved'] = 'ផ្ទេរសំបុត្របានដោយជោគជ័យ';
$messages['messagecopied'] = 'ចំលងសំបុត្របានដោយជោគជ័យ';
$messages['messagemarked'] = 'កំណត់សំគាល់សំបុត្របានដោយជោគជ័យ';
$messages['autocompletechars'] = 'សូមសរសេរអក្សរយ៉ាងតិច $minដើម្បីបង្ហាយដោយស្វ័យប្រវត្តិ';
$messages['namecannotbeempty'] = 'សូមសរសេរឈ្មោះ';
$messages['nametoolong'] = 'ឈ្មោះវែងពេក';
$messages['folderupdated'] = 'ផ្លាស់ប្តូរថតបានដោយជោគជ័យ';
$messages['foldercreated'] = 'បង្កើតថតបានដោយជោគជ័យ';
$messages['invalidimageformat'] = 'ប្រភេទរូបភាពមិនត្រឹមត្រូវ';
