<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/csv2vcard.inc                                     |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2013, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['Anniversaire de mariage ou fête'] = 'anniversary';
$map['Nom de l\'assistant(e)'] = 'assistant';
$map['Téléphone de l\'assistant(e)'] = 'phone:assistant';
$map['Anniversaire'] = 'birthday';
$map['Ville (bureau)'] = 'locality:work';
$map['Pays/Région (bureau)'] = 'country:work';
$map['Télécopie (bureau)'] = 'phone:workfax';
$map['Téléphone (bureau)'] = 'phone:work';
$map['Téléphone 2 (bureau)'] = 'phone:work2';
$map['Code postal (bureau)'] = 'zipcode:work';
$map['Dép/Région (bureau)'] = 'region:work';
$map['Rue (bureau)'] = 'street:work';
$map['Téléphone (voiture)'] = 'phone:car';
$map['Catégories'] = 'groups';
$map['Société'] = 'organization';
$map['Service'] = 'department';
$map['Adresse de messagerie'] = 'email:other';
$map['Prénom'] = 'firstname';
$map['Sexe'] = 'gender';
$map['Ville (domicile)'] = 'locality:home';
$map['Pays/Région (domicile)'] = 'country:home';
$map['Télécopie (domicile)'] = 'phone:homefax';
$map['Téléphone (domicile)'] = 'phone:home';
$map['Téléphone 2 (domicile)'] = 'phone:home2';
$map['Code postal (domicile)'] = 'zipcode:home';
$map['Dép/Région (domicile)'] = 'region:home';
$map['Rue (domicile)'] = 'street:home';
$map['Profession'] = 'jobtitle';
$map['Nom'] = 'surname';
$map['Manager\'s Name'] = 'manager';
$map['Deuxième prénom'] = 'middlename';
$map['Tél. mobile'] = 'phone:mobile';
$map['Notes'] = 'notes';
$map['Ville (autre)'] = 'locality:other';
$map['Pays/Région (autre)'] = 'country:other';
$map['Télécopie (autre)'] = 'phone:other';
$map['Téléphone (autre)'] = 'phone:other';
$map['Code postal (autre)'] = 'zipcode:other';
$map['Dép/Région (autre)'] = 'region:other';
$map['Rue (autre)'] = 'street:other';
$map['Récepteur de radiomessagerie'] = 'phone:pager';
$map['Téléphone principal'] = 'phone:main';
$map['Conjoint(e)'] = 'spouse';
$map['Suffixe'] = 'suffix';
$map['Titre'] = 'prefix';
$map['Page Web'] = 'website:homepage';
$map['Jour'] = 'birthday-d';
$map['Mois'] = 'birthday-m';
$map['Année de naissance'] = 'birthday-y';
$map['Nom à afficher'] = 'name';
$map['Fax'] = 'phone:homefax';
$map['Adresse privée'] = 'street:home';
$map['Région'] = 'country:home';
$map['Code postal'] = 'zipcode:home';
$map['Portable'] = 'phone:mobile';
$map['Surnom'] = 'nickname';
$map['Société'] = 'organization';
$map['Pager'] = 'phone:pager';
$map['Adresse électronique principale'] = 'email:home';
$map['Adresse électronique secondaire'] = 'email:other';
$map['Site Web 1'] = 'website:homepage';
$map['Site Web 2'] = 'website:other';
$map['Tél. professionnel'] = 'phone:work';
$map['Adresse professionnelle'] = 'street:work';
$map['Région'] = 'country:work';
$map['Code postal'] = 'zipcode:work';
$map['_home_city'] = 'Ville';
