<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Wolkom by $product';
$labels['username'] = 'Brûkersnamme';
$labels['password'] = 'Wachtwurd';
$labels['server'] = 'Tsjinner';
$labels['login'] = 'Ynlogge';
$labels['logout'] = 'Ôfmelde';
$labels['mail'] = 'E-post';
$labels['settings'] = 'Ynstellings';
$labels['addressbook'] = 'Adresboek';
$labels['inbox'] = 'Postfek Yn';
$labels['drafts'] = 'Konsepten';
$labels['sent'] = 'Ferstjoerd';
$labels['trash'] = 'Jiskefet';
$labels['junk'] = 'Spam';
$labels['show_real_foldernames'] = 'Lit echte nammen sjen foar spesjale mappen';
$labels['subject'] = 'Ûnderwerp';
$labels['from'] = 'Fan';
$labels['sender'] = 'Stjoerder';
$labels['to'] = 'Oan';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Antwurd oan';
$labels['followupto'] = 'Oanslutend oan';
$labels['date'] = 'Datum';
$labels['size'] = 'Grutte';
$labels['priority'] = 'Prioriteit';
$labels['organization'] = 'Organisaasje';
$labels['readstatus'] = 'Lêzen status';
$labels['listoptions'] = 'Lyst opsjes...';
$labels['mailboxlist'] = 'Mappen';
$labels['messagesfromto'] = 'Berjochten $from nei $to fan $count';
$labels['threadsfromto'] = 'Rigen $from oan $to fan $count';
$labels['messagenrof'] = 'Berjocht $nr fan $count';
$labels['fromtoshort'] = '$from – $to fan $count';
$labels['copy'] = 'Kopiearje';
$labels['move'] = 'Ferpleatse';
$labels['moveto'] = 'Ferpleatse nei...';
$labels['copyto'] = 'Kopiearje nei...';
$labels['download'] = 'Ynlade';
$labels['open'] = 'Iepenje';
$labels['showattachment'] = 'Toane';
$labels['showanyway'] = 'Dochs toane';
$labels['filename'] = 'Bestânsnamme';
$labels['filesize'] = 'Bestânsgrutte';
$labels['addtoaddressbook'] = 'Oan adresboek tafoegje';
$labels['sun'] = 'si';
$labels['mon'] = 'mo';
$labels['tue'] = 'ti';
$labels['wed'] = 'wo';
$labels['thu'] = 'to';
$labels['fri'] = 'fr';
$labels['sat'] = 'so';
$labels['sunday'] = 'snein';
$labels['monday'] = 'moandei';
$labels['tuesday'] = 'tiisdei';
$labels['wednesday'] = 'woansdei';
$labels['thursday'] = 'tongersdei';
$labels['friday'] = 'freed';
$labels['saturday'] = 'sneon';
$labels['jan'] = 'jan';
$labels['feb'] = 'feb';
$labels['mar'] = 'mrt';
$labels['apr'] = 'apr';
$labels['may'] = 'mai';
$labels['jun'] = 'jun';
$labels['jul'] = 'jul';
$labels['aug'] = 'aug';
$labels['sep'] = 'sep';
$labels['oct'] = 'okt';
$labels['nov'] = 'nov';
$labels['dec'] = 'des';
$labels['longjan'] = 'jannewaris';
$labels['longfeb'] = 'febrewaris';
$labels['longmar'] = 'maart';
$labels['longapr'] = 'april';
$labels['longmay'] = 'maaie';
$labels['longjun'] = 'juny';
$labels['longjul'] = 'july';
$labels['longaug'] = 'augustus';
$labels['longsep'] = 'septimber';
$labels['longoct'] = 'oktober';
$labels['longnov'] = 'novimber';
$labels['longdec'] = 'desimber';
$labels['today'] = 'Hjoed';
$labels['refresh'] = 'Ferfarskje';
$labels['checkmail'] = 'Op nije berjochten kontrolearje';
$labels['compose'] = 'Opstelle';
$labels['writenewmessage'] = 'Nij berjocht oanmeitsje';
$labels['reply'] = 'Beäntwurdzje';
$labels['replytomessage'] = 'Antwurd oan stjoerder';
$labels['replytoallmessage'] = 'Antwurd nei lyst of nei stjoerder en alle ûntfangers';
$labels['replyall'] = 'Antwurdzje alle';
$labels['replylist'] = 'Antwurdzje lyst';
$labels['forward'] = 'Trochstjoere';
$labels['forwardinline'] = 'Ynsletten trochstjoere';
$labels['forwardattachment'] = 'Trochstjoere as taheaksel';
$labels['forwardmessage'] = 'Stjoer it berjocht troch';
$labels['deletemessage'] = 'Berjocht wiskje';
$labels['movemessagetotrash'] = 'Berjocht ferpleatse nei jiskefet';
$labels['printmessage'] = 'Dit berjocht ôfdrukke';
$labels['previousmessage'] = 'Lit foarige berjocht sjen';
$labels['firstmessage'] = 'Lit earste berjocht sjen';
$labels['nextmessage'] = 'Lit folgjende berjocht sjen';
$labels['lastmessage'] = 'Lit lêste berjocht sjen';
$labels['backtolist'] = 'Tebek nei berjochtlyst';
$labels['viewsource'] = 'Toan boarne';
$labels['mark'] = 'Markearje';
$labels['markmessages'] = 'Markearje berjochten';
$labels['markread'] = 'As lêzen';
$labels['markunread'] = 'As net-lêzen';
$labels['markflagged'] = 'As flagge';
$labels['markunflagged'] = 'As net-flagge';
$labels['moreactions'] = 'Mear aksjes...';
$labels['markallread'] = 'Markearje alles as lêzen';
$labels['folders-cur'] = 'Allinnich selektearre map';
$labels['folders-sub'] = 'Selektearre map en ûnderlizzende mappen';
$labels['folders-all'] = 'Alle mappen';
$labels['more'] = 'Mear';
$labels['back'] = 'Tebek';
$labels['options'] = 'Opsjes';
$labels['first'] = 'Earst';
$labels['last'] = 'Lêst';
$labels['previous'] = 'Foarige';
$labels['next'] = 'Folgjende';
$labels['select'] = 'Selektearje';
$labels['all'] = 'Alle';
$labels['none'] = 'Gjin';
$labels['currpage'] = 'Aktuele side';
$labels['isread'] = 'Lêzen';
$labels['unread'] = 'Net-lêzen';
$labels['flagged'] = 'Flagge';
$labels['unflagged'] = 'Net-flagge';
$labels['unanswered'] = 'Unbeantwurde';
$labels['withattachment'] = 'Mei taheaksel';
$labels['deleted'] = 'Ferwidere';
$labels['undeleted'] = 'Net ferwidere';
$labels['replied'] = 'Antwurde';
$labels['forwarded'] = 'Trochstjoerd';
$labels['invert'] = 'Omkeart';
$labels['filter'] = 'Filter';
$labels['list'] = 'Lyst';
$labels['threads'] = 'Streamen';
$labels['expand-all'] = 'Alles útwreidzje';
$labels['expand-unread'] = 'Net-lêzen útwreidzje';
$labels['collapse-all'] = 'Alles ynsakje';
$labels['threaded'] = 'Streamde';
$labels['autoexpand_threads'] = 'Berjocht stream útwreidzje';
$labels['do_expand'] = 'Alle streamen';
$labels['expand_only_unread'] = 'Allinnich mei net-lêzen berjochten';
$labels['fromto'] = 'Fan/Nei';
$labels['flag'] = 'Flagge';
$labels['attachment'] = 'Taheaksel';
$labels['nonesort'] = 'Gjin';
$labels['sentdate'] = 'Ferstjoer datum';
$labels['arrival'] = 'Oankomst datum';
$labels['asc'] = 'oprinnend';
$labels['desc'] = 'delgeande';
$labels['listcolumns'] = 'Lyst kolommen';
$labels['listsorting'] = 'Skiftsje kolom';
$labels['listorder'] = 'Sorting oarder';
$labels['listmode'] = 'Lyst werjefte modus';
$labels['layout'] = 'Yndieling';
$labels['layoutwidescreen'] = 'Breedbyld';
$labels['layoutdesktop'] = 'Desktop';
$labels['layoutlist'] = 'Lyst';
$labels['folderactions'] = 'Map aksjes';
$labels['compact'] = 'Kompakt';
$labels['empty'] = 'Leech';
$labels['importmessages'] = 'Berjochten ymportearje';
$labels['quota'] = 'Skiifgebrûk';
$labels['unknown'] = 'ûnbekend';
$labels['unlimited'] = 'ûnbeheind';
$labels['quotatype'] = 'Kwota type';
$labels['quotatotal'] = 'Beheining';
$labels['quotaused'] = 'Brûkt';
$labels['quotastorage'] = 'Skiifromte';
$labels['quotamessage'] = 'Oantal berjochten';
$labels['quicksearch'] = 'Fluch sykje';
$labels['resetsearch'] = 'Sykopdracht wiskje';
$labels['searchmod'] = 'Syk modifikaasjes';
$labels['msgtext'] = 'Hiele berjocht';
$labels['body'] = 'Ynhâld';
$labels['type'] = 'Type';
$labels['namex'] = 'Namme';
$labels['searchscope'] = 'Berik';
$labels['currentfolder'] = 'Aktuele map';
$labels['subfolders'] = 'Dizze en ûnderlizzende mappen';
$labels['allfolders'] = 'Alle mappen';
$labels['searchinterval-1W'] = 'Alder as in wike';
$labels['searchinterval-1M'] = 'Alder as in moanne';
$labels['searchinterval-1Y'] = 'Alder as in jier';
$labels['searchinterval1W'] = 'Nijer as in wike';
$labels['searchinterval1M'] = 'Nijer as in moanne';
$labels['searchinterval1Y'] = 'Nijer as in jier';
$labels['openinextwin'] = 'Iepenje yn nij finster';
$labels['emlsave'] = 'Ynlade (.eml)';
$labels['changeformattext'] = 'Toan yn gewoane tekst';
$labels['changeformathtml'] = 'Toan yn HTML formaat';
$labels['editasnew'] = 'Bewurkje as nij';
$labels['send'] = 'Ferstjoere';
$labels['sendmessage'] = 'Berjocht ferstjoere';
$labels['savemessage'] = 'Bewarje as konsept';
$labels['addattachment'] = 'In bestân taheakje';
$labels['charset'] = 'Tekenset';
$labels['editortype'] = 'Bewurker type';
$labels['returnreceipt'] = 'Untfangst werom stjoere';
$labels['dsn'] = 'Levering status notifikaasje';
$labels['mailreplyintro'] = 'Op $date, skreau $sender:';
$labels['originalmessage'] = 'Oarspronklik Berjocht';
$labels['selectimage'] = 'Ofbylding selektearje';
$labels['addimage'] = 'Ofbylding tafoegje';
$labels['selectmedia'] = 'Fideo selektearje';
$labels['addmedia'] = 'Fideo tafoegje';
$labels['encrypt'] = 'Fersiferje';
$labels['encryptmessage'] = 'Berjocht fersiferje';
$labels['encryptmessagemailvelope'] = 'Berjocht fersiferje mei Mailvelope';
$labels['importpubkeys'] = 'Publike kaaien ymportearje';
$labels['encryptedsendialog'] = 'Fersifere berjocht ferstjoere';
$labels['keyid'] = 'Kaai ID';
$labels['keylength'] = 'Bits';
$labels['keyexpired'] = 'Ferrûn';
$labels['keyrevoked'] = 'Ynlutsen';
$labels['bccinstead'] = 'Bcc brûke';
$labels['insert'] = 'Ynfoegje';
$labels['editidents'] = 'Identiteiten bewurkje';
$labels['spellcheck'] = 'Stavering';
$labels['checkspelling'] = 'Stavering kontrolearje';
$labels['resumeediting'] = 'Bewurkje ferfetsje';
$labels['revertto'] = 'Tebeksette nei';
$labels['restore'] = 'Weromsette';
$labels['restoremessage'] = 'Berjocht weromsette?';
$labels['ignore'] = 'Negearje';
$labels['responses'] = 'Antwurden';
$labels['insertresponse'] = 'In antwurd ynfiere';
$labels['manageresponses'] = 'Antwurden beheare';
$labels['newresponse'] = 'Nij antwurd oanmeitsje';
$labels['addresponse'] = 'Antwurd tafoegje';
$labels['editresponse'] = 'Antwurd bewurkje';
$labels['editresponses'] = 'Antwurden bewurkje';
$labels['responsename'] = 'Namme';
$labels['responsetext'] = 'Antwurd tekst';
$labels['attach'] = 'Taheakje';
$labels['attachments'] = 'Taheaksels';
$labels['upload'] = 'Oplade';
$labels['uploadprogress'] = '$percent ($current fan $total)';
$labels['close'] = 'Slúte';
$labels['messageoptions'] = 'Berjocht opsjes...';
$labels['togglecomposeoptions'] = 'Komposysje opsjes skeakelje';
$labels['attachmentrename'] = 'Taheaksel omneame';
$labels['low'] = 'Leech';
$labels['lowest'] = 'Leechste';
$labels['normal'] = 'Normaal';
$labels['high'] = 'Heech';
$labels['highest'] = 'Heechste';
$labels['nosubject'] = '(gjin ûnderwerp)';
$labels['showimages'] = 'Ofbyldings toane';
$labels['alwaysshow'] = 'Ofbyldings fan $sender altyd toane';
$labels['isdraft'] = 'Dit is in konsept berjocht';
$labels['andnmore'] = '$nr mear...';
$labels['togglemoreheaders'] = 'Mear berjocht koppen toane';
$labels['togglefullheaders'] = 'Ruwe berjocht koppen skeakelje';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Gewoane tekst';
$labels['savesentmessagein'] = 'Bewarje ferstjoerd berjoch yn';
$labels['dontsave'] = 'net bewarje';
$labels['maxuploadsize'] = 'Maksimum bestâns grutte is $size';
$labels['addcc'] = 'CC tafoegje';
$labels['addbcc'] = 'BCC tafoegje';
$labels['addreplyto'] = 'Reagearje-Op Tafoegje';
$labels['addfollowupto'] = 'Ferfolch-Op Tafoegje';
$labels['mdnrequest'] = 'De stjoerder fan dit berjocht hat frege om op de hichte brocht te wurden as jo dit berjocht lêzen hawwe. Wolle jo de ôfstjoerder op de hichte bringe?';
$labels['receiptread'] = 'Weromstjoerd Untfangstbewiis (lêzen)';
$labels['yourmessage'] = 'Dit is in Weromstjoerd Untfangstbewiis foar jo berjocht';
$labels['receiptnote'] = 'Tink derom: Dit ûntfangstbewiis erkent allinnich dat it berjocht waard werjûn op de kompjûter fan ûntfanger. Der is gjin garânsje dat de ûntfanger de berjocht ynhâld lêzen of begrepen hat.';
$labels['name'] = 'Skerm Namme';
$labels['firstname'] = 'Foarnamme';
$labels['surname'] = 'Achternamme';
$labels['middlename'] = 'Twadde Namme';
$labels['nameprefix'] = 'Foarheaksel';
$labels['namesuffix'] = 'Efterheaksel';
$labels['nickname'] = 'Skûlnamme';
$labels['jobtitle'] = 'Funksjenamme';
$labels['department'] = 'Ofdieling';
$labels['gender'] = 'Geslacht';
$labels['maidenname'] = 'Famkesnamme';
$labels['email'] = 'E-post';
$labels['phone'] = 'Telefoannûmer';
$labels['address'] = 'Adres';
$labels['street'] = 'Strjitte';
$labels['locality'] = 'Doarp/Stêd';
$labels['zipcode'] = 'Postkoade';
$labels['region'] = 'Provinsje';
$labels['country'] = 'Lân';
$labels['birthday'] = 'Jierdei';
$labels['anniversary'] = 'Troudei';
$labels['website'] = 'Webstee';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Notysjes';
$labels['male'] = 'man';
$labels['female'] = 'frou';
$labels['manager'] = 'Behearder';
$labels['assistant'] = 'Assistint';
$labels['spouse'] = 'Echtgenoat';
$labels['allfields'] = 'Alle fjilden';
$labels['search'] = 'Sykje';
$labels['searchresult'] = 'Syk risseltaten';
$labels['advsearch'] = 'Avansearre Sykje';
$labels['advanced'] = 'Avansearre';
$labels['other'] = 'Oars';
$labels['printcontact'] = 'Kontakt ôfdrukke';
$labels['qrcode'] = 'QR Koade';
$labels['typehome'] = 'Thús';
$labels['typework'] = 'Wurk';
$labels['typeother'] = 'Oars';
$labels['typemobile'] = 'Mobyl';
$labels['typemain'] = 'Foarnaamste';
$labels['typehomefax'] = 'Fax Thús';
$labels['typeworkfax'] = 'Fax Wurk';
$labels['typecar'] = 'Auto';
$labels['typepager'] = 'Pieper';
$labels['typevideo'] = 'Fideo';
$labels['typeassistant'] = 'Assistint';
$labels['typehomepage'] = 'Thússide';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profyl';
$labels['addfield'] = 'Fjild tafoegje';
$labels['addcontact'] = 'Kontakt tafoegje';
$labels['editcontact'] = 'Kontakt bewurkje';
$labels['contacts'] = 'Kontakten';
$labels['contactproperties'] = 'Kontakt eigenskippen';
$labels['contactnameandorg'] = 'Namme en Organisaasje';
$labels['personalinfo'] = 'Persoanlike ynformaasje';
$labels['personal'] = 'Persoanlik';
$labels['contactphoto'] = 'Kontakt foto';
$labels['edit'] = 'Bewurkje';
$labels['cancel'] = 'Annulearje';
$labels['save'] = 'Bewarje';
$labels['delete'] = 'Fuortsmite';
$labels['rename'] = 'Omneame';
$labels['addphoto'] = 'Tafoegje';
$labels['replacephoto'] = 'Ferfange';
$labels['uploadphoto'] = 'Foto oplade';
$labels['newcontact'] = 'Nij kontakt oanmeitsje';
$labels['deletecontact'] = 'Selektearre kontakten ferwiderje';
$labels['composeto'] = 'Skriuw berjocht oan';
$labels['contactsfromto'] = 'Kontakten $from oant $to fan $count';
$labels['print'] = 'Ofdrukke';
$labels['export'] = 'Eksportearje';
$labels['exportall'] = 'Alles eksportearje';
$labels['exportsel'] = 'Selektearre eksportearje';
$labels['exportvcards'] = 'Kontakten eksportearje yn vCard formaat';
$labels['newgroup'] = 'Nije groep oanmeitsje';
$labels['addgroup'] = 'Groep tafoegje';
$labels['grouprename'] = 'Groep omneame';
$labels['groupdelete'] = 'Groep ferwiderje';
$labels['groupremoveselected'] = 'Selektearre kontakten út groep ferwiderje';
$labels['uponelevel'] = 'Ien nivo omheech';
$labels['previouspage'] = 'Lit foarige side sjen';
$labels['firstpage'] = 'Lit earste side sjen';
$labels['nextpage'] = 'Lit folgjende side sjen';
$labels['lastpage'] = 'Lit lêste side sjen';
$labels['group'] = 'Groep';
$labels['groups'] = 'Groepen';
$labels['listgroup'] = 'Groep leden yn lyst';
$labels['personaladrbook'] = 'Persoanlike adressen';
$labels['searchsave'] = 'Sykopdracht bewarje';
$labels['searchdelete'] = 'Sykopdracht wiskje';
$labels['import'] = 'Ymportearje';
$labels['importcontacts'] = 'Kontakten ymportearje';
$labels['importtarget'] = 'Kontakten tafoegje oan';
$labels['importreplace'] = 'It hiele adresboek ferfange';
$labels['importgroups'] = 'Ymportearje groep opdrachten';
$labels['importgroupsall'] = 'Alle (meitsje groepen oan wêr nedich)';
$labels['importgroupsexisting'] = 'Allinnich foar besteande groepen';
$labels['done'] = 'Klear';
$labels['settingsfor'] = 'Ynstellings foar';
$labels['about'] = 'Oer';
$labels['preferences'] = 'Foarkarren';
$labels['userpreferences'] = 'Brûkers foarkarren';
$labels['editpreferences'] = 'Brûkers foarkarren bewurkje';
$labels['identities'] = 'Identiteiten';
$labels['manageidentities'] = 'Identiteiten beheare';
$labels['newidentity'] = 'Nije identiteit oanmeitsje';
$labels['addidentity'] = 'Identiteit tafoegje';
$labels['editidentity'] = 'Identiteit bewurkje';
$labels['preferhtml'] = 'Toan HTML';
$labels['defaultcharset'] = 'Standert Teken Set';
$labels['htmlmessage'] = 'HTML Berjocht';
$labels['messagepart'] = 'Diel';
$labels['digitalsig'] = 'Digitale Hantekening';
$labels['dateformat'] = 'Datum formaat';
$labels['timeformat'] = 'Tiid formaat';
$labels['prettydate'] = 'Moaie datums';
$labels['setdefault'] = 'Set standert';
$labels['autodetect'] = 'Auto';
$labels['language'] = 'Taal';
$labels['timezone'] = 'Tiidsône';
$labels['pagesize'] = 'Rigen per side';
$labels['signature'] = 'Hantekening';
$labels['dstactive'] = 'Simmertiid';
$labels['showinextwin'] = 'Berjocht yn nij finster iepenje';
$labels['composeextwin'] = 'Skriuw yn in nij finster';
$labels['htmleditor'] = 'Skriuw HTML berjochten';
$labels['htmlonreply'] = 'Allinnich op HTML berjocht antwurdzje';
$labels['htmlonreplyandforward'] = 'op trochstjoerd of antwurd nei HTML berjocht';
$labels['htmlsignature'] = 'HTML hantekening';
$labels['showemail'] = 'Toan e-post adres mei skermnamme';
$labels['previewpane'] = 'Toan foarbyld skerm';
$labels['skin'] = 'Omjouwings tema';
$labels['logoutclear'] = 'Jiskefet leechje by útloggen';
$labels['logoutcompact'] = 'Komprimearje Postfek YN by útloggen';
$labels['uisettings'] = 'Brûkers omjouwing';
$labels['serversettings'] = 'Tsjinner Ynstellings';
$labels['mailboxview'] = 'Postfek Yndieling';
$labels['mdnrequests'] = 'Op fersyk by ûntfangstbewiis';
$labels['askuser'] = 'freegje my';
$labels['autosend'] = 'stjoer ûntfangstbewiis ';
$labels['autosendknown'] = 'stjoer ûntfangstbewiis nei kontakten, oars my freegje';
$labels['autosendknownignore'] = 'stjoer ûntfangstbewiis nei kontakten, oars negearje';
$labels['ignorerequest'] = 'fersyk negearje';
$labels['readwhendeleted'] = 'Markearje berjocht as lêzen by wiskjen';
$labels['flagfordeletion'] = 'Berjocht flagje foar wiskjen yn pleats fan wiskjen';
$labels['skipdeleted'] = 'Wiske berjochten net sjen litte';
$labels['deletealways'] = 'As berjochten nei Jiskefet ferpleatse mislearret, wiskje';
$labels['deletejunk'] = 'Berjochten yn Jiskefet fuort wiskje';
$labels['showremoteimages'] = 'Werjaan eksterne ynsletten ôfbyldings';
$labels['fromknownsenders'] = 'fan bekende stjoerders';
$labels['always'] = 'altyd';
$labels['alwaysbutplain'] = 'Altyd, útsein as antwurde wurd yn gewoane tekst';
$labels['showinlineimages'] = 'Lit taheake ôfbyldings ûnder it berjocht sjen';
$labels['autosavedraft'] = 'Konsept automatysk bewarje';
$labels['everynminutes'] = 'eltse $n minút(en)';
$labels['refreshinterval'] = 'Ferfarskje (op nije berjochten kontrolearje, ensaf.)';
$labels['never'] = 'nea';
$labels['immediately'] = 'fuortendaliks';
$labels['messagesdisplaying'] = 'Berjochten Toane';
$labels['messagescomposition'] = 'Berjochten Skriuwe';
$labels['mimeparamfolding'] = 'Taheaksel nammen';
$labels['2231folding'] = 'Fol RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Fol RFC 2047 (other)';
$labels['force7bit'] = 'Brûk MIME fersifering foar 8-bit tekens';
$labels['savelocalstorage'] = "Bewarje yn lokale opslach fan de browser (tydlik)";
$labels['advancedoptions'] = 'Avansearre opsjes';
$labels['toggleadvancedoptions'] = 'Avansearre opsjes skeakelje';
$labels['focusonnewmessage'] = 'Fokus browser finster by nij berjocht';
$labels['checkallfolders'] = 'Kontrolearje alle mappen op nije berjochten';
$labels['defaultfont'] = 'Standert lettertype fan HTML berjocht';
$labels['mainoptions'] = 'Haad Opsjes';
$labels['browseroptions'] = 'Browser Opsjes';
$labels['section'] = 'Seleksje';
$labels['maintenance'] = 'Underhâld';
$labels['newmessage'] = 'Nij Berjocht';
$labels['signatureoptions'] = 'Hantekening Opsjes';
$labels['whenreplying'] = 'By beäntwurdzjen';
$labels['replyempty'] = 'It oarspronklike berjocht net sitearje';
$labels['replytopposting'] = 'begjinne nij berjocht boppe de sitaat';
$labels['replybottomposting'] = 'begjinne nij berjocht ûnder de sitaat';
$labels['replyremovesignature'] = 'By it beäntwurdzjen oarspronklike hântekening fan berjocht wiskje';
$labels['autoaddsignature'] = 'Automatysk hantekening tafoegje';
$labels['newmessageonly'] = 'allinnich nije berjochten';
$labels['replyandforwardonly'] = 'by antwurdzjen en trochstjoeren';
$labels['insertsignature'] = 'Hantekening ynfoegje';
$labels['sigbelow'] = 'Hantekening ûnder it siteare berjocht';
$labels['sigseparator'] = 'Forsearje standert skiedingsteken yn hantekenings';
$labels['afternseconds'] = 'nei $n sekonden';
$labels['reqmdn'] = 'Freegje altyd in ûntfangstbewiis';
$labels['reqdsn'] = 'Freegje altyd in levering status notifikaasje';
$labels['replysamefolder'] = 'Set antwurden yn de map fan it berjocht dêr\'t op antwurde wurd';
$labels['defaultabook'] = 'Standert adresboek';
$labels['autocompletesingle'] = 'Sla alternative e-post adressen oer yn autokompleet';
$labels['listnamedisplay'] = 'Kontakten yn lyst as';
$labels['spellcheckbeforesend'] = 'Kontrolearje de stavering foar it ferstjoeren fan in berjocht';
$labels['spellcheckoptions'] = 'Staverings Opsjes';
$labels['spellcheckignoresyms'] = 'Negearje wurden mei symboalen';
$labels['spellcheckignorenums'] = 'Negearje wurden mei sifers';
$labels['spellcheckignorecaps'] = 'Negearje wurden mei alle letters as haadletters';
$labels['addtodict'] = 'Taheakje oan wurdboek';
$labels['mailtoprotohandler'] = 'Registrearje protokol handler foar mailto: keppelings';
$labels['standardwindows'] = 'Omgean mei popups as standert finsters';
$labels['forwardmode'] = 'Berjocht trochstjoeren';
$labels['inline'] = 'ynsletten';
$labels['asattachment'] = 'as taheaksel';
$labels['replyallmode'] = 'Standert aksje foar [Alles beäntwurdzje] knop';
$labels['replyalldefault'] = 'op alles antwurdzje';
$labels['replyalllist'] = 'allinnich antwurdzje nei mailing lyst (wêr fûn)';
$labels['folder'] = 'Map';
$labels['folders'] = 'Mappen';
$labels['foldername'] = 'Map namme';
$labels['subscribed'] = 'Ynskreaun';
$labels['messagecount'] = 'Berjochten';
$labels['create'] = 'Oanmeitsje';
$labels['createfolder'] = 'Nije map oanmeitsje';
$labels['managefolders'] = 'Mappen beheare';
$labels['specialfolders'] = 'Spesjale Mappen';
$labels['properties'] = 'Eigenskippen';
$labels['folderproperties'] = 'Map eigenskippen';
$labels['parentfolder'] = 'Boppelizzende map';
$labels['location'] = 'Lokaasje';
$labels['info'] = 'Ynformaasje';
$labels['getfoldersize'] = 'Klik om map grutte te krijen';
$labels['changesubscription'] = 'Klik om ynskriuwing te feroarjen';
$labels['foldertype'] = 'Map Type';
$labels['personalfolder'] = 'Privee Map';
$labels['otherfolder'] = 'Oare Brûker\'s Map';
$labels['sharedfolder'] = 'Publike Map';
$labels['findfolders'] = 'Mappen fine';
$labels['namespace.personal'] = 'Persoanlik';
$labels['namespace.other'] = 'Oare brûkers';
$labels['namespace.shared'] = 'Dielt';
$labels['sortby'] = 'Sortearje op';
$labels['sortasc'] = 'Sortearje oprinnend';
$labels['sortdesc'] = 'Sortearje delgeand';
$labels['undo'] = 'Ungedien meitsje';
$labels['installedplugins'] = 'Ynstallearre ynstekkers';
$labels['plugin'] = 'Ynstekker';
$labels['version'] = 'Ferzje';
$labels['source'] = 'Boarne';
$labels['license'] = 'Lisinsje';
$labels['support'] = 'Krij help';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Ingelsk';
$labels['westerneuropean'] = 'West Europeesk';
$labels['easterneuropean'] = 'East Europeesk';
$labels['southeasterneuropean'] = 'Súd-East Europeesk';
$labels['baltic'] = 'Baltysk';
$labels['cyrillic'] = 'Syrillysk';
$labels['arabic'] = 'Arabysk';
$labels['greek'] = 'Gryksk';
$labels['hebrew'] = 'Hebrieuwsk';
$labels['turkish'] = 'Turksk';
$labels['nordic'] = 'Noardsk';
$labels['thai'] = 'Taisk';
$labels['celtic'] = 'Keltysk';
$labels['vietnamese'] = 'Fietnameesk';
$labels['japanese'] = 'Japansk';
$labels['korean'] = 'Koreaansk';
$labels['chinese'] = 'Sineesk';
$labels['arialabeltopnav'] = 'Finster kontrôle';
$labels['arialabeltasknav'] = 'Applikaasje taken';
$labels['arialabeltoolbar'] = 'Applikaasje arkbalke';
$labels['arialabelactivetask'] = 'Aktive taak';
$labels['arialabelmessagessearchfilter'] = 'E-post fermelding filter';
$labels['arialabelmailsearchform'] = 'E-post berjocht syk formulier';
$labels['arialabelcontactsearchform'] = 'Kontakt syk formulier';
$labels['arialabelmailquicksearchbox'] = 'E-post sykje ynbring';
$labels['arialabelquicksearchbox'] = 'Sykje ynbring';
$labels['arialabelfoldersearchfilter'] = 'Map fermelding filter';
$labels['arialabelfoldersearchform'] = 'Map syk formulier';
$labels['arialabelfolderlist'] = 'E-post map seleksje';
$labels['arialabelmessagelist'] = 'E-post Berjocht Fermelding';
$labels['arialabelmailpreviewframe'] = 'Berjocht foarbyld';
$labels['arialabelmailboxmenu'] = 'Map aksje menu';
$labels['arialabellistselectmenu'] = 'Lyst seleksje menu';
$labels['arialabelthreadselectmenu'] = 'Stream fermelding menu';
$labels['arialabelmessagelistoptions'] = 'Berjocht lyst werjefte en sortearjen opsjes';
$labels['arialabelmailimportdialog'] = 'Berjocht ymport skerm';
$labels['arialabelmessagenav'] = 'Berjocht navigaasje';
$labels['arialabelmessagebody'] = 'Berjocht Ynhâld';
$labels['arialabelmessageactions'] = 'Berjocht aksjes';
$labels['arialabelcontactquicksearch'] = 'Kontakten syk formulier';
$labels['arialabelcontactsearchbox'] = 'Kontakt syk ynbring';
$labels['arialabelmessageheaders'] = 'Berjocht koppen';
$labels['arialabelforwardingoptions'] = 'Trochstjoer opsjes';
$labels['arialabelreplyalloptions'] = 'Antwurdzje-alle opsjes';
$labels['arialabelmoremessageactions'] = 'Mear berjocht aksjes';
$labels['arialabelmarkmessagesas'] = 'Markearje selektearre berjochten as...';
$labels['arialabelcomposeoptions'] = 'Skriuw opsjes';
$labels['arialabelresponsesmenu'] = 'Ynblikte antwurden menu';
$labels['arialabelattachmentuploadform'] = 'Taheaksel oplaad formulier';
$labels['arialabelattachmentpreview'] = 'Taheaksel foarbyld';
$labels['ariasummarycomposecontacts'] = 'Lyst fan kontakten en groepen te selektearjen as ûntfangers';
$labels['arialabelcontactexportoptions'] = 'Kontakt eksport opsjes';
$labels['arialabelabookgroupoptions'] = 'Adresboek/groep opsjes';
$labels['arialabelpreferencesform'] = 'Foarkarren formulier';
$labels['arialabelidentityeditfrom'] = 'Identiteit bewurkings formulier';
$labels['arialabelresponseeditfrom'] = 'Antwurd bewurkings formulier';
$labels['arialabelsearchterms'] = 'Syktermen';
$labels['helplistnavigation'] = 'Lyst toetseboerd navigaasje';
$labels['helplistkeyboardnavigation'] = "Pylken op/del: Beweegje rige fokus/seleksje.
Spatie: Selektearje fokuse rige.
Shift + op/del: Selektearje oanfoljende rige boppe/ûnder.
Ctrl + Spatie: Foegje fokuse rige ta oan seleksje/ferwiderje fan seleksje.";
$labels['helplistkeyboardnavmessages'] = "Pylken rjochts/lofts: útwreidzje/ynsakje berjocht stream (allinnich yn stream modus).
Enter: Iepenje it selektearre/fokuse berjocht.
Delete: Ferpleats selektearre berjocht nei jiskefet.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Iepenje it selektearre/fokuse kontakt.";
