<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'حدث خطأ!';
$messages['loginfailed']  = 'فشل تسجيل الدخول';
$messages['cookiesdisabled'] = 'المتصفح الخاص بك لا يقبل الكوكيز';
$messages['sessionerror'] = 'انتهت صلاحية الجلسة الحالية أو أنها غيرصالحة';
$messages['cookiesmismatch'] = 'تم اكتشاف عدم تطابق في ملف تعريف الارتباط. من فضلك ، امسح ملفات تعريف الارتباط في المتصفح الخاص بك.';
$messages['storageerror'] = 'فشل الاتصال بخادم التخزين.';
$messages['servererror'] = 'خطأ في الخادم!';
$messages['servererrormsg'] = 'خطأ خادم: $msg';
$messages['accountlocked'] = 'عدد كبير جدًا من محاولات تسجيل الدخول الفاشلة. حاول مرة أخرى في وقت لاحق.';
$messages['connerror'] = 'خطأ في الاتصال (فشل في الوصول الى الخادم)!';
$messages['dberror'] = 'خطأ في قاعدة البيانات!';
$messages['dbconnerror'] = 'غير قادر على الاتصال بقاعدة البيانات!';
$messages['windowopenerror'] = 'تم منع النافذة المنبثقة!';
$messages['requesttimedout'] = 'انتهت مهلة الطلب ';
$messages['errorreadonly'] = 'تعذر تنفيذ العملية. المجلد للقراءة فقط.';
$messages['errornoperm'] = 'تعذر تنفيذ العملية. ليست لديك الصلاحية.';
$messages['erroroverquota'] = 'تعذر تنفيذ العملية. لايوجد مساحة كافية.';
$messages['erroroverquotadelete'] = 'لا يوجد مساحة كافية. استخدم SHIFT+DEL لحذف الرسالة.';
$messages['invalidrequest'] = 'طلب غير صالح! لم تحفظ أية بيانات.';
$messages['invalidhost'] = 'اسم الملقم غير صالح.';
$messages['nomessagesfound'] = 'لم يعثر على أية رسائل في صندوق البريد هذا';
$messages['loggedout'] = 'لقد أنهيت الجلسة بنجاح. مع السلامة!';
$messages['mailboxempty'] = 'صندوق البريد فارغ';
$messages['nomessages'] = 'لا يوجد رسائل';
$messages['refreshing'] = 'جاري التحديث...';
$messages['loading'] = 'جاري العمل...';
$messages['uploading'] = 'جاري رفع الملف...';
$messages['attaching'] = 'إرفاق الملف جارٍ...';
$messages['uploadingmany'] = 'جاري تحميل الملفات...';
$messages['loadingdata'] = 'تحميل البيانات...';
$messages['checkingmail'] = 'التحقق من وجود رسائل جديدة...';
$messages['sendingmessage'] = 'إرسال الرسالة...';
$messages['messagesent'] = 'تم إرسال الرسالة بنجاح';
$messages['savingmessage'] = 'حفظ الرسالة...';
$messages['messagesaved'] = 'تم حفظ الرسالة في المسودات';
$messages['successfullysaved'] = 'تم الحفظ بنجاح';
$messages['savingresponse'] = 'جاري حفظ نص الرد...';
$messages['deleteresponseconfirm'] = 'هل تريد فعلاً حذف نص الرد هذا؟';
$messages['nocontactselected'] = 'لم تقم بتحديد جهة اتصال حتى الآن.';
$messages['addedsuccessfully'] = 'تمت إضافة المراسل إلى دفتر العناوينبنجاح';
$messages['contactexists'] = 'توجد جهة اتصال لها عنوان البريد الإلكتروني نفسه.';
$messages['contactnameexists'] = 'هناك مُرسال له نفس الإسم موجود مسبقاً.';
$messages['blockedimages'] = 'لحماية خصوصيتك، تم حجب الصور الغير مضمنة(البعيدة) في هذه الرسالة.';
$messages['blockedresources'] = 'لحماية خصوصيتك تم حظر الموارد البعيدة.';
$messages['suspiciousemail'] = 'تحتوي هذه الرسالة على عناوين بريد إلكتروني مشبوهة قد تكون احتيالية.';
$messages['bccemail'] = 'تحتوي الرسالة (الرسائل) المعاد توجيهها على مستلمين مخفيين (نسخة مخفية).';
$messages['bouncehint'] = 'سيتم إرسال الرسالة دون أي تعديلات، أي باستخدام النص الأصلي والمقدمات والمستلمين.';
$messages['encryptedmessage'] = 'هذه الرسالة مشفرة ولا يمكن عرضها. عذراً!';
$messages['externalmessagedecryption'] = 'هذه رسالة مشفرة ويمكن فك تشفيرها بملحق المتصفح الخاص بك.';
$messages['nopubkeyfor'] = 'لم يتم العثور على مفتاح عام صالح لـ $email';
$messages['nopubkeyforsender'] = 'لم يتم العثور على مفتاح عام صالح لهوية المرسل الخاصة بك. هل تريد تشفير الرسالة للمستلمين فقط؟';
$messages['encryptnoattachments'] = 'لا يمكن تشفير المرفقات التي تم تحميلها بالفعل. يرجى إعادة إضافتها في محرر التشفير.';
$messages['searchpubkeyservers'] = 'هل تريد البحث في خوادم المفاتيح العامة عن المفاتيح المفقودة؟';
$messages['encryptpubkeysfound'] = 'تم العثور على المفاتيح العامة التالية:';
$messages['keyservererror'] = 'فشل الحصول على مفتاح من خادم المفاتيح.';
$messages['keyimportsuccess'] = 'تم استيراد المفتاح العام $key بنجاح إلى حلقة المفاتيح.';
$messages['nocontactsfound'] = 'لم يعثر على أي مراسل';
$messages['contactnotfound'] = 'تعذر العثور على المراسل المطلوب';
$messages['contactsearchonly'] = 'يجب عليك استخدام نموذج بحث لرؤية جهات الاتصال من دفتر العناوين المحدد.';
$messages['sendingfailed'] = 'فشل إرسال الرسالة';
$messages['senttooquickly'] = 'رجاء انتظر $sec ثوان قبل إرسال هذه الرسالة';
$messages['errorsavingsent'] = 'حدث خطأ أثناء حفظ الرسالة المُرسلة.';
$messages['errorsaving'] = 'حدث خطأ أثناء الحفظ.';
$messages['errormoving'] = 'تعذر نقل هذه الرسالة';
$messages['errorcopying'] = 'تعذر نسخ الرسائل';
$messages['errordeleting'] = 'تعذر حذف هذه الرسالة';
$messages['errormarking'] = 'تعذر تحديد الرسائل';
$messages['alerttitle'] = 'انتباه';
$messages['confirmationtitle'] = 'هل أنت متأكد...';
$messages['deletecontactconfirm']  = 'هل تريد حقاً حذف المراسلـ(ين) المحدد(ين)؟';
$messages['deletegroupconfirm']  = 'هل تريد فعلاً حذف المجموعة المحددة؟';
$messages['deletemessagesconfirm'] = 'هل تريد حذف الرسائل المحددة؟';
$messages['deletefolderconfirm']  = 'هل تريد حقاً حذف هذا المجلد؟';
$messages['movefolderconfirm']  = 'هل تريد حقًا نقل هذا المجلد؟';
$messages['purgefolderconfirm']  = 'هل تريد حقاً حذف جميع الرسائل في هذاالمجلد؟';
$messages['contactdeleting'] = 'جاري حذف المُراسلين...';
$messages['groupdeleting'] = 'جاري حذف المجموعة...';
$messages['folderdeleting'] = 'جاري حذف المجلد...';
$messages['foldermoving'] = 'جاري نقل المجلد...';
$messages['foldersubscribing'] = 'الإشتراك في المجلد...';
$messages['folderunsubscribing'] = 'إلغاء الإشتراك في المجد...';
$messages['formincomplete'] = 'لم يتم تعبئة بيانات الاستمارة بالكامل';
$messages['noemailwarning'] = 'الرجاء إدخال عنوان بريد إلكتروني صالح';
$messages['nonamewarning']  = 'الرجاء إدخال اسم';
$messages['nopagesizewarning'] = 'الرجاء إدخال حجم الصفحة';
$messages['nosenderwarning'] = 'الرجاء إدخال عنوان البريد الإلكتروني للمرسِل.';
$messages['recipientsadded'] = 'تمت إضافة المستلم(ين) بنجاح.';
$messages['norecipientwarning'] = 'الرجاء إدخال اسم مستقبل واحد على الأقل';
$messages['disclosedrecipwarning'] = 'سيتمكن جميع المستلمين من رؤية عناوين البريد الإلكتروني لبعضهم البعض. لتجنب ذلك وحماية خصوصيتهم، يمكنك استخدام حقل "نسخة مخفية".';
$messages['disclosedreciptitle'] = 'عدد كبير جدًا من المستلمين العامين';
$messages['nosubjectwarning']  = 'حقل "الموضوع" فارغ. هل تريد كتابة موضوعللرسالة؟';
$messages['nosubjecttitle']  = 'لا يوجد عنوان';
$messages['nobodywarning'] = 'إرسال هذه الرسالة دون نص؟';
$messages['notsentwarning'] = 'لم يتم إرسال الرسالة وبها تغييرات غير محفوظة. هل تريد تجاهل التغييرات الخاصة بك؟';
$messages['restoresavedcomposedata'] = 'يوجد رسالة سابقة ولاكن غير مرسلة.\n\nالموضوع: $subject\nحفظ: $date\n\n هل تريد بالفعل استعادة هذة الرسالة ؟';
$messages['nosearchname'] = 'الرجاء إدخال اسم مراسل أو عنوان بريدإلكتروني';
$messages['notuploadedwarning'] = 'لم يتم رفع جميع المرفقات بعد. رجاءً الانتظار أو إلغاء عملية الرفع.';
$messages['searchsuccessful'] = 'عثر على $nr رسائل';
$messages['contactsearchsuccessful'] = 'عُثر على $nr مُراسَل';
$messages['searchnomatch'] = 'لم يعثر على شيء';
$messages['searching'] = 'جاري البحث...';
$messages['checking'] = 'جاري التحقق...';
$messages['stillsearching'] = 'البحث لازال جارياً...';
$messages['nospellerrors'] = 'لم يعثر على أية أخطاء إملائية';
$messages['folderdeleted'] = 'تم حذف المجلد بنجاح';
$messages['foldersubscribed'] = 'تم الإشتراك في المجلد بنجاح';
$messages['folderunsubscribed'] = 'تم إلغاء الإشتراك في المجلد بنجاح';
$messages['folderpurged'] = 'تم إفراغ المجلد بنجاح.';
$messages['folderexpunged'] = 'تم ضغط المجلد بنجاح.';
$messages['deletedsuccessfully'] = 'تم الحذف بنجاح';
$messages['converting'] = 'إزالة التنسيق من الرسالة...';
$messages['messageopenerror'] = 'تعذرت قراءة الرسالة من الخادم';
$messages['filelinkerror'] = 'فشل إرفاق الملف.';
$messages['fileuploaderror'] = 'فشل رفع الملف';
$messages['csvfilemismatch'] = 'لا يتم دعم استيراد ملفات CSV متعددة بحقول مختلفة.';
$messages['filesizeerror'] = 'حجم الملف الذي تحاول رفعه أكبر من الحجمالأقصى $size';
$messages['filecounterror'] = 'يمكنك تحميل ملفات بحد أقصى $count مرة واحدة.';
$messages['msgsizeerror'] = 'فشل إرفاق ملف. تم تجاوز الحد الأقصى لحجم الرسالة ($size).';
$messages['msgsizeerrorfwd'] = 'تم تجاوز الحد الأقصى لحجم الرسالة ($size). لم يتم إرفاق رسالة (رسائل) $num.';
$messages['copysuccess'] = 'تم نسخ $nr جهة اتصال بنجاح.';
$messages['movesuccess'] = 'تم نقل $nr جهة اتصال بنجاح.';
$messages['copyerror'] = 'لا يمكن نسخ أية جهة اتصال.';
$messages['moveerror'] = 'لا يمكن نقل أية جهة اتصال.';
$messages['sourceisreadonly'] = 'لا يمكن تعديل مصدر العنوان هذا';
$messages['errorsavingcontact'] = 'تعذر حفظ عنوان المراسل';
$messages['movingmessage'] = 'جاري نقل الرسالة...';
$messages['copyingmessage'] = 'جاري نسخ الرسالة...';
$messages['copyingcontact'] = 'جاري نسخ المُراسلين...';
$messages['movingcontact'] = 'جاري نقل جهات الاتصال...';
$messages['deletingmessage'] = 'جاري حذف الرسائل...';
$messages['markingmessage'] = 'جاري تحديد الرسائل...';
$messages['addingmember'] = 'جاري إضافة المُراسلين إلى المجموعة...';
$messages['removingmember'] = 'جاري إزالة المراسلين من المجموعة...';
$messages['receiptsent'] = 'أرسل إيصال الاستلام بنجاح';
$messages['errorsendingreceipt'] = 'تعذر إرسال إيصال الاستلام';
$messages['deleteidentityconfirm'] = 'هل تريد فعلاً حذف هذا المعرف؟';
$messages['nodeletelastidentity'] = 'لا يمكن حذف هذا السجل حيث أنه الوحيدالمتبقي.';
$messages['forbiddencharacter'] = 'اسم المجلّد يحتوي حروفاً ممنوعة';
$messages['selectimportfile'] = 'رجاء اختر ملفاً لرفعه';
$messages['addresswriterror'] = 'دفتر العناوين المحدد غير قابل للكتابة';
$messages['contactaddedtogroup'] = 'تمت إضافة المراسلين إلى هذه المجموعةبنجاح';
$messages['contactremovedfromgroup'] = 'تمت إزالة المراسلين من هذه المجموعةبنجاح';
$messages['nogroupassignmentschanged'] = 'لم يتم تغيير مهام المجموعة.';
$messages['importwait'] = 'جاري الاستيراد، رجاء انتظر...';
$messages['importformaterror'] = 'فشل في الاستيراد! الملف الذي تحاول رفعة ليس ملف استيراد صالح. ';
$messages['importconfirm'] = '<b>تم استيراد $inserted مراسلين بنجاح، وتجاهل$skipped موجودين مسبقاً</b>:<p><em>$names</em></p>';
$messages['importconfirmskipped'] = '<b>تم تخطي $skipped جهة/جهات اتصال موجودة</b>';
$messages['importconfirminvalid'] = '<b>تم تخطي $invalid جهة/جهات اتصال غير صالحة</b>';
$messages['importconfirmerrors'] = '<b>فشل استيراد $errors جهة/جهات اتصال صالحة</b>';
$messages['importmessagesuccess'] = 'تم استرداد $nr رسالة بنجاح';
$messages['importmessageerror'] = 'فشل في الاستيراد! الملف الذي تحاول رفعة ليس رسالة او صندوق بريد صالح. ';
$messages['opnotpermitted'] = 'العملية ممنوعة!';
$messages['nofromaddress'] = 'الهوية المحددة ينقصها عنوان البريد الإلكتروني.';
$messages['editorwarning'] = 'تغيير نوع المحرر قد يسبب فقد تنسيق النصز  هل ترغب المتابعة؟';
$messages['httpreceivedencrypterror'] = 'حدث خطأ جسيم في التهيئة. رجاءً اتصال بمدير الخادم حالاً. <b>لا يمكن إرسال بريدك.</b>';
$messages['smtpconnerror'] = 'خطأ SMTP ($code): تعذر الاتصال بالخادم';
$messages['smtpautherror'] = 'خطأ SMTP ($code): تعذر التحقق من هويتك';
$messages['smtpfromerror'] = 'خطأ SMTP ($code): تعذر تحديد المرسل "$from" ($msg)';
$messages['smtptoerror'] = 'خطأ SMTP ($code): تعذرت إضافة المستلم "$to" ($msg)';
$messages['smtprecipientserror'] = 'خطأ SMTP: تعذرت قراءة قائمة المرسل إليهم';
$messages['smtputf8error'] = 'خطأ SMTP: لا يدعم الخادم Unicode في عنوان البريد الإلكتروني.';
$messages['smtpsizeerror'] = 'خطأ SMTP: حجم الرسالة يتجاوز حد الخادم ($limit)';
$messages['smtperror'] = 'خطأ SMTP: $msg';
$messages['emailformaterror'] = 'عنوان بريد إلكتروني غير صحيح: $email';
$messages['toomanyrecipients'] = 'عدد المرسل إليهم كبير. قلص العدد إلى $max.';
$messages['maxgroupmembersreached'] = 'عدد أعضاء المجموعة أكثر من $max';
$messages['internalerror'] = 'حدث خطأ داخلي. الرجاء المحاولة مرة أخرى.';
$messages['contactdelerror'] = 'تعذر حذف أسماء جهات الإتصال';
$messages['contactdeleted'] = 'تم حذف أسماء جهات الإتصال بنجاح';
$messages['contactrestoreerror'] = 'تعذر استعادة المُراسل المحذوف.';
$messages['contactrestored'] = 'تم استعادة المُراسل بنجاح.';
$messages['groupdeleted'] = 'تم حذف المجموعة بنجاح';
$messages['grouprenamed'] = 'تم تغيير إسم المجموعة بنجاح';
$messages['groupcreated'] = 'تم إنشاء المجموعة بنجاح';
$messages['savedsearchdeleted'] = 'تم بنجاح حذف البحث المحفوظ.';
$messages['savedsearchdeleteerror'] = 'تعذر حذف البحث المحفوظ';
$messages['savedsearchcreated'] = 'تم بنجاح إنشاء البحث المحفوظ.';
$messages['savedsearchcreateerror'] = 'تعذر إنشاء بحث محفوظ.';
$messages['messagedeleted'] = 'تم حذف الرسائل بنجاح';
$messages['messagemoved'] = 'تم نقل الرسائل بنجاح';
$messages['messagemovedtotrash'] = 'تم نقل الرسالة (الرسائل) إلى المهملات بنجاح.';
$messages['messagecopied'] = 'تم نسخ الرسائل بنجاح';
$messages['messagemarked'] = 'تم تحديد الرسائل بنجاح';
$messages['autocompletechars'] = 'إكتب $min أحرف على الأقل للحصول على التكملةالتلقائية';
$messages['autocompletemore'] = 'هناك المزيد من النتائج المطابقة. رجاءاكتب كلمات بحث أكثر.';
$messages['namecannotbeempty'] = 'لا يمكن ترك الإسم فارغاً';
$messages['nametoolong'] = 'الإسم طويل جداً';
$messages['namedotforbidden'] = 'لا يمكن أن يبدأ اسم المجلد بنقطة.';
$messages['folderupdated'] = 'تم تحديث المجلد بنجاح';
$messages['foldercreated'] = 'تم إنشاء المجلد بنجاح';
$messages['invalidimageformat'] = 'ليست صيغة صورة صحيحة';
$messages['mispellingsfound'] = 'عُثر على أخطاء إملائية في الرسالة';
$messages['parentnotwritable'] = 'تعذر إنشاء/نقل المجلد إلى المجلد المحدد.ليست لديك الصلاحية.';
$messages['messagetoobig'] = 'جزء الرسالة أكبر بكثير مما يمكن معالجته.';
$messages['attachmentvalidationerror'] = 'هذا المرفق مريب لأن نوعه لا يتطابق مع النوع المعلن في الرسالة. إذا كنت لا تثق في المرسل ، فلا يجب عليك فتحه في المتصفح لأنه قد يحتوي على محتويات ضارة <br/><br/><em>. $expected; تم العثور على: $detected </em>';
$messages['noscriptwarning'] = 'تحذير: خادم البريد الالكتروني هذا يتطلب جافاسكربت , يرجى تفعيل الـ جافاسكربت في اعدادت المتصفح الخاص بك لتتمكن من استخدامة.';
$messages['messageissent'] = 'تم إرسال الرسالة بالفعل ، ولكن لم يتم حفظها بعد. هل تريد حفظها الآن؟';
$messages['errnotfound'] = 'لم يتم العثور على الملف';
$messages['errnotfoundexplain'] = 'لم يتم العثور على المورد المطلوب!';
$messages['errfailedrequest'] = 'لم يتم الطلب';
$messages['errauthorizationfailed'] = 'فشل التفويض';
$messages['errunauthorizedexplain'] = 'تعذر التحقق من أنك مخول للوصول إلى هذه الخدمة!';
$messages['errrequestcheckfailed'] = 'فشل التحقق من الطلب';
$messages['errcsrfprotectionexplain'] = "لحمايتك ، الوصول إلى هذا المورد مؤمن ضد CSRF.\n إذا رأيت هذا ، فمن المحتمل أنك لم تقم بتسجيل الخروج قبل مغادرة تطبيق الويب.\n\n التفاعل البشري مطلوب الآن للمتابعة.";
$messages['errcontactserveradmin'] = 'يرجى الاتصال بمسؤول الخادم الخاص بك.';
$messages['clicktoresumesession'] = 'انقر هنا لاستئناف جلستك السابقة';
$messages['errcomposesession'] = 'خطأ في تكوين الجلسة';
$messages['errcomposesessionexplain'] = 'لم يتم العثور على جلسة الإنشاء المطلوبة.';
$messages['clicktocompose'] = 'انقر هنا لإنشاء رسالة جديدة';
$messages['nosupporterror'] = 'هذه الميزة لا يدعمها متصفح الويب الخاص بك.';
$messages['siginserted'] = 'تم إدخال توقيع بنجاح.';
$messages['responseinserted'] = 'تم إدخال الرد بنجاح.';
$messages['noresponsesavailable'] = 'لا توجد ردود متاحة';
$messages['listempty'] = 'القائمة فارغة.';
$messages['listusebutton'] = 'استخدم الزر "إنشاء" لإضافة سجل جديد.';
$messages['keypaircreatesuccess'] = 'تم إنشاء زوج مفاتيح جديد بنجاح لـ $identity .';
$messages['emptyattachment'] = 'يبدو أن هذا المرفق فارغ. <br>من فضلك ، تحقق مع الشخص الذي أرسل هذا.';
$messages['oauthloginfailed'] = 'فشل تسجيل الدخول إلى OAuth. حاول مرة أخرى.';
$messages['oauthinvalidrequest'] = 'طلب التفويض غير صالح أو غير مكتمل.';
$messages['oauthaccessdenied'] = 'رفض خادم التفويض أو المستخدم الطلب.';
