<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['encryption'] = 'Şîfrekirin';
$labels['enigmacerts'] = 'Bawernamyên S/MIME';
$labels['enigmakeys'] = 'Kilîtên PGP';
$labels['keyname'] = 'Nav';
$labels['keyid'] = 'ID a kilîtê';
$labels['keyuserid'] = 'ID a bikarhêner';
$labels['keytype'] = 'Cûreya kilîtê';
$labels['keyprops'] = 'Taybetmendiyên kilîtê';
$labels['basicinfo'] = 'Zanyariyên bingehîn';
$labels['typesign'] = 'Têkeve';
$labels['subkeyid'] = 'ID';
$labels['subkeycreated'] = 'Hat afirandin';
$labels['subkeyusage'] = 'Bikaranîn';
$labels['expiresnever'] = 'ti car';
$labels['unknown'] = 'nenas';
$labels['uservalid'] = 'Derbasdar';
$labels['userid'] = 'ID';
$labels['valid'] = 'derbasdar';
$labels['keyremove'] = 'Rake';
$labels['keychpass'] = 'Şîfreyê biguherîne';
$labels['newkeypass'] = 'Borînpeyv';
$labels['newkeypassconfirm'] = 'Borînpeyvê biperjîne';
$labels['newkeytype'] = 'Cûreya kilîtê';
