<roundcube:include file="includes/layout.html" />

<h1 class="voice"><roundcube:object name="productname" /> <roundcube:label name="login" /></h1>

<div id="layout-content" class="selected no-navbar" role="main">
	<roundcube:object name="logo" src="/images/logo.svg" id="logo" alt="Logo" />
	<roundcube:form id="login-form" name="login-form" method="post" class="propform">
	<roundcube:object name="loginform" form="login-form" size="40" submit=true class="form-control" />
		<div id="login-footer" role="contentinfo">
			<roundcube:object name="productname" condition="config:display_product_info &gt; 0" />
			<roundcube:object name="version" condition="config:display_product_info == 2" />
			<roundcube:if condition="config:support_url" />
				&nbsp;&bull;&nbsp; <a href="<roundcube:var name='config:support_url' />" target="_blank" rel="noopener" class="support-link"><roundcube:label name="support" /></a>
			<roundcube:endif />
			<roundcube:container name="loginfooter" id="login-footer" />
		</div>
	</form>
</div>

<noscript>
	<p class="noscriptwarning"><roundcube:label name="noscriptwarning" /></p>
</noscript>

<roundcube:include file="includes/footer.html" />
