<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Geef browser melding weer bij een nieuw bericht';
$labels['desktop'] = 'Geef desktop meldingen weer bij een nieuw bericht';
$labels['sound'] = 'Speel het geluid af bij een nieuw bericht';
$labels['test'] = 'Test';
$labels['title'] = 'Nieuwe e-mail!';
$labels['body'] = 'Je hebt een nieuw bericht ontvangen.';
$labels['testbody'] = 'Dit is een test melding.';
$labels['desktopdisabled'] = 'Desktop meldingen zijn uitgeschakeld in uw browser.';
$labels['desktopunsupported'] = 'Uw browser ondersteund geen desktop meldingen.';
$labels['desktoptimeout'] = 'Sluit desktop melding';
