<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Filtry';
$labels['managefilters'] = 'Zarządzanie filtrami poczty przychodzącej';
$labels['filtername'] = 'Nazwa filtru';
$labels['newfilter'] = 'Nowy filtr';
$labels['filteradd'] = 'Dodaj filtr';
$labels['filterdel'] = 'Usuń filtr';
$labels['rules'] = 'Reguły';
$labels['actions'] = 'Akcje';
$labels['scope'] = 'Zakres';
$labels['moveup'] = 'W górę';
$labels['movedown'] = 'W dół';
$labels['filterallof'] = 'spełniających wszystkie poniższe kryteria';
$labels['filteranyof'] = 'spełniających dowolne z poniższych kryteriów';
$labels['filterany'] = 'wszystkich';
$labels['filtercontains'] = 'zawiera';
$labels['filternotcontains'] = 'nie zawiera';
$labels['filteris'] = 'jest równe';
$labels['filterisnot'] = 'nie jest równe';
$labels['filterexists'] = 'istnieje';
$labels['filternotexists'] = 'nie istnieje';
$labels['filtermatches'] = 'pasuje do wyrażenia';
$labels['filternotmatches'] = 'nie pasuje do wyrażenia';
$labels['filterregex'] = 'pasuje do wyrażenia regularnego';
$labels['filternotregex'] = 'nie pasuje do wyrażenia regularnego';
$labels['filterunder'] = 'poniżej';
$labels['filterover'] = 'ponad';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Część MIME:';
$labels['mime-message'] = 'wiadomość';
$labels['mime-anychild'] = 'dowolne';
$labels['mime-type'] = 'typ';
$labels['mime-subtype'] = 'podtyp';
$labels['mime-contenttype'] = 'typ treści';
$labels['mime-param'] = 'parametr';
$labels['addrule'] = 'Dodaj regułę';
$labels['delrule'] = 'Usuń regułę';
$labels['messagemoveto'] = 'Przenieś wiadomość do';
$labels['messageredirect'] = 'Przekaż wiadomość na konto';
$labels['messagecopyto'] = 'Skopiuj wiadomość do';
$labels['messagesendcopy'] = 'Wyślij kopię do';
$labels['messagereply'] = 'Odpowiedz wiadomością o treści';
$labels['messagedelete'] = 'Usuń wiadomość';
$labels['messagediscard'] = 'Odrzuć z komunikatem';
$labels['messagekeep'] = 'Zachowaj wiadomość w Odebranych';
$labels['messagesrules'] = 'W stosunku do przychodzącej poczty:';
$labels['messagesactions'] = '...wykonaj następujące czynności:';
$labels['add'] = 'Dodaj';
$labels['del'] = 'Usuń';
$labels['sender'] = 'Nadawca';
$labels['recipient'] = 'Odbiorca';
$labels['vacationaddr'] = 'Moje adresy e-mail:';
$labels['vacationdays'] = 'Częstotliwość wysyłania wiadomości (w dniach):';
$labels['vacationinterval'] = 'Jak często wysyłać wiadomości:';
$labels['vacationreason'] = 'Treść (przyczyna nieobecności):';
$labels['vacationfrom'] = 'Adres nadawcy odpowiedzi:';
$labels['vacationsubject'] = 'Temat wiadomości:';
$labels['days'] = 'dni';
$labels['seconds'] = 'sekundy';
$labels['rulestop'] = 'Przerwij przetwarzanie reguł';
$labels['enable'] = 'Włącz/Wyłącz';
$labels['filterset'] = 'Zbiory fitrów';
$labels['filtersets'] = 'Zbiory fitrów';
$labels['filtersetadd'] = 'Dodaj zbiór filtrów';
$labels['filtersetdel'] = 'Usuń zbiór filtrów';
$labels['filtersetact'] = 'Aktywuj bieżący zbiór filtrów';
$labels['filtersetdeact'] = 'Deaktywuj bieżący zbiór filtrów';
$labels['filterseteditraw'] = 'Edytuj zbiór filtrów';
$labels['filtersetswitch'] = 'Włącz/Wyłącz zbiór filtrów';
$labels['filterdef'] = 'Definicja filtra';
$labels['filtersetname'] = 'Nazwa zbioru';
$labels['newfilterset'] = 'Nowy zbiór filtrów';
$labels['active'] = 'aktywny';
$labels['none'] = 'brak';
$labels['fromset'] = 'ze zbioru';
$labels['fromfile'] = 'z pliku';
$labels['filterdisabled'] = 'Filtr wyłączony';
$labels['filterenabled'] = 'Filtr włączony';
$labels['countisgreaterthan'] = 'ilość jest większa od';
$labels['countisgreaterthanequal'] = 'ilość jest równa lub większa od';
$labels['countislessthan'] = 'ilość jest mniejsza od';
$labels['countislessthanequal'] = 'ilość jest równa lub mniejsza od';
$labels['countequals'] = 'ilość jest równa';
$labels['countnotequals'] = 'ilość nie jest równa';
$labels['valueisgreaterthan'] = 'wartość jest większa od';
$labels['valueisgreaterthanequal'] = 'wartość jest równa lub większa od';
$labels['valueislessthan'] = 'wartość jest mniejsza od';
$labels['valueislessthanequal'] = 'wartość jest równa lub mniejsza od';
$labels['valueequals'] = 'wartość jest równa';
$labels['valuenotequals'] = 'wartość nie jest równa';
$labels['setflags'] = 'Ustaw flagi wiadomości';
$labels['addflags'] = 'Dodaj flagi do wiadomości';
$labels['removeflags'] = 'Usuń flagi wiadomości';
$labels['flagread'] = 'Przeczytana';
$labels['flagdeleted'] = 'Usunięta';
$labels['flaganswered'] = 'Z odpowiedzią';
$labels['flagflagged'] = 'Oflagowana';
$labels['flagdraft'] = 'Szkic';
$labels['addheader'] = 'Dodaj nagłówek do wiadomości';
$labels['deleteheader'] = 'Usuń nagłówek z wiadomości';
$labels['headername'] = 'Nazwa nagłówka';
$labels['headervalue'] = 'Treść nagłówka';
$labels['headerpos'] = 'Pozycja nagłówka';
$labels['headeratstart'] = 'na początku';
$labels['headeratend'] = 'na końcu';
$labels['headeroccurrence'] = 'Wystąpienie/pozycja nagłówka';
$labels['headerfromstart'] = 'od początku';
$labels['headerfromend'] = 'od końca';
$labels['headerpatterns'] = 'Wzorce treści nagłówka';
$labels['headermatchtype'] = 'typ dopasowania:';
$labels['setvariable'] = 'Ustaw zmienną';
$labels['setvarname'] = 'Nazwa zmiennej:';
$labels['setvarvalue'] = 'Wartość zmiennej:';
$labels['setvarmodifiers'] = 'Modyfikatory:';
$labels['varlower'] = 'małe litery';
$labels['varupper'] = 'wielkie litery';
$labels['varlowerfirst'] = 'pierwsza mała litera';
$labels['varupperfirst'] = 'pierwsza wielka litera';
$labels['varquotewildcard'] = 'zamień znaki specjalne';
$labels['varlength'] = 'długość';
$labels['varencodeurl'] = 'zakodowane (dla URLi)';
$labels['notify'] = 'Wyślij powiadomienie';
$labels['notifytarget'] = 'Odbiorca powiadomienia:';
$labels['notifymessage'] = 'Wiadomość powiadomienia (opcjonalne):';
$labels['notifyoptions'] = 'Opcje powiadomienia (opcjonalne):';
$labels['notifyfrom'] = 'Nadawca powiadomienia (opcjonalne):';
$labels['notifyimportance'] = 'Priorytet:';
$labels['notifyimportancelow'] = 'niski';
$labels['notifyimportancenormal'] = 'normalny';
$labels['notifyimportancehigh'] = 'wysoki';
$labels['notifymethodmailto'] = 'E-Mail';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Utwórz filtr';
$labels['usedata'] = 'Użyj następujących danych do utworzenia filtra:';
$labels['nextstep'] = 'Następny krok';
$labels['...'] = '...';
$labels['string'] = 'Ciąg znaków';
$labels['currdate'] = 'Bieżąca data';
$labels['datetest'] = 'Data';
$labels['dateheader'] = 'nagłówek:';
$labels['year'] = 'rok';
$labels['month'] = 'miesiąc';
$labels['day'] = 'dzień';
$labels['date'] = 'data (rrrr-mm-dd)';
$labels['julian'] = 'data (kalendarz juliański)';
$labels['hour'] = 'godzina';
$labels['minute'] = 'minuta';
$labels['second'] = 'sekunda';
$labels['time'] = 'czas (gg:mm:ss)';
$labels['iso8601'] = 'data (ISO8601)';
$labels['std11'] = 'data (RFC2822)';
$labels['zone'] = 'Strefa czasowa';
$labels['weekday'] = 'dzień tygodnia (0-6)';
$labels['advancedopts'] = 'Zaawansowane opcje';
$labels['body'] = 'Treść';
$labels['address'] = 'adres';
$labels['envelope'] = 'koperta (envelope)';
$labels['modifier'] = 'modyfikator:';
$labels['text'] = 'tekst';
$labels['undecoded'] = 'nieprzetworzony (raw)';
$labels['contenttype'] = 'typ części (content type)';
$labels['modtype'] = 'typ:';
$labels['allparts'] = 'wszystkie';
$labels['domain'] = 'domena';
$labels['localpart'] = 'część lokalna';
$labels['user'] = 'użytkownik';
$labels['detail'] = 'detal';
$labels['comparator'] = 'komparator:';
$labels['default'] = 'domyślny';
$labels['octet'] = 'dokładny (octet)';
$labels['asciicasemap'] = 'nierozróżniający wielkości liter (ascii-casemap)';
$labels['asciinumeric'] = 'numeryczny (ascii-numeric)';
$labels['index'] = 'indeks:';
$labels['indexlast'] = 'wstecz';
$labels['spamtest'] = 'Poziom spamu';
$labels['spamtestisgreaterthan'] = 'jest większy od';
$labels['spamtestisgreaterthanequal'] = 'jest równy lub większy od';
$labels['spamtestislessthan'] = 'jest mniejszy od';
$labels['spamtestislessthanequal'] = 'jest równy lub mniejszy od';
$labels['spamtestequals'] = 'jest równe';
$labels['spamtestnotequals'] = 'nie jest równe';
$labels['spamtestisunknown'] = 'jest nieokreślony';
$labels['vacation'] = 'Nieobecność';
$labels['vacation.reply'] = 'Odpowiedź';
$labels['vacation.advanced'] = 'Ustawienia zaawansowane';
$labels['vacation.from'] = 'Adres nadawcy odpowiedzi';
$labels['vacation.subject'] = 'Temat';
$labels['vacation.body'] = 'Treść';
$labels['vacation.start'] = 'Początek nieobecności';
$labels['vacation.end'] = 'Koniec nieobecności';
$labels['vacation.status'] = 'Status';
$labels['vacation.on'] = 'włączone';
$labels['vacation.off'] = 'wyłączone';
$labels['vacation.addresses'] = 'Moje adresy e-mail';
$labels['vacation.interval'] = 'Częstotliwość odpowiedzi';
$labels['vacation.after'] = 'Umieść regułę odpowiedzi po';
$labels['vacation.saving'] = 'Zapisywanie danych...';
$labels['vacation.action'] = 'Akcje wiadomości przychodzących';
$labels['vacation.keep'] = 'Zachowaj';
$labels['vacation.discard'] = 'Odrzuć';
$labels['vacation.redirect'] = 'Przekaż do';
$labels['vacation.copy'] = 'Wyślij kopię do';
$labels['forward'] = 'Przekierowania';
$labels['forward.redirect'] = 'Przekaż do';
$labels['forward.copy'] = 'Wyślij kopię do';
$labels['forward.on'] = 'włączone';
$labels['forward.off'] = 'wyłączone';
$labels['forward.status'] = 'Status:';
$labels['forward.action'] = 'Dla wiadomości przychodzących wykonaj następującą akcję:';
$labels['forward.saving'] = 'Zapisywanie danych...';
$labels['filladdresses'] = 'Wypełnij wszystkimi moimi adresami';
$labels['arialabelfiltersetactions'] = 'Zbiór filtrów akcji';
$labels['arialabelfilteractions'] = 'Akcje filtrów';
$labels['arialabelfilterform'] = 'Ustawienia filtrów';
$labels['ariasummaryfilterslist'] = 'Spis filtrów';
$labels['ariasummaryfiltersetslist'] = 'Lista zbiorów filtrów';
$labels['filterstitle'] = 'Zarządzaj filtrami wiadomości przychodzących';
$labels['vacationtitle'] = 'Zarządzaj asystentem nieobecności';
$labels['forwardtitle'] = 'Edycja reguł przekierowań poczty';
$labels['message'] = 'Wiadomość';
$labels['duplicate'] = 'jest duplikatem';
$labels['notduplicate'] = 'nie jest duplikatem';
$labels['duplicate.handle'] = 'uchwyt:';
$labels['duplicate.header'] = 'nagłówek:';
$labels['duplicate.uniqueid'] = 'identyfikator:';
$labels['duplicate.seconds'] = 'Limit czasu (sekundy):';
$labels['duplicate.last'] = 'względem ostatniego wykonania';
$messages['filterunknownerror'] = 'Nieznany błąd serwera.';
$messages['filterconnerror'] = 'Nie można nawiązać połączenia z serwerem.';
$messages['filterdeleteerror'] = 'Nie można usunąć filtra. Błąd serwera.';
$messages['filterdeleted'] = 'Filtr został usunięty pomyślnie.';
$messages['filtersaved'] = 'Filtr został zapisany pomyślnie.';
$messages['filtersaveerror'] = 'Nie można zapisać filtra. Wystąpił błąd serwera.';
$messages['filterformerror'] = 'Formularz zawiera błędy.';
$messages['filterdeleteconfirm'] = 'Czy na pewno chcesz usunąć wybrany filtr?';
$messages['ruledeleteconfirm'] = 'Czy na pewno chcesz usunąć wybraną regułę?';
$messages['actiondeleteconfirm'] = 'Czy na pewno usunąć wybraną akcję?';
$messages['forbiddenchars'] = 'Pole zawiera niedozwolone znaki.';
$messages['cannotbeempty'] = 'Pole nie może być puste.';
$messages['ruleexist'] = 'Filtr o podanej nazwie już istnieje.';
$messages['setactivateerror'] = 'Nie można aktywować wybranego zbioru filtrów. Błąd serwera.';
$messages['setdeactivateerror'] = 'Nie można deaktywować wybranego zbioru filtrów. Błąd serwera.';
$messages['setdeleteerror'] = 'Nie można usunąć wybranego zbioru filtrów. Błąd serwera.';
$messages['setactivated'] = 'Zbiór filtrów został aktywowany pomyślnie.';
$messages['setdeactivated'] = 'Zbiór filtrów został deaktywowany pomyślnie.';
$messages['setdeleted'] = 'Zbiór filtrów został usunięty pomyślnie.';
$messages['setupdated'] = 'Zbiór filtrów został zaktualizowany pomyślnie.';
$messages['setdeleteconfirm'] = 'Czy na pewno chcesz usunąć wybrany zbiór filtrów?';
$messages['setcreateerror'] = 'Nie można utworzyć zbioru filtrów. Błąd serwera.';
$messages['setcreated'] = 'Zbiór filtrów został utworzony pomyślnie.';
$messages['activateerror'] = 'Nie można włączyć wybranych filtrów. Błąd serwera.';
$messages['deactivateerror'] = 'Nie można wyłączyć wybranych filtrów. Błąd serwera.';
$messages['deactivated'] = 'Filtr(y) wyłączono pomyślnie.';
$messages['activated'] = 'Filtr(y) włączono pomyślnie.';
$messages['moved'] = 'Filter został przeniesiony pomyślnie.';
$messages['moveerror'] = 'Nie można przenieść wybranego filtra. Błąd serwera.';
$messages['nametoolong'] = 'Zbyt długa nazwa.';
$messages['namereserved'] = 'Nazwa zarezerwowana.';
$messages['setexist'] = 'Zbiór już istnieje.';
$messages['nodata'] = 'Należy wybrać co najmniej jedną pozycję!';
$messages['invaliddateformat'] = 'Nieprawidłowy format daty lub fragmentu daty';
$messages['saveerror'] = 'Nie można zapisać danych. Wystąpił błąd serwera.';
$messages['vacationsaved'] = 'Dane nieobecności zapisano pomyślnie.';
$messages['forwardsaved'] = 'Dane przekierowania zostały zapisane pomyślnie.';
$messages['emptyvacationbody'] = 'Treść wiadomości jest wymagana!';
$messages['duplicate.conflict.err'] = 'Nagłówek i identyfikator nie mogą być używane równocześnie.';
$messages['disabledaction'] = 'Niedozwolona akcja';
$messages['lastindexempty'] = 'Number pozycji jest wymagany przy odliczaniu od końca';
$messages['noflagset'] = 'Przynajmniej jedna flaga musi być zaznaczona.';
$messages['saving.actionordererror'] = 'Akcja \'$previous\' musi być wykonana po akcji \'$current\'.';
