<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = '協定世界時';
$labels['tz:africa'] = 'アフリカ';
$labels['tz:africa:abidjan'] = 'アビジャン';
$labels['tz:africa:accra'] = 'アクラ';
$labels['tz:africa:addis_ababa'] = 'アディス・アベバ';
$labels['tz:africa:algiers'] = 'アルジェ';
$labels['tz:africa:asmara'] = 'アスマラ';
$labels['tz:africa:bamako'] = 'バマコ';
$labels['tz:africa:bangui'] = 'バンギ';
$labels['tz:africa:banjul'] = 'バンジュール';
$labels['tz:africa:bissau'] = 'ビサウ';
$labels['tz:africa:blantyre'] = 'ブランタイヤ';
$labels['tz:africa:brazzaville'] = 'ブラザヴィル';
$labels['tz:africa:bujumbura'] = 'ブジュンブラ';
$labels['tz:africa:cairo'] = 'カイロ';
$labels['tz:africa:casablanca'] = 'カサブランカ';
$labels['tz:africa:ceuta'] = 'セウタ';
$labels['tz:africa:conakry'] = 'コナクリ';
$labels['tz:africa:dakar'] = 'ダカール';
$labels['tz:africa:dar_es_salaam'] = 'ダルエスサラーム';
$labels['tz:africa:djibouti'] = 'ジブチ';
$labels['tz:africa:douala'] = 'ドゥアラ';
$labels['tz:africa:el_aaiun'] = 'アイウン';
$labels['tz:africa:freetown'] = 'フリータウン';
$labels['tz:africa:gaborone'] = 'ハボローネ';
$labels['tz:africa:harare'] = 'ハラレ';
$labels['tz:africa:johannesburg'] = 'ヨハネスブルグ';
$labels['tz:africa:juba'] = 'ジュバ';
$labels['tz:africa:kampala'] = 'カンパラ';
$labels['tz:africa:khartoum'] = 'ハルツーム';
$labels['tz:africa:kigali'] = 'キガリ';
$labels['tz:africa:kinshasa'] = 'キンシャサ';
$labels['tz:africa:lagos'] = 'ラゴス';
$labels['tz:africa:libreville'] = 'リーブルヴィル';
$labels['tz:africa:lome'] = 'ロメ';
$labels['tz:africa:luanda'] = 'ルアンダ';
$labels['tz:africa:lubumbashi'] = 'ルブンバシ';
$labels['tz:africa:lusaka'] = 'ルサカ';
$labels['tz:africa:malabo'] = 'マラボ';
$labels['tz:africa:maputo'] = 'マプト';
$labels['tz:africa:maseru'] = 'マセル';
$labels['tz:africa:mbabane'] = 'ムババーネ';
$labels['tz:africa:mogadishu'] = 'モガディシュ';
$labels['tz:africa:monrovia'] = 'モンロビア';
$labels['tz:africa:nairobi'] = 'ナイロビ';
$labels['tz:africa:ndjamena'] = 'ンジャメナ';
$labels['tz:africa:niamey'] = 'ニアメ';
$labels['tz:africa:nouakchott'] = 'ヌアクショット';
$labels['tz:africa:ouagadougou'] = 'ワガドゥグー';
$labels['tz:africa:porto-novo'] = 'ポルトノボ';
$labels['tz:africa:sao_tome'] = 'サントメ';
$labels['tz:africa:tripoli'] = 'トリポリ';
$labels['tz:africa:tunis'] = 'チュニス';
$labels['tz:africa:windhoek'] = 'ウィントフック';
$labels['tz:america'] = 'アメリカ';
$labels['tz:america:adak'] = 'アダック';
$labels['tz:america:anchorage'] = 'アンカレッジ';
$labels['tz:america:anguilla'] = 'アンギラ';
$labels['tz:america:antigua'] = 'アンティグア';
$labels['tz:america:araguaina'] = 'アラグァイーナ';
$labels['tz:america:argentina'] = 'アルゼンチン';
$labels['tz:america:argentina:buenos_aires'] = 'ブエノスアイレス';
$labels['tz:america:argentina:catamarca'] = 'カタマルカ';
$labels['tz:america:argentina:cordoba'] = 'コルドバ';
$labels['tz:america:argentina:jujuy'] = 'フフイ';
$labels['tz:america:argentina:la_rioja'] = 'ラ・リオハ';
$labels['tz:america:argentina:mendoza'] = 'メンドーサ';
$labels['tz:america:argentina:rio_gallegos'] = 'リオ・ガジェーゴス';
$labels['tz:america:argentina:salta'] = 'サルタ';
$labels['tz:america:argentina:san_juan'] = 'サン・フアン';
$labels['tz:america:argentina:san_luis'] = 'サン・ルイス';
$labels['tz:america:argentina:tucuman'] = 'トゥクマン';
$labels['tz:america:argentina:ushuaia'] = 'ウシュアイア';
$labels['tz:america:aruba'] = 'アルバ';
$labels['tz:america:asuncion'] = 'アスンシオン';
$labels['tz:america:atikokan'] = 'アティコーカン';
$labels['tz:america:bahia'] = 'バイーア';
$labels['tz:america:bahia_banderas'] = 'バイーア・デ・バンデラス';
$labels['tz:america:barbados'] = 'バルバドス';
$labels['tz:america:belem'] = 'ベレン';
$labels['tz:america:belize'] = 'ベリーズ';
$labels['tz:america:blanc-sablon'] = 'ブラン・サブロン';
$labels['tz:america:boa_vista'] = 'ボア・ヴィスタ';
$labels['tz:america:bogota'] = 'ボゴタ';
$labels['tz:america:boise'] = 'ボイシ';
$labels['tz:america:cambridge_bay'] = 'ケンブリッジ・ベイ';
$labels['tz:america:campo_grande'] = 'カンポ・グランデ';
$labels['tz:america:cancun'] = 'カンクン';
$labels['tz:america:caracas'] = 'カラカス';
$labels['tz:america:cayenne'] = 'カイエンヌ';
$labels['tz:america:cayman'] = 'ケイマン諸島';
$labels['tz:america:chicago'] = 'シカゴ';
$labels['tz:america:chihuahua'] = 'チワワ';
$labels['tz:america:costa_rica'] = 'コスタリカ';
$labels['tz:america:creston'] = 'クレストン';
$labels['tz:america:cuiaba'] = 'クイアバ';
$labels['tz:america:curacao'] = 'キュラソー島';
$labels['tz:america:danmarkshavn'] = 'デンマークシャン';
$labels['tz:america:dawson'] = 'ドーソン';
$labels['tz:america:dawson_creek'] = 'ドーソン・クリーク';
$labels['tz:america:denver'] = 'デンバー';
$labels['tz:america:detroit'] = 'デトロイト';
$labels['tz:america:dominica'] = 'ドミニカ';
$labels['tz:america:edmonton'] = 'エドモントン';
$labels['tz:america:eirunepe'] = 'エイルネペ';
$labels['tz:america:el_salvador'] = 'エルサルバドル';
$labels['tz:america:fort_nelson'] = 'フォートネルソン ';
$labels['tz:america:fortaleza'] = 'フォルタレザ';
$labels['tz:america:glace_bay'] = 'グレースベイ';
$labels['tz:america:godthab'] = 'ゴートホープ';
$labels['tz:america:goose_bay'] = 'グースベイ';
$labels['tz:america:grand_turk'] = 'グランドターク';
$labels['tz:america:grenada'] = 'グレナダ';
$labels['tz:america:guadeloupe'] = 'グアドループ';
$labels['tz:america:guatemala'] = 'グアテマラ';
$labels['tz:america:guayaquil'] = 'グアヤキル';
$labels['tz:america:guyana'] = 'ガイアナ';
$labels['tz:america:halifax'] = 'ハリファックス';
$labels['tz:america:havana'] = 'ハバナ';
$labels['tz:america:hermosillo'] = 'エルモシージョ';
$labels['tz:america:indiana'] = 'インディアナ';
$labels['tz:america:indiana:indianapolis'] = 'インディアナポリス';
$labels['tz:america:indiana:knox'] = 'ノックス';
$labels['tz:america:indiana:marengo'] = 'マレンゴ';
$labels['tz:america:indiana:petersburg'] = 'ピーターズバーグ';
$labels['tz:america:indiana:tell_city'] = 'テル・シティ';
$labels['tz:america:indiana:vevay'] = 'ベベイ';
$labels['tz:america:indiana:vincennes'] = 'ヴィンセンス';
$labels['tz:america:indiana:winamac'] = 'ウィナマク';
$labels['tz:america:inuvik'] = 'イヌヴィック';
$labels['tz:america:iqaluit'] = 'イカルイト';
$labels['tz:america:jamaica'] = 'ジャマイカ';
$labels['tz:america:juneau'] = 'ジュノー';
$labels['tz:america:kentucky'] = 'ケンタッキー';
$labels['tz:america:kentucky:louisville'] = 'ルイビル';
$labels['tz:america:kentucky:monticello'] = 'モンティチェロ';
$labels['tz:america:kralendijk'] = 'クラレンダイク';
$labels['tz:america:la_paz'] = 'ラパス';
$labels['tz:america:lima'] = 'リマ';
$labels['tz:america:los_angeles'] = ' ロサンゼルス';
$labels['tz:america:lower_princes'] = 'ローワー・プリンセズ';
$labels['tz:america:maceio'] = 'マセイオ';
$labels['tz:america:managua'] = 'マナグア';
$labels['tz:america:manaus'] = 'マナウス';
$labels['tz:america:marigot'] = 'マリゴ';
$labels['tz:america:martinique'] = 'マルティニーク';
$labels['tz:america:matamoros'] = 'マタモロス';
$labels['tz:america:mazatlan'] = 'マサトラン';
$labels['tz:america:menominee'] = 'メノミニー';
$labels['tz:america:merida'] = 'メリダ';
$labels['tz:america:metlakatla'] = 'メトラカトラ';
$labels['tz:america:mexico_city'] = 'メキシコ市';
$labels['tz:america:miquelon'] = 'ミクロン島';
$labels['tz:america:moncton'] = 'モンクトン';
$labels['tz:america:monterrey'] = 'モンテレイ';
$labels['tz:america:montevideo'] = 'モンテビデオ';
$labels['tz:america:montserrat'] = 'モントセラト';
$labels['tz:america:nassau'] = 'ナッソー';
$labels['tz:america:new_york'] = 'ニューヨーク';
$labels['tz:america:nipigon'] = 'ニピゴン';
$labels['tz:america:nome'] = 'ノーム';
$labels['tz:america:noronha'] = 'ノローニャ';
$labels['tz:america:north_dakota'] = 'ノースダコタ';
$labels['tz:america:north_dakota:beulah'] = 'ビューラー';
$labels['tz:america:north_dakota:center'] = 'センター';
$labels['tz:america:north_dakota:new_salem'] = 'ニューセーラム';
$labels['tz:america:ojinaga'] = 'オヒナガ';
$labels['tz:america:panama'] = 'パナマ';
$labels['tz:america:pangnirtung'] = 'パングナータング';
$labels['tz:america:paramaribo'] = 'パラマリボ';
$labels['tz:america:phoenix'] = 'フェニックス';
$labels['tz:america:port-au-prince'] = 'ポルトープランス';
$labels['tz:america:port_of_spain'] = 'ポートオブスペイン';
$labels['tz:america:porto_velho'] = 'ポルト・ヴェーリョ';
$labels['tz:america:puerto_rico'] = 'プエルトリコ';
$labels['tz:america:rainy_river'] = 'レイニーリバー';
$labels['tz:america:rankin_inlet'] = 'ランキン・インレット';
$labels['tz:america:recife'] = 'レシフェ';
$labels['tz:america:regina'] = 'レジャイナ';
$labels['tz:america:resolute'] = 'レゾリュート';
$labels['tz:america:rio_branco'] = 'リオ・ブランコ';
$labels['tz:america:santarem'] = 'サンタレン';
$labels['tz:america:santiago'] = 'サンティアゴ';
$labels['tz:america:santo_domingo'] = 'サントドミンゴ';
$labels['tz:america:sao_paulo'] = 'サンパウロ';
$labels['tz:america:scoresbysund'] = 'スコルズビスーン';
$labels['tz:america:sitka'] = 'シトカ';
$labels['tz:america:st_barthelemy'] = 'サン・バルテルミー島';
$labels['tz:america:st_johns'] = "セント・ジョンズ";
$labels['tz:america:st_kitts'] = 'セントキッツ島';
$labels['tz:america:st_lucia'] = 'セントルシア';
$labels['tz:america:st_thomas'] = 'セント・トーマス島';
$labels['tz:america:st_vincent'] = 'セントビンセント島';
$labels['tz:america:swift_current'] = 'スウィフトカレント';
$labels['tz:america:tegucigalpa'] = 'テグシガルパ';
$labels['tz:america:thule'] = 'チューレ';
$labels['tz:america:thunder_bay'] = 'サンダーベイ';
$labels['tz:america:tijuana'] = 'ティフアナ';
$labels['tz:america:toronto'] = 'トロント';
$labels['tz:america:tortola'] = 'トルトラ島';
$labels['tz:america:vancouver'] = 'バンクーバー';
$labels['tz:america:whitehorse'] = 'ホワイトホース';
$labels['tz:america:winnipeg'] = 'ウィニペグ';
$labels['tz:america:yakutat'] = 'ヤクタト';
$labels['tz:america:yellowknife'] = ' イエローナイフ';
$labels['tz:antarctica'] = '南極大陸';
$labels['tz:antarctica:casey'] = 'ケーシー基地';
$labels['tz:antarctica:davis'] = 'デービス基地';
$labels['tz:antarctica:dumontdurville'] = "デュモン・デュルヴィル基地";
$labels['tz:antarctica:macquarie'] = 'マッコーリー島';
$labels['tz:antarctica:mawson'] = 'モーソン基地';
$labels['tz:antarctica:mcmurdo'] = 'マクマード';
$labels['tz:antarctica:palmer'] = 'パーマー基地';
$labels['tz:antarctica:rothera'] = 'ロゼラ基地';
$labels['tz:antarctica:syowa'] = '昭和基地';
$labels['tz:antarctica:troll'] = 'トロル基地';
$labels['tz:antarctica:vostok'] = 'ボストーク基地';
$labels['tz:arctic'] = '北極圏';
$labels['tz:arctic:longyearbyen'] = 'ロングイェールビーン';
$labels['tz:asia'] = 'アジア';
$labels['tz:asia:aden'] = 'アデン';
$labels['tz:asia:almaty'] = 'アルマトイ';
$labels['tz:asia:amman'] = 'アンマン';
$labels['tz:asia:anadyr'] = 'アナディリ';
$labels['tz:asia:aqtau'] = 'アクタウ';
$labels['tz:asia:aqtobe'] = 'アクトベ';
$labels['tz:asia:ashgabat'] = 'アシガバート';
$labels['tz:asia:atyrau'] = 'アティラウ';
$labels['tz:asia:baghdad'] = 'バグダード';
$labels['tz:asia:bahrain'] = 'バーレーン';
$labels['tz:asia:baku'] = 'バクー';
$labels['tz:asia:bangkok'] = 'バンコク';
$labels['tz:asia:barnaul'] = 'バルナウル';
$labels['tz:asia:beirut'] = 'ベイルート';
$labels['tz:asia:bishkek'] = 'ビシュケク';
$labels['tz:asia:brunei'] = 'ブルネイ';
$labels['tz:asia:chita'] = 'チタ';
$labels['tz:asia:choibalsan'] = 'チョイバルサン';
$labels['tz:asia:colombo'] = 'コロンボ';
$labels['tz:asia:damascus'] = 'ダマスカス';
$labels['tz:asia:dhaka'] = 'ダッカ';
$labels['tz:asia:dili'] = 'ディリ';
$labels['tz:asia:dubai'] = 'ドバイ';
$labels['tz:asia:dushanbe'] = 'ドゥシャンベ';
$labels['tz:asia:famagusta'] = 'ファマグスタ';
$labels['tz:asia:gaza'] = 'ガザ';
$labels['tz:asia:hebron'] = 'ヘブロン';
$labels['tz:asia:ho_chi_minh'] = 'ホーチミン';
$labels['tz:asia:hong_kong'] = '香港';
$labels['tz:asia:hovd'] = 'ホブド';
$labels['tz:asia:irkutsk'] = 'イルクーツク';
$labels['tz:asia:jakarta'] = 'ジャカルタ';
$labels['tz:asia:jayapura'] = 'ジャヤプラ';
$labels['tz:asia:jerusalem'] = 'エルサレム';
$labels['tz:asia:kabul'] = 'カーブル';
$labels['tz:asia:kamchatka'] = 'カムチャツカ';
$labels['tz:asia:karachi'] = 'カラチ';
$labels['tz:asia:kathmandu'] = 'カトマンズ';
$labels['tz:asia:khandyga'] = 'ハンドゥイガ';
$labels['tz:asia:kolkata'] = 'コルカタ';
$labels['tz:asia:krasnoyarsk'] = 'クラスノヤルスク';
$labels['tz:asia:kuala_lumpur'] = 'クアラルンプール';
$labels['tz:asia:kuching'] = 'クチン';
$labels['tz:asia:kuwait'] = 'クウェート';
$labels['tz:asia:macau'] = 'マカオ';
$labels['tz:asia:magadan'] = 'マガダン';
$labels['tz:asia:makassar'] = 'マカッサル';
$labels['tz:asia:manila'] = 'マニラ';
$labels['tz:asia:muscat'] = 'マスカット';
$labels['tz:asia:nicosia'] = 'ニコシア';
$labels['tz:asia:novokuznetsk'] = 'ノヴォクズネツク';
$labels['tz:asia:novosibirsk'] = 'ノヴォシビルスク';
$labels['tz:asia:omsk'] = 'オムスク';
$labels['tz:asia:oral'] = 'オラル';
$labels['tz:asia:phnom_penh'] = 'プノンペン';
$labels['tz:asia:pontianak'] = 'ポンティアナック';
$labels['tz:asia:pyongyang'] = 'ピョンヤン';
$labels['tz:asia:qatar'] = 'カタール';
$labels['tz:asia:qyzylorda'] = 'クズロルダ';
$labels['tz:asia:riyadh'] = 'リヤド';
$labels['tz:asia:sakhalin'] = 'サハリン';
$labels['tz:asia:samarkand'] = 'サマルカンド';
$labels['tz:asia:seoul'] = 'ソウル';
$labels['tz:asia:shanghai'] = '上海';
$labels['tz:asia:singapore'] = 'シンガポール';
$labels['tz:asia:srednekolymsk'] = 'スレドネコリムスク';
$labels['tz:asia:taipei'] = '台北';
$labels['tz:asia:tashkent'] = 'タシュケント';
$labels['tz:asia:tbilisi'] = 'トビリシ';
$labels['tz:asia:tehran'] = 'テヘラン';
$labels['tz:asia:thimphu'] = 'ティンプー';
$labels['tz:asia:tokyo'] = '東京';
$labels['tz:asia:tomsk'] = 'トムスク';
$labels['tz:asia:ulaanbaatar'] = 'ウランバートル';
$labels['tz:asia:urumqi'] = 'ウルムチ';
$labels['tz:asia:ust-nera'] = 'ウスチ＝ネラ';
$labels['tz:asia:vientiane'] = 'ヴィエンチャン';
$labels['tz:asia:vladivostok'] = 'ウラジオストク';
$labels['tz:asia:yakutsk'] = 'ヤクーツク';
$labels['tz:asia:yangon'] = 'ヤンゴン';
$labels['tz:asia:yekaterinburg'] = 'エカテリンブルク';
$labels['tz:asia:yerevan'] = 'エレバン';
$labels['tz:atlantic'] = '大西洋';
$labels['tz:atlantic:azores'] = 'アゾレス諸島';
$labels['tz:atlantic:bermuda'] = 'バミューダ諸島';
$labels['tz:atlantic:canary'] = 'カナリア諸島';
$labels['tz:atlantic:cape_verde'] = 'カーボベルデ';
$labels['tz:atlantic:faroe'] = 'フェロー諸島';
$labels['tz:atlantic:madeira'] = 'マデイラ諸島';
$labels['tz:atlantic:reykjavik'] = 'レイキャヴィーク';
$labels['tz:atlantic:south_georgia'] = 'サウスジョージア島';
$labels['tz:atlantic:st_helena'] = 'セントヘレナ';
$labels['tz:atlantic:stanley'] = 'スタンリー';
$labels['tz:australia'] = 'オーストラリア';
$labels['tz:australia:adelaide'] = 'アデレード';
$labels['tz:australia:brisbane'] = 'ブリスベン';
$labels['tz:australia:broken_hill'] = 'ブロークンヒル';
$labels['tz:australia:currie'] = 'カレー ';
$labels['tz:australia:darwin'] = 'ダーウィン';
$labels['tz:australia:eucla'] = 'ユークラ';
$labels['tz:australia:hobart'] = 'ホバート';
$labels['tz:australia:lindeman'] = 'リンデマン島';
$labels['tz:australia:lord_howe'] = 'ロード・ハウ島';
$labels['tz:australia:melbourne'] = 'メルボルン';
$labels['tz:australia:perth'] = 'パース';
$labels['tz:australia:sydney'] = 'シドニー';
$labels['tz:europe'] = 'ヨーロッパ';
$labels['tz:europe:amsterdam'] = 'アムステルダム';
$labels['tz:europe:andorra'] = 'アンドラ';
$labels['tz:europe:astrakhan'] = 'アストラハン';
$labels['tz:europe:athens'] = 'アテナ';
$labels['tz:europe:belgrade'] = 'ベオグラード';
$labels['tz:europe:berlin'] = 'ベルリン';
$labels['tz:europe:bratislava'] = 'ブラチスラヴァ';
$labels['tz:europe:brussels'] = 'ブリュッセル';
$labels['tz:europe:bucharest'] = 'ブカレスト';
$labels['tz:europe:budapest'] = 'ブダペスト';
$labels['tz:europe:busingen'] = 'ビュージンゲン';
$labels['tz:europe:chisinau'] = 'キシナウ';
$labels['tz:europe:copenhagen'] = 'コペンハーゲン';
$labels['tz:europe:dublin'] = 'ダブリン';
$labels['tz:europe:gibraltar'] = 'ジブラルタル';
$labels['tz:europe:guernsey'] = 'ガーンジー島';
$labels['tz:europe:helsinki'] = 'ヘルシンキ';
$labels['tz:europe:isle_of_man'] = 'マン島';
$labels['tz:europe:istanbul'] = 'イスタンブール';
$labels['tz:europe:jersey'] = 'ジャージー';
$labels['tz:europe:kaliningrad'] = 'カリーニングラード';
$labels['tz:europe:kiev'] = 'キエフ';
$labels['tz:europe:kirov'] = 'キーロフ';
$labels['tz:europe:lisbon'] = 'リスボン';
$labels['tz:europe:ljubljana'] = 'リュブリャナ';
$labels['tz:europe:london'] = 'ロンドン';
$labels['tz:europe:luxembourg'] = 'ルクセンブルク';
$labels['tz:europe:madrid'] = 'マドリード';
$labels['tz:europe:malta'] = 'マルタ';
$labels['tz:europe:mariehamn'] = 'マリエハムン';
$labels['tz:europe:minsk'] = 'ミンスク';
$labels['tz:europe:monaco'] = 'モナコ';
$labels['tz:europe:moscow'] = 'モスクワ';
$labels['tz:europe:oslo'] = 'オスロ';
$labels['tz:europe:paris'] = 'パリ';
$labels['tz:europe:podgorica'] = 'ポドゴリツァ';
$labels['tz:europe:prague'] = 'プラハ';
$labels['tz:europe:riga'] = 'リガ';
$labels['tz:europe:rome'] = 'ローマ';
$labels['tz:europe:samara'] = 'サマーラ';
$labels['tz:europe:san_marino'] = 'サンマリノ';
$labels['tz:europe:sarajevo'] = 'サラエヴォ';
$labels['tz:europe:saratov'] = 'サラトフ';
$labels['tz:europe:simferopol'] = 'シンフェローポリ';
$labels['tz:europe:skopje'] = 'スコピエ';
$labels['tz:europe:sofia'] = 'ソフィア';
$labels['tz:europe:stockholm'] = 'ストックホルム';
$labels['tz:europe:tallinn'] = 'タリン';
$labels['tz:europe:tirane'] = 'ティラナ';
$labels['tz:europe:ulyanovsk'] = 'ウリヤノフスク';
$labels['tz:europe:uzhgorod'] = 'ウージュホロド';
$labels['tz:europe:vaduz'] = 'ファドゥーツ';
$labels['tz:europe:vatican'] = 'バチカン';
$labels['tz:europe:vienna'] = 'ウィーン ';
$labels['tz:europe:vilnius'] = 'ヴィリニュス';
$labels['tz:europe:volgograd'] = 'ヴォルゴグラード';
$labels['tz:europe:warsaw'] = 'ワルシャワ';
$labels['tz:europe:zagreb'] = 'ザグレブ';
$labels['tz:europe:zaporozhye'] = 'ザポリージャ';
$labels['tz:europe:zurich'] = 'チューリッヒ';
$labels['tz:indian'] = 'インド洋';
$labels['tz:indian:antananarivo'] = 'アンタナナリボ';
$labels['tz:indian:chagos'] = 'チャゴス諸島';
$labels['tz:indian:christmas'] = 'クリスマス諸島';
$labels['tz:indian:cocos'] = 'ココス諸島';
$labels['tz:indian:comoro'] = 'コモロ諸島';
$labels['tz:indian:kerguelen'] = 'ケルゲレン諸島 ';
$labels['tz:indian:mahe'] = 'マーヒ';
$labels['tz:indian:maldives'] = 'モルディブ';
$labels['tz:indian:mauritius'] = 'モーリシャス';
$labels['tz:indian:mayotte'] = 'マヨット';
$labels['tz:indian:reunion'] = 'レユニオン';
$labels['tz:pacific'] = '太平洋';
$labels['tz:pacific:apia'] = 'アピア';
$labels['tz:pacific:auckland'] = 'オークランド';
$labels['tz:pacific:bougainville'] = 'ブーゲンビル島';
$labels['tz:pacific:chatham'] = 'チャタム諸島';
$labels['tz:pacific:chuuk'] = 'チューク諸島';
$labels['tz:pacific:easter'] = 'イースター島';
$labels['tz:pacific:efate'] = 'エファテ島';
$labels['tz:pacific:enderbury'] = 'エンダーベリー島';
$labels['tz:pacific:fakaofo'] = 'ファカオフォ島';
$labels['tz:pacific:fiji'] = 'フィジー';
$labels['tz:pacific:funafuti'] = 'フナフティ島';
$labels['tz:pacific:galapagos'] = 'ガラパゴス島';
$labels['tz:pacific:gambier'] = 'ガンビエ諸島';
$labels['tz:pacific:guadalcanal'] = 'ガダルカナル島';
$labels['tz:pacific:guam'] = 'グアム';
$labels['tz:pacific:honolulu'] = 'ホノルル';
$labels['tz:pacific:johnston'] = 'ジョンストン島';
$labels['tz:pacific:kiritimati'] = 'キリスィマスィ島';
$labels['tz:pacific:kosrae'] = 'コスラエ';
$labels['tz:pacific:kwajalein'] = 'クェゼリン環礁';
$labels['tz:pacific:majuro'] = 'マジュロ';
$labels['tz:pacific:marquesas'] = 'マルキーズ諸島';
$labels['tz:pacific:midway'] = 'ミッドウェー島';
$labels['tz:pacific:nauru'] = 'ナウル';
$labels['tz:pacific:niue'] = 'ニウエ';
$labels['tz:pacific:norfolk'] = 'ノーフォーク島';
$labels['tz:pacific:noumea'] = 'ヌメア';
$labels['tz:pacific:pago_pago'] = 'パゴパゴ';
$labels['tz:pacific:palau'] = 'パラオ';
$labels['tz:pacific:pitcairn'] = 'ピトケアン諸島';
$labels['tz:pacific:pohnpei'] = 'ポンペイ島';
$labels['tz:pacific:port_moresby'] = 'ポートモレスビー';
$labels['tz:pacific:rarotonga'] = 'ラロトンガ島';
$labels['tz:pacific:saipan'] = 'サイパン島';
$labels['tz:pacific:tahiti'] = 'タヒチ';
$labels['tz:pacific:tarawa'] = 'タラワ';
$labels['tz:pacific:tongatapu'] = 'トンガタプ島';
$labels['tz:pacific:wake'] = 'ウェーク島';
$labels['tz:pacific:wallis'] = 'ウォリス島';
