<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Tharla botún!';
$messages['loginfailed']  = 'Níor éirigh leis an síniú isteach.';
$messages['cookiesdisabled'] = 'Ní ghlacann do líonléitheoir le fianáin.';
$messages['sessionerror'] = 'Tá an seisiúin neamhbhailí nó as feidhm.';
$messages['storageerror'] = 'Theip ar an iarracht chun nasc leis an bhfreastalaí Prótacal Rochtana Teachtaireachtaí Idirlín (IMAP)';
$messages['servererror'] = 'Botún ar an bhfreastalaí!';
$messages['servererrormsg'] = 'Botún freastalaithe: %msg';
$messages['accountlocked'] = 'Bhí an iomarca iarrachtaí chun síniú isteach nár éirigh leo. Déan iarracht arís níos déanaí.';
$messages['connerror'] = 'Botún nasctha (Theip air an freastalaí a aimsiú)!';
$messages['dberror'] = 'Botún sa bhunachar sonraí!';
$messages['windowopenerror'] = 'Cuireadh bac ar an bhfuinneog aníos!';
$messages['requesttimedout'] = 'D\'imigh an t-iarratas thar am';
$messages['errorreadonly'] = 'Ní féidir an oibríocht sin a dhéanamh. Tá an fillteán inléite amháin.';
$messages['errornoperm'] = 'Ní féidir an oibríocht sin a dhéanamh. Diúltaíodh cead duit.';
$messages['erroroverquota'] = 'Ní féidir an oibríocht sin a dhéanamh. Níl aon slí saor fágtha ar an ndiosc.';
$messages['erroroverquotadelete'] = 'Níl aon slí saor fágtha ar an ndiosca. Brúigh SHIFT+DEL chun teachtaireacht a scriosadh.';
$messages['invalidrequest'] = 'Iarratas neamhbhailí! Níor cuireadh sonraí i dtaisce.';
$messages['invalidhost'] = 'Ainm freastalaithe neamhbhailí.';
$messages['nomessagesfound'] = 'Níor aimsíodh aon teachtaireacht sa bhosca poist seo.';
$messages['loggedout'] = 'Chuir tú deireadh leis an dreas seo. Slán leat!';
$messages['mailboxempty'] = 'Tá an bosca poist folamh';
$messages['nomessages'] = 'Níl teachtaireachtaí ann';
$messages['refreshing'] = 'Ag athnuaigh...';
$messages['loading'] = 'Ag luchtú...';
$messages['uploading'] = 'Ag luchtú an chomhaid...';
$messages['attaching'] = 'Ag ceangail an chomhaid...';
$messages['uploadingmany'] = 'Ag uasluchtú comhaid...';
$messages['loadingdata'] = 'Ag luchtú sonraí...';
$messages['checkingmail'] = 'Ag dearbháil an bhfuil teachtaireachtaí nua ann...';
$messages['sendingmessage'] = 'Ag seoladh na teachtaireachta...';
$messages['messagesent'] = 'Seoladh an teachtaireacht go rathúil.';
$messages['savingmessage'] = 'Ag cur an teachtaireacht i dtaisce...';
$messages['messagesaved'] = 'Cuireadh an teachtaireacht i dtaisce sna Dréachtaí.';
$messages['successfullysaved'] = 'Cuireadh i dtaisce go rathúil é.';
$messages['savingresponse'] = 'Ag cur i dtaisce an téacs freagartha...';
$messages['deleteresponseconfirm'] = 'An bhfuil tú cinnte gur mian leat an téacs freagartha seo a scriosadh?';
$messages['nocontactselected'] = 'Níl teagmhálaí roghnaithe agat fós.';
$messages['addedsuccessfully'] = 'Cuireadh an teagmhálaí go rathúil sa leabhar seoltaí.';
$messages['contactexists'] = 'Tá teagmhálaí leis an seoladh ríomhphoist céanna ann cheana féin.';
$messages['contactnameexists'] = 'Tá teagmhálaí leis an ainm céanna ann cheana féin.';
$messages['blockedimages'] = 'Ar mhaithe le do phríobháideachas a chosaint, tá bac ar íomhánna cianda sa teachtaireacht seo.';
$messages['blockedresources'] = 'Ar mhaithe le do phríobháideachas a chosaint, tá bac ar acmhainní cianda.';
$messages['encryptedmessage'] = 'Is teachtaireacht chriptithe í seo agus ní féidir í a thaispeáint. Is dona linn sin!';
$messages['externalmessagedecryption'] = 'Is teachtaireacht chriptithe í seo agus is féidir í a dhíchriptiú le breiseán ar do líonléitheoir.';
$messages['nopubkeyfor'] = 'Níor aimsíodh eochair phoiblí bhailí i gcomhair $email';
$messages['encryptpubkeysfound'] = 'Aimsíodh na heochracha poiblí seo a leanas:';
$messages['nocontactsfound'] = 'Níor aimsíodh aon duine sa leabhar seoltaí.';
$messages['contactnotfound'] = 'Níor aimsíodh an teagmhálaí atá á lorg agat.';
$messages['sendingfailed'] = 'Theip ar sheoladh na teachtaireachta.';
$messages['senttooquickly'] = 'Fan $sec soic(indí) sula sheolann tú an teachtaireacht seo.';
$messages['errorsavingsent'] = 'Tharla botún fad is a bhí an teachteachtaireacht a sheoladh á cur i dtaisce.';
$messages['errorsaving'] = 'Tharla botún fad is a bhí sí á cur i dtaisce.';
$messages['errormoving'] = 'Níorbh fhéidir na teachtaireachtaí a bhogadh.';
$messages['errorcopying'] = 'Níorbh fhéidir na teachtaireachtaí a mhacasamhlú.';
$messages['errordeleting'] = 'Níorbh fhéidir na teachtaireachtaí a scriosadh.';
$messages['errormarking'] = 'Níorbh fhéidir rian a chur ar na teachtaireachtaí';
$messages['alerttitle'] = 'Aire';
$messages['confirmationtitle'] = 'An bhfuil tú cinnte...';
$messages['deletecontactconfirm']  = 'An bhfuil tú cinnte gur mian leat an daoine roghnaithe a scriosadh?';
$messages['deletegroupconfirm']  = 'An bhfuil tú cinnte gur mian leat an bhaicle roghnaithe a scriosadh?';
$messages['deletemessagesconfirm'] = 'An bhfuil tú cinnte gur mian leat na teachtaireachtaí roghnaithe a scriosadh?';
$messages['deletefolderconfirm']  = 'An bhfuil tú cinnte gur mian leat an fillteán seo a scriosadh?';
$messages['movefolderconfirm']  = 'An mian leat dáiríre an fillteán sin a bhogadh?';
$messages['purgefolderconfirm']  = 'Ar bhfuil tú cinnte gur mian leat gach teachtaireacht sa bhfillteán seo a scriosadh?';
$messages['contactdeleting'] = 'Ag scriosadh na teagmhálacha...';
$messages['groupdeleting'] = 'Ag scriosadh na baicle...';
$messages['folderdeleting'] = 'Ag scriosadh an fhillteáin...';
$messages['foldermoving'] = 'Ag bogadh an fhillteáin...';
$messages['foldersubscribing'] = 'Ag cur síntiús leis an bhfillteán...';
$messages['folderunsubscribing'] = 'Ag baint síntiús den bhfillteán...';
$messages['formincomplete'] = 'Níor líon tú an fhoirm go hiomlán.';
$messages['noemailwarning'] = 'Cuir isteach seoladh ríomhphoist bailí le do thoil.';
$messages['nonamewarning']  = 'Cuir isteach ainm le do thoil.';
$messages['nopagesizewarning'] = 'Cuir isteach méid leathanaigh le do thoil.';
$messages['nosenderwarning'] = 'Cuir isteach seoladh ríomhphoist an tseoltóra.';
$messages['recipientsadded'] = 'Cuireadh faighteoir(í) go rathúil leis.';
$messages['norecipientwarning'] = 'Abair liom faighteoir amhain ar a laghad';
$messages['disclosedreciptitle'] = 'An iomarca faighteoirí poiblí';
$messages['nosubjectwarning']  = 'Níl aon ábhair ar an teachtaireacht, ba mhaith tú déarfaidh mé ábair?';
$messages['nosubjecttitle']  = 'Gan ábhar';
$messages['nobodywarning'] = 'Níl aon teacs san teachtaireacht, ba mhaith tú déarfaidh mé teachtaireacht ar bith?';
$messages['notsentwarning'] = 'Níor seoladh an teachtaireacht seo agus tá athruithe nach cuireadh i dtaisce inti. An mian leat do chuid athruithe a chuileáil?';
$messages['restoresavedcomposedata'] = 'Aimsíodh teachtaireacht a chumadh ach nár seoladh.\n\nÁbhar: $subject\nTaiscthe: $date\n\nAr mhaith leat an teachtaireacht seo a chur ar ais?';
$messages['nosearchname'] = 'Abair liom ainm duine nó seoladh ríomhphost';
$messages['notuploadedwarning'] = 'Níl gach ceangaltán uasluchtaithe fós. Fan le do thoil nó cealaigh an t-uasluchtú.';
$messages['searchsuccessful'] = 'Fuair mé $n teachtaireacht';
$messages['contactsearchsuccessful'] = 'Aimsíodh $nr dteagmhálaí.';
$messages['searchnomatch'] = 'Níor aimsigh an cuardach aon rud.';
$messages['searching'] = 'Ag cuardach...';
$messages['checking'] = 'Ag dearbháil...';
$messages['stillsearching'] = 'Fós ag cuardach...';
$messages['nospellerrors'] = 'Níor aimsíodh aon bhotún litrithe.';
$messages['folderdeleted'] = 'Scriosadh an fillteán.';
$messages['deletedsuccessfully'] = 'D\'éirigh mé, Scrios mé';
$messages['converting'] = 'Scrios mé formáidithe as an teachtaireacht seo';
$messages['messageopenerror'] = 'Níorbh fhéidir an teachtaireacht a luchtú ón bhfreastalaí.';
$messages['filelinkerror'] = 'Níor éirigh leis an gcomhad a cheangail.';
$messages['fileuploaderror'] = 'Theip ar uasluchtú an chomhaid.';
$messages['filesizeerror'] = 'Beigh an comhad ró-mhor. Is ea $size uas-saghas chun admháil léite';
$messages['filecounterror'] = 'Is féidir suas go dtí $count gcomhad a uasluchtú in aon dreas amháin.';
$messages['msgsizeerror'] = 'Theip air comhad a cheangail. Sáraíodh uasmhéid teachtaireachta ($size).';
$messages['copyerror'] = 'Níorbh fhéidir aon teagmháil a mhacasamhlú.';
$messages['moveerror'] = 'Níorbh fhéidir aon teagmháil a bhogadh...';
$messages['sourceisreadonly'] = 'Tá an foinse seolaigh seo inléite amháin';
$messages['errorsavingcontact'] = 'Theip mé, Níl an cumas agam an seolagh seo a sábháil';
$messages['movingmessage'] = 'Ag bogadh na teachtaireachtaí...';
$messages['copyingmessage'] = 'Ag macasamhlú na teachtaireachtaí...';
$messages['copyingcontact'] = 'Ag macasamhlú teagmhálach(a)...';
$messages['movingcontact'] = 'Ag bogadh teachtaireacht(aí)';
$messages['deletingmessage'] = 'Ag scriosadh teachtaireacht(aí)...';
$messages['markingmessage'] = 'Ag cur rian ar theachtaireacht(aí)...';
$messages['addingmember'] = 'Ag cur teagmhálacha leis an mbaicle...';
$messages['removingmember'] = 'Ag baint teagmhálaí (teagmhálaithe) ón mbaicle...';
$messages['receiptsent'] = 'Seoladh admháil léite go rathúil.';
$messages['errorsendingreceipt'] = 'Níorbh fhéidir an admháil a sheoladh.';
$messages['deleteidentityconfirm'] = 'An bhfuil tú cinnte gur mian leat an t-aitheantas seo a scriosadh?';
$messages['nodeletelastidentity'] = 'Ní féidir leat an t-aitheantas seo a scriosadh. Is é an ceann deireanach atá agat.';
$messages['forbiddencharacter'] = 'Tá carachtar neamhcheadaithe in ainm an fhillteáin.';
$messages['selectimportfile'] = 'Roghnaigh comhad le huasluchtú.';
$messages['addresswriterror'] = 'Ní féidir scríobh sa leabhar seoltaí roghnaithe.';
$messages['contactaddedtogroup'] = 'Cuireadh na teagmhálacha go rathúil leis an mbaicle seo.';
$messages['contactremovedfromgroup'] = 'Baineadh teagmhálaithe go rathúil on mbaicle.';
$messages['importwait'] = 'Á tabhairt isteach, fan le do thoil...';
$messages['importmessagesuccess'] = 'Tugadh $nr teachtaireacht isteach go rathúil';
$messages['importmessageerror'] = 'Theip ar an tabhairt isteach! Ní comhad teachtaireachta nó comhad bosca poist bailí é an comhad uasluchtaithe ';
$messages['opnotpermitted'] = 'Níl cead sin a dhéanamh!';
$messages['nofromaddress'] = 'Tá seoladh ríomhphoist ar iarraidh san aitheantas roghnaithe. ';
$messages['smtpconnerror'] = 'Botún SMTP ($code): Theip ar an nasc leis an bhfreastalaí.';
$messages['smtpautherror'] = 'Botún SMTP ($code): Theip ar an bhfíordheimhniú.';
$messages['smtperror'] = 'Botún SMTP: $msg';
$messages['emailformaterror'] = 'Seoladh ríomhphoist neamhbhailí: $email';
$messages['toomanyrecipients'] = 'Tá an iomarca faighteoirí ann. Laghdaigh líon na bhfaighteoir chuig $max.';
$messages['internalerror'] = 'Tharla botún inmheánach. Déan iarracht eile arís le do thoil.';
$messages['contactdelerror'] = 'Níorbh fhéidir na teagmhálaithe a scriosadh.';
$messages['contactdeleted'] = 'Scriosadh na teagmhálaithe go rathúil.';
$messages['contactrestoreerror'] = 'Níorbh fhéidir na teagmhálacha a scriosadh a chur ar ais.';
$messages['contactrestored'] = 'Cuireadh teagmhálaí(ithe) ar ais go rathúil.';
$messages['groupdeleted'] = 'Scriosadh an bhaicle.';
$messages['grouprenamed'] = 'Athainmníodh an bhaicle.';
$messages['groupcreated'] = 'Cruthaíodh an bhaicle.';
$messages['savedsearchdeleteerror'] = 'Níorbh fhéidir an cuardach atá i dtaisce a scriosadh.';
$messages['savedsearchcreateerror'] = 'Níorbh fhéidir cuardach i dtaisce a chruthú.';
$messages['messagedeleted'] = 'Scriosadh na teachtaireachtaí.';
$messages['messagemoved'] = 'Bogadh na teachtaireachtaí go rathúil.';
$messages['messagemovedtotrash'] = 'Bogadh na teachtaireachtaí go dtí Bruscar.';
$messages['messagecopied'] = 'Macasamhlaíodh na teachtaireachtaí.';
$messages['messagemarked'] = 'Cuireadh rian ar na teachtaireachtaí.';
$messages['namecannotbeempty'] = 'Ní féidir leis a bheith gan ainm.';
$messages['nametoolong'] = 'Tá an t-ainm rófhada.';
$messages['namedotforbidden'] = 'Ní féidir lanstád a bheith ag tús ainm an fhillteáin.';
$messages['folderupdated'] = 'Nuashonraíodh an fillteán.';
$messages['foldercreated'] = 'Cruthaíodh an fillteán.';
$messages['invalidimageformat'] = 'Ní formáid íomhá bailí í sin.';
$messages['mispellingsfound'] = 'Aimsíodh botúin litrithe san teachtaireacht.';
$messages['messagetoobig'] = 'Tá an teachtaireacht rómhór le gur féidir obair léi.';
$messages['noscriptwarning'] = 'Rabhadh: Tá Javascript de dhíth ar an gcóras ríomhphoist ghréasáin. Chun feidhm a bhaint as cumasaigh Javascript sna socruithe i líonléitheoir.';
$messages['messageissent'] = 'Seoladh an teachtaireacht seo cheana, ach níor cuireadh i dtaisce fós í. An mian leat í a chur i dtaisce?';
$messages['errnotfound'] = 'Níor Aimsíodh an Comhad';
$messages['errnotfoundexplain'] = 'Níor aimsíodh an acmhainn a lorgadh!';
$messages['errfailedrequest'] = 'Iarratas ar theip air';
$messages['errauthorizationfailed'] = 'Theip ar an bhfíordheimhniú';
$messages['errunauthorizedexplain'] = 'Níorbh fhéidir a fhíordheimhniú go bhfuil cead agat rochtain a fháil ar an seirbhís seo!';
$messages['errcontactserveradmin'] = 'Déan teagmháil le riarthóir d\'fhreastalaí.';
$messages['clicktoresumesession'] = 'Brúigh anseo chun leanúint ar aghaidh le do dhreas roimhe';
$messages['errcomposesession'] = 'Botún i gcum teachtaireacht';
$messages['clicktocompose'] = 'Brúigh anseo chun teachtaireacht nua a chumadh';
$messages['nosupporterror'] = 'Ní thacaíonn do líonléitheoir leis an ngné sin.';
$messages['siginserted'] = 'Cuireadh an síniú isteach go rathúil.';
$messages['responseinserted'] = 'Cuireadh an freagra isteach go rathúil.';
$messages['listempty'] = 'Tá an liosta folamh.';
$messages['listusebutton'] = 'Bain feidhm as an gcnaipe Cruthaigh chun taifead nua a chur leis.';
