<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['keyname'] = 'ชื่อ';
$labels['keyid'] = 'คีย์ไอดี';
$labels['typeencrypt'] = 'เข้ารหัส';
$labels['subkeycreated'] = 'สร้าง';
$labels['expiresnever'] = 'ไม่ใช้';
$labels['unknown'] = 'ไม่ทราบ';
$labels['keychpass'] = 'เปลี่ยนรหัสผ่าน';
$labels['newkeypass'] = 'รหัสผ่าน';
