<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['changepasswd']  = 'Змяніць пароль';
$labels['curpasswd']  = 'Бягучы пароль:';
$labels['newpasswd']  = 'Новы пароль:';
$labels['confpasswd']  = 'Паўтарыце новы пароль:';
$messages['nopassword'] = 'Увядзіце новы пароль.';
$messages['nocurpassword'] = 'Увядзіце бягучы пароль.';
$messages['passwordincorrect'] = 'Няслушны бягучы пароль.';
$messages['passwordinconsistency'] = 'Паролі не супадаюць. Паспрабуйце яшчэ раз.';
$messages['crypterror'] = 'Не ўдалося захаваць новы пароль. Бракуе функцыі шыфравання.';
$messages['connecterror'] = 'Не ўдалося захаваць новы пароль. Памылка злучэння.';
$messages['internalerror'] = 'Не ўдалося захаваць новы пароль.';
$messages['passwordshort'] = 'Пароль мусіць быць мінімум $length знакаў.';
$messages['passwordweak'] = 'Пароль мусіць утрымліваць мінімум адну лічбу і адзін знак пунктуацыі.';
$messages['passwordforbidden'] = 'Пароль утрымлівае забароненыя знакі.';
$messages['firstloginchange'] = 'Гэта ваш першы ўваход. Трэба змяніць пароль.';
