<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Erşîv';
$labels['buttontitle'] = 'Vê peyamê erşîvê bike';
$labels['archived'] = 'Bi serkeftin hat erşîvkirin';
$labels['archivedreload'] = 'Bi serkeftin hat erşîvkirin. Rûpelê ji nû ve bar bike bo peldankên erşîvê yên nû bibînî.';
$labels['archiveerror'] = 'Hinek peyam nayên erşîvkirin';
$labels['archivefolder'] = 'Erşîv';
$labels['settingstitle'] = 'Erşîv';
$labels['archivetype'] = 'Erşîvê dabeşîne bi riya';
$labels['archivetypeyear'] = 'Sal (b.m. Erşîv/2012)';
$labels['archivetypemonth'] = 'Meh (b.m. Erşîv/2012/06)';
$labels['archivetypetbmonth'] = 'Meh - Thunderbird compatible (b.m. erşîv/2012/2012-06)';
$labels['archivetypefolder'] = 'Peldankê resen';
$labels['archivetypefolderyear'] = 'Sal û peldanka resen (b.m. erşîv/2012/...)';
$labels['archivetypefoldermonth'] = 'Sal, meh û peldanka resen (b.m. erşîv/2012/06/...)';
$labels['archivetypesender'] = 'E-peyama şander';
$labels['unkownsender'] = 'nenas';
$labels['readonarchive'] = 'Peyamê wekî xwendî li ser erşîvê nîşan bike';
