<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Bonvenon al $product';
$labels['username'] = 'Uzantnomo';
$labels['password'] = 'Pasvorto';
$labels['server'] = 'Servilo';
$labels['login'] = 'Ensaluti';
$labels['logout'] = 'Elsaluti';
$labels['mail'] = 'Retpoŝto';
$labels['settings'] = 'Agordoj';
$labels['addressbook'] = 'Adresaro';
$labels['inbox'] = 'Ricevitujo';
$labels['drafts'] = 'Malnetujo';
$labels['sent'] = 'Senditujo';
$labels['trash'] = 'Rubujo';
$labels['junk'] = 'Spamujo';
$labels['subject'] = 'Temo';
$labels['from'] = 'Sendanto';
$labels['sender'] = 'Sendinto';
$labels['to'] = 'Ricevanto';
$labels['cc'] = 'Kopio';
$labels['bcc'] = 'Blindkopio';
$labels['replyto'] = 'Respondu-Al';
$labels['followupto'] = 'Respondo-Al';
$labels['date'] = 'Dato';
$labels['size'] = 'Grando';
$labels['priority'] = 'Prioritato';
$labels['organization'] = 'Organizo';
$labels['readstatus'] = 'Legis statuson';
$labels['listoptions'] = 'List-agordoj...';
$labels['mailboxlist'] = 'Dosierujoj';
$labels['messagesfromto'] = 'Mesaĝoj ekde $from ĝis $to de $count';
$labels['threadsfromto'] = 'Fadenoj $from al $to de $count';
$labels['messagenrof'] = 'Mesaĝo $nr-a de $count';
$labels['fromtoshort'] = '$from - $to de $count';
$labels['copy'] = 'Kopii';
$labels['move'] = 'Movi';
$labels['moveto'] = 'transloku al...';
$labels['download'] = 'elŝutu';
$labels['showattachment'] = 'Montri';
$labels['showanyway'] = 'Tamen montri ĝin';
$labels['filename'] = 'Dosiernomo';
$labels['filesize'] = 'Dosiergrando';
$labels['addtoaddressbook'] = 'Aldonu al adresaro';
$labels['sun'] = 'Dim';
$labels['mon'] = 'Lun';
$labels['tue'] = 'Mar';
$labels['wed'] = 'Mer';
$labels['thu'] = 'Ĵaŭ';
$labels['fri'] = 'Ven';
$labels['sat'] = 'Sab';
$labels['sunday'] = 'Dimanĉo';
$labels['monday'] = 'Lundo';
$labels['tuesday'] = 'Mardo';
$labels['wednesday'] = 'Merkredo';
$labels['thursday'] = 'Ĵaŭdo';
$labels['friday'] = 'Vendredo';
$labels['saturday'] = 'Sabato';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Majo';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Aŭg';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dec';
$labels['longjan'] = 'Januaro';
$labels['longfeb'] = 'Februaro';
$labels['longmar'] = 'Marto';
$labels['longapr'] = 'Aprilo';
$labels['longmay'] = 'Majo';
$labels['longjun'] = 'Junio';
$labels['longjul'] = 'Julio';
$labels['longaug'] = 'Aŭgusto';
$labels['longsep'] = 'Septembro';
$labels['longoct'] = 'Oktobro';
$labels['longnov'] = 'Novembro';
$labels['longdec'] = 'Decembro';
$labels['today'] = 'Hodiaŭ';
$labels['refresh'] = 'Aktualigi';
$labels['checkmail'] = 'Kontroli por novaj mesaĝoj';
$labels['compose'] = 'Verki';
$labels['writenewmessage'] = 'Verki novan mesaĝon';
$labels['reply'] = 'Respondi';
$labels['replytomessage'] = 'Respondi al sendanto';
$labels['replytoallmessage'] = 'Respondi al listo aŭ al sendanto kaj al ĉiuj ricevintoj';
$labels['replyall'] = 'Respondi al ĉiuj';
$labels['replylist'] = 'Respondi al listo';
$labels['forward'] = 'Plusendi';
$labels['forwardinline'] = 'Plusendu enmesaĝe';
$labels['forwardattachment'] = 'Plusendu alfikse';
$labels['forwardmessage'] = 'Plusendu mesaĝon';
$labels['deletemessage'] = 'Forigu mesaĝon';
$labels['movemessagetotrash'] = 'Transloku mesaĝon al rubujo';
$labels['printmessage'] = 'Printu ĉi tiun mesaĝon';
$labels['previousmessage'] = 'Montru antaŭan mesaĝon';
$labels['firstmessage'] = 'Montru unuan mesaĝon';
$labels['nextmessage'] = 'Montru sekvan mesaĝon';
$labels['lastmessage'] = 'Montru lastan mesaĝon';
$labels['backtolist'] = 'Reen al mesaĝo-listo';
$labels['viewsource'] = 'Montri fonton';
$labels['mark'] = 'Marki';
$labels['markmessages'] = 'Marki mesaĝojn';
$labels['markread'] = 'Kiel legita';
$labels['markunread'] = 'Kiel nelegita';
$labels['markflagged'] = 'kiel markita';
$labels['markunflagged'] = 'kiel nemarkita';
$labels['moreactions'] = 'Pliaj agoj';
$labels['more'] = 'Pli';
$labels['back'] = 'Malantaŭen';
$labels['options'] = 'Agordoj';
$labels['select'] = 'Elektu';
$labels['all'] = 'Ĉion';
$labels['none'] = 'Nenion';
$labels['currpage'] = 'Nuna paĝo';
$labels['isread'] = 'Legi';
$labels['unread'] = 'Nelegitan';
$labels['flagged'] = 'Markita';
$labels['unanswered'] = 'Nerespondita';
$labels['deleted'] = 'Forigita';
$labels['undeleted'] = 'Ne forigita';
$labels['invert'] = 'Inversigu';
$labels['filter'] = 'Filtru';
$labels['list'] = 'Listo';
$labels['threads'] = 'Fadenoj';
$labels['expand-all'] = 'Malfaldi ĉion';
$labels['expand-unread'] = 'Malfaldi Nelegitajn';
$labels['collapse-all'] = 'Faldi ĉion';
$labels['threaded'] = 'Fadenita';
$labels['autoexpand_threads'] = 'Malfaldi mesaĝ-fadenojn';
$labels['do_expand'] = 'Ĉiuj fadenoj';
$labels['expand_only_unread'] = 'Nur kun nelegitaj mesaĝoj';
$labels['fromto'] = 'De/Al';
$labels['flag'] = 'Marko';
$labels['attachment'] = 'Aldonaĵo';
$labels['nonesort'] = 'Nenion';
$labels['sentdate'] = 'Send-dato';
$labels['arrival'] = 'Ricev-dato';
$labels['asc'] = 'kreskante';
$labels['desc'] = 'malkreskante';
$labels['listcolumns'] = 'List-rubrikoj';
$labels['listsorting'] = 'Ordig-rubriko';
$labels['listorder'] = 'Ordig-ordo';
$labels['listmode'] = 'Lista vido';
$labels['layoutlist'] = 'Listo';
$labels['folderactions'] = 'Dosierujo-agoj';
$labels['compact'] = 'Kompakta';
$labels['empty'] = 'Malplena';
$labels['quota'] = 'Diskuzo';
$labels['unknown'] = 'nekonata';
$labels['unlimited'] = 'senlima';
$labels['quicksearch'] = 'Rapida serĉo';
$labels['resetsearch'] = 'Vakigu serĉon';
$labels['searchmod'] = 'Serĉ-opcioj';
$labels['msgtext'] = 'Tuta mesaĝo';
$labels['openinextwin'] = 'Malfermu en nova fenestro';
$labels['emlsave'] = 'Elŝutu (.eml)';
$labels['editasnew'] = 'Redaktu kiel nova';
$labels['send'] = 'Sendi';
$labels['sendmessage'] = 'Sendu mesaĝon';
$labels['savemessage'] = 'Savu ĉi tiun malneton';
$labels['addattachment'] = 'Alfiksu dosieron';
$labels['charset'] = 'Karaktraro';
$labels['editortype'] = 'Speco de redaktilo';
$labels['returnreceipt'] = 'Return receipt';
$labels['dsn'] = 'Ricev-status-konfirmo';
$labels['mailreplyintro'] = 'Je $date, $sender skribis:';
$labels['originalmessage'] = 'Originala mesaĝo';
$labels['insert'] = 'Enmeti';
$labels['recipient'] = 'Ricevanto';
$labels['editidents'] = 'Redaktu identojn';
$labels['spellcheck'] = 'Literumu';
$labels['checkspelling'] = 'Kontrolu literumadon';
$labels['resumeediting'] = 'Rekomencu redaktadon';
$labels['revertto'] = 'Reiru al';
$labels['attach'] = 'Alfiksu';
$labels['attachments'] = 'Alfiksaĵoj';
$labels['upload'] = 'Alŝutu';
$labels['close'] = 'Fermi';
$labels['messageoptions'] = 'Mesaĝ-agordoj...';
$labels['low'] = 'Malalta';
$labels['lowest'] = 'Plej malalta';
$labels['normal'] = 'Normala';
$labels['high'] = 'Alta';
$labels['highest'] = 'Plej alta';
$labels['nosubject'] = '(sen temo)';
$labels['showimages'] = 'Montru bildojn';
$labels['alwaysshow'] = 'Ĉiam montru bildojn de $sender';
$labels['isdraft'] = 'Ĉi-mesaĝo estas malneto';
$labels['andnmore'] = '$nr pli';
$labels['togglemoreheaders'] = 'Montri pli multajn mesaĝtitolojn';
$labels['togglefullheaders'] = 'Maligi ĉu mesaĝaj titoloj nudu';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Plata teksto';
$labels['savesentmessagein'] = 'Konservu senditan mesaĝon en';
$labels['dontsave'] = 'Ne konservu';
$labels['maxuploadsize'] = 'Maksimuma permesata dosier-grando estas $size';
$labels['addcc'] = 'Aldonu kopi-ricevanton';
$labels['addbcc'] = 'Aldonu blindan kopi-ricevanton';
$labels['addreplyto'] = 'Aldonu Respondu-Al';
$labels['addfollowupto'] = 'Aldonu Respondu-Al';
$labels['mdnrequest'] = 'La sendinto de ĉi tiu mesaĝo petis sciigon de kiam vi legas ĝin. Ĉu volas sciigi la sendinton?';
$labels['receiptread'] = 'Legokonfirmo';
$labels['yourmessage'] = 'Jen estas legokonfirmo de via mesaĝo';
$labels['receiptnote'] = 'Notu: Ĉi tiu konfirmo nur asertas ke la mesaĝo estis malfermita je la komputilo de la ricevinto. Ne estas garantio ke la ricevinto legis aŭ komprenis la enhavon.';
$labels['name'] = 'Nomo';
$labels['firstname'] = 'Antaŭnomo';
$labels['surname'] = 'Familia nomo';
$labels['middlename'] = 'Meza Nomo';
$labels['nameprefix'] = 'Prefikso';
$labels['namesuffix'] = 'Sufikso';
$labels['nickname'] = 'Kromnomo';
$labels['jobtitle'] = 'Postena titolo';
$labels['department'] = 'Departemento';
$labels['gender'] = 'Sekso';
$labels['maidenname'] = 'Fraŭla nomo';
$labels['email'] = 'Retpoŝto';
$labels['phone'] = 'Telefono';
$labels['address'] = 'Adreso';
$labels['street'] = 'Strato';
$labels['locality'] = 'Urbo';
$labels['zipcode'] = 'Poŝt-kodo';
$labels['region'] = 'Ŝtato/Provinco';
$labels['country'] = 'Lando';
$labels['birthday'] = 'Naskiĝdato';
$labels['anniversary'] = 'Datreveno';
$labels['website'] = 'Retejo';
$labels['instantmessenger'] = 'TM';
$labels['notes'] = 'Notoj';
$labels['male'] = 'viro';
$labels['female'] = 'virino';
$labels['manager'] = 'Estro';
$labels['assistant'] = 'Asistanto';
$labels['spouse'] = 'Edz(in)o';
$labels['allfields'] = 'Ĉiuj kampoj';
$labels['search'] = 'Serĉu';
$labels['advsearch'] = 'Detala sercô';
$labels['advanced'] = 'Altnivela';
$labels['other'] = 'Alia';
$labels['typehome'] = 'Hejmo';
$labels['typework'] = 'Laboro';
$labels['typeother'] = 'Alia';
$labels['typemobile'] = 'Poŝtelefono';
$labels['typemain'] = 'Ĉefa';
$labels['typehomefax'] = 'Hejma faksilo';
$labels['typeworkfax'] = 'Laboreja faksilo';
$labels['typecar'] = 'Aŭtomobilo';
$labels['typepager'] = 'Televokilo';
$labels['typeassistant'] = 'Asistanto';
$labels['typehomepage'] = 'Hejmpaĝo';
$labels['typeblog'] = 'Blogo';
$labels['typeprofile'] = 'Profilo';
$labels['addfield'] = 'Aldonu kampon...';
$labels['editcontact'] = 'Redaktu kontakton';
$labels['contacts'] = 'Kontaktoj';
$labels['contactproperties'] = 'Kontakt-informoj';
$labels['personalinfo'] = 'Personaj informoj';
$labels['edit'] = 'Redaktu';
$labels['cancel'] = 'Nuligi';
$labels['save'] = 'Konservi';
$labels['delete'] = 'Forigi';
$labels['rename'] = 'Alinomu';
$labels['addphoto'] = 'Aldonu';
$labels['replacephoto'] = 'Anstataŭu';
$labels['uploadphoto'] = 'Alŝutu bildon';
$labels['deletecontact'] = 'Forigu elektatajn kontaktojn';
$labels['composeto'] = 'Verku mesaĝon al';
$labels['contactsfromto'] = 'Kontaktoj ekde $from ĝis $to de $count';
$labels['print'] = 'Presi';
$labels['export'] = 'Elporti';
$labels['previouspage'] = 'Montru auntaŭan';
$labels['firstpage'] = 'Montru unuan';
$labels['nextpage'] = 'Montru sekvan';
$labels['lastpage'] = 'Montru lastan';
$labels['groups'] = 'Grupoj';
$labels['personaladrbook'] = 'Persona Adresoj';
$labels['settingsfor'] = 'Preferoj de';
$labels['about'] = 'Pri';
$labels['preferences'] = 'Preferoj';
$labels['userpreferences'] = 'Uzant-preferoj';
$labels['editpreferences'] = 'Redaktu uzant-preferojn';
$labels['identities'] = 'Identoj';
$labels['preferhtml'] = 'Montru HTML';
$labels['htmlmessage'] = 'HTML Mesaĝo';
$labels['prettydate'] = 'Agrablaj Datoj';
$labels['setdefault'] = 'Agordu kiel norma';
$labels['language'] = 'Lingvo';
$labels['timezone'] = 'Tempzono';
$labels['pagesize'] = 'Mesaĝoj po paĝo';
$labels['signature'] = 'Subskribo';
$labels['dstactive'] = 'Taglumsavado';
$labels['htmleditor'] = 'Uzado de HTML-redaktilo';
$labels['htmlsignature'] = 'HTML subskribo';
$labels['previewpane'] = 'Montru antaŭrigardejon';
$labels['skin'] = 'Interfaco-etoso';
$labels['logoutclear'] = 'Malplenigu rubujon je eliro';
$labels['logoutcompact'] = 'Kompaktigu ricevitujon je eliro';
$labels['uisettings'] = 'Uzanto-interfaco';
$labels['serversettings'] = 'Servilo-agordo';
$labels['mailboxview'] = 'Ricevitujo vido';
$labels['mdnrequests'] = 'Sendanto-sciigoj';
$labels['askuser'] = 'demandu';
$labels['autosend'] = 'sendu aŭtomate';
$labels['readwhendeleted'] = 'Marku mesaĝon kiel legita kiam forigata';
$labels['flagfordeletion'] = 'Marku mesaĝon kiel forigita anstataŭ forigi';
$labels['showinlineimages'] = 'Montru alfiksitajn bildojn sub la mesaĝo';
$labels['autosavedraft'] = 'Aŭtomate savu malneton';
$labels['never'] = 'neniam';
$labels['messagesdisplaying'] = 'Mesaĝoj vidigante';
$labels['messagescomposition'] = 'Mesaĝo-verkado';
$labels['allmessages'] = 'ĉiuj mesaĝoj';
$labels['folder'] = 'Dosierujo';
$labels['folders'] = 'Dosierujoj';
$labels['foldername'] = 'Dosierujo-nomo';
$labels['subscribed'] = 'Abonata';
$labels['messagecount'] = 'Mesaĝoj';
$labels['create'] = 'Krei';
$labels['createfolder'] = 'Kreu novan dosierujon';
$labels['managefolders'] = 'Administru dosierujon';
$labels['sortby'] = 'Ordigu per';
$labels['sortasc'] = 'Ordigu kreskante';
$labels['sortdesc'] = 'Ordigu malkreskante';
$labels['license'] = 'Permesilo';
