<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Iragazkiak';
$labels['managefilters'] = 'Kudeatu sarrerako posta-iragazkiak';
$labels['filtername'] = 'Iragazkiaren izena';
$labels['newfilter'] = 'Iragazki berria';
$labels['filteradd'] = 'Gehitu iragazkia';
$labels['filterdel'] = 'Ezabatu iragazkia';
$labels['rules'] = 'Araudia';
$labels['actions'] = 'Ekintzak';
$labels['scope'] = 'Esparrua';
$labels['moveup'] = 'Mugitu gora';
$labels['movedown'] = 'Mugitu behera';
$labels['filterallof'] = 'datozen arau guztiak parekatzen';
$labels['filteranyof'] = 'datozen arauetako batzuk parekatzen';
$labels['filterany'] = 'mezu guztiak';
$labels['filtercontains'] = 'badu';
$labels['filternotcontains'] = 'ez du';
$labels['filteris'] = 'honen berdina da';
$labels['filterisnot'] = 'ez da honen berdina';
$labels['filterexists'] = 'badago';
$labels['filternotexists'] = 'ez dago';
$labels['filtermatches'] = 'bat datorren espresioa';
$labels['filternotmatches'] = 'bat ez datorren espresioa';
$labels['filterregex'] = 'bat datozen adierazpen erregularra';
$labels['filternotregex'] = 'bat ez datorren espresio erregularra';
$labels['filterunder'] = 'azpian';
$labels['filterover'] = 'gainean';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME zatia:';
$labels['mime-message'] = 'mezua';
$labels['mime-anychild'] = 'baten bat';
$labels['mime-type'] = 'mota';
$labels['mime-subtype'] = 'azpi-mota';
$labels['mime-contenttype'] = 'eduki mota';
$labels['mime-param'] = 'parametroa';
$labels['addrule'] = 'Gehitu araua';
$labels['delrule'] = 'Ezabatu araua';
$labels['messagemoveto'] = 'Mugitu mezua hona';
$labels['messageredirect'] = 'Birbideratu mezua hona ';
$labels['messagecopyto'] = 'Kopiatu mezua hona';
$labels['messagesendcopy'] = 'Bidali mezuaren kopia hona';
$labels['messagereply'] = 'Erantzun mezuarekin';
$labels['messagedelete'] = 'Ezabatu mezua';
$labels['messagediscard'] = 'Baztertu mezuarekin';
$labels['messagekeep'] = 'Mantendu mezua Sarrera-ontzian';
$labels['messagesrules'] = 'Sarrerako postarako:';
$labels['messagesactions'] = '...exekutatu datozen ekintzak:';
$labels['add'] = 'Gehitu';
$labels['del'] = 'Ezabatu';
$labels['sender'] = 'Bidaltzailea';
$labels['recipient'] = 'Hartzailea';
$labels['vacationaddr'] = 'Nire e-posta helbideak:';
$labels['vacationdays'] = 'Zenbatero bidali mezuak (egunak)';
$labels['vacationinterval'] = 'Zenbatero bidali mezuak:';
$labels['vacationreason'] = 'Mezuaren gorputza (oporrak direla medio):';
$labels['vacationfrom'] = 'Erantzun bidaltzailearen helbidera:';
$labels['vacationsubject'] = 'Mezuaren gaia:';
$labels['days'] = 'egun';
$labels['seconds'] = 'segundo';
$labels['rulestop'] = 'Gelditu arauak ebaluatzen';
$labels['enable'] = 'Gaitu/Ezgaitu';
$labels['filterset'] = 'Iragazki-paketea';
$labels['filtersets'] = 'Iragazki-paketeak';
$labels['filtersetadd'] = 'Gehitu iragazki-paketea';
$labels['filtersetdel'] = 'Ezabatu iragazki-paketea';
$labels['filtersetact'] = 'Aktibatu uneko iragazki-paketea';
$labels['filtersetdeact'] = 'Desaktibatu uneko iragazki-paketea';
$labels['filterseteditraw'] = 'Editatu iragazki multzoa';
$labels['filtersetswitch'] = 'Gaitu/Desgaitu iragazki-paketea';
$labels['filterdef'] = 'Iragazkiaren definizioa';
$labels['filtersetname'] = 'Iragazki-paketearen izena';
$labels['newfilterset'] = 'Iragazki-pakete berria';
$labels['active'] = 'aktiboa';
$labels['none'] = 'Bat ere ez';
$labels['fromset'] = 'paketetik';
$labels['fromfile'] = 'fitxategitik';
$labels['filterdisabled'] = 'Iragazki ezgaitua';
$labels['filterenabled'] = 'Iragazkia gaituta';
$labels['countisgreaterthan'] = 'kopurua handiagoa da hau baino';
$labels['countisgreaterthanequal'] = 'kopurua hau baino handiagoa edo berdina da';
$labels['countislessthan'] = 'kopurua hau baino txikiagoa da';
$labels['countislessthanequal'] = 'kopurua hau baino txikiagoa edo berdina da';
$labels['countequals'] = 'kopurua honen berdina da';
$labels['countnotequals'] = 'kopurua ez da honen berdina';
$labels['valueisgreaterthan'] = 'balioa hau baino handiagoa da';
$labels['valueisgreaterthanequal'] = 'balioa hau baino handiagoa edo berdina da';
$labels['valueislessthan'] = 'balioa hau baino txikiagoa da';
$labels['valueislessthanequal'] = 'balioa hau baino txikiagoa edo berdina da';
$labels['valueequals'] = 'balioa honen berdina da';
$labels['valuenotequals'] = 'balioa ez da honen berdina';
$labels['setflags'] = 'Jarri banderak mezuarik';
$labels['addflags'] = 'Gehitu banderak mezuari';
$labels['removeflags'] = 'Ezabatu banderak mezutik';
$labels['flagread'] = 'Irakurri';
$labels['flagdeleted'] = 'Ezabatuta';
$labels['flaganswered'] = 'Erantzunda';
$labels['flagflagged'] = 'Bandera jarrita';
$labels['flagdraft'] = 'Ziriborroa';
$labels['addheader'] = 'Gehitu goiburua mezuari';
$labels['deleteheader'] = 'Kendu goiburua mezuari';
$labels['headername'] = 'Goiburuaren izena';
$labels['headervalue'] = 'Goiburuaren balioa';
$labels['headerpos'] = 'Goiburuaren kokapena';
$labels['headeratstart'] = 'hisieran';
$labels['headeratend'] = 'bukaeran';
$labels['headeroccurrence'] = 'Goiburuko agerraldia/kokapnena';
$labels['headerfromstart'] = 'hasieratik';
$labels['headerfromend'] = 'bukaeratik';
$labels['headerpatterns'] = 'Goiburuaren balio ereduak';
$labels['headermatchtype'] = 'konparatu mota:';
$labels['setvariable'] = 'Ezarri aldagaia';
$labels['setvarname'] = 'Aldagaiaren izena:';
$labels['setvarvalue'] = 'Aldagaiaren balioa:';
$labels['setvarmodifiers'] = 'Modifikatzaileak:';
$labels['varlower'] = 'minuskulan';
$labels['varupper'] = 'maiuskulan';
$labels['varlowerfirst'] = 'lehenengo karakterea minuskulan';
$labels['varupperfirst'] = 'lehenengo karakterea maiuskulan';
$labels['varquotewildcard'] = 'aipatu karaktere bereziak';
$labels['varlength'] = 'luzera';
$labels['varencodeurl'] = 'kodetutako ehunekoa (URLtarako)';
$labels['notify'] = 'Bidali jakinarazpena';
$labels['notifytarget'] = 'Jakinarazpenaren xedea:';
$labels['notifymessage'] = 'Jakinarazpenaren mezua (aukerakoa):';
$labels['notifyoptions'] = 'Jakinarazpenaren aukerak (aukerakoa):';
$labels['notifyfrom'] = 'Jakinarazpenaren bidaltzailea (aukerakoa):';
$labels['notifyimportance'] = 'Garrantzia:';
$labels['notifyimportancelow'] = 'baxua';
$labels['notifyimportancenormal'] = 'normala';
$labels['notifyimportancehigh'] = 'altua';
$labels['notifymethodmailto'] = 'Helbide elektronikoa';
$labels['notifymethodtel'] = 'Telefonoa';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Sortu iragazkia';
$labels['usedata'] = 'Erabili datorren data iragazkian:';
$labels['nextstep'] = 'Hurrengo urratsa';
$labels['...'] = '...';
$labels['string'] = 'Katea';
$labels['currdate'] = 'Uneko data';
$labels['datetest'] = 'Data';
$labels['dateheader'] = 'goiburua:';
$labels['year'] = 'urte';
$labels['month'] = 'hilabete';
$labels['day'] = 'egun';
$labels['date'] = 'data (yyyy-mm-dd)';
$labels['julian'] = 'data (juliarra)';
$labels['hour'] = 'ordu';
$labels['minute'] = 'minutu';
$labels['second'] = 'segundo';
$labels['time'] = 'ordua  (hh:mm:ss)';
$labels['iso8601'] = 'data  (ISO8601)';
$labels['std11'] = 'data (RFC2822)';
$labels['zone'] = 'ordu-zona';
$labels['weekday'] = 'asteguna (0-6)';
$labels['advancedopts'] = 'Aukera aurreratuak';
$labels['body'] = 'Gorputza';
$labels['address'] = 'helbidea';
$labels['envelope'] = 'gutun-azala';
$labels['modifier'] = 'modifikatzailea:';
$labels['text'] = 'testua';
$labels['undecoded'] = 'kodetu gabe (gordina)';
$labels['contenttype'] = 'eduki mota';
$labels['modtype'] = 'mota:';
$labels['allparts'] = 'denak';
$labels['domain'] = 'domeinua';
$labels['localpart'] = 'zati lokala';
$labels['user'] = 'erabiltzailea';
$labels['detail'] = 'xehetasuna';
$labels['comparator'] = 'alderatzailea:';
$labels['default'] = 'lehenetsia';
$labels['octet'] = 'zorrotza (zortzikotea)';
$labels['asciicasemap'] = 'minuskulak eta maiuskulak (ascii-casemap)';
$labels['asciinumeric'] = 'numerikoa  (ascii-numeric)';
$labels['index'] = 'indexatu:';
$labels['indexlast'] = 'atzeraka';
$labels['spamtest'] = 'Zabor-maila';
$labels['spamtestisgreaterthan'] = 'hau baino handiagoa da';
$labels['spamtestisgreaterthanequal'] = 'hau baino handiagoa edo berdina da';
$labels['spamtestislessthan'] = 'hau baino txikiagoa da';
$labels['spamtestislessthanequal'] = 'hau baino txikiagoa edo berdina da';
$labels['spamtestequals'] = 'honen berdina da';
$labels['spamtestnotequals'] = 'ez da honen berdina';
$labels['spamtestisunknown'] = 'ezezaguna da';
$labels['vacation'] = 'Bulegotik kanpo';
$labels['vacation.reply'] = 'Erantzun mezua';
$labels['vacation.advanced'] = 'Ezarpen aurreratuak';
$labels['vacation.from'] = 'Erantzun bidaltzailearen helbidera';
$labels['vacation.subject'] = 'Gaia';
$labels['vacation.body'] = 'Gorputza';
$labels['vacation.start'] = 'Hasiera-unea';
$labels['vacation.end'] = 'Bukaera-unea';
$labels['vacation.status'] = 'Egoera';
$labels['vacation.on'] = 'Piztuta';
$labels['vacation.off'] = 'Itzalita';
$labels['vacation.addresses'] = 'Nire e-posta helbideak';
$labels['vacation.interval'] = 'Erantzun tartea';
$labels['vacation.after'] = 'Jarri bulegotik kanpoko araua ondoren';
$labels['vacation.saving'] = 'Datuak gordetzen...';
$labels['vacation.action'] = 'Sarrerako mezuaren ekintza';
$labels['vacation.keep'] = 'Mantendu';
$labels['vacation.discard'] = 'Baztertu';
$labels['vacation.redirect'] = 'Birbideratu hona';
$labels['vacation.copy'] = 'Bidali kopia hona';
$labels['forward'] = 'Birbidaltzen';
$labels['forward.redirect'] = 'Birbideratu hona';
$labels['forward.copy'] = 'Bidali kopia hona';
$labels['forward.on'] = 'Piztuta';
$labels['forward.off'] = 'Itzalita';
$labels['forward.status'] = 'Egoera:';
$labels['forward.action'] = 'Sartzen diren posta-mezuei hurrengo ekintza exekutatu:';
$labels['forward.saving'] = 'Datuak gordetzen...';
$labels['filladdresses'] = 'Bete nire helbide guztiekin';
$labels['arialabelfiltersetactions'] = 'Iragazki-paketearen ekintzak';
$labels['arialabelfilteractions'] = 'Iragazki-ekintzak';
$labels['arialabelfilterform'] = 'Iragazkiaren ezaugarriak';
$labels['ariasummaryfilterslist'] = 'Iragazkien zerrenda';
$labels['ariasummaryfiltersetslist'] = 'Iragazki-paketeen zerrenda';
$labels['filterstitle'] = 'Editatu postaren sarrera-iragazkiak';
$labels['vacationtitle'] = 'Bulegotik-kanpo -erantzun automatiko- araua';
$labels['forwardtitle'] = 'Editatu posta birbidaltzeko araua';
$labels['message'] = 'Mezua';
$labels['duplicate'] = 'bikoiztuta dago';
$labels['notduplicate'] = 'ez dago bikoiztuta';
$labels['duplicate.handle'] = 'heldulekua:';
$labels['duplicate.header'] = 'goiburua:';
$labels['duplicate.uniqueid'] = 'Identifikatzailea:';
$labels['duplicate.seconds'] = 'Denbora-muga (segundo)';
$labels['duplicate.last'] = 'azken exekuzioari dagokiona';
$messages['filterunknownerror'] = 'Zerbitzari ezezaguna errorea';
$messages['filterconnerror'] = 'Ezin da konektatu zerbitzariarekin.';
$messages['filterdeleteerror'] = 'Ezin da ezabatu iragazkia. Errore bat gertatu da zerbitzarian.';
$messages['filterdeleted'] = 'Iragazkia ongi ezabatu da.';
$messages['filtersaved'] = 'Iragazkia ongi ezabatu da.';
$messages['filtersaveerror'] = 'Ezin da gorde iragazkia. Zerbitzarian errore bat gertatu da.';
$messages['filterformerror'] = 'Iragazkien formularioa erroreak ditu.';
$messages['filterdeleteconfirm'] = 'Seguru zaude hautatutako iragazkiak ezabatu nahi dituzula?';
$messages['ruledeleteconfirm'] = 'Seguru zaude hautatutako arauak ezabatu nahi dituzula?';
$messages['actiondeleteconfirm'] = 'Seguru zaude hautatutako ekintzak ezabatu nahi dituzula?';
$messages['forbiddenchars'] = 'Debekatutako karaktereak eremuan.';
$messages['cannotbeempty'] = 'Eremua ezin da hutsik egon.';
$messages['ruleexist'] = 'Lehendik badago izen hori duen iragazki bat.';
$messages['setactivateerror'] = 'Ezin izan da aktibatu hautatutako iragazki-paketea. Zerbitzarian errorea gertatu da.';
$messages['setdeactivateerror'] = 'Ezin izan da desaktibatu hautatutako iragazki-paketea. Zerbitzarian errorea gertatu da.';
$messages['setdeleteerror'] = 'Ezin izan da ezabatu hautatutako iragazki-paketea. Zerbitzarian errorea gertatu da.';
$messages['setactivated'] = 'iragazki-paketea behar bezala aktibatu da.';
$messages['setdeactivated'] = 'iragazki-paketea behar bezala desaktibatu da.';
$messages['setdeleted'] = 'iragazki-paketea behar bezala ezabatu da.';
$messages['setupdated'] = 'iragazki-paketea behar bezala egineratu da.';
$messages['setdeleteconfirm'] = 'Ziur zaude hautatutako iragazki-paketea ezabatu nahi duzula?';
$messages['setcreateerror'] = 'Ezin izan da sortu iragazki-paketea. Zerbitzarian errorea gertatu da.';
$messages['setcreated'] = 'Iragazki-paketea behar bezala sortu da.';
$messages['activateerror'] = 'Ezin da gaitu hautatutako iragazkia(k). Zerbitzarian errore bat gertatu da.';
$messages['deactivateerror'] = 'Ezin da ezgaitu hautatutako iragazkia(k). Zerbitzarian errore bat gertatu da.';
$messages['deactivated'] = 'Iragazkia(k) ongi ezgaitu da.';
$messages['activated'] = 'Iragazkia(k) ongi gaitu da.';
$messages['moved'] = 'Iragazkia ongi mugitu da.';
$messages['moveerror'] = 'Ezin da mugitu hautatutako iragazkia. Zerbitzarian errore bat gertatu da.';
$messages['nametoolong'] = 'Izen luzeegia.';
$messages['namereserved'] = 'Izen erreserbatua.';
$messages['setexist'] = 'Lehendik badago pakete hori.';
$messages['nodata'] = 'Gutxienez posizio bat hautatu behar da!';
$messages['invaliddateformat'] = 'Dataren edo dataren zati baten formatua ez da baliozkoa ';
$messages['saveerror'] = 'Ezin dira datuak gorde. Errorea gertatu da zerbitzarian.';
$messages['vacationsaved'] = 'Bulegotik kanpoko datuak behar bezala gorde dira.';
$messages['forwardsaved'] = 'Birbidaltzeko datuak behar bezala gorde dira.';
$messages['emptyvacationbody'] = 'Beharrezkoa da oporraldiko mezua jartzea!';
$messages['duplicate.conflict.err'] = 'Goiburua eta identifikatzaile bakarra ez dira onartzen.';
$messages['disabledaction'] = 'Ekintza ez da onartzen.';
$messages['lastindexempty'] = 'Indizea beharrezkoa da amaieratik zenbatzen denean';
$messages['noflagset'] = 'Gutxienez bandera bat hautatu behar da.';
$messages['saving.actionordererror'] = '\'$previous\' ekintza \'$current\' ekintzaren aurretik izan behar du.';
