<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Afficher les notifications du navigateur pour les nouveaux courriels';
$labels['desktop'] = 'Afficher les notifications de bureau pour les nouveaux courriels ';
$labels['sound'] = 'Jouer le son pour les nouveaux courriels';
$labels['test'] = 'Test';
$labels['title'] = 'Nouveau courriel';
$labels['body'] = 'Vous avez reçu un nouveau courriel.';
$labels['testbody'] = 'Ceci est une notification de test.';
$labels['desktopdisabled'] = 'Les notifications du bureau sont désactivées dans votre navigateur.';
$labels['desktopunsupported'] = 'Votre navigateur ne prend pas en charge les notifications du bureau.';
$labels['desktoptimeout'] = 'Fermer la notification du bureau';
