<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'გაზიარება';
$labels['myrights'] = 'წვდომის უფლებები';
$labels['username'] = 'მომხმარებელი:';
$labels['advanced'] = 'დამატებითი პარამეტრები';
$labels['add'] = 'დამატება';
$labels['newuser'] = 'ჩანაწერის დამატება';
$labels['editperms'] = 'წვდომების ჩასწორება';
$labels['anonymous'] = 'სტუმრები (ანონიმური)';
$labels['identifier'] = 'იდენტიფიკატორი';
$labels['acll'] = 'ძებნა';
$labels['aclr'] = 'წაკითხული შეტყობინებები';
$labels['aclw'] = 'ალმების ჩაწერა';
$labels['aclp'] = 'პოსტი';
$labels['aclc'] = 'ქვესაქაღალდეების შექმნა';
$labels['aclk'] = 'ქვესაქაღალდეების შექმნა';
$labels['acld'] = 'შეტყობინებების წაშლა';
$labels['aclt'] = 'შეტყობინებების წაშლა';
$labels['acle'] = 'ამოშლა';
$labels['aclx'] = 'საქაღალდის წაშლა';
$labels['acla'] = 'ადმინისტრირება';
$labels['acln'] = 'შეტყობინებების ანოტაცია';
$labels['aclfull'] = 'სრული კონტროლი';
$labels['aclother'] = 'სხვა';
$labels['aclread'] = 'წაკითხვა';
$labels['aclwrite'] = 'ჩაწერა';
$labels['acldelete'] = 'წაშლა';
$labels['shortacll'] = 'ძებნა';
$labels['shortaclr'] = 'წაკითხვა';
$labels['shortacls'] = 'შენარჩუნება';
$labels['shortaclw'] = 'ჩაწერა';
$labels['shortacli'] = 'ჩასმა';
$labels['shortaclp'] = 'პოსტი';
$labels['shortaclc'] = 'შექმნა';
$labels['shortaclk'] = 'შექმნა';
$labels['shortacld'] = 'წაშლა';
$labels['shortaclt'] = 'წაშლა';
$labels['shortacle'] = 'ამოშლა';
$labels['shortaclx'] = 'საქაღალდის წაშლა';
$labels['shortacla'] = 'ადმინისტრირება';
$labels['shortacln'] = 'ანოტაცია';
$labels['shortaclother'] = 'სხვა';
$labels['shortaclread'] = 'წაკითხვა';
$labels['shortaclwrite'] = 'ჩაწერა';
$labels['shortacldelete'] = 'წაშლა';
$labels['arialabelaclactions'] = 'ქმედებების სია';
