<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Er is een fout opgetreden!';
$messages['loginfailed']  = 'Aanmelden mislukt.';
$messages['cookiesdisabled'] = 'Uw browser accepteert geen cookies.';
$messages['sessionerror'] = 'Sessie is reeds beëindigd of is ongeldig.';
$messages['storageerror'] = 'Kon geen verbinding maken met de IMAP server...';
$messages['servererror'] = 'Server fout!';
$messages['servererrormsg'] = 'Server fout: $msg';
$messages['accountlocked'] = 'Te veel mislukte inlogpogingen. Probeer het later opnieuw.';
$messages['connerror'] = 'Verbindingsfout (Mislukt om de server te bereiken)!';
$messages['dberror'] = 'Database Fout!';
$messages['windowopenerror'] = 'Het popup venster werd geblokkeerd!';
$messages['requesttimedout'] = 'Aanvraag verlopen';
$messages['errorreadonly'] = 'Kon opdracht niet uitvoeren. Map is alleen-lezen.';
$messages['errornoperm'] = 'Kon opdracht niet uitvoeren. Toegang geweigerd.';
$messages['erroroverquota'] = 'Kon opdracht niet uitvoeren. Geen vrije schijfruimte.';
$messages['erroroverquotadelete'] = 'Geen vrije schijfruimte. Gebruik SHIFT+DEL om een bericht te verwijderen.';
$messages['invalidrequest'] = 'Ongeldige aanvraag! Er zijn geen gegevens opgeslagen.';
$messages['invalidhost'] = 'Ongeldige server.';
$messages['nomessagesfound'] = 'Er zijn geen berichten in deze map...';
$messages['mailboxempty'] = 'Mailbox is leeg';
$messages['nomessages'] = 'Geen berichten';
$messages['refreshing'] = 'Bezig met vernieuwen...';
$messages['loading'] = 'Bezig met ophalen gegevens...';
$messages['uploading'] = 'Bezig met uploaden...';
$messages['attaching'] = 'Bestand aan het toevoegen...';
$messages['uploadingmany'] = 'Bestanden worden geüpload...';
$messages['loadingdata'] = 'Bezig met gegevens ophalen...';
$messages['checkingmail'] = 'Controleer op nieuwe berichten...';
$messages['sendingmessage'] = 'Bericht wordt verstuurd...';
$messages['messagesent'] = 'Het bericht is verzonden.';
$messages['savingmessage'] = 'Bericht wordt bewaard...';
$messages['messagesaved'] = 'Bericht bewaard in Concepten.';
$messages['successfullysaved'] = 'Succesvol opgeslagen...';
$messages['savingresponse'] = 'Respons tekst wordt bewaard...';
$messages['deleteresponseconfirm'] = 'Bent u zeker dat u deze respons tekst wilt verwijderen?';
$messages['addedsuccessfully'] = 'Contactpersoon is toegevoegd.';
$messages['contactnameexists'] = 'Er bestaat al een contactpersoon met deze naam.';
$messages['blockedimages'] = 'Om uw privacy te beschermen worden de afbeeldingen in dit bericht niet getoond.';
$messages['encryptedmessage'] = 'Dit bericht is geëncrypteerd en kan niet worden weergegeven, sorry!';
$messages['externalmessagedecryption'] = 'Dit bericht is geëncrypteerd en kan niet worden gedecodeerd met uw browser extensie, sorry!';
$messages['nopubkeyfor'] = 'Geen geldige publieke sleutel gevonden voor $email';
$messages['encryptpubkeysfound'] = 'De volgende publieke sleutels werden gevonden:';
$messages['nocontactsfound'] = 'Geen contactpersonen gevonden.';
$messages['contactnotfound'] = 'De gevraagde contactpersoon was niet gevonden.';
$messages['sendingfailed'] = 'Kon het bericht niet versturen.';
$messages['senttooquickly'] = 'U moet $sec second(en) wachten om het bericht te versturen.';
$messages['errorsavingsent'] = 'Er is een fout opgetreden tijdens het opslaan van het verzonden bericht.';
$messages['errorsaving'] = 'Er is een fout opgetreden tijdens het opslaan.';
$messages['errormoving'] = 'Kon de bericht(en) niet verplaatsen.';
$messages['errorcopying'] = 'Kon de bericht(en) niet kopiëren';
$messages['errordeleting'] = 'Kon de bericht(en) niet verwijderen.';
$messages['errormarking'] = 'Kon de bericht(en) niet markeren.';
$messages['deletecontactconfirm']  = 'Bent u zeker dat u de geselecteerde contactpers(o)on(en) wilt verwijderen?';
$messages['deletegroupconfirm']  = 'Weet u zeker dat u de geselecteerde groep wilt verwijderen?';
$messages['deletemessagesconfirm'] = 'Bent u zeker dat u de geselecteerde bericht(en) wilt verwijderen?';
$messages['deletefolderconfirm']  = 'Weet u zeker dat u deze map wilt verwijderen?';
$messages['purgefolderconfirm']  = 'Bent u zeker dat u alle berichten in deze map wilt verwijderen?';
$messages['contactdeleting'] = 'Bezig met verwijderen één of meer contactpersonen...';
$messages['groupdeleting'] = 'Groep wordt verwijderd...';
$messages['folderdeleting'] = 'Map verwijderen...';
$messages['foldermoving'] = 'Map verplaatsen...';
$messages['foldersubscribing'] = 'Bezig met abonneren op map...';
$messages['folderunsubscribing'] = 'Abonnement op map wordt opgezegd...';
$messages['formincomplete'] = 'Het formulier is niet volledig ingevuld.';
$messages['noemailwarning'] = 'Geef een geldig e-mailadres op.';
$messages['nonamewarning']  = 'Geef een naam op.';
$messages['nopagesizewarning'] = 'Geef een geldig aantal berichten per pagina op.';
$messages['norecipientwarning'] = 'Geef minstens één bestemmeling op.';
$messages['nosubjectwarning']  = 'Geen onderwerp opgegeven. Wenst u alsnog een onderwerp te geven?';
$messages['nobodywarning'] = 'Wilt u dit lege bericht versturen?';
$messages['nosearchname'] = 'Geen een contacpersoon of e-mailadres op.';
$messages['notuploadedwarning'] = 'Nog niet alle bijlagen zijn geüpload. Wacht even of annuleer de upload.';
$messages['searchsuccessful'] = '$nr berichten gevonden.';
$messages['contactsearchsuccessful'] = '$nr contactpersonen gevonden.';
$messages['searchnomatch'] = 'Zoekopdracht leverde geen resultaten.';
$messages['searching'] = 'Bezig met zoeken...';
$messages['checking'] = 'Bezig met controleren...';
$messages['stillsearching'] = 'Nog steeds aan het zoeken...';
$messages['nospellerrors'] = 'Geen spelfouten gevonden.';
$messages['folderdeleted'] = 'Map met succes verwijderd.';
$messages['foldersubscribed'] = 'Folder succesvol geabonneerd.';
$messages['folderunsubscribed'] = 'Folder succesvol uitgeschreven.';
$messages['deletedsuccessfully'] = 'Succesvol verwijderd.';
$messages['converting'] = 'Opmaak van het bericht wordt gewist...';
$messages['messageopenerror'] = 'Kon het bericht niet ophalen van de server.';
$messages['filelinkerror'] = 'Toevoegen van het bestand mislukt.';
$messages['fileuploaderror'] = 'Bestandsupload mislukt.';
$messages['filesizeerror'] = 'Het bestand overschrijdt de maximum grootte van $size.';
$messages['copysuccess'] = '$nr contactpersonen succesvol gekopieerd.';
$messages['movesuccess'] = '$nr contactpersonen succesvol verplaatst.';
$messages['copyerror'] = 'Kon contactpersoon niet kopiëren.';
$messages['moveerror'] = 'Kon contactpersoon niet verplaatsen.';
$messages['sourceisreadonly'] = 'Het adres kan niet worden opgeslagen.';
$messages['errorsavingcontact'] = 'Kon de contactpersoon niet bewaren.';
$messages['movingmessage'] = 'Bericht wordt verplaatst...';
$messages['copyingmessage'] = 'Bericht wordt gekopieerd...';
$messages['copyingcontact'] = 'Kopiëren contactpersonen...';
$messages['movingcontact'] = 'Verplaatsen contactperso(o)n(en)...';
$messages['deletingmessage'] = 'Bericht wordt verwijderd...';
$messages['markingmessage'] = 'Bericht wordt gemarkeerd...';
$messages['addingmember'] = 'Contactpersonen worden toegevoegd aan de groep...';
$messages['removingmember'] = 'Contactpersonen worden verwijderd uit de groep...';
$messages['receiptsent'] = 'Ontvangstbevestiging verstuurd.';
$messages['errorsendingreceipt'] = 'Kon de ontvangstbevestigign niet versturen.';
$messages['deleteidentityconfirm'] = 'Bent u zeker dat u deze identiteit wilt verwijderen?';
$messages['nodeletelastidentity'] = 'U kunt dit laatste afzendadres niet verwijderen.';
$messages['forbiddencharacter'] = 'De naam van de map bevat een karakter dat niet is toegestaan.';
$messages['selectimportfile'] = 'Selecteer een bestand om te uploaden.';
$messages['addresswriterror'] = 'Het geselecteerde adresboek is alleen-lezen.';
$messages['contactaddedtogroup'] = 'Contact(en) met succes toegevoegd aan de groep.';
$messages['contactremovedfromgroup'] = 'Contact(en) met succes verwijderd aan de groep.';
$messages['nogroupassignmentschanged'] = 'Geen groepslidmaatschap gewijzigd.';
$messages['importwait'] = 'Bezig met importeren, even geduld...';
$messages['importformaterror'] = 'Importeren mislukt! Het geüploade bestand is geen importeerbaar bestand.';
$messages['importconfirm'] = '<b>Er zijn $inserted contactpersonen succesvol geïmporteerd</b>';
$messages['importmessagesuccess'] = '$nr adressen met succes geïmporteerd.';
$messages['importmessageerror'] = 'Importeren mislukt! Het geüploade bestand is geen geldig bericht of mailbox bestand.';
$messages['opnotpermitted'] = 'Deze actie is niet toegestaan!';
$messages['httpreceivedencrypterror'] = 'Er is een fatale fout opgetreden. Neem direct contact op met uw systeembeheerder. <b>Uw bericht kon niet worden verzonden.</b>';
$messages['smtpconnerror'] = 'SMTP Fout ($code): Verbinding met server mislukt.';
$messages['smtpautherror'] = 'SMTP Fout ($code): Authenticatie mislukt.';
$messages['smtpfromerror'] = 'SMTP Fout ($code): Kon afzender "$from" niet instellen ($msg).';
$messages['smtptoerror'] = 'SMTP Fout ($code): Kon ontvanger "$to" niet toevoegen ($msg).';
$messages['smtprecipientserror'] = 'SMTP Fout: Kon lijst van ontvangers niet verwerken.';
$messages['smtperror'] = 'SMTP Fout: $msg';
$messages['toomanyrecipients'] = 'Te veel geadresseerden. Verminder de hoeveelheid geadresseerden tot $max.';
$messages['maxgroupmembersreached'] = 'Het aantal leden van de groep groter is dan de maximale van $max.';
$messages['internalerror'] = 'Er is een interne fout opgetreden. Probeer het later opnieuw.';
$messages['contactdelerror'] = 'Kon contactpersoon niet verwijderen.';
$messages['contactdeleted'] = 'Contactpersoon succesvol verwijderd.';
$messages['contactrestoreerror'] = 'Verwijderde contactpersonen konden niet hersteld worden.';
$messages['contactrestored'] = 'Contactpersonen succesvol hersteld.';
$messages['groupdeleted'] = 'Groep succesvol verwijderd.';
$messages['grouprenamed'] = 'Groep succesvol hernoemd.';
$messages['groupcreated'] = 'Groep succesvol aangemaakt.';
$messages['savedsearchdeleted'] = 'Opgeslagen zoekopdracht successvol verwijderd.';
$messages['savedsearchdeleteerror'] = 'Opgeslagen zoekopdracht kon niet worden verwijderd.';
$messages['savedsearchcreated'] = 'Zoekopdracht successvol opgeslagen.';
$messages['savedsearchcreateerror'] = 'Zoekopdracht kon niet worden opgeslagen.';
$messages['messagedeleted'] = 'Bericht(en) succesvol verwijderd.';
$messages['messagemoved'] = 'Bericht(en) succesvol verplaatst.';
$messages['messagecopied'] = 'Bericht(en) succesvol gekopieerd.';
$messages['messagemarked'] = 'Bericht(en) succesvol gemarkeerd.';
$messages['autocompletechars'] = 'Geef ten minste $min karakters voor auto-aanvullen.';
$messages['autocompletemore'] = 'Meerdere resultaten gevonden. Verfijn uw zoekopdracht.';
$messages['namecannotbeempty'] = 'Naam kan niet leeg zijn.';
$messages['nametoolong'] = 'Naam is te lang.';
$messages['namedotforbidden'] = 'Mapnaam kan niet met een punt starten.';
$messages['folderupdated'] = 'Map succesvol bijgewerkt.';
$messages['foldercreated'] = 'Map succesvol aangemaakt.';
$messages['invalidimageformat'] = 'Geen geldig afbeeldingsformaat.';
$messages['mispellingsfound'] = 'Spellingsfouten gedetecteerd in bericht.';
$messages['parentnotwritable'] = 'U heeft niet voldoende rechten een map te maken / verplaatsen in deze map.';
$messages['messagetoobig'] = 'Dit deel van uw bericht is te groot om het te verwerken.';
$messages['noscriptwarning'] = 'Opgelet: deze webmail service vereist JavaScript! Om deze service te kunnen gebruiken dient u JavaScript toe te staan in de instellingen van uw browser.';
$messages['messageissent'] = 'Het bericht werd reeds verzonden, maar nog niet  bewaard. Wil je het nu bewaren?';
$messages['errnotfound'] = 'Bestand niet gevonden';
$messages['errnotfoundexplain'] = 'De gevraagde hulpbron werd niet gevonden.';
$messages['errfailedrequest'] = 'Mislukt verzoek';
$messages['errauthorizationfailed'] = 'Autorisatie mislukt';
$messages['errrequestcheckfailed'] = 'Verzoek mislukt';
$messages['clicktoresumesession'] = 'Klik hier om uw vorige sessie te hernemen.';
