<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Condivisione';
$labels['myrights'] = 'Diritti d\'accesso';
$labels['username'] = 'Utente:';
$labels['advanced'] = 'Modalità avanzata';
$labels['add'] = 'Aggiungi';
$labels['newuser'] = 'Aggiungi voce';
$labels['editperms'] = 'Modifica permessi';
$labels['actions'] = 'Azioni permessi d\'accesso...';
$labels['anyone'] = 'Tutti gli utenti';
$labels['anonymous'] = 'Osptiti (anonimi)';
$labels['identifier'] = 'Identificatore';
$labels['acll'] = 'Ricerca';
$labels['aclr'] = 'Leggi messaggi';
$labels['acls'] = 'Mantieni lo stato Visto';
$labels['aclw'] = 'Flag di scrittura';
$labels['acli'] = 'Inserisci (Copia in)';
$labels['aclp'] = 'Invio';
$labels['aclc'] = 'Crea sottocartelle';
$labels['aclk'] = 'Crea sottocartelle';
$labels['acld'] = 'Elimina messaggi';
$labels['aclt'] = 'Elimina messaggi';
$labels['acle'] = 'Elimina';
$labels['aclx'] = 'Elimina cartella';
$labels['acla'] = 'Amministra';
$labels['acln'] = 'Annota messaggi';
$labels['aclfull'] = 'Controllo completo';
$labels['aclother'] = 'Altro';
$labels['aclread'] = 'Lettura';
$labels['aclwrite'] = 'Scrittura';
$labels['acldelete'] = 'Elimina';
$labels['shortacll'] = 'Ricerca';
$labels['shortaclr'] = 'Lettura';
$labels['shortacls'] = 'Mantieni';
$labels['shortaclw'] = 'Scrivi';
$labels['shortacli'] = 'Inserisci';
$labels['shortaclp'] = 'Invio';
$labels['shortaclc'] = 'Crea';
$labels['shortaclk'] = 'Crea';
$labels['shortacld'] = 'Elimina';
$labels['shortaclt'] = 'Elimina';
$labels['shortacle'] = 'Elimina';
$labels['shortaclx'] = 'Elimina cartella';
$labels['shortacla'] = 'Amministra';
$labels['shortacln'] = 'Annota';
$labels['shortaclother'] = 'Altro';
$labels['shortaclread'] = 'Lettura';
$labels['shortaclwrite'] = 'Scrittura';
$labels['shortacldelete'] = 'Elimina';
$labels['longacll'] = 'La cartella è visibile sulle liste e può essere sottoscritta';
$labels['longaclr'] = 'Questa cartella può essere aperta in lettura';
$labels['longacls'] = 'Il flag Messaggio Visto può essere cambiato';
$labels['longaclw'] = 'I flag dei messaggi e le keywords possono essere cambiati, ad esclusione di Visto ed Eliminato';
$labels['longacli'] = 'I messaggi possono essere scritti o copiati nella cartella';
$labels['longaclp'] = 'I messaggi possono essere inviati a questa cartella';
$labels['longaclc'] = 'Possono essere create (o rinominata) cartelle direttamente in questa cartella.';
$labels['longaclk'] = 'Possono essere create (o rinominata) cartelle direttamente in questa cartella.';
$labels['longacld'] = 'Il flag Messaggio Eliminato può essere cambiato';
$labels['longaclt'] = 'Il flag Messaggio Eliminato può essere cambiato';
$labels['longacle'] = 'I messaggi possono essere cancellati';
$labels['longaclx'] = 'La cartella può essere eliminata o rinominata';
$labels['longacla'] = 'I diritti di accesso della cartella possono essere cambiati';
$labels['longacln'] = 'I metadati (annotazioni) dei messaggi condivisi possono essere modificati';
$labels['longaclfull'] = 'Controllo completo incluso cartella di amministrazione';
$labels['longaclread'] = 'Questa cartella può essere aperta in lettura';
$labels['longaclwrite'] = 'I messaggi possono essere marcati, scritti o copiati nella cartella';
$labels['longacldelete'] = 'I messaggi possono essere eliminati';
$labels['longaclother'] = 'Altri diritti di accesso';
$labels['ariasummaryacltable'] = 'Elenco dei diritti di accesso';
$labels['arialabelaclactions'] = 'Lista azioni';
$labels['arialabelaclform'] = 'Modulo di accesso';
$messages['deleting'] = 'Sto eliminando i diritti di accesso...';
$messages['saving'] = 'Sto salvando i diritti di accesso...';
$messages['updatesuccess'] = 'I diritti d\'accesso sono stati cambiati';
$messages['deletesuccess'] = 'I diritti d\'accesso sono stati eliminati';
$messages['createsuccess'] = 'I diritti d\'accesso sono stati aggiunti';
$messages['updateerror'] = 'Impossibile aggiornare i diritti d\'accesso';
$messages['deleteerror'] = 'Impossibile eliminare i diritti d\'accesso';
$messages['createerror'] = 'Impossibile aggiungere i diritti d\'accesso';
$messages['deleteconfirm'] = 'Sei sicuro di voler rimuovere i diritti d\'accesso degli utenti selezionati?';
$messages['norights'] = 'Nessun diritto specificato!';
$messages['nouser'] = 'Lo username non è stato specificato!';
