<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Prikaži obavijesti za nove poruke u pregledniku';
$labels['desktop'] = 'Prikaži obavijesti za nove poruke na desktopu';
$labels['sound'] = 'Zvučni signal za novu poruku';
$labels['test'] = 'Testiraj';
$labels['title'] = 'Novi email!';
$labels['body'] = 'Dobili ste novu poruku.';
$labels['testbody'] = 'Ovo je testna obavijest.';
$labels['desktopdisabled'] = 'Desktop obavijesti su onemogućene u vašem pregledniku.';
$labels['desktopunsupported'] = 'Vaš preglednik ne podržava desktop obavijesti.';
$labels['desktoptimeout'] = 'Zatvori desktop obavijesti';
