<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Eraro okazis!';
$messages['loginfailed']  = 'Malsukcesis ensaluti';
$messages['cookiesdisabled'] = 'Via foliumilo ne akceptas kuketojn';
$messages['sessionerror'] = 'Via seanco estas nevalida aŭ finita';
$messages['storageerror'] = 'Konekto kun IMAP-servilo malsukcesis';
$messages['servererror'] = 'Servil-eraro!';
$messages['servererrormsg'] = 'Servil-eraro: $msg';
$messages['dberror'] = 'Datumbaz-eraro!';
$messages['errorreadonly'] = 'Ne povis fari agon. Dosierujo estas nurlega';
$messages['errornoperm'] = 'Ne povis fari agon. Ne havas permeson.';
$messages['invalidrequest'] = 'Nevalida peto';
$messages['invalidhost'] = 'Nevalida servilo-nomo';
$messages['nomessagesfound'] = 'Neniu mesaĝo en ĉi tiu dosierujo';
$messages['nomessages'] = 'Neniu mesaĝo';
$messages['loading'] = 'Ŝarganta...';
$messages['uploading'] = 'Alŝutanta dosieron...';
$messages['uploadingmany'] = 'Alŝutanta dosierojn...';
$messages['loadingdata'] = 'Ŝarganta datumojn...';
$messages['checkingmail'] = 'Kontrolanta, ĉu  novaj mesaĝoj...';
$messages['sendingmessage'] = 'Sedanta mesaĝon...';
$messages['messagesent'] = 'Mesaĝo estas sendita sukcese';
$messages['savingmessage'] = 'Savanta mesaĝon...';
$messages['messagesaved'] = 'Mesaĝo savita en Malnetujo';
$messages['successfullysaved'] = 'Sukcese savis';
$messages['addedsuccessfully'] = 'Sukcese aldonis kontakton al adresaro';
$messages['blockedimages'] = 'Por protekti vian privatecon, foraj bildoj estas blokitaj en ĉi tiu mesaĝo.';
$messages['encryptedmessage'] = 'Ĉi tiu mesaĝo estas ĉifrata kaj ne estas montrebla. Pardonu!';
$messages['nocontactsfound'] = 'Trovis neniun kontakton';
$messages['contactnotfound'] = 'La petita kontakto ne trovis';
$messages['sendingfailed'] = 'Ne sukcesis sendi mesaĝon';
$messages['errormoving'] = 'Ne povis transloki mesaĝon';
$messages['errordeleting'] = 'Ne povis forigi mesaĝon';
$messages['deletecontactconfirm']  = 'Ĉu vi vere volas forigi la elektata(j)n kontakto(j)n?';
$messages['deletemessagesconfirm'] = 'Ĉu vi vere volas forigi la elektata(j)n mesaĝo(j)n?';
$messages['deletefolderconfirm']  = 'Ĉu vi vere volas forigi la elektatan dosierujon?';
$messages['purgefolderconfirm']  = 'Ĉu vi vere volas forigi ĉiun mesaĝon el ĉi tiu dosierujo?';
$messages['formincomplete'] = 'La formularo ne estis kompletigita';
$messages['noemailwarning'] = 'Bonvolu enmeti validan retpoŝt-adreson';
$messages['nonamewarning']  = 'Bonvulu enmeti nomon';
$messages['nopagesizewarning'] = 'Bonvolu enmeti paĝ-grando';
$messages['norecipientwarning'] = 'Bonvolu enmeti minumume unu ricevonto';
$messages['nosubjectwarning']  = 'La temkampo estas malplena. Ĉu vi volas skribi temon nun?';
$messages['nobodywarning'] = 'Ĉu sendi ĉi tiun mesaĝon sen teksto?';
$messages['nosearchname'] = 'Bonvolu enmeti kontakt-nomon aŭ retpoŝt-adreson.';
$messages['searchsuccessful'] = 'trovis $nr mesaĝojn';
$messages['searchnomatch'] = 'Serĉo donis nenion';
$messages['searching'] = 'Serĉanta...';
$messages['checking'] = 'Kontrolanta...';
$messages['nospellerrors'] = 'Neniujn literumada eraro trovita';
$messages['folderdeleted'] = 'Forigis dosierujon sukcese';
$messages['deletedsuccessfully'] = 'Sukcese forigis';
$messages['converting'] = 'Foriganta formatan de mesaĝo...';
$messages['messageopenerror'] = 'Ne povis ŝargi mesaĝon de servilo';
$messages['fileuploaderror'] = 'Malsukcesis alŝuti dosieron';
$messages['filesizeerror'] = 'La alŝutita dosiero superas la maksimuman grandon de $size';
$messages['sourceisreadonly'] = 'Ĉi tiu adres-fonto estas nurlegebla';
$messages['errorsavingcontact'] = 'Ne povis savi la kontakt-adreson';
$messages['movingmessage'] = 'Translokanta mesaĝon...';
$messages['receiptsent'] = 'Sukcese sendis konfirmon';
$messages['errorsendingreceipt'] = 'Ne povis sendi konfirmon';
$messages['nodeletelastidentity'] = 'Vi ne povas forigi ĉi tiun identon, ĉar ĝi estas la lasta';
$messages['forbiddencharacter'] = 'Dosierujo-nomo enhavas malpermesitan karaktron';
