<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Kunhavigado';
$labels['myrights'] = 'Atingrajtoj';
$labels['username'] = 'Uzanto:';
$labels['add'] = 'Aldoni';
$labels['newuser'] = 'Aldoni eron';
$labels['actions'] = 'Agoj de atingrajtoj...';
$labels['anyone'] = 'Ĉiuj uzantoj (iu ajn)';
$labels['anonymous'] = 'Gasto (sennome)';
$labels['identifier'] = 'Identigilo';
$labels['acll'] = 'Elserĉo';
$labels['aclr'] = 'Legi mesaĝojn';
$labels['acls'] = 'Manteni legitan staton';
$labels['acli'] = 'Enmeti (alglui)';
$labels['aclp'] = 'Afiŝi';
$labels['aclc'] = 'Krei subdosierujojn';
$labels['aclk'] = 'Krei subdosierujojn';
$labels['acld'] = 'Forigi mesaĝojn';
$labels['aclt'] = 'Forigi mesaĝojn';
$labels['aclx'] = 'Forigi dosierujon';
$labels['acla'] = 'Administri';
$labels['aclfull'] = 'Plena kontrolo';
$labels['aclother'] = 'Alia';
$labels['aclread'] = 'Legi';
$labels['aclwrite'] = 'Skribi';
$labels['acldelete'] = 'Forigi';
$labels['shortacll'] = 'Elserĉo';
$labels['shortaclr'] = 'Legi';
$labels['shortacls'] = 'Manteni';
$labels['shortaclw'] = 'Skribi';
$labels['shortacli'] = 'Enmeti';
$labels['shortaclp'] = 'Afiŝi';
$labels['shortaclc'] = 'Krei';
$labels['shortaclk'] = 'Krei';
$labels['shortacld'] = 'Forigi';
$labels['shortaclt'] = 'Forigi';
$labels['shortaclx'] = 'Forigo de dosierujo';
$labels['shortacla'] = 'Administri';
$labels['shortaclother'] = 'Alia';
$labels['shortaclread'] = 'Legi';
$labels['shortaclwrite'] = 'Skribi';
$labels['shortacldelete'] = 'Forigi';
$labels['longacll'] = 'La dosierujo videblas en listoj kaj oni povas aboni al ĝi';
$labels['longaclr'] = 'La dosierujo malfermeblas por legado';
$labels['longacli'] = 'Mesaĝoj skribeblas aŭ kopieblas en la dosierujo';
$labels['longaclp'] = 'Mesaĝoj afiŝeblas en ĉi tiu dosierujo';
$labels['longaclread'] = 'La dosierujo malfermeblas por legado';
