<roundcube:include file="includes/layout.html" />

<h1 class="voice"><roundcube:label name="managesieve.filterseteditraw" /></h1>

<div class="formcontent raweditor">
	<roundcube:object name="filterseteditraw" /></form>
</div>

<div class="formbuttons">
	<roundcube:button command="plugin.managesieve-save" class="btn btn-primary submit" label="save" />
</div>

<roundcube:include file="includes/footer.html" />
