<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Ласкаво просимо до $product';
$labels['username'] = 'Ім\'я користувача';
$labels['password'] = 'Пароль';
$labels['server'] = 'Сервер';
$labels['login'] = 'Увійти';
$labels['oauthlogin'] = 'Увійти використовуючи $provider';
$labels['menu'] = 'Меню';
$labels['logout'] = 'Вийти';
$labels['mail'] = 'Пошта';
$labels['settings'] = 'Налаштування';
$labels['addressbook'] = 'Контакти';
$labels['darkmode'] = 'Темний режим';
$labels['lightmode'] = 'Світлий режим';
$labels['inbox'] = 'Вхідні';
$labels['drafts'] = 'Чернетки';
$labels['sent'] = 'Надіслані';
$labels['trash'] = 'Кошик';
$labels['junk'] = 'Спам';
$labels['show_real_foldernames'] = 'Показувати справжні імені для спеціальних тек';
$labels['subject'] = 'Тема';
$labels['from'] = 'Від кого';
$labels['sender'] = 'Відправник';
$labels['to'] = 'Кому';
$labels['cc'] = 'Копія';
$labels['bcc'] = 'Прихована';
$labels['replyto'] = 'Зворотня адреса';
$labels['followupto'] = 'Відповісти всім';
$labels['date'] = 'Дата';
$labels['size'] = 'Розмір';
$labels['priority'] = 'Пріоритет';
$labels['organization'] = 'Організація';
$labels['readstatus'] = 'Статус прочитання';
$labels['listoptions'] = 'Налаштування списку...';
$labels['mailboxlist'] = 'Теки';
$labels['messagesfromto'] = 'Повідомлення з $from по $to із $count';
$labels['threadsfromto'] = 'Обговорення з $from по $to із $count';
$labels['messagenrof'] = 'Лист $nr із $count';
$labels['fromtoshort'] = '$from – $to з $count';
$labels['copy'] = 'Копіювати';
$labels['move'] = 'Перемістити';
$labels['moveto'] = 'Перемістити до...';
$labels['copyto'] = 'Копіювати до…';
$labels['download'] = 'Завантажити';
$labels['open'] = 'Відкрити';
$labels['showattachment'] = 'Показати';
$labels['showanyway'] = 'Все одно показати';
$labels['filename'] = 'Ім\'я файлу';
$labels['filesize'] = 'Розмір файлу';
$labels['addtoaddressbook'] = 'Додати до контактів';
$labels['sun'] = 'Нд';
$labels['mon'] = 'Пн';
$labels['tue'] = 'Вт';
$labels['wed'] = 'Ср';
$labels['thu'] = 'Чт';
$labels['fri'] = 'Пт';
$labels['sat'] = 'Сб';
$labels['sunday'] = 'Неділя';
$labels['monday'] = 'Понеділок';
$labels['tuesday'] = 'Вівторок';
$labels['wednesday'] = 'Середа';
$labels['thursday'] = 'Четвер';
$labels['friday'] = 'П\'ятниця';
$labels['saturday'] = 'Субота';
$labels['jan'] = 'січ';
$labels['feb'] = 'лют';
$labels['mar'] = 'бер';
$labels['apr'] = 'кві';
$labels['may'] = 'тра';
$labels['jun'] = 'чер';
$labels['jul'] = 'лип';
$labels['aug'] = 'сер';
$labels['sep'] = 'вер';
$labels['oct'] = 'жов';
$labels['nov'] = 'лис';
$labels['dec'] = 'гру';
$labels['longjan'] = 'Січень';
$labels['longfeb'] = 'Лютий';
$labels['longmar'] = 'Березень';
$labels['longapr'] = 'Квітень';
$labels['longmay'] = 'Травень';
$labels['longjun'] = 'Червень';
$labels['longjul'] = 'Липень';
$labels['longaug'] = 'Серпень';
$labels['longsep'] = 'Вересень';
$labels['longoct'] = 'Жовтень';
$labels['longnov'] = 'Листопад';
$labels['longdec'] = 'Грудень';
$labels['today'] = 'Сьогодні';
$labels['refresh'] = 'Оновити';
$labels['checkmail'] = 'Перевірити пошту';
$labels['compose'] = 'Написати листа';
$labels['writenewmessage'] = 'Створити нового листа';
$labels['reply'] = 'Відповісти';
$labels['replytomessage'] = 'Відповісти відправнику';
$labels['replytoallmessage'] = 'Відповісти списку або відправнику та усім отримувачам';
$labels['replyall'] = 'Відповісти усім';
$labels['replylist'] = 'Відповісти списку';
$labels['forward'] = 'Переслати';
$labels['forwardinline'] = 'Переслати у тілі листа';
$labels['forwardattachment'] = 'Переслати як прикріплення';
$labels['forwardmessage'] = 'Переслати повідомлення';
$labels['bounce'] = 'Перевідправити';
$labels['deletemessage'] = 'У кошик';
$labels['movemessagetotrash'] = 'Перемістити лист у кошик';
$labels['printmessage'] = 'Друкувати';
$labels['previousmessage'] = 'Показати попередній лист';
$labels['firstmessage'] = 'Показати перший лист';
$labels['nextmessage'] = 'Показати наступний лист';
$labels['lastmessage'] = 'Показати останній лист';
$labels['backtolist'] = 'До переліку листів';
$labels['viewsource'] = 'Вихідний текст';
$labels['mark'] = 'Помітити';
$labels['markmessages'] = 'Позначити листи';
$labels['markread'] = 'Позначити як прочитане';
$labels['markunread'] = 'Позначити як непрочитане';
$labels['markflagged'] = 'Додати прапорець';
$labels['markunflagged'] = 'Зняти прапорець';
$labels['moreactions'] = 'Інші дії...';
$labels['markallread'] = 'Позначити усі повідомлення прочитаними';
$labels['folders-cur'] = 'Лише обрані теки';
$labels['folders-sub'] = 'Обрана тека і її вкладені теки';
$labels['folders-all'] = 'Усі теки';
$labels['more'] = 'Ще';
$labels['back'] = 'Назад';
$labels['options'] = 'Параметри';
$labels['actions'] = 'Дії';
$labels['first'] = 'Перше';
$labels['last'] = 'Останнє';
$labels['previous'] = 'Попереднє';
$labels['next'] = 'Наступне';
$labels['select'] = 'Вибрати';
$labels['all'] = 'Всі';
$labels['none'] = 'Не сортувати';
$labels['currpage'] = 'Поточна сторінка';
$labels['isread'] = 'Прочитано';
$labels['unread'] = 'Непрочитано';
$labels['flagged'] = 'З прапорцем';
$labels['unflagged'] = 'Без прапорця';
$labels['unanswered'] = 'Без відповіді';
$labels['withattachment'] = 'З вкладенням';
$labels['deleted'] = 'Видалено';
$labels['undeleted'] = 'Не видалено';
$labels['replied'] = 'Із відповіддю';
$labels['forwarded'] = 'Переслано';
$labels['invert'] = 'Інвертувати виділення';
$labels['filter'] = 'Фільтр';
$labels['list'] = 'Списком';
$labels['threads'] = 'Гілки';
$labels['expand-all'] = 'Розкрити всі';
$labels['expand-unread'] = 'Розкрити непрочитані';
$labels['collapse-all'] = 'Згорнути всі';
$labels['threaded'] = 'Гілками';
$labels['showunread'] = 'Показати непрочитані листи';
$labels['autoexpand_threads'] = 'Розкривати гілки';
$labels['do_expand'] = 'усі гілки';
$labels['expand_only_unread'] = 'тільки з непрочитаними листами';
$labels['fromto'] = 'Відправник/Одержувач';
$labels['flag'] = 'Позначка';
$labels['attachment'] = 'Вкладення';
$labels['nonesort'] = 'Не сортувати';
$labels['sentdate'] = 'Дата відправлення';
$labels['arrival'] = 'Дата оримання';
$labels['asc'] = 'за зростанням';
$labels['desc'] = 'за спаданням';
$labels['listcolumns'] = 'Атрибути для відображення';
$labels['listsorting'] = 'Сортувати за атрибутом';
$labels['listorder'] = 'Порядок сортування';
$labels['listmode'] = 'Режим перегляду списку';
$labels['layoutlist'] = 'Списком';
$labels['folderactions'] = 'Операції з текою...';
$labels['compact'] = 'Стиснути';
$labels['empty'] = 'Спорожнити';
$labels['importmessages'] = 'Імпорт повідомлень';
$labels['quota'] = 'Використано';
$labels['unknown'] = 'невідомо';
$labels['unlimited'] = 'без обмеження';
$labels['quotatype'] = 'Тип квоти';
$labels['quotatotal'] = 'Ліміт';
$labels['quotaused'] = 'Використано';
$labels['quotastorage'] = 'Розмір простору';
$labels['quotamessage'] = 'Кількість повідомленьй';
$labels['quicksearch'] = 'Швидкий пошук';
$labels['searchplaceholder'] = 'Пошук...';
$labels['resetsearch'] = 'Очистити пошук';
$labels['searchmod'] = 'Де шукати';
$labels['msgtext'] = 'В усьому листі';
$labels['body'] = 'Тіло повідомлення';
$labels['type'] = 'Тип';
$labels['namex'] = 'Ім\'я';
$labels['searchscope'] = 'Масштаб';
$labels['currentfolder'] = 'Поточна тека';
$labels['subfolders'] = 'Ця і підтека';
$labels['allfolders'] = 'Усі теки';
$labels['searchinterval-1W'] = 'старіші ніж тиждень';
$labels['searchinterval-1M'] = 'старіші ніж місяць';
$labels['searchinterval-1Y'] = 'старіші ніж рік';
$labels['searchinterval1W'] = 'новіші ніж тиждень';
$labels['searchinterval1M'] = 'новіші ніж місяць';
$labels['searchinterval1Y'] = 'новіші ніж рік';
$labels['openinextwin'] = 'Відкрити в новому вікні';
$labels['emlsave'] = 'Зберегти (.eml)';
$labels['changeformattext'] = 'Відображення в текстовому форматі';
$labels['changeformathtml'] = 'Відображення у форматі HTML';
$labels['editasnew'] = 'Редагувати як новий';
$labels['send'] = 'Відправити';
$labels['sendmessage'] = 'Надіслати зараз';
$labels['savemessage'] = 'Зберегти чернетку';
$labels['addattachment'] = 'Вкласти файл';
$labels['charset'] = 'Кодування';
$labels['editortype'] = 'Редактор';
$labels['returnreceipt'] = 'Запит відповіді';
$labels['dsn'] = 'Повідомлення про доставку';
$labels['mailreplyintro'] = '$date, $sender написав:';
$labels['originalmessage'] = 'Оригінальне повідомлення';
$labels['selectimage'] = 'Обрати зображення';
$labels['addimage'] = 'Додати зображення';
$labels['selectmedia'] = 'Обрати відео';
$labels['addmedia'] = 'Додати відео';
$labels['encrypt'] = 'Шифрувати';
$labels['encryptmessage'] = 'Шифрувати повідомлення';
$labels['encryptmessagemailvelope'] = 'Шифрувати повідомлення з Mailvelope';
$labels['importpubkeys'] = 'Імпортувати публічні ключі';
$labels['encryptedsendialog'] = 'Надсилання шифрованого повідомлення';
$labels['encryptandsign'] = 'Зашифрувати і підписати';
$labels['keyid'] = 'ID ключа';
$labels['keylength'] = 'Біти';
$labels['keyexpired'] = 'Закінчився';
$labels['keyrevoked'] = 'Відкликаний';
$labels['insert'] = 'Вставити';
$labels['recipient'] = 'Отримувач';
$labels['editidents'] = 'Змінити дані';
$labels['spellcheck'] = 'Орфографія';
$labels['checkspelling'] = 'Перевірити орфографію';
$labels['resumeediting'] = 'Продовжити редагування';
$labels['revertto'] = 'Відмінити редагування';
$labels['restore'] = 'Відновити';
$labels['restoremessage'] = 'ВІдновити повідомлення?';
$labels['ignore'] = 'Ігнорувати';
$labels['responses'] = 'Відповіді';
$labels['insertresponse'] = 'Вставити відповідь';
$labels['manageresponses'] = 'Керувати відповідями';
$labels['newresponse'] = 'Створити нову відповідь';
$labels['addresponse'] = 'Додати відповідь';
$labels['editresponse'] = 'Редагувати відповідь';
$labels['editresponses'] = 'Редагувати відповіді';
$labels['responsename'] = 'Ім\'я';
$labels['responsetext'] = 'Текст відповіді';
$labels['attach'] = 'Вкласти';
$labels['attachments'] = 'Вкладені файли';
$labels['upload'] = 'Прикріпити';
$labels['uploadprogress'] = '$percent ($current із $total)';
$labels['close'] = 'Закрити';
$labels['messageoptions'] = 'Налаштування листів';
$labels['togglecomposeoptions'] = 'Перемкнути опції написання';
$labels['attachmentrename'] = 'Перейменувати вкладення';
$labels['low'] = 'Низький';
$labels['lowest'] = 'Найнижчий';
$labels['normal'] = 'Нормальний';
$labels['high'] = 'Високий';
$labels['highest'] = 'Найвищий';
$labels['nosubject'] = '(без теми)';
$labels['showimages'] = 'Показувати зображення';
$labels['allow'] = 'Дозволити';
$labels['alwaysshow'] = 'Завжди показувати зображення від $sender';
$labels['alwaysallow'] = 'Завжди дозволяти від $sender';
$labels['isdraft'] = 'Це чернетка.';
$labels['andnmore'] = 'ще $nr...';
$labels['details'] = 'Деталі';
$labels['headers'] = 'Заголовки';
$labels['allheaders'] = 'Всі заголовки...';
$labels['togglemoreheaders'] = 'Завантажити ще заголовки повідомлень';
$labels['togglefullheaders'] = 'Показати оригінальні заголовки повідомлення';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Звичайний текст';
$labels['savesentmessagein'] = 'зберегти надісланого листа в';
$labels['dontsave'] = 'не зберігати';
$labels['maxuploadsize'] = 'Максимальний розмір файлу $size';
$labels['addcc'] = 'Додати копію';
$labels['addbcc'] = 'Додати приховану копію';
$labels['addreplyto'] = 'Додати зворотню адресу';
$labels['addfollowupto'] = 'Додати інших отримувачів';
$labels['mdnrequest'] = 'Відправник цього листа запитав про прочитання. Повідомити відправника?';
$labels['receiptread'] = 'Повідомлення про прочитання';
$labels['yourmessage'] = 'Повідомлення про прочитання Вашого листа';
$labels['receiptnote'] = 'Зауваження: Це повідомлення означає лише, що листа було відкрито одержувачем, і не гарантує того, що його було прочитано.';
$labels['zoomin'] = 'Збільшити';
$labels['zoomout'] = 'Зменшити';
$labels['rotate'] = 'Повернути';
$labels['increaseimage'] = 'Збільшити розмір зображення';
$labels['decreaseimage'] = 'Зменшити розмір зображення';
$labels['rotateimage'] = 'Повернути зображення';
$labels['name'] = 'Ім\'я для відображення';
$labels['firstname'] = 'Ім`я';
$labels['surname'] = 'Прізвище';
$labels['middlename'] = 'По батькові';
$labels['nameprefix'] = 'Префікс';
$labels['namesuffix'] = 'Суфікс';
$labels['nickname'] = 'Нікнейм';
$labels['jobtitle'] = 'Посада';
$labels['department'] = 'Відділ';
$labels['gender'] = 'Стать';
$labels['maidenname'] = 'Дівоче прізвище';
$labels['email'] = 'Електронна адреса';
$labels['phone'] = 'Телефон';
$labels['address'] = 'Адреса';
$labels['street'] = 'Вулиця';
$labels['locality'] = 'Місто';
$labels['zipcode'] = 'Індекс';
$labels['region'] = 'Область';
$labels['country'] = 'Країна';
$labels['birthday'] = 'День народження';
$labels['anniversary'] = 'Ювілей';
$labels['website'] = 'Веб-сайт';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Примітки';
$labels['male'] = 'чоловіча';
$labels['female'] = 'жіноча';
$labels['manager'] = 'Менеждер';
$labels['assistant'] = 'Помічник';
$labels['spouse'] = 'Шлюбний партнер';
$labels['allfields'] = 'Усі поля';
$labels['search'] = 'Пошук';
$labels['searchresult'] = 'Результат пошуку';
$labels['advsearch'] = 'Розширений пошук';
$labels['advanced'] = 'Додатково';
$labels['other'] = 'Інше';
$labels['printcontact'] = 'Роздрукувати контакт';
$labels['qrcode'] = 'QR Код';
$labels['typehome'] = 'Дім';
$labels['typework'] = 'Робота';
$labels['typeother'] = 'Інше';
$labels['typemobile'] = 'Мобільний';
$labels['typemain'] = 'Основний';
$labels['typehomefax'] = 'Домашній факс';
$labels['typeworkfax'] = 'Робочий факс';
$labels['typecar'] = 'Автомобіль';
$labels['typepager'] = 'Пейджер';
$labels['typevideo'] = 'Відео';
$labels['typeassistant'] = 'Помічник';
$labels['typehomepage'] = 'Домашня сторінка';
$labels['typeblog'] = 'Блог';
$labels['typeprofile'] = 'Профіль';
$labels['addfield'] = 'Додати поле...';
$labels['addcontact'] = 'Додати контакт ';
$labels['editcontact'] = 'Редагувати контакт';
$labels['contacts'] = 'Контакти';
$labels['contactproperties'] = 'Властивості контакта';
$labels['contactnameandorg'] = 'Ім\'я та організація';
$labels['personalinfo'] = 'Особова інформація';
$labels['personal'] = 'Особисті';
$labels['contactphoto'] = 'Фото контакту';
$labels['edit'] = 'Редагувати';
$labels['cancel'] = 'Скасувати';
$labels['save'] = 'Зберегти';
$labels['delete'] = 'Видалити';
$labels['discard'] = 'Відкинути';
$labels['continue'] = 'Продовжити';
$labels['ok'] = 'ОК';
$labels['rename'] = 'Перейменувати';
$labels['addphoto'] = 'Додати';
$labels['replacephoto'] = 'Замінити';
$labels['uploadphoto'] = 'Завантажити фотографію';
$labels['choosefile'] = 'Обрати файл...';
$labels['choosefiles'] = 'Обрати файли...';
$labels['browse'] = 'Огляд';
$labels['newcontact'] = 'Створити новий контакт';
$labels['deletecontact'] = 'Видалити вибрані контакти';
$labels['composeto'] = 'Створити листа для вибранних контактів';
$labels['contactsfromto'] = 'Контакти  $from - $to / $count';
$labels['print'] = 'Друкувати';
$labels['export'] = 'Експортувати';
$labels['exportall'] = 'Експортувати все';
$labels['exportsel'] = 'Експортувати виділені';
$labels['exportvcards'] = 'Експортувати контакти у формат vCard';
$labels['newgroup'] = 'Створити нову групу';
$labels['addgroup'] = 'Додати групу';
$labels['grouprename'] = 'Перейменувати групу';
$labels['groupdelete'] = 'Видалити групу';
$labels['groupassign'] = 'Додати в групу...';
$labels['groupremove'] = 'Видалити з групи';
$labels['groupremoveselected'] = 'Видалити обрані контакти з групи';
$labels['uponelevel'] = 'На рівень вище';
$labels['previouspage'] = 'Попередня сторінка';
$labels['firstpage'] = 'Перша сторінка';
$labels['nextpage'] = 'Наступна сторінка';
$labels['lastpage'] = 'Остання сторінка';
$labels['group'] = 'Група';
$labels['groups'] = 'Групи';
$labels['listgroup'] = 'Список членів групи';
$labels['personaladrbook'] = 'Персональні адреси';
$labels['searchsave'] = 'Зберегти пошук';
$labels['searchdelete'] = 'Видалити пошук';
$labels['import'] = 'Імпорт';
$labels['importcontacts'] = 'Імпортувати контакти';
$labels['importfromfile'] = 'Імпортувати з файлу';
$labels['importtarget'] = 'Додати контакти до';
$labels['importreplace'] = 'Замінити всю адресну книгу';
$labels['importgroups'] = 'Імпортувати розподіл за групами';
$labels['importgroupsall'] = 'Усі (створити групи за потреби)';
$labels['importgroupsexisting'] = 'Лише для наявних груп';
$labels['done'] = 'Готово';
$labels['settingsfor'] = 'Налаштування для';
$labels['about'] = 'Про програму';
$labels['preferences'] = 'Параметри';
$labels['userpreferences'] = 'Налаштування користувача';
$labels['editpreferences'] = 'Редагувати налаштування користувача';
$labels['identities'] = 'Профілі';
$labels['manageidentities'] = 'Керувати профілями';
$labels['newidentity'] = 'Створити новий профіль';
$labels['addidentity'] = 'Додати профіль';
$labels['editidentity'] = 'Редагувати профіль';
$labels['identityencryption'] = 'Шифрування';
$labels['preferhtml'] = 'Показувати в HTML';
$labels['defaultcharset'] = 'Кодування типово';
$labels['htmlmessage'] = 'Лист у HTML';
$labels['messagepart'] = 'Частина';
$labels['digitalsig'] = 'Цифровий підпис';
$labels['dateformat'] = 'Формат дати';
$labels['timeformat'] = 'Формат часу';
$labels['prettydate'] = 'Дати у зручному форматі';
$labels['setdefault'] = 'Встановити типово';
$labels['autodetect'] = 'Визначати автоматично';
$labels['language'] = 'Мова';
$labels['timezone'] = 'Часовий пояс';
$labels['pagesize'] = 'Рядків на сторінці';
$labels['signature'] = 'Підпис';
$labels['dstactive'] = 'Літній час';
$labels['showinextwin'] = 'Відкрити повідомлення в новому вікні';
$labels['composeextwin'] = 'Створити в новому вікні';
$labels['htmleditor'] = 'Створювати листи в HTML';
$labels['htmlonreply'] = 'тільки у відповідь на HTML-повідомлення';
$labels['htmlonreplyandforward'] = 'під час пересилання або відповіді на HTML-повідомлення ';
$labels['htmlsignature'] = 'Підпис в HTML';
$labels['showemail'] = 'Показувати електронну адресу та ім\'я';
$labels['previewpane'] = 'Показати попередній перегляд';
$labels['skin'] = 'Тема';
$labels['logoutclear'] = 'Очищати кошик при виході';
$labels['logoutcompact'] = 'Стискати теку Вхідні при виході';
$labels['uisettings'] = 'Інтерфейс користувача';
$labels['serversettings'] = 'Налаштування сервера';
$labels['mailboxview'] = 'Вид інтерфейсу';
$labels['mdnrequests'] = 'При запиті повідомлення про прочитання ';
$labels['askuser'] = 'запитати мене ';
$labels['autosend'] = 'відправляти автоматично';
$labels['autosendknown'] = 'відправити повідомлення моїм контактам, в іншому випадку запитати мене';
$labels['autosendknownignore'] = 'відправити повідомлення моїм контактам, в іншому випадку ігнорувати';
$labels['ignorerequest'] = 'ігнорувати запит';
$labels['readwhendeleted'] = 'Позначати як прочитане при видаленні';
$labels['flagfordeletion'] = 'Позначати для видалення замість видалення';
$labels['skipdeleted'] = 'Не показувати видалені листи';
$labels['deletealways'] = 'Видаляти листи при невдалому переміщенні до кошика';
$labels['deletejunk'] = 'Напряму видаляти повідомлення з теки Спам';
$labels['showremoteimages'] = 'Показувати віддалені зображення ';
$labels['allowremoteresources'] = 'Дозволити зовнішні ресурси (зображення, стилі)';
$labels['fromknownsenders'] = 'від відомих відправників';
$labels['fromtrustedsenders'] = 'від довірених відправників';
$labels['frommycontacts'] = 'від моїх контактів';
$labels['always'] = 'завжди';
$labels['alwaysbutplain'] = 'завжди, окрім відповідей на простий текст';
$labels['showinlineimages'] = 'Показувати вкладені зображення внизу листа';
$labels['autosavedraft'] = 'Автозбереження чернетки';
$labels['everynminutes'] = 'кожні $n хвилин(и)';
$labels['refreshinterval'] = 'Оновити (перевірити нові повідомлення, тощо)';
$labels['never'] = 'ніколи';
$labels['immediately'] = 'одразу';
$labels['messagesdisplaying'] = 'Відображення листів';
$labels['messagescomposition'] = 'Створення листів';
$labels['mimeparamfolding'] = 'Назви вкладень';
$labels['2231folding'] = 'Повний RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'RFC 2047 (інші поштові клієнти)';
$labels['force7bit'] = 'Використовувати MIME-кодування для 8-бітних символів';
$labels['savelocalstorage'] = "Зберегти у локальному сховищі браузера (тимчасово)";
$labels['advancedoptions'] = 'Додаткові параметри';
$labels['toggleadvancedoptions'] = 'Перемкнути додаткові параметри';
$labels['focusonnewmessage'] = 'Фокусувати вікно браузера при новому листі';
$labels['checkallfolders'] = 'Перевіряти нові листи у всіх теках';
$labels['defaultfont'] = 'Типовий шрифт HTML повідомлення';
$labels['mainoptions'] = 'Основні налаштування';
$labels['browseroptions'] = 'Налаштування браузера';
$labels['section'] = 'Розділ';
$labels['maintenance'] = 'Додатково';
$labels['newmessage'] = 'Новий лист';
$labels['signatureoptions'] = 'Налаштування підпису';
$labels['whenreplying'] = 'При відповіді';
$labels['replyempty'] = 'не цитувати оригінальне повідомлення';
$labels['replytopposting'] = 'починати новий лист перед цитованим';
$labels['replybottomposting'] = 'починати новий лист після цитованого';
$labels['replyremovesignature'] = 'При відповіді видаляти первинний підпис з листа';
$labels['autoaddsignature'] = 'Автоматично додавати підпис';
$labels['newmessageonly'] = 'тільки до нових листів';
$labels['replyandforwardonly'] = 'тільки при відповідях та пересилках';
$labels['insertsignature'] = 'Додати підпис';
$labels['sigbelow'] = 'Поставити підпис під цитованим повідомленням';
$labels['sigseparator'] = 'Ставити стандартний розділювач підписів';
$labels['afternseconds'] = 'через $n секунд';
$labels['reqmdn'] = 'Завжди вимагати повідомлення про доставку';
$labels['reqdsn'] = 'Завжди вимагати повідомлення про статус доставки';
$labels['replysamefolder'] = 'Розмістити відповіді у тій же теці, де знаходиться оригінал';
$labels['defaultabook'] = 'Адресна книга типово';
$labels['autocompletesingle'] = 'Пропускати додаткові адреси в автозавершенні';
$labels['listnamedisplay'] = 'Виводити список контактів як';
$labels['privatemode'] = 'Особистий (домашній)';
$labels['businessmode'] = 'Бізнес (робочий)';
$labels['trustedsenders'] = 'Довірені відправники';
$labels['spellcheckbeforesend'] = 'Перевірити орфографію перед відправкою повідомлення';
$labels['spellcheckoptions'] = 'Налаштування перевірки орфографії';
$labels['spellcheckignoresyms'] = 'Ігнорувати слова із символами';
$labels['spellcheckignorenums'] = 'Ігнорувати слова із цифрами';
$labels['spellcheckignorecaps'] = 'Ігнорувати слова з великими буквами';
$labels['addtodict'] = 'Додати до словника';
$labels['mailtoprotohandler'] = 'Зареєструвати обробник для посилань mailto:';
$labels['standardwindows'] = 'Сприймати спливні вікна як звичайні';
$labels['forwardmode'] = 'Пересилання повідомлень';
$labels['inline'] = 'у тексті';
$labels['asattachment'] = 'як вкладення';
$labels['replyallmode'] = 'Типова дія для кнопки [Відповісти всім]';
$labels['replyalldefault'] = 'відповісти усім';
$labels['replyalllist'] = 'відповісти лише списку розсилки (якщо є)';
$labels['allmessages'] = 'всі повідомлення';
$labels['olderxdays'] = 'старіше $x днів';
$labels['folder'] = 'Тека';
$labels['folders'] = 'Теки';
$labels['foldername'] = 'Назва теки';
$labels['subscribed'] = 'Підписані';
$labels['messagecount'] = 'Листи';
$labels['create'] = 'Створити';
$labels['createfolder'] = 'Створити нову теку';
$labels['managefolders'] = 'Керування теками';
$labels['specialfolders'] = 'Особливі теки';
$labels['properties'] = 'Властивості';
$labels['folderproperties'] = 'Властивості теки';
$labels['parentfolder'] = 'Батьківська тека';
$labels['location'] = 'Розташування';
$labels['info'] = 'Інформація';
$labels['getfoldersize'] = 'Показати розмір теки';
$labels['changesubscription'] = 'Змінити підписку';
$labels['foldertype'] = 'Тип теки';
$labels['personalfolder'] = 'Приватна тека';
$labels['otherfolder'] = 'Тека іншого користувача';
$labels['sharedfolder'] = 'Публічна тека';
$labels['findfolders'] = 'Знайти теки';
$labels['namespace.personal'] = 'Особисті';
$labels['namespace.other'] = 'Інші користувачі';
$labels['namespace.shared'] = 'Поширені';
$labels['dualusemail'] = 'листи';
$labels['dualusefolder'] = 'теки';
$labels['encryptioncreatekey'] = 'Створити нову пару ключів';
$labels['encryption'] = 'Шифрування';
$labels['sortby'] = 'Відсортувати за';
$labels['sortasc'] = 'Сортувати за зростанням';
$labels['sortdesc'] = 'Сортувати за спаданням';
$labels['undo'] = 'Відмінити';
$labels['installedplugins'] = 'Встановлені плагіни';
$labels['plugin'] = 'Плагін';
$labels['version'] = 'Версія';
$labels['source'] = 'Джерело';
$labels['destination'] = 'Призначення';
$labels['license'] = 'Ліцензія';
$labels['support'] = 'Отримати підтримку';
$labels['dateformatY'] = 'РРРР';
$labels['dateformaty'] = 'РР';
$labels['dateformatm'] = 'ММ';
$labels['dateformatd'] = 'ДД';
$labels['dateformatj'] = 'Д';
$labels['dateformatn'] = 'М';
$labels['B'] = 'б';
$labels['KB'] = 'Кб';
$labels['MB'] = 'Мб';
$labels['GB'] = 'Гб';
$labels['unicode'] = 'Юнікод';
$labels['english'] = 'Англійське';
$labels['westerneuropean'] = 'Західноєвропейське';
$labels['easterneuropean'] = 'Східноєвропейське';
$labels['southeasterneuropean'] = 'Південно-Західна Європа';
$labels['baltic'] = 'Балтійське';
$labels['cyrillic'] = 'Кирилиця';
$labels['arabic'] = 'Арабське';
$labels['greek'] = 'Грецьке';
$labels['hebrew'] = 'Іврит';
$labels['turkish'] = 'Турецьке';
$labels['nordic'] = 'Скандинавське';
$labels['thai'] = 'Тайське';
$labels['celtic'] = 'Кельтське';
$labels['vietnamese'] = 'В\'єтнамське';
$labels['japanese'] = 'Японське';
$labels['korean'] = 'Корейське';
$labels['chinese'] = 'Китайське';
$labels['arialabeltopnav'] = 'Управління вікном';
$labels['arialabeltasknav'] = 'Завдання програми';
$labels['arialabeltoolbar'] = 'Панель інструментів програми';
$labels['arialabelactivetask'] = 'Активне завдання';
$labels['arialabelmessagessearchfilter'] = 'Фільтр списку пошти';
$labels['arialabelmailsearchform'] = 'Форма пошуку електронних листів';
$labels['arialabelcontactsearchform'] = 'Форма пошуку контактів';
$labels['arialabelmailquicksearchbox'] = 'Ввід пошуку пошти';
$labels['arialabelquicksearchbox'] = 'Ввід пошуку';
$labels['arialabelfoldersearchfilter'] = 'Фільтр списку тек';
$labels['arialabelfoldersearchform'] = 'Форма пошуку тек';
$labels['arialabelfolderlist'] = 'Вибір теки пошти';
$labels['arialabelmessagelist'] = 'Список повідомлень пошти';
$labels['arialabelmailpreviewframe'] = 'Попередній перегляд повідомлення';
$labels['arialabelmailboxmenu'] = 'Меню дій з теками';
$labels['arialabellistselectmenu'] = 'Меню вибору списку';
$labels['arialabelthreadselectmenu'] = 'Меню списку гілок';
$labels['arialabelmessagelistoptions'] = 'Опції відображення і сортування списку повідомлень';
$labels['arialabelmailimportdialog'] = 'Діалог імпортування повідомлень';
$labels['arialabelmessagenav'] = 'Навігація повідомленнями';
$labels['arialabelmessagebody'] = 'Тіло повідомлення';
$labels['arialabelmessageactions'] = 'Дії з повідомленням';
$labels['arialabelcontactquicksearch'] = 'Форма пошуку контактів';
$labels['arialabelcontactsearchbox'] = 'Ввід пошуку контактів';
$labels['arialabelmessageheaders'] = 'Заголовки повідомлень';
$labels['arialabelforwardingoptions'] = 'Опції пересилання';
$labels['arialabelreplyalloptions'] = 'Опції відповіді всім';
$labels['arialabelmoremessageactions'] = 'Більше дій з повідомленнями';
$labels['arialabelmarkmessagesas'] = 'Позначити обрані повідомлення як…';
$labels['arialabelcomposeoptions'] = 'Опції написання';
$labels['arialabelresponsesmenu'] = 'Меню заготовлених відповідей';
$labels['arialabelattachmentuploadform'] = 'Форма завантаження вкладень';
$labels['arialabelattachmentpreview'] = 'Попередній перегляд вкладення';
$labels['ariasummarycomposecontacts'] = 'Список контактів і груп для вибору одержувачів';
$labels['arialabelcontactexportoptions'] = 'Опції експорту контактів';
$labels['arialabelabookgroupoptions'] = 'Опції адресної книги/групи';
$labels['arialabelpreferencesform'] = 'Форма налаштувань';
$labels['arialabelidentityeditfrom'] = 'Форма редагування профілю';
$labels['arialabelresponseeditfrom'] = 'Форма редагування відповіді';
$labels['arialabelsearchterms'] = 'Умови пошуку';
$labels['helplistnavigation'] = 'Навігація клавіатурою по списку';
$labels['helplistkeyboardnavigation'] = "Стрілки вгору/вниз: Перемістити підсвічення/обирання рядка.
Пробіл: Обрати підсвічений рядок.
Shift + вгору/вниз: Обрати додатковий рядок вище/нижче.
Ctrl + пробіл: Додати підсвічений рядок до вибірки/вилучити з вибірки.";
$labels['helplistkeyboardnavmessages'] = "Стрілки вправо/вліво: розгорнути/згорнути гілку повідомлень (лише у режимі гілок).
Enter: Відкрити обране/підсвічене повідомлення.
Delete: Перемістити обрані повідомлення у Кошик.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Відкрити обраний/підсвічений контакт.";
