<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Arquivo';
$labels['buttontitle'] = 'Arquivar esta mensaxe';
$labels['archived'] = 'Arquivado correctamente';
$labels['archivedreload'] = 'Arquivado correctamente. Recarga a páxina para ver os novos cartafoles arquivados.';
$labels['archiveerror'] = 'Non se puideron arquivar algunhas mensaxes';
$labels['archivefolder'] = 'Arquivo';
$labels['settingstitle'] = 'Arquivo';
$labels['archivetype'] = 'Dividir o arquivo por';
$labels['archivetypeyear'] = 'Ano (p. ex. Arquivo/2012)';
$labels['archivetypemonth'] = 'Mes (p. ex. Arquivo/2012/06)';
$labels['archivetypetbmonth'] = 'Mes - compatible con Thunderbird (p. ex. Arquivo/2012/2012-06)';
$labels['archivetypefolder'] = 'Cartafol orixinal';
$labels['archivetypefolderyear'] = 'Ano e o cartafol orixinal (p. ex. Arquivo/2012/...)';
$labels['archivetypefoldermonth'] = 'Ano, mes e o cartafol orixinal (p. ex. Arquivo/2012/06/...)';
$labels['archivetypesender'] = 'Correo electrónico do remitente';
$labels['unkownsender'] = 'descoñecido';
$labels['readonarchive'] = 'Marcar a mensaxe como lida ao arquivar';
