<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Dijeljenje';
$labels['myrights'] = 'Prava pristupa';
$labels['username'] = 'Korisnik:';
$labels['advanced'] = 'Napredni način';
$labels['add'] = 'Dodaj';
$labels['newuser'] = 'Dodaj unos/pravilo';
$labels['editperms'] = 'Uredi dozvole';
$labels['actions'] = 'Akcije prava pristupa...';
$labels['anyone'] = 'Svi korisnici (anyone)';
$labels['anonymous'] = 'Gosti (anonymous)';
$labels['identifier'] = 'Identifikator';
$labels['acll'] = 'Pretraga';
$labels['aclr'] = 'Pročitaj poruke';
$labels['acls'] = 'Zadrži u stanju "Viđeno"';
$labels['aclw'] = 'Zapiši oznake';
$labels['acli'] = 'Umetni (kopiraj u)';
$labels['aclp'] = 'Pošalji';
$labels['aclc'] = 'Napravi podmapu';
$labels['aclk'] = 'Napravi podmapu';
$labels['acld'] = 'Obriši poruke';
$labels['aclt'] = 'Obriši poruke';
$labels['acle'] = 'Trajno obriši';
$labels['aclx'] = 'Obriši mapu';
$labels['acla'] = 'Administriraj';
$labels['acln'] = 'Zabilježi poruke';
$labels['aclfull'] = 'Potpuna kontrola';
$labels['aclother'] = 'Drugo';
$labels['aclread'] = 'Čitanje';
$labels['aclwrite'] = 'Pisanje';
$labels['acldelete'] = 'Obriši';
$labels['shortacll'] = 'Pretraži';
$labels['shortaclr'] = 'Čitaj';
$labels['shortacls'] = 'Zadrži';
$labels['shortaclw'] = 'Piši';
$labels['shortacli'] = 'Umetni';
$labels['shortaclp'] = 'Pošalji';
$labels['shortaclc'] = 'Stvori';
$labels['shortaclk'] = 'Stvori';
$labels['shortacld'] = 'Obriši';
$labels['shortaclt'] = 'Obriši';
$labels['shortacle'] = 'Trajno obriši';
$labels['shortaclx'] = 'Obriši mapu';
$labels['shortacla'] = 'Administriraj';
$labels['shortacln'] = 'Zabilježi';
$labels['shortaclother'] = 'Drugo';
$labels['shortaclread'] = 'Čitanje';
$labels['shortaclwrite'] = 'Pisanje';
$labels['shortacldelete'] = 'Brisanje';
$labels['longacll'] = 'Mapa je vidljiva u listi i može se na nju pretplatiti';
$labels['longaclr'] = 'Mapa može biti otvorena za čitanje';
$labels['longacls'] = 'Oznaku "Viđeno" je moguće mijenjati u porukama';
$labels['longaclw'] = 'Oznake i ključne riječi, osim oznaka "Viđeno" i "Obrisano", se mogu mijenjati';
$labels['longacli'] = 'Poruke mogu biti pohranjene ili kopirane u mapu';
$labels['longaclp'] = 'Poruke mogu biti postavljene u mapu';
$labels['longaclc'] = 'Mape pod ovom mapom se mogu stvarati (i preimenovati)';
$labels['longaclk'] = 'Mape pod ovom mapom se mogu stvarati (i preimenovati)';
$labels['longacld'] = 'Oznaku "Obrisano" je moguće mijenjati u porukama';
$labels['longaclt'] = 'Oznaku "Obrisano" je moguće mijenjati u porukama';
$labels['longacle'] = 'Poruke mogu biti izbrisane';
$labels['longaclx'] = 'Mapa može biti obrisana ili preimenovana';
$labels['longacla'] = 'Prava pristupa nad mapom se mogu mijenjati';
$labels['longaclfull'] = 'Potpuna kontrola uključujući administraciju mapa';
$labels['longaclread'] = 'Mapa može biti otvorena za čitanje';
$labels['longaclwrite'] = 'Poruke mogu biti označene, pohranjene ili kopirane u mapu';
$labels['longacldelete'] = 'Poruke mogu biti obrisane';
$labels['longaclother'] = 'Ostala prava pristupa';
$labels['ariasummaryacltable'] = 'Popis prava pristupa';
$labels['arialabelaclactions'] = 'Popis radnji';
$labels['arialabelaclform'] = 'Obrazac prava pristupa';
$messages['deleting'] = 'Brišem prava pristupa...';
$messages['saving'] = 'Pohranjujem prava pristupa';
$messages['updatesuccess'] = 'Prava pristupa uspješno promjenjena';
$messages['deletesuccess'] = 'Prava pristupa uspješno obrisana';
$messages['createsuccess'] = 'Prava pristupa uspješno dodana';
$messages['updateerror'] = 'Ne mogu pohraniti vCard';
$messages['deleteerror'] = 'Ne mogu obrisati prava pristupa';
$messages['createerror'] = 'Ne mogu dodati prava pristupa';
$messages['deleteconfirm'] = 'Jeste li sigurni da želite obrisati prava pristupa za odabranog korisnika(e)?';
$messages['norights'] = 'Nije navedeno pravo pristupa!';
$messages['nouser'] = 'Nije navedeno korisničko ime!';
